{
 "metadata": {
  "name": "",
  "signature": "sha256:dfc4bc93a3dfa6e710f000ae8ca8389f0091c899d5820fe703a32c54f16d8113"
 },
 "nbformat": 3,
 "nbformat_minor": 0,
 "worksheets": [
  {
   "cells": [
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "%matplotlib inline\n",
      "import numpy as np\n",
      "import matplotlib.pyplot as plt, mpld3\n",
      "import matplotlib.cm as cm\n",
      "from numpy import sqrt, exp, sinh\n",
      "plt.rcParams['figure.figsize'] = 12, 9\n",
      "mpld3.enable_notebook()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 43
    },
    {
     "cell_type": "heading",
     "level": 1,
     "metadata": {},
     "source": [
      "Numerov's Method"
     ]
    },
    {
     "cell_type": "heading",
     "level": 4,
     "metadata": {},
     "source": [
      "Single Step"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def numerov_step(k0, k1, k2, psi0, psi1, dx):\n",
      "    \"\"\"compute psi2 via a single numerov step\"\"\"\n",
      "    dx_sqr = dx**2\n",
      "    c0 = (1 + 1/12. * dx_sqr * k0)\n",
      "    c1 = 2 * (1 - 5/12. * dx_sqr * k1)\n",
      "    c2 = (1 + 1/12. * dx_sqr * k2)\n",
      "    return (c1 * psi1 - c0 * psi0) / c2"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 44
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "As a basic test, let's check the \"symmetry property\" of a single Numerov step:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "assert np.isclose(numerov_step(2, 4, 7, numerov_step(7, 4, 2, 2, 4, .25), 4, .25), 2)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 45
    },
    {
     "cell_type": "heading",
     "level": 4,
     "metadata": {},
     "source": [
      "Low-Level Numerov"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def numerov_iter(ks, psi0, psi1, dx):\n",
      "    \"\"\"compute psis = [psi0, psi1, psi2, ...] for ks = [k0, k1, ...] via iterated numerov steps\"\"\"\n",
      "    n = len(ks)\n",
      "    psis = np.zeros(n, dtype=np.complex128)\n",
      "    psis[0] = psi0\n",
      "    psis[1] = psi1\n",
      "    for i in range(2, n):\n",
      "        psis[i] = numerov_step(ks[i-2], ks[i-1], ks[i], psis[i-2], psis[i-1], dx)\n",
      "    return psis"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 46
    },
    {
     "cell_type": "heading",
     "level": 4,
     "metadata": {},
     "source": [
      "High-Level Numerov"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def numerov(k, psi0, psi1, x_min, x_max, n):\n",
      "    \"\"\"compute psis = [psi0, psi1, ...] for k = k(x) according to given discretization\"\"\"\n",
      "    xs, dx = np.linspace(x_min, x_max, num=n, retstep=True)\n",
      "    ks = np.vectorize(k)(xs)\n",
      "    return xs, numerov_iter(ks, psi0, psi1, dx)\n",
      "\n",
      "def numerov_right_to_left(k, psi_2ndlast, psi_last, x_min, x_max, n):\n",
      "    \"\"\"compute psis = [..., psi_2ndlast, psi_last] for k = k(x) according to given discretization\"\"\"\n",
      "    xs, dx = np.linspace(x_min, x_max, num=n, retstep=True)\n",
      "    ks = np.vectorize(k)(xs)\n",
      "    return xs, numerov_iter(ks[::-1], psi_last, psi_2ndlast, dx)[::-1]"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 47
    },
    {
     "cell_type": "heading",
     "level": 4,
     "metadata": {},
     "source": [
      "Scattering Coefficients"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def scatter(V, E, x_min, x_max, n, return_xs_psis=False):\n",
      "    \"\"\"compute transmission & reflection coefficient for given potential and energy (and m = hbar = 1)\"\"\"\n",
      "    # compute step size\n",
      "    dx = (x_max - x_min) / float(n)\n",
      "\n",
      "    # start with right-travling wave at energy E (w/ phase fixed to 1 at x_max)\n",
      "    q_free = sqrt(2. * E)\n",
      "    psi_2nd_last = 1\n",
      "    psi_last = exp(1j * q_free * dx)\n",
      "\n",
      "    # compute resulting solution using Numerov\n",
      "    def k(x):\n",
      "        return 2. * (E - V(x))\n",
      "    xs, psis = numerov_right_to_left(k, psi_2nd_last, psi_last, x_min - dx, x_max + dx, n + 2)\n",
      "    \n",
      "    # fit psis[] to A * exp(iqx) + B * exp(-iqx)\n",
      "    A, B = np.linalg.solve(\n",
      "        [[exp(1j*q_free*(-dx)), exp(-1j*q_free*(-dx))],\n",
      "         [1, 1]],\n",
      "        [psis[0], psis[1]])\n",
      "    \n",
      "    # extract transmission and reflection coefficients\n",
      "    T = 1 / abs(A)**2\n",
      "    R = abs(B)**2 / abs(A)**2\n",
      "    return (T, R, xs, psis) if return_xs_psis else (T, R)"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 48
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "\"Test\" with a free particle:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "assert np.allclose(scatter(V=lambda _: 0, E=1, x_min=0, x_max=1, n=1e5), [1, 0])"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 49
    },
    {
     "cell_type": "heading",
     "level": 1,
     "metadata": {},
     "source": [
      "Rectangular Potential"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def rect_potential(a):\n",
      "    def V(x):\n",
      "        return float(0 < x <= a)\n",
      "    return V\n",
      "\n",
      "xs = np.linspace(-0.5, 1.5, num=100)\n",
      "plt.figure(figsize=(4, 3))\n",
      "plt.plot(xs, [rect_potential(a=1)(x) for x in xs])\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el95201688278163211971252\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "       mpld3.draw_figure(\"fig_el95201688278163211971252\", {\"axes\": [{\"xlim\": [-0.5, 1.5], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-0.5, 1.5], \"ylim\": [0.0, 1.0], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 5, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 6, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170342664\"}], \"markers\": [], \"id\": \"el9520170502632\", \"ydomain\": [0.0, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 240.0, \"width\": 320.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data01\": [[-0.5, 0.0], [-0.4797979797979798, 0.0], [-0.4595959595959596, 0.0], [-0.4393939393939394, 0.0], [-0.41919191919191917, 0.0], [-0.398989898989899, 0.0], [-0.3787878787878788, 0.0], [-0.35858585858585856, 0.0], [-0.33838383838383834, 0.0], [-0.3181818181818182, 0.0], [-0.29797979797979796, 0.0], [-0.2777777777777778, 0.0], [-0.25757575757575757, 0.0], [-0.23737373737373735, 0.0], [-0.21717171717171713, 0.0], [-0.19696969696969696, 0.0], [-0.17676767676767674, 0.0], [-0.15656565656565652, 0.0], [-0.13636363636363635, 0.0], [-0.11616161616161613, 0.0], [-0.09595959595959591, 0.0], [-0.07575757575757575, 0.0], [-0.055555555555555525, 0.0], [-0.035353535353535304, 0.0], [-0.015151515151515138, 0.0], [0.005050505050505083, 1.0], [0.025252525252525304, 1.0], [0.045454545454545525, 1.0], [0.06565656565656575, 1.0], [0.08585858585858586, 1.0], [0.10606060606060608, 1.0], [0.1262626262626263, 1.0], [0.14646464646464652, 1.0], [0.16666666666666674, 1.0], [0.18686868686868696, 1.0], [0.20707070707070718, 1.0], [0.2272727272727273, 1.0], [0.24747474747474751, 1.0], [0.26767676767676774, 1.0], [0.28787878787878796, 1.0], [0.3080808080808082, 1.0], [0.3282828282828284, 1.0], [0.3484848484848485, 1.0], [0.36868686868686873, 1.0], [0.38888888888888895, 1.0], [0.40909090909090917, 1.0], [0.4292929292929294, 1.0], [0.4494949494949496, 1.0], [0.4696969696969697, 1.0], [0.48989898989898994, 1.0], [0.5101010101010102, 1.0], [0.5303030303030305, 1.0], [0.5505050505050506, 1.0], [0.5707070707070707, 1.0], [0.590909090909091, 1.0], [0.6111111111111112, 1.0], [0.6313131313131315, 1.0], [0.6515151515151516, 1.0], [0.6717171717171717, 1.0], [0.691919191919192, 1.0], [0.7121212121212122, 1.0], [0.7323232323232325, 1.0], [0.7525252525252526, 1.0], [0.7727272727272729, 1.0], [0.792929292929293, 1.0], [0.8131313131313131, 1.0], [0.8333333333333335, 1.0], [0.8535353535353536, 1.0], [0.8737373737373739, 1.0], [0.893939393939394, 1.0], [0.9141414141414144, 1.0], [0.9343434343434345, 1.0], [0.9545454545454546, 1.0], [0.9747474747474749, 1.0], [0.994949494949495, 1.0], [1.0151515151515154, 0.0], [1.0353535353535355, 0.0], [1.0555555555555556, 0.0], [1.075757575757576, 0.0], [1.095959595959596, 0.0], [1.1161616161616164, 0.0], [1.1363636363636365, 0.0], [1.1565656565656568, 0.0], [1.176767676767677, 0.0], [1.196969696969697, 0.0], [1.2171717171717173, 0.0], [1.2373737373737375, 0.0], [1.2575757575757578, 0.0], [1.277777777777778, 0.0], [1.2979797979797982, 0.0], [1.3181818181818183, 0.0], [1.3383838383838385, 0.0], [1.3585858585858588, 0.0], [1.378787878787879, 0.0], [1.3989898989898992, 0.0], [1.4191919191919193, 0.0], [1.4393939393939394, 0.0], [1.4595959595959598, 0.0], [1.47979797979798, 0.0], [1.5, 0.0]]}, \"id\": \"el9520168827816\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "         \n",
        "         mpld3.draw_figure(\"fig_el95201688278163211971252\", {\"axes\": [{\"xlim\": [-0.5, 1.5], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-0.5, 1.5], \"ylim\": [0.0, 1.0], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 5, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 6, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170342664\"}], \"markers\": [], \"id\": \"el9520170502632\", \"ydomain\": [0.0, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 240.0, \"width\": 320.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data01\": [[-0.5, 0.0], [-0.4797979797979798, 0.0], [-0.4595959595959596, 0.0], [-0.4393939393939394, 0.0], [-0.41919191919191917, 0.0], [-0.398989898989899, 0.0], [-0.3787878787878788, 0.0], [-0.35858585858585856, 0.0], [-0.33838383838383834, 0.0], [-0.3181818181818182, 0.0], [-0.29797979797979796, 0.0], [-0.2777777777777778, 0.0], [-0.25757575757575757, 0.0], [-0.23737373737373735, 0.0], [-0.21717171717171713, 0.0], [-0.19696969696969696, 0.0], [-0.17676767676767674, 0.0], [-0.15656565656565652, 0.0], [-0.13636363636363635, 0.0], [-0.11616161616161613, 0.0], [-0.09595959595959591, 0.0], [-0.07575757575757575, 0.0], [-0.055555555555555525, 0.0], [-0.035353535353535304, 0.0], [-0.015151515151515138, 0.0], [0.005050505050505083, 1.0], [0.025252525252525304, 1.0], [0.045454545454545525, 1.0], [0.06565656565656575, 1.0], [0.08585858585858586, 1.0], [0.10606060606060608, 1.0], [0.1262626262626263, 1.0], [0.14646464646464652, 1.0], [0.16666666666666674, 1.0], [0.18686868686868696, 1.0], [0.20707070707070718, 1.0], [0.2272727272727273, 1.0], [0.24747474747474751, 1.0], [0.26767676767676774, 1.0], [0.28787878787878796, 1.0], [0.3080808080808082, 1.0], [0.3282828282828284, 1.0], [0.3484848484848485, 1.0], [0.36868686868686873, 1.0], [0.38888888888888895, 1.0], [0.40909090909090917, 1.0], [0.4292929292929294, 1.0], [0.4494949494949496, 1.0], [0.4696969696969697, 1.0], [0.48989898989898994, 1.0], [0.5101010101010102, 1.0], [0.5303030303030305, 1.0], [0.5505050505050506, 1.0], [0.5707070707070707, 1.0], [0.590909090909091, 1.0], [0.6111111111111112, 1.0], [0.6313131313131315, 1.0], [0.6515151515151516, 1.0], [0.6717171717171717, 1.0], [0.691919191919192, 1.0], [0.7121212121212122, 1.0], [0.7323232323232325, 1.0], [0.7525252525252526, 1.0], [0.7727272727272729, 1.0], [0.792929292929293, 1.0], [0.8131313131313131, 1.0], [0.8333333333333335, 1.0], [0.8535353535353536, 1.0], [0.8737373737373739, 1.0], [0.893939393939394, 1.0], [0.9141414141414144, 1.0], [0.9343434343434345, 1.0], [0.9545454545454546, 1.0], [0.9747474747474749, 1.0], [0.994949494949495, 1.0], [1.0151515151515154, 0.0], [1.0353535353535355, 0.0], [1.0555555555555556, 0.0], [1.075757575757576, 0.0], [1.095959595959596, 0.0], [1.1161616161616164, 0.0], [1.1363636363636365, 0.0], [1.1565656565656568, 0.0], [1.176767676767677, 0.0], [1.196969696969697, 0.0], [1.2171717171717173, 0.0], [1.2373737373737375, 0.0], [1.2575757575757578, 0.0], [1.277777777777778, 0.0], [1.2979797979797982, 0.0], [1.3181818181818183, 0.0], [1.3383838383838385, 0.0], [1.3585858585858588, 0.0], [1.378787878787879, 0.0], [1.3989898989898992, 0.0], [1.4191919191919193, 0.0], [1.4393939393939394, 0.0], [1.4595959595959598, 0.0], [1.47979797979798, 0.0], [1.5, 0.0]]}, \"id\": \"el9520168827816\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "                 \n",
        "                 mpld3.draw_figure(\"fig_el95201688278163211971252\", {\"axes\": [{\"xlim\": [-0.5, 1.5], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-0.5, 1.5], \"ylim\": [0.0, 1.0], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 5, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 6, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170342664\"}], \"markers\": [], \"id\": \"el9520170502632\", \"ydomain\": [0.0, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 240.0, \"width\": 320.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data01\": [[-0.5, 0.0], [-0.4797979797979798, 0.0], [-0.4595959595959596, 0.0], [-0.4393939393939394, 0.0], [-0.41919191919191917, 0.0], [-0.398989898989899, 0.0], [-0.3787878787878788, 0.0], [-0.35858585858585856, 0.0], [-0.33838383838383834, 0.0], [-0.3181818181818182, 0.0], [-0.29797979797979796, 0.0], [-0.2777777777777778, 0.0], [-0.25757575757575757, 0.0], [-0.23737373737373735, 0.0], [-0.21717171717171713, 0.0], [-0.19696969696969696, 0.0], [-0.17676767676767674, 0.0], [-0.15656565656565652, 0.0], [-0.13636363636363635, 0.0], [-0.11616161616161613, 0.0], [-0.09595959595959591, 0.0], [-0.07575757575757575, 0.0], [-0.055555555555555525, 0.0], [-0.035353535353535304, 0.0], [-0.015151515151515138, 0.0], [0.005050505050505083, 1.0], [0.025252525252525304, 1.0], [0.045454545454545525, 1.0], [0.06565656565656575, 1.0], [0.08585858585858586, 1.0], [0.10606060606060608, 1.0], [0.1262626262626263, 1.0], [0.14646464646464652, 1.0], [0.16666666666666674, 1.0], [0.18686868686868696, 1.0], [0.20707070707070718, 1.0], [0.2272727272727273, 1.0], [0.24747474747474751, 1.0], [0.26767676767676774, 1.0], [0.28787878787878796, 1.0], [0.3080808080808082, 1.0], [0.3282828282828284, 1.0], [0.3484848484848485, 1.0], [0.36868686868686873, 1.0], [0.38888888888888895, 1.0], [0.40909090909090917, 1.0], [0.4292929292929294, 1.0], [0.4494949494949496, 1.0], [0.4696969696969697, 1.0], [0.48989898989898994, 1.0], [0.5101010101010102, 1.0], [0.5303030303030305, 1.0], [0.5505050505050506, 1.0], [0.5707070707070707, 1.0], [0.590909090909091, 1.0], [0.6111111111111112, 1.0], [0.6313131313131315, 1.0], [0.6515151515151516, 1.0], [0.6717171717171717, 1.0], [0.691919191919192, 1.0], [0.7121212121212122, 1.0], [0.7323232323232325, 1.0], [0.7525252525252526, 1.0], [0.7727272727272729, 1.0], [0.792929292929293, 1.0], [0.8131313131313131, 1.0], [0.8333333333333335, 1.0], [0.8535353535353536, 1.0], [0.8737373737373739, 1.0], [0.893939393939394, 1.0], [0.9141414141414144, 1.0], [0.9343434343434345, 1.0], [0.9545454545454546, 1.0], [0.9747474747474749, 1.0], [0.994949494949495, 1.0], [1.0151515151515154, 0.0], [1.0353535353535355, 0.0], [1.0555555555555556, 0.0], [1.075757575757576, 0.0], [1.095959595959596, 0.0], [1.1161616161616164, 0.0], [1.1363636363636365, 0.0], [1.1565656565656568, 0.0], [1.176767676767677, 0.0], [1.196969696969697, 0.0], [1.2171717171717173, 0.0], [1.2373737373737375, 0.0], [1.2575757575757578, 0.0], [1.277777777777778, 0.0], [1.2979797979797982, 0.0], [1.3181818181818183, 0.0], [1.3383838383838385, 0.0], [1.3585858585858588, 0.0], [1.378787878787879, 0.0], [1.3989898989898992, 0.0], [1.4191919191919193, 0.0], [1.4393939393939394, 0.0], [1.4595959595959598, 0.0], [1.47979797979798, 0.0], [1.5, 0.0]]}, \"id\": \"el9520168827816\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAQcAAADICAYAAADlYiRyAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nOBCREMOBiIT+Dx/NA7Yxm2gtAAAAAElFTkSuQmCC\n",
       "text": [
        "<matplotlib.figure.Figure at 0xa101ba8>"
       ]
      }
     ],
     "prompt_number": 50
    },
    {
     "cell_type": "heading",
     "level": 4,
     "metadata": {},
     "source": [
      "Wave Function"
     ]
    },
    {
     "cell_type": "markdown",
     "metadata": {},
     "source": [
      "This is a bit of a hack..."
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "plt.title('Norm square of wave function for varying barrier width and E = 0.7')\n",
      "plt.xlabel('$x$')\n",
      "plt.ylabel('$|\\psi|^2$')\n",
      "plt.ylim(0, 1.1)\n",
      "for a, color in zip([1, 2, 3, 5], ['red', 'blue', 'green', 'orange']):\n",
      "    V = rect_potential(a=a)\n",
      "    T, _, xs, psis = scatter(V=V, E=0.7, x_min=0, x_max=a, n=1000, return_xs_psis=True)\n",
      "    plt.plot(xs, [V(x) for x in xs], color=color)\n",
      "    plt.plot(xs, np.abs(psis)**2/np.abs(psis[0])**2, '--', color=color, label='a = %s' % a)\n",
      "plt.legend()\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el95201695815921320083937\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "       mpld3.draw_figure(\"fig_el95201695815921320083937\", {\"axes\": [{\"xlim\": [-1.0, 6.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$x$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520175869848\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$|\\\\psi|^2$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520169514096\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Norm square of wave function for varying barrier width and E = 0.7\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520168826696\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.93647093413978533, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el9520170365168\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.93647093413978533, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el9520170368976\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.93647093413978533, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el9520170516096\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.93647093413978533, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el9520170515032\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [-1.0, 6.0], \"ylim\": [0.0, 1.1000000000000001], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170367016\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 7, \"tickvalues\": null}], \"lines\": [{\"color\": \"#FF0000\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168751456\"}, {\"color\": \"#FF0000\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168631712\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 3, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170360392\"}, {\"color\": \"#0000FF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 3, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170360784\"}, {\"color\": \"#008000\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 5, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169553704\"}, {\"color\": \"#008000\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 5, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169550624\"}, {\"color\": \"#FFA500\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 7, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170341208\"}, {\"color\": \"#FFA500\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 7, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170343728\"}, {\"color\": \"#FF0000\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170365728\"}, {\"color\": \"#0000FF\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170515704\"}, {\"color\": \"#008000\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170463752\"}, {\"color\": \"#FFA500\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170463920\"}], \"markers\": [], \"id\": \"el9520169580024\", \"ydomain\": [0.0, 1.1000000000000001], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data02\": [[0.8916680667562725, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086], [0.9167576724910396, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086]], \"data03\": [[0.879123263888889, 0.8399044205495819], [0.9910394265232977, 0.8399044205495819], [0.9910394265232977, 0.9880525686977301], [0.879123263888889, 0.9880525686977301], [0.879123263888889, 0.8399044205495819]], \"data01\": [[-0.001, 0.0, 1.0, -0.002, 1.0, -0.003, 1.0, -0.005, 1.0], [9.990009990008038e-07, 1.0, 0.9983104963843705, 1.9980019980016077e-06, 0.9968026613469056, 2.997002997003062e-06, 0.9953268747517187, 4.995004995005103e-06, 0.9922819273137575], [0.0010019980019980016, 1.0, 0.9966235241632159, 0.0020039960039960033, 0.9936139322073837, 0.003005994005994006, 0.9906724513467232, 0.00500999000999001, 0.984615181374895], [0.0020029970029970022, 1.0, 0.9949394132794194, 0.0040059940059940045, 0.9904351179077963, 0.00600899100899101, 0.9860396350489311, 0.010014985014985014, 0.9770076512763524], [0.0030039960039960033, 1.0, 0.9932581596830351, 0.0060079920079920066, 0.9872661878704999, 0.009011988011988013, 0.9814283255892915, 0.01501998001998002, 0.9694588796515854], [0.004004995004995004, 1.0, 0.9915797593309861, 0.008009990009990009, 0.9841071116129285, 0.012014985014985016, 0.9768384231642308, 0.020024975024975026, 0.961968412666624], [0.0050059940059940045, 1.0, 0.9899042081870599, 0.010011988011988009, 0.9809578587473022, 0.015017982017982021, 0.972269828433493, 0.02502997002997003, 0.9545357999927858], [0.0060069930069930055, 1.0, 0.9882315022218942, 0.012013986013986011, 0.977818398980333, 0.018020979020979024, 0.967722442517989, 0.030034965034965038, 0.9471605947796035], [0.007007992007992007, 1.0, 0.9865616374129681, 0.014015984015984013, 0.9746887021129349, 0.021023976023976026, 0.963196166997657, 0.035039960039960044, 0.9398423536279628], [0.008008991008991006, 1.0, 0.9848946097445942, 0.016017982017982012, 0.9715687380399352, 0.024026973026973028, 0.9586909039093311, 0.04004495504495505, 0.9325806365634384], [0.009009990009990008, 1.0, 0.9832304152079078, 0.018019980019980016, 0.9684584767497803, 0.02702997002997003, 0.9542065557446231, 0.045049950049950056, 0.9253750070098493], [0.01001098901098901, 1.0, 0.9815690498008568, 0.02002197802197802, 0.9653578883242513, 0.030032967032967036, 0.9497430254478103, 0.05005494505494506, 0.9182250317630095], [0.011011988011988008, 1.0, 0.9799105095281934, 0.022023976023976016, 0.9622669429381733, 0.03303596403596404, 0.9453002164137365, 0.05505994005994006, 0.9111302809646818], [0.01201298701298701, 1.0, 0.9782547904014625, 0.02402597402597402, 0.9591856108591303, 0.03603896103896104, 0.9408780324857191, 0.060064935064935064, 0.9040903280767375], [0.013013986013986012, 1.0, 0.9766018884389942, 0.026027972027972024, 0.9561138624471793, 0.03904195804195804, 0.9364763779534707, 0.06506993006993007, 0.8971047498555103], [0.014014985014985014, 1.0, 0.9749517996658928, 0.028029970029970028, 0.9530516681545629, 0.04204495504495504, 0.9320951575510246, 0.07007492507492508, 0.8901731263263529], [0.015015984015984012, 1.0, 0.9733045201140288, 0.030031968031968025, 0.9499989985254279, 0.04504795204795205, 0.927734276454675, 0.07507992007992008, 0.8832950407583869], [0.016016983016983014, 1.0, 0.9716600458220267, 0.03203396603396603, 0.9469558241955406, 0.04805094905094905, 0.9233936402809239, 0.08008491508491508, 0.8764700796394485], [0.017017982017982013, 1.0, 0.9700183728352582, 0.034035964035964025, 0.9439221158920037, 0.05105394605394605, 0.9190731550844391, 0.08508991008991008, 0.8696978326512295], [0.018018981018981015, 1.0, 0.9683794972058312, 0.03603796203796203, 0.9408978444329769, 0.05405694305694306, 0.9147727273560203, 0.0900949050949051, 0.8629778926446069], [0.019019980019980016, 1.0, 0.9667434149925804, 0.03803996003996003, 0.937882980727393, 0.057059940059940056, 0.9104922640205746, 0.0950999000999001, 0.8563098556151669], [0.020020979020979015, 1.0, 0.9651101222610589, 0.04004195804195803, 0.9348774957746813, 0.06006293706293707, 0.9062316724351038, 0.1001048951048951, 0.8496933206789152], [0.021021978021978017, 1.0, 0.9634796150835273, 0.042043956043956034, 0.9318813606644856, 0.06306593406593407, 0.9019908603866974, 0.10510989010989011, 0.8431278900481752], [0.02202297702297702, 1.0, 0.9618518895389446, 0.04404595404595404, 0.9288945465763901, 0.06606893106893107, 0.8977697360905381, 0.11011488511488511, 0.836613169007674], [0.023023976023976017, 1.0, 0.9602269417129606, 0.046047952047952034, 0.9259170247796376, 0.06907192807192808, 0.8935682081879147, 0.11511988011988011, 0.8301487658908117], [0.02402497502497502, 1.0, 0.9586047676979031, 0.04804995004995004, 0.9229487666328569, 0.07207492507492508, 0.8893861857442458, 0.12012487512487513, 0.8237342920561131], [0.02502597402597402, 1.0, 0.9569853635927708, 0.05005194805194804, 0.9199897435837835, 0.07507792207792208, 0.8852235782471102, 0.12512987012987012, 0.8173693618638644], [0.026026973026973023, 1.0, 0.955368725503225, 0.052053946053946046, 0.9170399271689893, 0.07808091908091908, 0.8810802956042879, 0.13013486513486514, 0.8110535926529272], [0.02702797202797202, 1.0, 0.9537548495415765, 0.05405594405594404, 0.9140992890136064, 0.08108391608391609, 0.8769562481418125, 0.13513986013986015, 0.804786604717733], [0.028028971028971023, 1.0, 0.9521437318267794, 0.056057942057942046, 0.9111678008310526, 0.08408691308691309, 0.8728513466020283, 0.14014485514485514, 0.7985680212854555], [0.029029970029970025, 1.0, 0.9505353684844218, 0.05805994005994005, 0.9082454344227628, 0.08708991008991009, 0.8687655021416577, 0.14514985014985016, 0.7923974684933588], [0.030030969030969024, 1.0, 0.9489297556467137, 0.06006193806193805, 0.9053321616779155, 0.0900929070929071, 0.8646986263298819, 0.15015484515484515, 0.7862745753663207], [0.031031968031968026, 1.0, 0.9473268894524812, 0.06206393606393605, 0.9024279545731632, 0.0930959040959041, 0.8606506311464227, 0.15515984015984016, 0.7801989737945296], [0.03203296703296703, 1.0, 0.9457267660471539, 0.06406593406593405, 0.8995327851723626, 0.0960989010989011, 0.8566214289796403, 0.16016483516483518, 0.7741702985113538], [0.03303396603396603, 1.0, 0.944129381582759, 0.06606793206793206, 0.8966466256263058, 0.09910189810189811, 0.8526109326246365, 0.16516983016983017, 0.7681881870713809], [0.03403496503496503, 1.0, 0.9425347322179085, 0.06806993006993006, 0.8937694481724517, 0.10210489510489511, 0.848619055281366, 0.17017482517482518, 0.7622522798286283], [0.035035964035964026, 1.0, 0.9409428141177935, 0.07007192807192805, 0.8909012251346606, 0.1051078921078921, 0.8446457105527599, 0.17517982017982017, 0.7563622199149211], [0.03603696303696303, 1.0, 0.9393536234541724, 0.07207392607392606, 0.888041928922927, 0.10811088911088912, 0.8406908124428545, 0.1801848151848152, 0.7505176532184362], [0.03703796203796203, 1.0, 0.9377671564053619, 0.07407592407592406, 0.8851915320331141, 0.11111388611388612, 0.8367542753549293, 0.1851898101898102, 0.7447182283624141], [0.03803896103896103, 1.0, 0.9361834091562299, 0.07607792207792206, 0.8823500070466891, 0.11411688311688312, 0.8328360140896569, 0.1901948051948052, 0.7389635966840343], [0.039039960039960034, 1.0, 0.9346023778981836, 0.07807992007992007, 0.879517326630461, 0.11711988011988012, 0.8289359438432562, 0.1951998001998002, 0.7332534122134511], [0.040040959040959036, 1.0, 0.9330240588291621, 0.08008191808191807, 0.8766934635363147, 0.12012287712287713, 0.8250539802056589, 0.2002047952047952, 0.7275873316529978], [0.04104195804195803, 1.0, 0.9314484481536268, 0.08208391608391606, 0.8738783906009528, 0.12312587412587414, 0.8211900391586827, 0.20520979020979022, 0.721965014356544], [0.04204295704295703, 1.0, 0.9298755420825522, 0.08408591408591407, 0.8710720807456304, 0.12612887112887114, 0.8173440370742107, 0.21021478521478523, 0.716386122309018], [0.043043956043956035, 1.0, 0.9283053368334164, 0.08608791208791207, 0.8682745069758973, 0.12913186813186814, 0.8135158907123836, 0.21521978021978022, 0.7108503201060836], [0.044044955044955036, 1.0, 0.9267378286301935, 0.08808991008991007, 0.8654856423813366, 0.13213486513486514, 0.8097055172197976, 0.22022477522477524, 0.7053572749339775], [0.04504595404595404, 1.0, 0.9251730137033419, 0.09009190809190808, 0.8627054601353079, 0.13513786213786214, 0.8059128341277103, 0.22522977022977023, 0.6999066565494991], [0.04604695304695304, 1.0, 0.9236108882897978, 0.09209390609390608, 0.8599339334946874, 0.13814085914085913, 0.8021377593502578, 0.23023476523476524, 0.694498137260156], [0.047047952047952035, 1.0, 0.922051448632965, 0.09409590409590407, 0.8571710357996111, 0.14114385614385616, 0.7983802111826745, 0.23523976023976023, 0.6891313919044644], [0.04804895104895104, 1.0, 0.9204946909827066, 0.09609790209790207, 0.8544167404732183, 0.14414685314685316, 0.7946401082995298, 0.24024475524475525, 0.683806097832399], [0.04904995004995004, 1.0, 0.9189406115953349, 0.09809990009990008, 0.8516710210213971, 0.14714985014985016, 0.7909173697529626, 0.24524975024975026, 0.6785219348859958], [0.05005094905094904, 1.0, 0.9173892067336018, 0.10010189810189808, 0.848933851032528, 0.15015284715284716, 0.7872119149709335, 0.2502547452547453, 0.6732785853801035], [0.05105194805194804, 1.0, 0.9158404726666924, 0.10210389610389609, 0.8462052041772308, 0.15315584415584416, 0.783523663755479, 0.25525974025974024, 0.6680757340832851], [0.052052947052947045, 1.0, 0.9142944056702137, 0.10410589410589409, 0.8434850542081104, 0.15615884115884116, 0.7798525362809758, 0.26026473526473526, 0.6629130681988665], [0.05305394605394605, 1.0, 0.9127510020261875, 0.1061078921078921, 0.8407733749595059, 0.15916183816183815, 0.776198453092414, 0.2652697302697303, 0.6577902773461288], [0.05405494505494504, 1.0, 0.9112102580230395, 0.10810989010989008, 0.8380701403472377, 0.16216483516483518, 0.7725613351036765, 0.2702747252747253, 0.6527070535416508], [0.055055944055944044, 1.0, 0.9096721699555906, 0.11011188811188809, 0.8353753243683553, 0.16516783216783218, 0.7689411035958278, 0.2752797202797203, 0.647663091180791], [0.056056943056943045, 1.0, 0.9081367341250505, 0.11211388611388609, 0.8326889011008908, 0.16817082917082918, 0.7653376802154102, 0.28028471528471527, 0.6426580870193156], [0.05705794205794205, 1.0, 0.9066039468390058, 0.1141158841158841, 0.8300108447036064, 0.17117382617382618, 0.7617509869727477, 0.2852897102897103, 0.6376917401551669], [0.05805894105894105, 1.0, 0.9050738044114126, 0.1161178821178821, 0.8273411294157469, 0.17417682317682318, 0.7581809462402592, 0.2902947052947053, 0.6327637520103743], [0.05905994005994005, 1.0, 0.9035463031625867, 0.1181198801198801, 0.824679729556792, 0.17717982017982017, 0.7546274807507767, 0.2952997002997003, 0.6278738263131012], [0.060060939060939046, 1.0, 0.9020214394191962, 0.12012187812187809, 0.8220266195262094, 0.1801828171828172, 0.7510905135958736, 0.30030469530469533, 0.6230216690798357], [0.06106193806193805, 1.0, 0.9004992095142523, 0.1221238761238761, 0.819381773803208, 0.1831858141858142, 0.747569968224201, 0.3053096903096903, 0.6182069885977144], [0.06206293706293706, 1.0, 0.898979609787099, 0.12412587412587411, 0.8167451669464926, 0.1861888111888112, 0.7440657684398295, 0.3103146853146853, 0.6134294954069853], [0.06306393606393605, 1.0, 0.8974626365834062, 0.1261278721278721, 0.81411677359402, 0.1891918081918082, 0.7405778384006018, 0.31531968031968033, 0.6086889022836056], [0.06406493506493505, 1.0, 0.8959482862551592, 0.1281298701298701, 0.8114965684627536, 0.1921948051948052, 0.737106102616489, 0.32032467532467535, 0.6039849242219727], [0.06506593406593406, 1.0, 0.8944365551606517, 0.1301318681318681, 0.8088845263484215, 0.1951978021978022, 0.7336504859479591, 0.32532967032967036, 0.5993172784177921], [0.06606693306693305, 1.0, 0.8929274396644755, 0.1321338661338661, 0.8062806221252727, 0.1982007992007992, 0.7302109136043493, 0.3303346653346653, 0.5946856842510709], [0.06706793206793206, 1.0, 0.891420936137512, 0.13413586413586412, 0.8036848307458369, 0.20120379620379622, 0.7267873111422473, 0.33533966033966034, 0.5900898632692513], [0.06806893106893105, 1.0, 0.8899170409569249, 0.1361378621378621, 0.8010971272406824, 0.20420679320679322, 0.7233796044638807, 0.34034465534465536, 0.5855295391704675], [0.06906993006993006, 1.0, 0.8884157505061505, 0.13813986013986013, 0.7985174867181765, 0.20720979020979022, 0.7199877198155128, 0.34534965034965037, 0.5810044377869346], [0.07007092907092906, 1.0, 0.8869170611748877, 0.14014185814185812, 0.7959458843642463, 0.21021278721278722, 0.7166115837858468, 0.3503546453546454, 0.5765142870684656], [0.07107192807192805, 1.0, 0.8854209693590911, 0.1421438561438561, 0.7933822954421383, 0.21321578421578422, 0.713251123304436, 0.35535964035964035, 0.5720588170661169], [0.07207292707292706, 1.0, 0.8839274714609624, 0.14414585414585412, 0.7908266952921846, 0.21621878121878121, 0.7099062656401038, 0.36036463536463537, 0.5676377599159569], [0.07307392607392606, 1.0, 0.8824365638889402, 0.14614785214785211, 0.7882790593315592, 0.21922177822177824, 0.7065769383993686, 0.3653696303696304, 0.5632508498229637], [0.07407492507492507, 1.0, 0.8809482430576937, 0.14814985014985013, 0.7857393630540479, 0.22222477522477524, 0.703263069524877, 0.3703746253746254, 0.5588978230450441], [0.07507592407592406, 1.0, 0.8794625053881113, 0.15015184815184812, 0.7832075820298091, 0.22522777222777224, 0.6999645872938443, 0.3753796203796204, 0.5545784178771779], [0.07607692307692306, 1.0, 0.8779793473072941, 0.1521538461538461, 0.7806836919051392, 0.22823076923076924, 0.6966814203165025, 0.3803846153846154, 0.550292374635685], [0.07707792207792206, 1.0, 0.8764987652485463, 0.15415584415584413, 0.7781676684022395, 0.23123376623376624, 0.6934134975345546, 0.3853896103896104, 0.546039435642612], [0.07807892107892106, 1.0, 0.8750207556513672, 0.15615784215784212, 0.7756594873189809, 0.23423676323676323, 0.6901607482196377, 0.3903946053946054, 0.5418193452102402], [0.07907992007992007, 1.0, 0.8735453149614419, 0.15815984015984014, 0.7731591245286736, 0.23723976023976023, 0.686923101971791, 0.3953996003996004, 0.5376318496257158], [0.08008091908091906, 1.0, 0.8720724396306335, 0.16016183816183813, 0.7706665559798316, 0.24024275724275726, 0.6837004887179322, 0.40040459540459544, 0.5334766971357939], [0.08108191808191807, 1.0, 0.8706021261169743, 0.16216383616383614, 0.7681817576959449, 0.24324575424575426, 0.6804928387103425, 0.4054095904095904, 0.5293536379317045], [0.08208291708291707, 1.0, 0.8691343708846568, 0.16416583416583413, 0.7657047057752463, 0.24624875124875126, 0.677300082525155, 0.4104145854145854, 0.5252624241341342], [0.08308391608391606, 1.0, 0.8676691704040259, 0.16616783216783212, 0.7632353763904828, 0.24925174825174828, 0.6741221510608536, 0.41541958041958044, 0.5212028097783216], [0.08408491508491507, 1.0, 0.8662065211515709, 0.16816983016983014, 0.7607737457886856, 0.2522547452547453, 0.6709589755367762, 0.42042457542457545, 0.517174550799273], [0.08508591408591407, 1.0, 0.8647464196099152, 0.17017182817182813, 0.7583197902909421, 0.2552577422577423, 0.6678104874916282, 0.42542957042957047, 0.5131774050170871], [0.08608691308691307, 1.0, 0.8632888622678094, 0.17217382617382615, 0.7558734862921689, 0.2582607392607393, 0.664676618781997, 0.43043456543456543, 0.509211132122395], [0.08708791208791207, 1.0, 0.8618338456201228, 0.17417582417582414, 0.7534348102608825, 0.2612637362637363, 0.661557301580881, 0.43543956043956045, 0.5052754936619142], [0.08808891108891108, 1.0, 0.8603813661678343, 0.17617782217782216, 0.7510037387389755, 0.2642667332667333, 0.6584524683762203, 0.44044455544455546, 0.5013702530241105], [0.08908991008991007, 1.0, 0.8589314204180237, 0.17817982017982015, 0.7485802483414892, 0.2672697302697303, 0.6553620519694345, 0.4454495504495505, 0.4974951754249754], [0.09009090909090907, 1.0, 0.857484004883865, 0.18018181818181814, 0.7461643157563888, 0.2702727272727273, 0.652285985473969, 0.4504545454545455, 0.49365002789390866], [0.09109190809190808, 1.0, 0.8560391160846151, 0.18218381618381616, 0.7437559177443408, 0.2732757242757243, 0.6492242023138478, 0.45545954045954046, 0.48983457925971324], [0.09209290709290707, 1.0, 0.8545967505456086, 0.18418581418581415, 0.7413550311384871, 0.2762787212787213, 0.646176636222233, 0.4604645354645355, 0.48604860013669704], [0.09309390609390608, 1.0, 0.8531569047982479, 0.18618781218781216, 0.7389616328442247, 0.27928171828171827, 0.6431432212399883, 0.4654695304695305, 0.48229186291088205], [0.09409490509490508, 1.0, 0.8517195753799945, 0.18818981018981015, 0.7365756998389802, 0.28228471528471527, 0.6401238917142539, 0.4704745254745255, 0.47856414172631995], [0.09509590409590407, 1.0, 0.8502847588343608, 0.19019180819180814, 0.7341972091719919, 0.2852877122877123, 0.6371185822970241, 0.47547952047952047, 0.4748652124715141], [0.09609690309690308, 1.0, 0.8488524517109034, 0.19219380619380616, 0.7318261379640867, 0.2882907092907093, 0.6341272279437341, 0.4804845154845155, 0.4711948527659453], [0.09709790209790208, 1.0, 0.8474226505652127, 0.19419580419580415, 0.7294624634074609, 0.2912937062937063, 0.6311497639118511, 0.4854895104895105, 0.46755284194670327], [0.09809890109890108, 1.0, 0.8459953519589061, 0.19619780219780217, 0.7271061627654605, 0.2942967032967033, 0.628186125759473, 0.4904945054945055, 0.46393896105521876], [0.09909990009990008, 1.0, 0.844570552459618, 0.19819980019980016, 0.7247572133723629, 0.2972997002997003, 0.625236249343936, 0.49549950049950053, 0.4603529928241008], [0.10010089910089909, 1.0, 0.8431482486409934, 0.20020179820179818, 0.7224155926331589, 0.3003026973026973, 0.6223000708204224, 0.5005044955044955, 0.4567947216640747], [0.10110189810189808, 1.0, 0.8417284370826789, 0.20220379620379617, 0.7200812780233348, 0.3033056943056943, 0.6193775266405827, 0.5055094905094906, 0.4532639336510198], [0.10210289710289708, 1.0, 0.8403111143703144, 0.20420579420579416, 0.7177542470886554, 0.3063086913086913, 0.6164685535511575, 0.5105144855144855, 0.449760416513109], [0.10310389610389609, 1.0, 0.8388962770955256, 0.20620779220779217, 0.7154344774449493, 0.3093116883116883, 0.6135730885926097, 0.5155194805194805, 0.44628395961804723], [0.10410489510489508, 1.0, 0.8374839218559136, 0.20820979020979016, 0.7131219467778929, 0.3123146853146853, 0.6106910690977618, 0.5205244755244756, 0.44283435396040716], [0.10510589410589409, 1.0, 0.83607404525505, 0.21021178821178818, 0.7108166328427957, 0.3153176823176823, 0.6078224326904388, 0.5255294705294705, 0.43941139214906466], [0.10610689310689309, 1.0, 0.8346666439024654, 0.21221378621378617, 0.7085185134643857, 0.3183206793206793, 0.6049671172841197, 0.5305344655344656, 0.43601486839473], [0.1071078921078921, 1.0, 0.8332617144136443, 0.2142157842157842, 0.706227566536598, 0.3213236763236763, 0.6021250610805922, 0.5355394605394606, 0.432644578497576], [0.10810889110889109, 1.0, 0.8318592534100148, 0.21621778221778218, 0.7039437700223596, 0.32432667332667336, 0.5992962025686157, 0.5405444555444555, 0.429300319834961], [0.10910989010989008, 1.0, 0.8304592575189409, 0.21821978021978017, 0.70166710195338, 0.32732967032967036, 0.5964804805225905, 0.5455494505494506, 0.4259818913492478], [0.11011088911088909, 1.0, 0.8290617233737154, 0.22022177822177819, 0.6993975404299373, 0.33033266733266736, 0.5936778340012321, 0.5505544455544455, 0.42268909353571527], [0.11111188811188809, 1.0, 0.827666647613551, 0.22222377622377618, 0.6971350636206696, 0.33333566433566436, 0.5908882023462522, 0.5555594405594406, 0.4194217284305647], [0.1121128871128871, 1.0, 0.8262740268835725, 0.2242257742257742, 0.6948796497623649, 0.33633866133866136, 0.5881115251810465, 0.5605644355644356, 0.4161795995990177], [0.11311388611388609, 1.0, 0.8248838578348081, 0.22622777222777218, 0.6926312771597503, 0.33934165834165836, 0.5853477424093876, 0.5655694305694305, 0.41296251212350715], [0.1141148851148851, 1.0, 0.8234961371241819, 0.2282297702297702, 0.6903899241852838, 0.34234465534465536, 0.5825967942141236, 0.5705744255744256, 0.40977027259195753], [0.1151158841158841, 1.0, 0.822110861414506, 0.2302317682317682, 0.6881555692789472, 0.34534765234765236, 0.579858621055885, 0.5755794205794206, 0.40660268908615876], [0.11611688311688309, 1.0, 0.8207280273744718, 0.23223376623376618, 0.6859281909480385, 0.34835064935064936, 0.5771331636717943, 0.5805844155844156, 0.40345957117022646], [0.1171178821178821, 1.0, 0.8193476316786419, 0.2342357642357642, 0.6837077677669641, 0.35135364635364635, 0.574420363074185, 0.5855894105894106, 0.4003407298791529], [0.1181188811188811, 1.0, 0.8179696710074443, 0.2362377622377622, 0.6814942783770335, 0.35435664335664335, 0.5717201605493241, 0.5905944055944056, 0.3972459777074478], [0.1191198801198801, 1.0, 0.8165941420471617, 0.2382397602397602, 0.6792877014862537, 0.35735964035964035, 0.5690324976561407, 0.5955994005994006, 0.39417512859786424], [0.1201208791208791, 1.0, 0.8152210414899249, 0.2402417582417582, 0.6770880158691244, 0.36036263736263735, 0.5663573162249629, 0.6006043956043956, 0.39112799793021263], [0.1211218781218781, 1.0, 0.8138503660337036, 0.2422437562437562, 0.6748952003664338, 0.3633656343656344, 0.5636945583562569, 0.6056093906093907, 0.38810440251026246], [0.1221228771228771, 1.0, 0.8124821123823005, 0.2442457542457542, 0.6727092338850554, 0.3663686313686314, 0.5610441664193757, 0.6106143856143856, 0.38510416055872776], [0.1231238761238761, 1.0, 0.811116277245342, 0.2462477522477522, 0.6705300953977441, 0.3693716283716284, 0.5584060830513098, 0.6156193806193806, 0.3821270917003388], [0.1241248751248751, 1.0, 0.8097528573382705, 0.2482497502497502, 0.6683577639429351, 0.3723746253746254, 0.5557802511554472, 0.6206243756243757, 0.3791730169529978], [0.12512587412587411, 1.0, 0.808391849382336, 0.25025174825174823, 0.6661922186245424, 0.3753776223776224, 0.5531666139003374, 0.6256293706293706, 0.3762417587170185], [0.1261268731268731, 1.0, 0.8070332501045895, 0.2522537462537462, 0.6640334386117565, 0.3783806193806194, 0.5505651147184609, 0.6306343656343657, 0.3733331407644484], [0.1271278721278721, 1.0, 0.8056770562378736, 0.2542557442557442, 0.6618814031388445, 0.3813836163836164, 0.5479756973050056, 0.6356393606393607, 0.3704469882284748], [0.1281288711288711, 1.0, 0.8043232645208165, 0.2562577422577422, 0.6597360915049507, 0.3843866133866134, 0.545398305616647, 0.6406443556443556, 0.3675831275929113], [0.1291298701298701, 1.0, 0.8029718716978221, 0.2582597402597402, 0.6575974830738976, 0.3873896103896104, 0.5428328838703366, 0.6456493506493507, 0.3647413866817654], [0.1301308691308691, 1.0, 0.8016228745190634, 0.2602617382617382, 0.6554655572739874, 0.3903926073926074, 0.5402793765420937, 0.6506543456543457, 0.3619215946488884], [0.1311318681318681, 1.0, 0.800276269740475, 0.2622637362637362, 0.653340293597803, 0.3933956043956044, 0.5377377283658038, 0.6556593406593407, 0.3591235819677031], [0.13213286713286712, 1.0, 0.7989320541237438, 0.26426573426573424, 0.6512216716020129, 0.3963986013986014, 0.5352078843320232, 0.6606643356643357, 0.35634718042101216], [0.1331338661338661, 1.0, 0.7975902244363028, 0.2662677322677322, 0.6491096709071715, 0.3994015984015984, 0.5326897896867869, 0.6656693306693306, 0.3535922230908848], [0.1341348651348651, 1.0, 0.7962507774513232, 0.2682697302697302, 0.647004271197526, 0.40240459540459544, 0.5301833899304252, 0.6706743256743257, 0.3508585443486219], [0.13513586413586412, 1.0, 0.7949137099477048, 0.27027172827172824, 0.6449054522208191, 0.40540759240759244, 0.5276886308163832, 0.6756793206793207, 0.3481459798447982], [0.1361368631368631, 1.0, 0.79357901871007, 0.2722737262737262, 0.6428131937880958, 0.40841058941058944, 0.5252054583500466, 0.6806843156843158, 0.3454543664993814], [0.1371378621378621, 1.0, 0.7922467005287569, 0.2742757242757242, 0.6407274757735074, 0.41141358641358644, 0.5227338187875743, 0.6856893106893107, 0.34278354249192766], [0.13813886113886112, 1.0, 0.7909167521998083, 0.27627772227772224, 0.6386482781141194, 0.41441658341658344, 0.5202736586347336, 0.6906943056943057, 0.3401333472518539], [0.13913986013986013, 1.0, 0.7895891705249678, 0.27827972027972026, 0.6365755808097173, 0.41741958041958044, 0.517824924645743, 0.6956993006993007, 0.3375036214487828], [0.1401408591408591, 1.0, 0.788263952311669, 0.2802817182817182, 0.6345093639226154, 0.42042257742257744, 0.5153875638221209, 0.7007042957042957, 0.3348942069829649], [0.14114185814185812, 1.0, 0.7869410943730298, 0.28228371628371624, 0.6324496075774639, 0.42342557442557444, 0.512961523411537, 0.7057092907092908, 0.3323049469757729], [0.14214285714285713, 1.0, 0.7856205935278442, 0.28428571428571425, 0.6303962919610588, 0.42642857142857143, 0.5105467509066708, 0.7107142857142857, 0.3297356857602709], [0.1431438561438561, 1.0, 0.7843024466005738, 0.2862877122877122, 0.6283493973221498, 0.42943156843156843, 0.5081431940440763, 0.7157192807192807, 0.3271862688718546], [0.14414485514485512, 1.0, 0.7829866504213416, 0.28828971028971023, 0.6263089039712525, 0.43243456543456543, 0.5057508008030496, 0.7207242757242758, 0.324656543038966], [0.14514585414585413, 1.0, 0.7816732018259237, 0.29029170829170825, 0.6242747922804568, 0.43543756243756243, 0.5033695194045033, 0.7257292707292707, 0.32214635617387766], [0.14614685314685313, 1.0, 0.7803620976557415, 0.29229370629370627, 0.6222470426832396, 0.43844055944055943, 0.5009992983098465, 0.7307342657342658, 0.31965555736354995], [0.14714785214785212, 1.0, 0.7790533347578539, 0.29429570429570423, 0.6202256356742755, 0.4414435564435565, 0.49864008621986866, 0.7357392607392608, 0.31718399686055737], [0.14814885114885112, 1.0, 0.7777469099849502, 0.29629770229770225, 0.6182105518092499, 0.4444465534465535, 0.49629183207363003, 0.7407442557442557, 0.31473152607408655], [0.14914985014985013, 1.0, 0.7764428201953432, 0.29829970029970027, 0.616201771704672, 0.4474495504495505, 0.4939544850473546, 0.7457492507492508, 0.3122979975610024], [0.1501508491508491, 1.0, 0.7751410622529596, 0.3003016983016982, 0.6141992760376882, 0.4504525474525475, 0.4916279945533331, 0.7507542457542458, 0.30988326501698354], [0.15115184815184812, 1.0, 0.7738416330273349, 0.30230369630369625, 0.6122030455458957, 0.4534555444555445, 0.4893123102388258, 0.7557592407592408, 0.30748718326772717], [0.15215284715284713, 1.0, 0.772544529393604, 0.30430569430569426, 0.610213061027158, 0.4564585414585415, 0.4870073819849733, 0.7607642357642358, 0.3051096082602204], [0.1531538461538461, 1.0, 0.7712497482324946, 0.3063076923076922, 0.6082293033394199, 0.4594615384615385, 0.48471315990571245, 0.7657692307692308, 0.3027503970540804], [0.15415484515484512, 1.0, 0.7699572864303191, 0.30830969030969024, 0.606251753400523, 0.4624645354645355, 0.4824295943466961, 0.7707742257742258, 0.3004094078129603], [0.15515584415584413, 1.0, 0.7686671408789689, 0.31031168831168826, 0.6042803921880232, 0.4654675324675325, 0.480156635884218, 0.7757792207792208, 0.29808649979602236], [0.15615684315684314, 1.0, 0.767379308475903, 0.3123136863136863, 0.6023152007390058, 0.4684705294705295, 0.47789423532414393, 0.7807842157842159, 0.2957815333494761], [0.15715784215784212, 1.0, 0.7660937861241452, 0.31431568431568424, 0.6003561601499051, 0.47147352647352647, 0.47564234370084685, 0.7857892107892108, 0.29349436989818295], [0.15815884115884113, 1.0, 0.7648105707322742, 0.31631768231768226, 0.5984032515763212, 0.47447652347652347, 0.4734009122761466, 0.7907942057942058, 0.29122487193732466], [0.15915984015984014, 1.0, 0.7635296592144155, 0.3183196803196803, 0.5964564562328405, 0.47747952047952047, 0.47116989253825564, 0.7957992007992009, 0.28897290302413636], [0.16016083916083912, 1.0, 0.7622510484902357, 0.32032167832167824, 0.5945157553928525, 0.4804825174825175, 0.4689492362007283, 0.8008041958041958, 0.2867383277697039], [0.16116183816183813, 1.0, 0.7609747354849343, 0.32232367632367626, 0.592581130388371, 0.4834855144855145, 0.46673889520141687, 0.8058091908091909, 0.2845210118308238], [0.16216283716283714, 1.0, 0.7597007171292366, 0.3243256743256743, 0.5906525626098554, 0.4864885114885115, 0.46453882170143046, 0.8108141858141859, 0.28232082190192703], [0.16316383616383615, 1.0, 0.7584289903593854, 0.3263276723276723, 0.5887300335060303, 0.4894915084915085, 0.4623489680840999, 0.8158191808191808, 0.2801376257070645], [0.16416483516483513, 1.0, 0.7571595521171346, 0.32832967032967025, 0.5868135245837066, 0.4924945054945055, 0.4601692869539475, 0.8208241758241759, 0.2779712919919543], [0.16516583416583414, 1.0, 0.7558923993497413, 0.33033166833166827, 0.5849030174076056, 0.4954975024975025, 0.4579997311356601, 0.8258291708291708, 0.27582169051609096], [0.16616683316683314, 1.0, 0.7546275290099597, 0.3323336663336663, 0.5829984936001806, 0.49850049950049957, 0.45584025367307, 0.8308341658341659, 0.27368869204491525], [0.16716783216783213, 1.0, 0.7533649380560312, 0.33433566433566425, 0.5810999348414395, 0.5015034965034966, 0.45369080782813653, 0.8358391608391609, 0.27157216834204473], [0.16816883116883113, 1.0, 0.7521046234516797, 0.33633766233766227, 0.5792073228687694, 0.5045064935064936, 0.451551347079936, 0.8408441558441558, 0.2694719921615637], [0.16916983016983014, 1.0, 0.7508465821661032, 0.3383396603396603, 0.5773206394767612, 0.5075094905094906, 0.4494218251236541, 0.8458491508491509, 0.26738803724037363], [0.17017082917082915, 1.0, 0.7495908111739659, 0.3403416583416583, 0.575439866517033, 0.5105124875124876, 0.44730219586958414, 0.8508541458541459, 0.26532017829060217], [0.17117182817182813, 1.0, 0.748337307455393, 0.34234365634365627, 0.5735649858980579, 0.5135154845154846, 0.44519241344212956, 0.8558591408591409, 0.2632682909920703], [0.17217282717282714, 1.0, 0.7470860679959607, 0.3443456543456543, 0.5716959795849873, 0.5165184815184816, 0.44309243217881045, 0.8608641358641359, 0.26123225198481886], [0.17317382617382615, 1.0, 0.7458370897866907, 0.3463476523476523, 0.5698328295994791, 0.5195214785214786, 0.44100220662927553, 0.8658691308691309, 0.2592119388616916], [0.17417482517482513, 1.0, 0.7445903698240429, 0.34834965034965026, 0.5679755180195247, 0.5225244755244756, 0.4389216915543191, 0.8708741258741259, 0.25720723016097613], [0.17517582417582414, 1.0, 0.7433459051099071, 0.3503516483516483, 0.5661240269792762, 0.5255274725274726, 0.4368508419249005, 0.8758791208791209, 0.255218005359102], [0.17617682317682315, 1.0, 0.7421036926515968, 0.3523536463536463, 0.564278338668874, 0.5285304695304696, 0.43478961292117124, 0.880884115884116, 0.2532441448633943], [0.17717782217782216, 1.0, 0.7408637294618425, 0.3543556443556443, 0.5624384353342767, 0.5315334665334666, 0.43273795993150377, 0.8858891108891109, 0.2512855300048838], [0.17817882117882114, 1.0, 0.7396260125587827, 0.3563576423576423, 0.5606042992770899, 0.5345364635364636, 0.43069583855152627, 0.8908941058941059, 0.24934204303117308], [0.17917982017982015, 1.0, 0.7383905389659586, 0.3583596403596403, 0.5587759128543953, 0.5375394605394606, 0.42866320458316176, 0.895899100899101, 0.24741356709935614], [0.18018081918081916, 1.0, 0.7371573057123054, 0.3603616383616383, 0.5569532584785816, 0.5405424575424576, 0.42664001403367136, 0.9009040959040959, 0.24549998626899508], [0.18118181818181814, 1.0, 0.7359263098321457, 0.3623636363636363, 0.5551363186171756, 0.5435454545454546, 0.42462622311470194, 0.905909090909091, 0.2436011854951487], [0.18218281718281715, 1.0, 0.7346975483651838, 0.3643656343656343, 0.5533250757926725, 0.5465484515484516, 0.42262178824133895, 0.910914085914086, 0.24171705062145651], [0.18318381618381616, 1.0, 0.733471018356496, 0.3663676323676323, 0.5515195125823689, 0.5495514485514486, 0.42062666603116244, 0.9159190809190809, 0.23984746837327547], [0.18418481518481516, 1.0, 0.7322467168565251, 0.36836963036963033, 0.5497196116181944, 0.5525544455544456, 0.4186408133033085, 0.920924075924076, 0.2379923263508698], [0.18518581418581415, 1.0, 0.7310246409210737, 0.3703716283716283, 0.5479253555865451, 0.5555574425574425, 0.416664187077535, 0.925929070929071, 0.23615151302265375], [0.18618681318681315, 1.0, 0.729804787611296, 0.3723736263736263, 0.5461367272281173, 0.5585604395604395, 0.4146967445732906, 0.930934065934066, 0.23432491771848593], [0.18718781218781216, 1.0, 0.7285871539936906, 0.3743756243756243, 0.5443537093377402, 0.5615634365634365, 0.4127384432087894, 0.935939060939061, 0.23251243062301594], [0.18818881118881114, 1.0, 0.7273717371400951, 0.3763776223776223, 0.5425762847642114, 0.5645664335664335, 0.41078924060008926, 0.940944055944056, 0.2307139427690827], [0.18918981018981015, 1.0, 0.7261585341276767, 0.3783796203796203, 0.5408044364101314, 0.5675694305694305, 0.40884909456017415, 0.945949050949051, 0.22892934603116238], [0.19019080919080916, 1.0, 0.7249475420389272, 0.3803816183816183, 0.5390381472317403, 0.5705724275724275, 0.40691796309804135, 0.950954045954046, 0.2271585331188688], [0.19119180819180814, 1.0, 0.7237387579616559, 0.3823836163836163, 0.5372774002387528, 0.5735754245754247, 0.404995804417793, 0.9559590409590409, 0.22540139757050245], [0.19219280719280715, 1.0, 0.7225321789889803, 0.3843856143856143, 0.5355221784941945, 0.5765784215784217, 0.4030825769177306, 0.960964035964036, 0.22365783374665046], [0.19319380619380616, 1.0, 0.7213278022193219, 0.3863876123876123, 0.5337724651142396, 0.5795814185814187, 0.4011782391894552, 0.965969030969031, 0.22192773682383515], [0.19419480519480517, 1.0, 0.7201256247563974, 0.38838961038961034, 0.5320282432680487, 0.5825844155844156, 0.39928275001697183, 0.970974025974026, 0.22021100278821226], [0.19519580419580415, 1.0, 0.7189256437092134, 0.3903916083916083, 0.5302894961776059, 0.5855874125874126, 0.3973960683757957, 0.975979020979021, 0.21850752842931737], [0.19619680319680316, 1.0, 0.7177278561920575, 0.3923936063936063, 0.5285562071175588, 0.5885904095904096, 0.3955181534320658, 0.980984015984016, 0.21681721133386117], [0.19719780219780217, 1.0, 0.7165322593244923, 0.39439560439560434, 0.5268283594150563, 0.5915934065934066, 0.393648964541661, 0.985989010989011, 0.21513994987957213], [0.19819880119880115, 1.0, 0.7153388502313489, 0.3963976023976023, 0.525105936449589, 0.5945964035964036, 0.3917884612493196, 0.990994005994006, 0.21347564322908713], [0.19919980019980016, 1.0, 0.7141476260427193, 0.3983996003996003, 0.5233889216528298, 0.5975994005994006, 0.3899366032877642, 0.9959990009990011, 0.21182419132388883], [0.20020079920079917, 1.0, 0.7129585838939505, 0.40040159840159834, 0.5216772985084729, 0.6006023976023976, 0.3880933505768306, 1.0010039960039963, 0.21018549487829033], [0.20120179820179818, 1.0, 0.7117717209256351, 0.40240359640359635, 0.5199710505520759, 0.6036053946053946, 0.38625866322259933, 1.006008991008991, 0.20855945537346626], [0.20220279720279716, 1.0, 0.710587034283609, 0.4044055944055943, 0.518270161370902, 0.6066083916083916, 0.3844325015165328, 1.0110139860139862, 0.2069459750515292], [0.20320379620379617, 1.0, 0.7094045211189385, 0.40640759240759233, 0.5165746146037611, 0.6096113886113886, 0.38261482593461676, 1.0160189810189812, 0.20534495690965326], [0.20420479520479518, 1.0, 0.7082241785879182, 0.40840959040959035, 0.5148843939408527, 0.6126143856143856, 0.38080559713650297, 1.021023976023976, 0.2037563046942412], [0.20520579420579416, 1.0, 0.7070460038520635, 0.4104115884115883, 0.5131994831236093, 0.6156173826173826, 0.3790047759646593, 1.0260289710289712, 0.20217992289513909], [0.20620679320679317, 1.0, 0.7058699940781021, 0.41241358641358633, 0.5115198659445406, 0.6186203796203796, 0.3772123234435212, 1.0310339660339662, 0.20061571673989265], [0.20720779220779217, 1.0, 0.7046961464379675, 0.41441558441558435, 0.5098455262470752, 0.6216233766233766, 0.3754282007786493, 1.036038961038961, 0.19906359218805048], [0.20820879120879118, 1.0, 0.703524458108793, 0.41641758241758237, 0.5081764479254087, 0.6246263736263736, 0.373652369355889, 1.0410439560439562, 0.1975234559255104], [0.20920979020979016, 1.0, 0.7023549262729054, 0.41841958041958033, 0.5065126149243458, 0.6276293706293706, 0.3718847907405342, 1.0460489510489512, 0.19599521535890863], [0.21021078921078917, 1.0, 0.7011875481178159, 0.42042157842157835, 0.5048540112391475, 0.6306323676323676, 0.37012542667649717, 1.0510539460539463, 0.19447877861005383], [0.21121178821178818, 1.0, 0.7000223208362162, 0.42242357642357636, 0.5032006209153764, 0.6336353646353646, 0.36837423908547856, 1.0560589410589412, 0.19297405451040275], [0.21221278721278716, 1.0, 0.6988592416259699, 0.4244255744255743, 0.5015524280487429, 0.6366383616383616, 0.36663119006614475, 1.0610639360639362, 0.19148095259557965], [0.21321378621378617, 1.0, 0.6976983076901067, 0.42642757242757234, 0.4999094167849537, 0.6396413586413586, 0.3648962418933067, 1.0660689310689313, 0.18999938309993733], [0.21421478521478518, 1.0, 0.6965395162368144, 0.42842957042957036, 0.4982715713195578, 0.6426443556443556, 0.3631693570171039, 1.0710739260739262, 0.1885292569511603], [0.2152157842157842, 1.0, 0.6953828644794335, 0.4304315684315684, 0.49663887589779526, 0.6456473526473526, 0.3614504980621915, 1.0760789210789212, 0.1870704857649099], [0.21621678321678317, 1.0, 0.6942283496364505, 0.43243356643356634, 0.4950113148144454, 0.6486503496503496, 0.3597396278269312, 1.0810839160839163, 0.18562298183951054], [0.21721778221778218, 1.0, 0.6930759689314898, 0.43443556443556436, 0.49338887241367546, 0.6516533466533467, 0.3580367092825866, 1.0860889110889111, 0.184186658150677], [0.2182187812187812, 1.0, 0.6919257195933085, 0.4364375624375624, 0.49177153308889104, 0.6546563436563437, 0.3563417055725214, 1.0910939060939062, 0.18276142834628292], [0.21921978021978017, 1.0, 0.6907775988557899, 0.43843956043956034, 0.4901592812825843, 0.6576593406593407, 0.3546545800114019, 1.0960989010989013, 0.1813472067411684], [0.22022077922077918, 1.0, 0.689631603957935, 0.44044155844155836, 0.48855210148618594, 0.6606623376623377, 0.35297529608440265, 1.1011038961038964, 0.17994390831198964], [0.2212217782217782, 1.0, 0.6884877321438575, 0.4424435564435564, 0.4869499782399151, 0.6636653346653347, 0.35130381744641626, 1.1061088911088912, 0.17855144869210648], [0.2222227772227772, 1.0, 0.6873459806627766, 0.4444455544455544, 0.4853528961326307, 0.6666683316683317, 0.34964010792126754, 1.1111138861138863, 0.17716974416651077], [0.22322377622377618, 1.0, 0.6862063467690107, 0.44644755244755235, 0.4837608398016834, 0.6696713286713287, 0.34798413150092905, 1.1161188811188814, 0.1757987116667932], [0.22422477522477519, 1.0, 0.6850688277219703, 0.44844955044955037, 0.48217379393276816, 0.6726743256743257, 0.34633585234474346, 1.1211238761238762, 0.17443826876614912], [0.2252257742257742, 1.0, 0.6839334207861518, 0.4504515484515484, 0.4805917432597765, 0.6756773226773227, 0.34469523477864644, 1.1261288711288713, 0.1730883336744231], [0.22622677322677318, 1.0, 0.6828001232311307, 0.45245354645354635, 0.47901467256464914, 0.6786803196803197, 0.343062243294395, 1.1311338661338664, 0.17174882523319207], [0.22722777222777218, 1.0, 0.6816689323315553, 0.45445554445554437, 0.47744256667723123, 0.6816833166833167, 0.3414368425487999, 1.1361388611388612, 0.17041966291088523], [0.2282287712287712, 1.0, 0.6805398453671397, 0.4564575424575424, 0.4758754104751244, 0.6846863136863137, 0.3398189973629592, 1.1411438561438563, 0.16910076679794334], [0.2292297702297702, 1.0, 0.6794128596226582, 0.4584595404595404, 0.47431318888354285, 0.6876893106893107, 0.33820867272149757, 1.1461488511488513, 0.16779205760201382], [0.23023076923076918, 1.0, 0.6782879723879373, 0.46046153846153837, 0.47275588687516756, 0.6906923076923077, 0.3366058337718088, 1.1511538461538464, 0.16649345664318418], [0.2312317682317682, 1.0, 0.67716518095785, 0.4624635364635364, 0.47120348947000185, 0.6936953046953047, 0.3350104458233011, 1.1561588411588413, 0.16520488584925172], [0.2322327672327672, 1.0, 0.6760444826323102, 0.4644655344655344, 0.4696559817352273, 0.6966983016983017, 0.3334224743466458, 1.1611638361638363, 0.16392626775102917], [0.23323376623376618, 1.0, 0.6749258747162645, 0.46646753246753236, 0.46811334878506133, 0.6997012987012987, 0.33184188497303124, 1.1661688311688314, 0.16265752547768839], [0.2342347652347652, 1.0, 0.673809354519687, 0.4684695304695304, 0.4665755757806109, 0.7027042957042957, 0.330268643493418, 1.1711738261738263, 0.16139858275213773], [0.2352357642357642, 1.0, 0.6726949193575715, 0.4704715284715284, 0.46504264792973365, 0.7057072927072927, 0.3287027158577985, 1.1761788211788213, 0.16014936388643686], [0.23623676323676318, 1.0, 0.6715825665499269, 0.47247352647352636, 0.46351455048689266, 0.7087102897102897, 0.3271440681744603, 1.1811838161838164, 0.1589097937772462], [0.2372377622377622, 1.0, 0.6704722934217688, 0.4744755244755244, 0.4619912687530158, 0.7117132867132867, 0.32559266670925296, 1.1861888111888113, 0.15767979790131192], [0.2382387612387612, 1.0, 0.6693640973031151, 0.4764775224775224, 0.46047278807535447, 0.7147162837162837, 0.32404847788485713, 1.1911938061938063, 0.15645930231098523], [0.2392397602397602, 1.0, 0.6682579755289778, 0.4784795204795204, 0.458959093847342, 0.7177192807192807, 0.32251146828005833, 1.1961988011988014, 0.15524823362977694], [0.2402407592407592, 1.0, 0.667153925439357, 0.4804815184815184, 0.45745017150845374, 0.7207222777222777, 0.32098160462902353, 1.2012037962037965, 0.15404651904794564], [0.2412417582417582, 1.0, 0.6660519443792356, 0.4824835164835164, 0.455946006544067, 0.7237252747252747, 0.31945885382058103, 1.2062087912087913, 0.15285408631812109], [0.2422427572427572, 1.0, 0.6649520296985717, 0.4844855144855144, 0.4544465844853208, 0.7267282717282717, 0.31794318289750395, 1.2112137862137864, 0.15167086375095978], [0.2432437562437562, 1.0, 0.6638541787522922, 0.4864875124875124, 0.4529518909089774, 0.7297312687312688, 0.3164345590557968, 1.2162187812187815, 0.1504967802108355], [0.2442447552447552, 1.0, 0.6627583889002877, 0.4884895104895104, 0.4514619114372831, 0.7327342657342658, 0.3149329496439862, 1.2212237762237763, 0.14933176511156285], [0.2452457542457542, 1.0, 0.6616646575074044, 0.4904915084915084, 0.4499766317378303, 0.7357372627372628, 0.3134383221624127, 1.2262287712287714, 0.1481757484121528], [0.2462467532467532, 1.0, 0.6605729819434392, 0.4924935064935064, 0.44849603752341893, 0.7387402597402598, 0.3119506442625289, 1.2312337662337665, 0.14702866061260286], [0.2472477522477522, 1.0, 0.6594833595831329, 0.4944955044955044, 0.44702011455192053, 0.7417432567432568, 0.3104698837461985, 1.2362387612387613, 0.14589043274971755], [0.2482487512487512, 1.0, 0.6583957878061639, 0.4964975024975024, 0.4455488486261394, 0.7447462537462538, 0.3089960085649997, 1.2412437562437564, 0.14476099639296333], [0.2492497502497502, 1.0, 0.6573102639971417, 0.4984995004995004, 0.44408222559367694, 0.7477492507492508, 0.3075289868195312, 1.2462487512487515, 0.14364028364035406], [0.2502507492507492, 1.0, 0.6562267855456003, 0.5005014985014984, 0.4426202313467959, 0.7507522477522478, 0.3060687867587228, 1.2512537462537465, 0.14252822711436858], [0.25125174825174823, 1.0, 0.6551453498459932, 0.5025034965034965, 0.44116285182228376, 0.7537552447552448, 0.30461537677914685, 1.2562587412587414, 0.14142475995790052], [0.2522527472527472, 1.0, 0.6540659542976859, 0.5045054945054944, 0.4397100730013183, 0.7567582417582418, 0.3031687254243352, 1.2612637362637364, 0.14032981583023807], [0.2532537462537462, 1.0, 0.6529885963049495, 0.5065074925074924, 0.4382618809093323, 0.7597612387612388, 0.3017288013840978, 1.2662687312687315, 0.13924332890307628], [0.25425474525474523, 1.0, 0.6519132732769566, 0.5085094905094905, 0.4368182616158793, 0.7627642357642358, 0.3002955734938458, 1.2712737262737264, 0.13816523385655907], [0.2552557442557442, 1.0, 0.6508399826277715, 0.5105114885114884, 0.43537920123449864, 0.7657672327672328, 0.2988690107339163, 1.2762787212787214, 0.13709546587535218], [0.2562567432567432, 1.0, 0.649768721776347, 0.5125134865134864, 0.43394468592258395, 0.7687702297702298, 0.2974490822289012, 1.2812837162837165, 0.13603396064474652], [0.25725774225774223, 1.0, 0.6486994881465177, 0.5145154845154845, 0.43251470188124813, 0.7717732267732268, 0.29603575724697945, 1.2862887112887114, 0.13498065434679155], [0.2582587412587412, 1.0, 0.6476322791669915, 0.5165174825174824, 0.4310892353551918, 0.7747762237762238, 0.2946290051992508, 1.2912937062937064, 0.1339354836564586], [0.2592597402597402, 1.0, 0.6465670922713475, 0.5185194805194804, 0.4296682726325694, 0.7777792207792208, 0.29322879563907495, 1.2962987012987015, 0.1328983857378337], [0.2602607392607392, 1.0, 0.6455039248980255, 0.5205214785214785, 0.42825180004485897, 0.7807822177822178, 0.2918350982614119, 1.3013036963036964, 0.13186929824033974], [0.2612617382617382, 1.0, 0.6444427744903234, 0.5225234765234764, 0.4268398039667303, 0.7837852147852148, 0.29044788290216644, 1.3063086913086914, 0.1308481592949883], [0.2622627372627372, 1.0, 0.6433836384963878, 0.5245254745254744, 0.4254322708159136, 0.7867882117882118, 0.2890671195375348, 1.3113136863136865, 0.12983490751065968], [0.2632637362637362, 1.0, 0.6423265143692112, 0.5265274725274725, 0.42402918705306825, 0.7897912087912088, 0.2876927782833549, 1.3163186813186816, 0.12882948197041202], [0.2642647352647352, 1.0, 0.6412713995666234, 0.5285294705294704, 0.42263053918165366, 0.7927942057942058, 0.2863248293944609, 1.3213236763236764, 0.12783182222781958], [0.26526573426573424, 1.0, 0.6402182915512858, 0.5305314685314685, 0.4212363137477991, 0.7957972027972028, 0.28496324326403705, 1.3263286713286715, 0.12684186830333785], [0.2662667332667332, 1.0, 0.639167187790687, 0.5325334665334664, 0.4198464973401739, 0.7988001998001998, 0.28360799042297863, 1.3313336663336666, 0.12585956068069815], [0.2672677322677322, 1.0, 0.6381180857571346, 0.5345354645354644, 0.4184610765898585, 0.8018031968031968, 0.28225904153925396, 1.3363386613386614, 0.12488484030332922], [0.26826873126873124, 1.0, 0.6370709829277491, 0.5365374625374625, 0.4170800381702164, 0.8048061938061939, 0.2809163674172689, 1.3413436563436565, 0.12391764857080693], [0.2692697302697302, 1.0, 0.6360258767844608, 0.5385394605394604, 0.4157033687967652, 0.8078091908091909, 0.2795799389972357, 1.3463486513486516, 0.12295792733533095], [0.2702707292707292, 1.0, 0.6349827648140002, 0.5405414585414584, 0.4143310552270496, 0.8108121878121879, 0.278249727354543, 1.3513536463536464, 0.12200561889822921], [0.27127172827172824, 1.0, 0.6339416445078937, 0.5425434565434565, 0.4129630842605135, 0.8138151848151849, 0.2769257036991317, 1.3563586413586415, 0.12106066600648878], [0.2722727272727272, 1.0, 0.6329025133624568, 0.5445454545454544, 0.4115994427383731, 0.8168181818181819, 0.2756078393748692, 1.3613636363636366, 0.1201230118493138], [0.2732737262737262, 1.0, 0.6318653688787891, 0.5465474525474524, 0.4102401175434903, 0.8198211788211789, 0.27429610585893194, 1.3663686313686316, 0.11919260005471029], [0.27427472527472524, 1.0, 0.6308302085627677, 0.5485494505494505, 0.40888509560024705, 0.8228241758241759, 0.2729904747611858, 1.3713736263736265, 0.11826937468609663], [0.2752757242757242, 1.0, 0.6297970299250406, 0.5505514485514484, 0.4075343638744187, 0.8258271728271729, 0.27169091782357324, 1.3763786213786215, 0.11735328023894107], [0.2762767232767232, 1.0, 0.6287658304810223, 0.5525534465534464, 0.4061879093730492, 0.8288301698301699, 0.2703974069195009, 1.3813836163836166, 0.11644426163742438], [0.27727772227772224, 1.0, 0.627736607750886, 0.5545554445554445, 0.404845719144326, 0.8318331668331669, 0.2691099140532309, 1.3863886113886115, 0.11554226423112902], [0.2782787212787212, 1.0, 0.626709359259559, 0.5565574425574424, 0.403507780277455, 0.8348361638361639, 0.26782841135927543, 1.3913936063936065, 0.11464723379175339], [0.27927972027972026, 1.0, 0.6256840825367161, 0.5585594405594405, 0.4021740799025379, 0.8378391608391609, 0.2665528711017927, 1.3963986013986016, 0.11375911650985156], [0.28028071928071924, 1.0, 0.6246607751167741, 0.5605614385614385, 0.40084460519044623, 0.8408421578421579, 0.2652832656739878, 1.4014035964035965, 0.11287785899159831], [0.2812817182817182, 1.0, 0.6236394345388848, 0.5625634365634364, 0.3995193433526994, 0.8438451548451549, 0.2640195675975142, 1.4064085914085915, 0.11200340825557915], [0.28228271728271725, 1.0, 0.6226200583469309, 0.5645654345654345, 0.39819828164134125, 0.8468481518481519, 0.26276174952187986, 1.4114135864135866, 0.11113571172960483], [0.28328371628371624, 1.0, 0.6216026440895182, 0.5665674325674325, 0.3968814073488172, 0.8498511488511489, 0.2615097842238548, 1.4164185814185817, 0.11027471724755099], [0.2842847152847152, 1.0, 0.6205871893199705, 0.5685694305694304, 0.3955687078078531, 0.8528541458541459, 0.2602636446068814, 1.4214235764235765, 0.10942037304622168], [0.28528571428571425, 1.0, 0.6195736915963246, 0.5705714285714285, 0.39426017039133177, 0.8558571428571429, 0.25902330370048915, 1.4264285714285716, 0.10857262776223742], [0.28628671328671323, 1.0, 0.6185621484813226, 0.5725734265734265, 0.3929557825121724, 0.8588601398601399, 0.2577887346597102, 1.4314335664335667, 0.10773143042894728], [0.2872877122877122, 1.0, 0.6175525575424078, 0.5745754245754244, 0.3916555316232097, 0.8618631368631369, 0.25655991076449847, 1.4364385614385615, 0.10689673047336468], [0.28828871128871125, 1.0, 0.6165449163517182, 0.5765774225774225, 0.39035940521707274, 0.8648661338661339, 0.2553368054191511, 1.4414435564435566, 0.10606847771312693], [0.28928971028971023, 1.0, 0.6155392224860796, 0.5785794205794205, 0.3890673908260646, 0.8678691308691309, 0.2541193921517331, 1.4464485514485517, 0.10524662235347836], [0.2902907092907092, 1.0, 0.6145354735270017, 0.5805814185814184, 0.3877794760220433, 0.8708721278721279, 0.25290764461350457, 1.4514535464535465, 0.10443111498427653], [0.29129170829170825, 1.0, 0.6135336670606709, 0.5825834165834165, 0.3864956484163013, 0.8738751248751249, 0.25170153657835004, 1.4564585414585416, 0.10362190657702162], [0.29229270729270723, 1.0, 0.6125338006779449, 0.5845854145854145, 0.3852158956594461, 0.8768781218781219, 0.2505010419422108, 1.4614635364635367, 0.10281894848190898], [0.29329370629370627, 1.0, 0.6115358719743467, 0.5865874125874125, 0.38394020544128254, 0.8798811188811189, 0.24930613472252058, 1.4664685314685317, 0.10202219242490441], [0.29429470529470525, 1.0, 0.6105398785500596, 0.5885894105894105, 0.38266856549069367, 0.882884115884116, 0.24811678905764264, 1.4714735264735266, 0.1012315905048415], [0.29529570429570423, 1.0, 0.6095458180099204, 0.5905914085914085, 0.38140096357552306, 0.885887112887113, 0.24693297920631016, 1.4764785214785217, 0.10044709519054204], [0.29629670329670327, 1.0, 0.6085536879634138, 0.5925934065934065, 0.38013738750245635, 0.88889010989011, 0.24575467954706898, 1.4814835164835167, 0.0996686593179586], [0.29729770229770225, 1.0, 0.6075634860246681, 0.5945954045954045, 0.3788778251169052, 0.891893106893107, 0.24458186457772363, 1.4864885114885116, 0.09889623608733879], [0.29829870129870123, 1.0, 0.6065752098124472, 0.5965974025974025, 0.3776222643028895, 0.894896103896104, 0.2434145089147844, 1.4914935064935066, 0.09812977906041163], [0.29929970029970027, 1.0, 0.6055888569501463, 0.5985994005994005, 0.3763706929829209, 0.897899100899101, 0.24225258729291896, 1.4964985014985017, 0.09736924215759579], [0.30030069930069925, 1.0, 0.6046044250657865, 0.6006013986013985, 0.3751230991178871, 0.900902097902098, 0.24109607456440507, 1.5015034965034966, 0.09661457965522931], [0.30130169830169823, 1.0, 0.603621911792007, 0.6026033966033965, 0.3738794707069356, 0.903905094905095, 0.23994494569858632, 1.5065084915084916, 0.09586574618282043], [0.30230269730269727, 1.0, 0.6026413147660622, 0.6046053946053945, 0.37263979578735845, 0.906908091908092, 0.23879917578133028, 1.5115134865134867, 0.09512269672032019], [0.30330369630369625, 1.0, 0.6016626316298146, 0.6066073926073925, 0.3714040624344769, 0.909911088911089, 0.23765874001448958, 1.5165184815184818, 0.09438538659541564], [0.3043046953046952, 1.0, 0.6006858600297282, 0.6086093906093905, 0.3701722587615266, 0.912914085914086, 0.23652361371536482, 1.5215234765234766, 0.09365377148084428], [0.30530569430569426, 1.0, 0.5997109976168651, 0.6106113886113885, 0.36894437291954446, 0.915917082917083, 0.2353937723161708, 1.5265284715284717, 0.09292780739172894], [0.30630669330669325, 1.0, 0.5987380420468775, 0.6126133866133865, 0.36772039309725335, 0.91892007992008, 0.23426919136350446, 1.5315334665334668, 0.09220745068293348], [0.3073076923076922, 1.0, 0.5977669909800042, 0.6146153846153845, 0.3665003075209485, 0.921923076923077, 0.23314984651781565, 1.5365384615384616, 0.09149265804643883], [0.30830869130869126, 1.0, 0.5967978420810637, 0.6166173826173825, 0.3652841044543853, 0.924926073926074, 0.23203571355288052, 1.5415434565434567, 0.0907833865087392], [0.30930969030969024, 1.0, 0.5958305930194477, 0.6186193806193805, 0.36407177219866543, 0.927929070929071, 0.23092676835527698, 1.5465484515484518, 0.09007959342825872], [0.3103106893106893, 1.0, 0.5948652414691178, 0.6206213786213786, 0.3628632990921249, 0.930932067932068, 0.2298229869238631, 1.5515534465534466, 0.08938123649278763], [0.31131168831168826, 1.0, 0.5939017851085985, 0.6226233766233765, 0.3616586735102213, 0.933935064935065, 0.22872434536925731, 1.5565584415584417, 0.08868827371693853], [0.31231268731268724, 1.0, 0.5929402216209722, 0.6246253746253745, 0.3604578838654226, 0.936938061938062, 0.22763081991332146, 1.5615634365634368, 0.0880006634396222], [0.3133136863136863, 1.0, 0.5919805486938723, 0.6266273726273726, 0.35926091860709536, 0.939941058941059, 0.22654238688864659, 1.5665684315684318, 0.08731836432154294], [0.31431468531468526, 1.0, 0.5910227640194797, 0.6286293706293705, 0.35806776622139325, 0.942944055944056, 0.2254590227380398, 1.5715734265734267, 0.08664133534271314], [0.31531568431568424, 1.0, 0.5900668652945151, 0.6306313686313685, 0.3568784152311476, 0.945947052947053, 0.22438070401401541, 1.5765784215784218, 0.0859695357999873], [0.3163166833166833, 1.0, 0.5891128502202353, 0.6326333666333666, 0.3556928541957554, 0.94895004995005, 0.2233074073782868, 1.5815834165834168, 0.08530292530461495], [0.31731768231768226, 1.0, 0.5881607165024265, 0.6346353646353645, 0.3545110717110704, 0.9519530469530469, 0.2222391096012615, 1.5865884115884117, 0.08464146377981219], [0.31831868131868124, 1.0, 0.5872104618513999, 0.6366373626373625, 0.35333305640929247, 0.9549560439560439, 0.22117578756153844, 1.5915934065934068, 0.08398511145835272], [0.3193196803196803, 1.0, 0.5862620839819845, 0.6386393606393606, 0.35215879695885915, 0.9579590409590409, 0.2201174182454074, 1.5965984015984018, 0.08333382888017662], [0.32032067932067926, 1.0, 0.5853155806135233, 0.6406413586413585, 0.35098828206433624, 0.960962037962038, 0.21906397874635125, 1.6016033966033967, 0.08268757689001818], [0.32132167832167824, 1.0, 0.5843709494698661, 0.6426433566433565, 0.34982150046630867, 0.963965034965035, 0.21801544626454997, 1.6066083916083918, 0.0820463166350519], [0.3223226773226773, 1.0, 0.5834281882793665, 0.6446453546453546, 0.3486584409412734, 0.966968031968032, 0.21697179810638687, 1.6116133866133868, 0.08141000956255655], [0.32332367632367626, 1.0, 0.582487294774874, 0.6466473526473525, 0.3474990923015306, 0.969971028971029, 0.21593301168395798, 1.616618381618382, 0.08077861741759745], [0.3243246753246753, 1.0, 0.5815482666937298, 0.6486493506493506, 0.3463434433950757, 0.972974025974026, 0.21489906451458288, 1.6216233766233767, 0.08015210224072661], [0.3253256743256743, 1.0, 0.5806111017777611, 0.6506513486513485, 0.3451914831054931, 0.975977022977023, 0.21386993422031808, 1.6266283716283718, 0.07953042636570037], [0.32632667332667326, 1.0, 0.5796757977732752, 0.6526533466533465, 0.3440432003518486, 0.97898001998002, 0.212845598527473, 1.6316333666333669, 0.0789135524172153], [0.3273276723276723, 1.0, 0.5787423524310551, 0.6546553446553446, 0.34289858408858315, 0.981983016983017, 0.2118260352661275, 1.6366383616383617, 0.07830144330866069], [0.3283286713286713, 1.0, 0.577810763506353, 0.6566573426573425, 0.34175762330540543, 0.984986013986014, 0.2108112223696521, 1.6416433566433568, 0.07769406223988942], [0.32932967032967025, 1.0, 0.5768810287588859, 0.6586593406593405, 0.34062030702718815, 0.987989010989011, 0.20980113787423077, 1.6466483516483519, 0.07709137269500511], [0.3303306693306693, 1.0, 0.5759531459528293, 0.6606613386613386, 0.3394866243138607, 0.990992007992008, 0.20879575991838512, 1.6516533466533467, 0.07649333844016694], [0.33133166833166827, 1.0, 0.5750271128568125, 0.6626633366633365, 0.3383565642603042, 0.993995004995005, 0.20779506674250134, 1.6566583416583418, 0.07589992352141124], [0.33233266733266725, 1.0, 0.5741029272439125, 0.6646653346653345, 0.3372301159962473, 0.996998001998002, 0.20679903668835953, 1.6616633366633369, 0.07531109226248997], [0.3333336663336663, 1.0, 0.5731805868916502, 0.6666673326673326, 0.33610726868616086, 1.0000009990009993, 0.20580764819866473, 1.666668331668332, 0.07472680926272583], [0.33433466533466527, 1.0, 0.5722600895819829, 0.6686693306693305, 0.3349880115291544, 1.0030039960039963, 0.2048208798165801, 1.6716733266733268, 0.07414703939488392], [0.33533566433566425, 1.0, 0.5713414331013001, 0.6706713286713285, 0.3338723337588714, 1.0060069930069933, 0.20383871018526326, 1.6766783216783219, 0.07357174780306003], [0.3363366633366633, 1.0, 0.5704246152404188, 0.6726733266733266, 0.33276022464338656, 1.0090099900099903, 0.20286111804740306, 1.681683316683317, 0.07300089990058481], [0.33733766233766227, 1.0, 0.5695096337945771, 0.6746753246753245, 0.3316516734851018, 1.0120129870129873, 0.20188808224476026, 1.6866883116883118, 0.07243446136794474], [0.3383386613386613, 1.0, 0.5685964865634292, 0.6766773226773226, 0.33054666962064405, 1.0150159840159843, 0.20091958171770963, 1.6916933066933069, 0.07187239815071851], [0.3393396603396603, 1.0, 0.5676851713510404, 0.6786793206793206, 0.32944520242076214, 1.0180189810189813, 0.19995559550478353, 1.696698301698302, 0.07131467645753], [0.34034065934065927, 1.0, 0.5667756859658819, 0.6806813186813185, 0.32834726129022473, 1.0210219780219782, 0.19899610274221888, 1.7017032967032968, 0.07076126275801645], [0.3413416583416583, 1.0, 0.5658680282208248, 0.6826833166833166, 0.3272528356677191, 1.0240249750249752, 0.19804108266350504, 1.7067082917082919, 0.07021212378081283], [0.3423426573426573, 1.0, 0.5649621959331352, 0.6846853146853146, 0.32616191502574754, 1.0270279720279722, 0.19709051459893495, 1.711713286713287, 0.06966722651155131], [0.34334365634365627, 1.0, 0.5640581869244702, 0.6866873126873125, 0.32507448887052887, 1.0300309690309692, 0.19614437797515705, 1.716718281718282, 0.06912653819087665], [0.3443446553446553, 1.0, 0.5631559990208701, 0.6886893106893106, 0.32399054674189515, 1.0330339660339662, 0.19520265231473088, 1.7217232767232769, 0.0685900263124766], [0.3453456543456543, 1.0, 0.5622556300527556, 0.6906913086913086, 0.32291007821319256, 1.0360369630369632, 0.19426531723568316, 1.726728271728272, 0.06805765862112766], [0.34634665334665327, 1.0, 0.5613570778549204, 0.6926933066933065, 0.3218330728911801, 1.0390399600399602, 0.193332352451067, 1.731733266733267, 0.0675294031107558], [0.3473476523476523, 1.0, 0.5604603402665287, 0.6946953046953046, 0.3207595204159304, 1.0420429570429572, 0.19240373776852263, 1.7367382617382618, 0.0670052280225123], [0.3483486513486513, 1.0, 0.5595654151311075, 0.6966973026973026, 0.31968941046072946, 1.0450459540459542, 0.19147945308984066, 1.741743256743257, 0.06648510184286444], [0.34934965034965026, 1.0, 0.558672300296542, 0.6986993006993005, 0.31862273273197733, 1.0480489510489512, 0.19055947841052664, 1.746748251748252, 0.06596899330170083], [0.3503506493506493, 1.0, 0.5577809936150717, 0.7007012987012986, 0.31755947696909004, 1.0510519480519482, 0.1896437938193688, 1.7517532467532468, 0.06545687137045145], [0.3513516483516483, 1.0, 0.5568914929432841, 0.7027032967032966, 0.3164996329443995, 1.0540549450549452, 0.1887323794980062, 1.756758241758242, 0.06494870526022234], [0.35235264735264726, 1.0, 0.5560037961421098, 0.7047052947052945, 0.31544319046305613, 1.0570579420579422, 0.18782521572050065, 1.761763236763237, 0.06444446441994436], [0.3533536463536463, 1.0, 0.5551179010768169, 0.7067072927072926, 0.3143901393629305, 1.0600609390609392, 0.18692228285290907, 1.766768231768232, 0.06394411853453655], [0.3543546453546453, 1.0, 0.5542338056170073, 0.7087092907092906, 0.31334046951451533, 1.0630639360639362, 0.18602356135285927, 1.771773226773227, 0.0634476375230836], [0.3553556443556443, 1.0, 0.5533515076366088, 0.7107112887112886, 0.31229417082082844, 1.0660669330669332, 0.18512903176912637, 1.776778221778222, 0.06295499153702735], [0.3563566433566433, 1.0, 0.5524710050138736, 0.7127132867132866, 0.3112512332173153, 1.0690699300699302, 0.18423867474121208, 1.781783216783217, 0.062466150958372345], [0.3573576423576423, 1.0, 0.5515922956313706, 0.7147152847152846, 0.31021164667175266, 1.0720729270729272, 0.18335247099892568, 1.786788211788212, 0.06198108639790499], [0.3583586413586413, 1.0, 0.5507153773759811, 0.7167172827172826, 0.3091754011841514, 1.0750759240759242, 0.1824704013619667, 1.791793206793207, 0.06149976869342697], [0.3593596403596403, 1.0, 0.549840248138894, 0.7187192807192806, 0.30814248678666106, 1.0780789210789212, 0.18159244673951047, 1.796798201798202, 0.06102216890800178], [0.3603606393606393, 1.0, 0.5489669058155999, 0.7207212787212786, 0.30711289354347315, 1.0810819180819182, 0.18071858812979408, 1.801803196803197, 0.06054825832821511], [0.3613616383616383, 1.0, 0.548095348305887, 0.7227232767232766, 0.30608661155072664, 1.0840849150849152, 0.17984880661970548, 1.806808191808192, 0.0600780084624486], [0.3623626373626373, 1.0, 0.5472255735138355, 0.7247252747252746, 0.30506363093641153, 1.0870879120879122, 0.1789830833843746, 1.811813186813187, 0.05961139103916692], [0.3633636363636363, 1.0, 0.5463575793478123, 0.7267272727272726, 0.3040439418602747, 1.0900909090909092, 0.17812139968676502, 1.816818181818182, 0.059148378005218036], [0.3643646353646353, 1.0, 0.5454913637204671, 0.7287292707292706, 0.30302753451372505, 1.0930939060939062, 0.1772637368772691, 1.821823176823177, 0.05868894152414663], [0.3653656343656343, 1.0, 0.544626924548726, 0.7307312687312686, 0.30201439911973865, 1.0960969030969032, 0.17641007639330428, 1.826828171828172, 0.058233053974520686], [0.3663666333666333, 1.0, 0.5437642597537874, 0.7327332667332666, 0.3010045259327657, 1.0990999000999002, 0.17556039975891108, 1.831833166833167, 0.05778068794827071], [0.3673676323676323, 1.0, 0.5429033672611168, 0.7347352647352646, 0.2999979052386358, 1.1021028971028972, 0.17471468858435332, 1.836838161838162, 0.05733181624904212], [0.3683686313686313, 1.0, 0.5420442450004415, 0.7367372627372626, 0.2989945273544652, 1.1051058941058942, 0.17387292456572007, 1.841843156843157, 0.05688641189056014], [0.36936963036963033, 1.0, 0.5411868909057458, 0.7387392607392607, 0.29799438262856304, 1.1081088911088912, 0.17303508948452978, 1.846848151848152, 0.05644444809500722], [0.3703706293706293, 1.0, 0.5403313029152663, 0.7407412587412586, 0.29699746144033906, 1.1111118881118882, 0.1722011652073356, 1.851853146853147, 0.056005898291413454], [0.3713716283716283, 1.0, 0.5394774789714866, 0.7427432567432566, 0.2960037542002112, 1.1141148851148852, 0.171371133685333, 1.856858141858142, 0.055570736114058814], [0.37237262737262733, 1.0, 0.5386254170211328, 0.7447452547452547, 0.2950132513495123, 1.1171178821178822, 0.17054497695396933, 1.861863136863137, 0.05513893540088825], [0.3733736263736263, 1.0, 0.5377751150151677, 0.7467472527472526, 0.29402594336039956, 1.1201208791208792, 0.16972267713255465, 1.8668681318681322, 0.05471047019193874], [0.3743746253746253, 1.0, 0.5369265709087867, 0.7487492507492506, 0.29304182073576146, 1.1231238761238762, 0.1689042164238753, 1.871873126873127, 0.05428531472777853], [0.37537562437562433, 1.0, 0.5360797826614127, 0.7507512487512487, 0.29206087400912756, 1.1261268731268732, 0.1680895771138082, 1.876878121878122, 0.0538634434479586], [0.3763766233766233, 1.0, 0.5352347482366908, 0.7527532467532466, 0.29108309374457725, 1.1291298701298702, 0.16727874157093758, 1.8818831168831172, 0.05344483098947585], [0.3773776223776223, 1.0, 0.534391465602484, 0.7547552447552446, 0.2901084705366481, 1.1321328671328672, 0.16647169224617353, 1.886888111888112, 0.0530294521852483], [0.3783786213786213, 1.0, 0.5335499327308675, 0.7567572427572427, 0.28913699501024664, 1.1351358641358642, 0.16566841167237195, 1.891893106893107, 0.05261728206260206], [0.3793796203796203, 1.0, 0.5327101475981246, 0.7587592407592406, 0.28816865782055723, 1.1381388611388612, 0.16486888246395687, 1.8968981018981022, 0.05220829584176993], [0.3803806193806193, 1.0, 0.5318721081847423, 0.7607612387612386, 0.2872034496529525, 1.1411418581418582, 0.16407308731654363, 1.901903096903097, 0.051802468934401706], [0.3813816183816183, 1.0, 0.5310358124754049, 0.7627632367632367, 0.2862413612229041, 1.1441448551448552, 0.16328100900656484, 1.906908091908092, 0.05139977694208574], [0.3823826173826173, 1.0, 0.5302012584589892, 0.7647652347652346, 0.2852823832758927, 1.1471478521478522, 0.16249263039089742, 1.9119130869130871, 0.05100019565488237], [0.3833836163836163, 1.0, 0.5293684441285622, 0.7667672327672326, 0.2843265065873194, 1.1501508491508494, 0.16170793440649156, 1.916918081918082, 0.05060370104986825], [0.3843846153846153, 1.0, 0.5285373674813728, 0.7687692307692306, 0.2833737219624171, 1.1531538461538464, 0.1609269040700015, 1.921923076923077, 0.05021026928969203], [0.3853856143856143, 1.0, 0.5277080265188501, 0.7707712287712286, 0.28242402023616153, 1.1561568431568434, 0.16014952247741782, 1.9269280719280721, 0.04981987672114148], [0.38638661338661334, 1.0, 0.5268804192465961, 0.7727732267732267, 0.281477392273184, 1.1591598401598404, 0.15937577280370172, 1.9319330669330672, 0.049432499873721183], [0.3873876123876123, 1.0, 0.5260545436743831, 0.7747752247752246, 0.2805338289676821, 1.1621628371628374, 0.1586056383024207, 1.936938061938062, 0.049048115458241594], [0.3883886113886113, 1.0, 0.5252303978161464, 0.7767772227772226, 0.27959332124333397, 1.1651658341658344, 0.1578391023053863, 1.9419430569430571, 0.048666700365418994], [0.38938961038961034, 1.0, 0.524407979689982, 0.7787792207792207, 0.278655860053209, 1.1681688311688314, 0.15707614822229324, 1.9469480519480522, 0.048288231664486016], [0.3903906093906093, 1.0, 0.5235872873181406, 0.7807812187812186, 0.2777214363796828, 1.1711718281718284, 0.15631675954036053, 1.951953046953047, 0.04791268660181302], [0.3913916083916083, 1.0, 0.5227683187270221, 0.7827832167832166, 0.2767900412343484, 1.1741748251748254, 0.15556091982397355, 1.9569580419580421, 0.04754004259954031], [0.39239260739260734, 1.0, 0.521951071947173, 0.7847852147852147, 0.27586166565793174, 1.1771778221778224, 0.15480861271432927, 1.9619630369630372, 0.04717027725422058], [0.3933936063936063, 1.0, 0.5211355450132794, 0.7867872127872126, 0.27493630072020436, 1.1801808191808194, 0.1540598219290813, 1.966968031968032, 0.04680336833547203], [0.3943946053946053, 1.0, 0.5203217359641642, 0.7887892107892106, 0.27401393751989717, 1.1831838161838164, 0.1533145312619877, 1.9719730269730271, 0.046439293784642025], [0.39539560439560434, 1.0, 0.5195096428427807, 0.7907912087912087, 0.2730945671846161, 1.1861868131868134, 0.15257272458256066, 1.9769780219780222, 0.0460780317134807], [0.3963966033966033, 1.0, 0.5186992636962087, 0.7927932067932066, 0.2721781808707556, 1.1891898101898104, 0.15183438583571676, 1.9819830169830173, 0.04571956040282525], [0.3973976023976023, 1.0, 0.5178905965756498, 0.7947952047952046, 0.27126476976341446, 1.1921928071928074, 0.15109949904143008, 1.9869880119880121, 0.04536385830129399], [0.39839860139860134, 1.0, 0.5170836395364236, 0.7967972027972027, 0.2703543250763098, 1.1951958041958044, 0.15036804829438594, 1.9919930069930072, 0.04501090402399078], [0.3993996003996003, 1.0, 0.5162783906379608, 0.7987992007992006, 0.26944683805169417, 1.1981988011988014, 0.14964001776363664, 1.9969980019980023, 0.04466067635121933], [0.40040059940059936, 1.0, 0.5154748479438005, 0.8008011988011987, 0.26854229996027, 1.2012017982017984, 0.14891539169225926, 2.002002997002997, 0.04431315422720747], [0.40140159840159834, 1.0, 0.5146730095215848, 0.8028031968031967, 0.26764070210110624, 1.2042047952047954, 0.14819415439701408, 2.0070079920079924, 0.04396831675884133], [0.4024025974025973, 1.0, 0.5138728734430545, 0.8048051948051946, 0.26674203580155453, 1.2072077922077924, 0.14747629026800566, 2.0120129870129873, 0.04362614321440909], [0.40340359640359635, 1.0, 0.5130744377840433, 0.8068071928071927, 0.2658462924171653, 1.2102107892107894, 0.14676178376834445, 2.017017982017982, 0.04328661302235472], [0.40440459540459534, 1.0, 0.5122777006244751, 0.8088091908091907, 0.264953463331606, 1.2132137862137864, 0.1460506194338109, 2.0220229770229774, 0.0429497057700412], [0.4054055944055943, 1.0, 0.5114826600483575, 0.8108111888111886, 0.26406353995657633, 1.2162167832167834, 0.14534278187252073, 2.0270279720279722, 0.042615401202523266], [0.40640659340659335, 1.0, 0.5106893141437785, 0.8128131868131867, 0.26317651373172735, 1.2192197802197804, 0.14463825576459166, 2.032032967032967, 0.042283679221329626], [0.40740759240759233, 1.0, 0.509897661002902, 0.8148151848151847, 0.2622923761245782, 1.2222227772227774, 0.14393702586181198, 2.0370379620379624, 0.04195451988325483], [0.4084085914085913, 1.0, 0.5091076987219615, 0.8168171828171826, 0.26141111863043354, 1.2252257742257744, 0.1432390769873105, 2.0420429570429572, 0.04162790339916004], [0.40940959040959035, 1.0, 0.5083194254012577, 0.8188191808191807, 0.26053273277230343, 1.2282287712287714, 0.14254439403522778, 2.047047952047952, 0.04130381013278348], [0.41041058941058933, 1.0, 0.507532839145152, 0.8208211788211787, 0.2596572101008202, 1.2312317682317684, 0.14185296197038985, 2.0520529470529474, 0.040982220599559784], [0.4114115884115883, 1.0, 0.5067479380620638, 0.8228231768231766, 0.2587845421941577, 1.2342347652347654, 0.14116476582798204, 2.0570579420579422, 0.04066311546544862], [0.41241258741258735, 1.0, 0.5059647202644636, 0.8248251748251747, 0.25791472065795057, 1.2372377622377624, 0.1404797907132257, 2.062062937062937, 0.04034647554577242], [0.41341358641358633, 1.0, 0.5051831838688715, 0.8268271728271727, 0.257047737125213, 1.2402407592407594, 0.13979802180105538, 2.0670679320679324, 0.04003228180406277], [0.41441458541458537, 1.0, 0.5044033269958497, 0.8288291708291707, 0.25618358325625873, 1.2432437562437564, 0.13911944433579831, 2.0720729270729272, 0.03972051535091617], [0.41541558441558435, 1.0, 0.5036251477700003, 0.8308311688311687, 0.2553222507386206, 1.2462467532467534, 0.13844404363085486, 2.077077922077922, 0.03941115744285825], [0.41641658341658333, 1.0, 0.5028486443199593, 0.8328331668331667, 0.2544637312869701, 1.2492497502497504, 0.13777180506838071, 2.0820829170829174, 0.039104189481216974], [0.41741758241758237, 1.0, 0.5020738147783925, 0.8348351648351647, 0.25360801664303884, 1.2522527472527474, 0.13710271409897046, 2.0870879120879122, 0.03879959301100443], [0.41841858141858135, 1.0, 0.5013006572819914, 0.8368371628371627, 0.25275509857553813, 1.2552557442557444, 0.13643675624134277, 2.092092907092907, 0.03849734971980737], [0.41941958041958033, 1.0, 0.5005291699714688, 0.8388391608391607, 0.25190496888008, 1.2582587412587414, 0.13577391708202705, 2.0970979020979024, 0.03819744143668622], [0.42042057942057937, 1.0, 0.4997593509915527, 0.8408411588411587, 0.25105761937909865, 1.2612617382617384, 0.13511418227505112, 2.102102897102897, 0.037899850131082644], [0.42142157842157835, 1.0, 0.4989911984909845, 0.8428431568431567, 0.2502130419217711, 1.2642647352647354, 0.13445753754163112, 2.1071078921078925, 0.03760455791173563], [0.42242257742257733, 1.0, 0.49822471062251256, 0.8448451548451547, 0.24937122838393966, 1.2672677322677324, 0.13380396866986238, 2.1121128871128874, 0.037311547025605664], [0.42342357642357636, 1.0, 0.49745988554288795, 0.8468471528471527, 0.24853217066803313, 1.2702707292707294, 0.13315346151441163, 2.117117882117882, 0.03702079985680761], [0.42442457542457535, 1.0, 0.49669672141286075, 0.8488491508491507, 0.24769586070298907, 1.2732737262737264, 0.1325060019962111, 2.1221228771228775, 0.03673229892555159], [0.4254255744255743, 1.0, 0.4959352163971758, 0.8508511488511487, 0.24686229044417624, 1.2762767232767234, 0.13186157610215365, 2.1271278721278724, 0.03644602688709197], [0.42642657342657336, 1.0, 0.49517536866456685, 0.8528531468531467, 0.2460314518733171, 1.2792797202797204, 0.13122016988478952, 2.132132867132867, 0.0361619665306848], [0.42742757242757234, 1.0, 0.49441717638775334, 0.8548551448551447, 0.24520333699841107, 1.2822827172827174, 0.13058176946202452, 2.1371378621378625, 0.035880100778552894], [0.4284285714285713, 1.0, 0.4936606377434364, 0.8568571428571427, 0.244377937853657, 1.2852857142857144, 0.12994636101681947, 2.1421428571428573, 0.035600412684859285], [0.42942957042957036, 1.0, 0.492905750912293, 0.8588591408591407, 0.24355524649937688, 1.2882887112887114, 0.12931393079689124, 2.147147852147852, 0.03532288543468828], [0.43043056943056934, 1.0, 0.49215251407897326, 0.8608611388611387, 0.2427352550219398, 1.2912917082917084, 0.128684465114415, 2.1521528471528475, 0.03504750234303468], [0.4314315684315684, 1.0, 0.4914009254320941, 0.8628631368631368, 0.2419179555336852, 1.2942947052947054, 0.12805795034572812, 2.1571578421578423, 0.034774246853800594], [0.43243256743256736, 1.0, 0.4906509831642368, 0.8648651348651347, 0.2411033401728473, 1.2972977022977024, 0.1274343729310353, 2.162162837162837, 0.03450310253880009], [0.43343356643356634, 1.0, 0.489902685471942, 0.8668671328671327, 0.2402914011034795, 1.3003006993006994, 0.1268137193741149, 2.1671678321678325, 0.03423405309677158], [0.4344345654345654, 1.0, 0.4891560305557043, 0.8688691308691308, 0.2394821305153793, 1.3033036963036964, 0.12619597624202708, 2.1721728271728273, 0.03396708235239766], [0.43543556443556436, 1.0, 0.48841101661996966, 0.8708711288711287, 0.23867552062401243, 1.3063066933066936, 0.12558113016482295, 2.177177822177822, 0.03370217425533281], [0.43643656343656334, 1.0, 0.4876676418731303, 0.8728731268731267, 0.23787156367043866, 1.3093096903096906, 0.1249691678352551, 2.1821828171828175, 0.03343931287923836], [0.4374375624375624, 1.0, 0.48692590452751944, 0.8748751248751248, 0.23707025192123665, 1.3123126873126876, 0.12436007600848979, 2.1871878121878123, 0.03317848242082497], [0.43843856143856136, 1.0, 0.4861858027994093, 0.8768771228771227, 0.23627157766842993, 1.3153156843156846, 0.12375384150182017, 2.192192807192807, 0.03291966719890255], [0.43943956043956034, 1.0, 0.4854473349090044, 0.8788791208791207, 0.23547553322941275, 1.3183186813186816, 0.12315045119438102, 2.1971978021978025, 0.03266285165343751], [0.4404405594405594, 1.0, 0.4847104990804382, 0.8808811188811188, 0.23468211094687574, 1.3213216783216786, 0.1225498920268647, 2.2022027972027973, 0.03240802034461738], [0.44144155844155836, 1.0, 0.48397529354176955, 0.8828831168831167, 0.23389130318873314, 1.3243246753246756, 0.12195215100123857, 2.2072077922077926, 0.03215515795192234], [0.44244255744255734, 1.0, 0.48324171652497766, 0.8848851148851147, 0.23310310234804793, 1.3273276723276726, 0.12135721518046359, 2.2122127872127875, 0.0319042492732044], [0.4434435564435564, 1.0, 0.48250976626595754, 0.8868871128871127, 0.23231750084296052, 1.3303306693306696, 0.12076507168821443, 2.2172177822177823, 0.03165527922377324], [0.44444455544455536, 1.0, 0.48177944100451714, 0.8888891108891107, 0.23153449111661425, 1.3333336663336666, 0.12017570770860082, 2.2222227772227776, 0.031408232835489464], [0.4454455544455544, 1.0, 0.4810507389843715, 0.8908911088911088, 0.2307540656370835, 1.3363366633366636, 0.11958911048588998, 2.2272277722277725, 0.031163095255864606], [0.4464465534465534, 1.0, 0.4803236584531393, 0.8928931068931067, 0.22997621689730083, 1.3393396603396606, 0.1190052673242306, 2.2322327672327673, 0.03091985174716825], [0.44744755244755235, 1.0, 0.4795981976623385, 0.8948951048951047, 0.22920093741498507, 1.3423426573426576, 0.11842416558737831, 2.2372377622377626, 0.03067848768554197], [0.4484485514485514, 1.0, 0.4788743548673825, 0.8968971028971028, 0.22842821973256947, 1.3453456543456546, 0.11784579269842183, 2.2422427572427575, 0.03043898856012018], [0.4494495504495504, 1.0, 0.47815212832757564, 0.8988991008991007, 0.22765805641712958, 1.3483486513486516, 0.11727013613951082, 2.2472477522477523, 0.030201339972157706], [0.45045054945054935, 1.0, 0.4774315163061084, 0.9009010989010987, 0.22689044006031192, 1.3513516483516486, 0.11669718345158528, 2.2522527472527476, 0.029965527634164095], [0.4514515484515484, 1.0, 0.47671251707005485, 0.9029030969030968, 0.2261253632782625, 1.3543546453546456, 0.11612692223410574, 2.2572577422577424, 0.029731537369044724], [0.45245254745254737, 1.0, 0.47599512889036705, 0.9049050949050947, 0.22536281871155622, 1.3573576423576426, 0.11555934014478451, 2.2622627372627373, 0.029499355109248403], [0.45345354645354635, 1.0, 0.47527935004187144, 0.9069070929070927, 0.22460279902512598, 1.3603606393606396, 0.11499442489931916, 2.2672677322677326, 0.029268966895921657], [0.4544545454545454, 1.0, 0.4745651788032642, 0.9089090909090908, 0.22384529690819174, 1.3633636363636366, 0.11443216427112607, 2.2722727272727274, 0.029040358878069574], [0.45545554445554437, 1.0, 0.4738526134571078, 0.9109110889110887, 0.22309030507419056, 1.3663666333666336, 0.11387254609107629, 2.2772777222777223, 0.028813517311722922], [0.45645654345654335, 1.0, 0.4731416522898266, 0.9129130869130867, 0.22233781626070645, 1.3693696303696306, 0.1133155582472318, 2.2822827172827176, 0.02858842855911207], [0.4574575424575424, 1.0, 0.472432293591702, 0.9149150849150848, 0.22158782322940032, 1.3723726273726276, 0.11276118868458365, 2.2872877122877124, 0.028365079087846898], [0.45845854145854137, 1.0, 0.4717245356568699, 0.9169170829170827, 0.22084031876594074, 1.3753756243756246, 0.11220942540479076, 2.2922927072927073, 0.02814345547010333], [0.4594595404595404, 1.0, 0.4710183767833155, 0.9189190809190808, 0.22009529567993422, 1.3783786213786215, 0.11166025646592061, 2.2972977022977026, 0.027923544381816014], [0.4604605394605394, 1.0, 0.47031381527286903, 0.9209210789210788, 0.219352746804856, 1.3813816183816185, 0.11111366998219041, 2.3023026973026974, 0.027705332601877283], [0.46146153846153837, 1.0, 0.4696108494312024, 0.9229230769230767, 0.21861266499798138, 1.3843846153846155, 0.11056965412370998, 2.3073076923076927, 0.027488807011342282], [0.4624625374625374, 1.0, 0.4689094775678248, 0.9249250749250748, 0.21787504314031686, 1.3873876123876125, 0.11002819711622587, 2.3123126873126876, 0.02727395459264029], [0.4634635364635364, 1.0, 0.46820969799607864, 0.9269270729270728, 0.21713987413653169, 1.3903906093906095, 0.10948928724086636, 2.3173176823176824, 0.027060762428792063], [0.46446453546453537, 1.0, 0.4675115090331351, 0.9289290709290707, 0.2164071509148895, 1.3933936063936065, 0.1089529128338878, 2.3223226773226777, 0.026849217702633276], [0.4654655344655344, 1.0, 0.4668149089999906, 0.9309310689310688, 0.21567686642718042, 1.3963966033966035, 0.10841906228642219, 2.3273276723276726, 0.026639307696043994], [0.4664665334665334, 1.0, 0.4661198962214629, 0.9329330669330668, 0.2149490136486535, 1.3993996003996005, 0.10788772404422614, 2.3323326673326674, 0.026431019789183982], [0.46746753246753237, 1.0, 0.4654264690261865, 0.9349350649350647, 0.2142235855779484, 1.4024025974025975, 0.10735888660743048, 2.3373376623376627, 0.026224341459734037], [0.4684685314685314, 1.0, 0.464734625746609, 0.9369370629370628, 0.21350057523702903, 1.4054055944055945, 0.1068325385302917, 2.3423426573426576, 0.02601926028214313], [0.4694695304695304, 1.0, 0.46404436471898725, 0.9389390609390608, 0.21277997567111548, 1.4084085914085915, 0.10630866842094384, 2.3473476523476524, 0.025815763926881424], [0.47047052947052936, 1.0, 0.4633556842833826, 0.9409410589410587, 0.21206177994861797, 1.4114115884115885, 0.10578726494115225, 2.3523526473526477, 0.025613840159698933], [0.4714715284715284, 1.0, 0.4626685827836579, 0.9429430569430568, 0.21134598116106948, 1.4144145854145855, 0.10526831680606806, 2.3573576423576426, 0.025413476840890077], [0.4724725274725274, 1.0, 0.46198305856747246, 0.9449450549450548, 0.21063257242305958, 1.4174175824175825, 0.10475181278398386, 2.3623626373626374, 0.025214661924563796], [0.47347352647352636, 1.0, 0.46129910998627965, 0.9469470529470527, 0.2099215468721684, 1.4204205794205795, 0.10423774169609089, 2.3673676323676327, 0.025017383457919377], [0.4744745254745254, 1.0, 0.46061673539532055, 0.9489490509490508, 0.20921289766890014, 1.4234235764235765, 0.1037260924162367, 2.3723726273726276, 0.0248216295805278], [0.4754755244755244, 1.0, 0.4599359331536224, 0.9509510489510488, 0.20850661799661793, 1.4264265734265735, 0.10321685387068472, 2.3773776223776224, 0.02462738852361875], [0.4764765234765234, 1.0, 0.4592567016239932, 0.9529530469530468, 0.20780270106147758, 1.4294295704295705, 0.10271001503787439, 2.3823826173826177, 0.024434648609373045], [0.4774775224775224, 1.0, 0.4585790391730183, 0.9549550449550448, 0.20710114009236258, 1.4324325674325675, 0.10220556494818264, 2.3873876123876125, 0.024243398250220535], [0.4784785214785214, 1.0, 0.4579029441710565, 0.9569570429570428, 0.20640192834081897, 1.4354355644355645, 0.10170349268368652, 2.3923926073926074, 0.024053625948143503], [0.4794795204795204, 1.0, 0.45722841499223565, 0.9589590409590408, 0.20570505908099052, 1.4384385614385615, 0.10120378737792682, 2.3973976023976027, 0.023865320293985397], [0.4804805194805194, 1.0, 0.45655545001444897, 0.9609610389610388, 0.20501052560955368, 1.4414415584415585, 0.10070643821567299, 2.4024025974025975, 0.02367846996676484], [0.4814815184815184, 1.0, 0.45588404761935203, 0.9629630369630368, 0.20431832124565344, 1.4444445554445555, 0.10021143443268891, 2.407407592407593, 0.023493063732995097], [0.4824825174825174, 1.0, 0.45521420619235714, 0.9649650349650348, 0.20362843933083882, 1.4474475524475525, 0.09971876531550013, 2.4124125874125877, 0.023309090446008686], [0.4834835164835164, 1.0, 0.45454592412263095, 0.9669670329670328, 0.20294087322899895, 1.4504505494505495, 0.09922842020116183, 2.4174175824175825, 0.023126539045287206], [0.4844845154845154, 1.0, 0.45387919980309044, 0.9689690309690308, 0.2022556163262994, 1.4534535464535465, 0.09874038847702807, 2.422422577422578, 0.02294539855579643], [0.4854855144855144, 1.0, 0.45321403163039803, 0.9709710289710288, 0.2015726620311183, 1.4564565434565435, 0.098254659580522, 2.4274275724275727, 0.022765658087326408], [0.4864865134865134, 1.0, 0.45255041800495877, 0.9729730269730268, 0.20089200377398292, 1.4594595404595407, 0.09777122299890761, 2.4324325674325675, 0.02258730683383686], [0.4874875124875124, 1.0, 0.45188835733091554, 0.9749750249750248, 0.20021363500750664, 1.4624625374625377, 0.09729006826906196, 2.437437562437563, 0.022410334072807382], [0.4884885114885114, 1.0, 0.45122784801614646, 0.9769770229770228, 0.1995375492063258, 1.4654655344655347, 0.09681118497724842, 2.4424425574425577, 0.02223472916459291], [0.4894895104895104, 1.0, 0.45056888847225934, 0.9789790209790208, 0.1988637398670373, 1.4684685314685317, 0.09633456275889185, 2.4474475524475525, 0.02206048155178399], [0.49049050949050943, 1.0, 0.44991147711459, 0.9809810189810189, 0.19819220050813552, 1.4714715284715287, 0.095860191298354, 2.452452547452548, 0.021887580758572132], [0.4914915084915084, 1.0, 0.4492556123621972, 0.9829830169830168, 0.19752292466995036, 1.4744745254745257, 0.09538806032871013, 2.4574575424575427, 0.021716016390119924], [0.4924925074925074, 1.0, 0.44860129263785814, 0.9849850149850148, 0.19685590591458493, 1.4774775224775227, 0.09491815963152701, 2.4624625374625375, 0.02154577813193615], [0.49349350649350643, 1.0, 0.4479485163680661, 0.9869870129870129, 0.1961911378258537, 1.4804805194805197, 0.09445047903664165, 2.467467532467533, 0.021376855749255696], [0.4944945054945054, 1.0, 0.4472972819830258, 0.9889890109890108, 0.1955286140092208, 1.4834835164835167, 0.09398500842194131, 2.4724725274725277, 0.021209239086424154], [0.4954955044955044, 1.0, 0.4466475879166502, 0.9909910089910088, 0.1948683280917384, 1.4864865134865137, 0.09352173771314423, 2.4774775224775225, 0.02104291806628732], [0.4964965034965034, 1.0, 0.44599943260655656, 0.9929930069930069, 0.19421027372198538, 1.4894895104895107, 0.09306065688358175, 2.482482517482518, 0.02087788268958536], [0.4974975024975024, 1.0, 0.44535281449406167, 0.9949950049950048, 0.19355444457000637, 1.4924925074925077, 0.09260175595398124, 2.4874875124875127, 0.020714123034351613], [0.4984985014985014, 1.0, 0.4447077320241803, 0.9969970029970028, 0.19290083432725097, 1.4954955044955047, 0.09214502499225005, 2.4924925074925075, 0.020551629255316096], [0.4994995004995004, 1.0, 0.44406418364561884, 0.9989990009990009, 0.19224943670651248, 1.4984985014985017, 0.09169045411326068, 2.497497502497503, 0.020390391583313613], [0.5005004995004995, 1.0, 0.44342216781077326, 1.001000999000999, 0.19160024544186846, 1.5015014985014987, 0.09123803347863672, 2.5025024975024976, 0.02023040032469646], [0.5015014985014984, 1.0, 0.44278168297572573, 1.0030029970029968, 0.19095325428861937, 1.5045044955044957, 0.09078775329654006, 2.507507492507493, 0.02007164586075156], [0.5025024975024974, 1.0, 0.442142727600239, 1.0050049950049948, 0.19030845702322913, 1.5075074925074927, 0.09033960382145882, 2.512512487512488, 0.019914118647122264], [0.5035034965034965, 1.0, 0.4415053001477549, 1.007006993006993, 0.18966584744326515, 1.5105104895104897, 0.08989357535399646, 2.5175174825174826, 0.019757809213234476], [0.5045044955044954, 1.0, 0.44086939908538864, 1.0090089910089908, 0.18902541936733858, 1.5135134865134867, 0.08944965824066183, 2.522522477522478, 0.019602708161727347], [0.5055054945054944, 1.0, 0.44023502288392685, 1.0110109890109888, 0.1883871666350448, 1.5165164835164837, 0.08900784287366037, 2.527527472527473, 0.019448806167888244], [0.5065064935064935, 1.0, 0.43960217001782276, 1.013012987012987, 0.18775108310690444, 1.5195194805194807, 0.08856811969068602, 2.5325324675324676, 0.01929609397909216], [0.5075074925074924, 1.0, 0.438970838965193, 1.0150149850149848, 0.1871171626643039, 1.5225224775224777, 0.08813047917471432, 2.537537462537463, 0.01914456241424548], [0.5085084915084914, 1.0, 0.4383410282078138, 1.0170169830169828, 0.1864853992094369, 1.5255254745254747, 0.0876949118537964, 2.542542457542458, 0.018994202363233983], [0.5095094905094905, 1.0, 0.4377127362311176, 1.019018981018981, 0.18585578666524558, 1.5285284715284717, 0.08726140830085398, 2.5475474525474526, 0.018845004786375123], [0.5105104895104894, 1.0, 0.4370859615241888, 1.0210209790209788, 0.18522831897536224, 1.5315314685314687, 0.08682995913347549, 2.552552447552448, 0.018696960713874604], [0.5115114885114884, 1.0, 0.4364607025797607, 1.0230229770229768, 0.18460299010405062, 1.5345344655344657, 0.08640055501371276, 2.5575574425574428, 0.018550061245287082], [0.5125124875124875, 1.0, 0.4358369578942125, 1.025024975024975, 0.18397979403614872, 1.5375374625374627, 0.08597318664787905, 2.5625624375624376, 0.01840429754898106], [0.5135134865134864, 1.0, 0.43521472596756366, 1.0270269730269728, 0.18335872477700993, 1.5405404595404597, 0.08554784478634789, 2.567567432567433, 0.018259660861607966], [0.5145144855144854, 1.0, 0.43459400530347214, 1.0290289710289708, 0.1827397763524461, 1.5435434565434567, 0.08512452022335293, 2.5725724275724278, 0.018116142487575267], [0.5155154845154845, 1.0, 0.43397479440923, 1.031030969030969, 0.18212294280866964, 1.5465464535464537, 0.08470320379678854, 2.5775774225774226, 0.017973733798523694], [0.5165164835164834, 1.0, 0.43335709179576065, 1.0330329670329668, 0.18150821821223645, 1.5495494505494507, 0.08428388638801176, 2.582582417582418, 0.01783242623280852], [0.5175174825174824, 1.0, 0.43274089597761306, 1.0350349650349648, 0.18089559664998894, 1.5525524475524477, 0.08386655892164467, 2.5875874125874128, 0.017692211294984803], [0.5185184815184815, 1.0, 0.4321262054729611, 1.037036963036963, 0.180285072228999, 1.5555554445554447, 0.0834512123653782, 2.5925924075924076, 0.017553080555296665], [0.5195194805194804, 1.0, 0.4315130188035981, 1.0390389610389608, 0.17967663907651119, 1.5585584415584417, 0.08303783772977646, 2.597597402597403, 0.017415025649170475], [0.5205204795204794, 1.0, 0.43090133449493423, 1.0410409590409588, 0.17907029133988658, 1.5615614385614387, 0.08262642606808253, 2.6026023976023978, 0.017278038276711972], [0.5215214785214785, 1.0, 0.43029115107599186, 1.043042957042957, 0.17846602318654609, 1.5645644355644357, 0.08221696847602417, 2.6076073926073926, 0.01714211020220729], [0.5225224775224774, 1.0, 0.42968246707940333, 1.0450449550449548, 0.17786382880391471, 1.5675674325674327, 0.08180945609162174, 2.612612387612388, 0.017007233253627813], [0.5235234765234764, 1.0, 0.42907528104140646, 1.0470469530469528, 0.17726370239936523, 1.5705704295704297, 0.08140388009499613, 2.6176173826173827, 0.016873399322138837], [0.5245244755244755, 1.0, 0.4284695915018416, 1.049048951048951, 0.17666563820016296, 1.5735734265734267, 0.08100023170817777, 2.622622377622378, 0.016740600361612137], [0.5255254745254744, 1.0, 0.4278653970041476, 1.0510509490509488, 0.17606963045340987, 1.5765764235764237, 0.0805985021949169, 2.627627372627373, 0.01660882838814216], [0.5265264735264734, 1.0, 0.4272626960953588, 1.0530529470529468, 0.17547567342598927, 1.5795794205794207, 0.08019868286049439, 2.6326323676323677, 0.01647807547956608], [0.5275274725274725, 1.0, 0.426661487326101, 1.055054945054945, 0.17488376140451095, 1.5825824175824177, 0.07980076505153338, 2.637637362637363, 0.016348333774987508], [0.5285284715284715, 1.0, 0.4260617692505883, 1.057056943056943, 0.1742938886952559, 1.5855854145854147, 0.07940474015581221, 2.642642357642358, 0.016219595474303874], [0.5295294705294704, 1.0, 0.4254635404266203, 1.0590589410589408, 0.17370604962412164, 1.5885884115884117, 0.07901059960207794, 2.6476473526473527, 0.01609185283773747], [0.5305304695304695, 1.0, 0.42486679941557726, 1.061060939060939, 0.17312023853656772, 1.5915914085914087, 0.07861833485986087, 2.652652347652348, 0.01596509818537018], [0.5315314685314685, 1.0, 0.4242715447824174, 1.063062937062937, 0.17253644979756125, 1.5945944055944057, 0.07822793743928996, 2.657657342657343, 0.015839323896681752], [0.5325324675324674, 1.0, 0.4236777750956739, 1.0650649350649348, 0.17195467779152268, 1.5975974025974027, 0.07783939889090889, 2.6626623376623377, 0.01571452241009158], [0.5335334665334664, 1.0, 0.42308548892745035, 1.067066933066933, 0.17137491692227183, 1.6006003996003997, 0.07745271080549344, 2.667667332667333, 0.015590686222504202], [0.5345344655344655, 1.0, 0.42249468485341773, 1.069068931068931, 0.17079716161297412, 1.6036033966033967, 0.07706786481386922, 2.672672327672328, 0.015467807888858147], [0.5355354645354644, 1.0, 0.42190536145281204, 1.0710709290709288, 0.17022140630608668, 1.6066063936063937, 0.07668485258673079, 2.6776773226773227, 0.01534588002167837], [0.5365364635364634, 1.0, 0.421317517308429, 1.073072927072927, 0.1696476454633051, 1.6096093906093907, 0.07630366583446119, 2.682682317682318, 0.015224895290632076], [0.5375374625374625, 1.0, 0.4207311510066225, 1.075074925074925, 0.16907587356551032, 1.612612387612388, 0.07592429630695269, 2.687687312687313, 0.015104846422088045], [0.5385384615384614, 1.0, 0.4201462611372998, 1.0770769230769228, 0.16850608511271495, 1.615615384615385, 0.0755467357934281, 2.6926923076923077, 0.014985726198679362], [0.5395394605394604, 1.0, 0.41956284629391905, 1.079078921078921, 0.16793827462401117, 1.618618381618382, 0.07517097612226312, 2.697697302697303, 0.014867527458869458], [0.5405404595404595, 1.0, 0.4189809050734853, 1.081080919080919, 0.16737243663751739, 1.621621378621379, 0.07479700916080952, 2.702702297702298, 0.01475024309652158], [0.5415414585414584, 1.0, 0.4184004360765475, 1.0830829170829168, 0.16680856571032587, 1.624624375624376, 0.07442482681521902, 2.7077072927072927, 0.014633866060471597], [0.5425424575424574, 1.0, 0.41782143790719495, 1.085084915084915, 0.1662466564184505, 1.627627372627373, 0.07405442103026821, 2.712712287712288, 0.014518389354104], [0.5435434565434565, 1.0, 0.417243909173054, 1.087086913086913, 0.1656867033567744, 1.63063036963037, 0.0736857837891841, 2.717717282717283, 0.014403806034931368], [0.5445444555444554, 1.0, 0.41666784848528476, 1.0890889110889108, 0.1651287011389982, 1.633633366633367, 0.0733189071134707, 2.722722277722278, 0.014290109214176894], [0.5455454545454544, 1.0, 0.41609325445857703, 1.091090909090909, 0.16457264439758795, 1.6366363636363639, 0.07295378306273645, 2.727727272727273, 0.014177292056360308], [0.5465464535464535, 1.0, 0.41552012571114855, 1.093092907092907, 0.16401852778372392, 1.6396393606393609, 0.07259040373452202, 2.732732267732268, 0.014065347778886862], [0.5475474525474524, 1.0, 0.41494846086474046, 1.0950949050949048, 0.16346634596724824, 1.6426423576423579, 0.07222876126412968, 2.737737262737263, 0.013954269651639609], [0.5485484515484514, 1.0, 0.41437825854461435, 1.0970969030969029, 0.16291609363661486, 1.6456453546453549, 0.07186884782445277, 2.742742257742258, 0.013844050996574734], [0.5495494505494505, 1.0, 0.41380951737954846, 1.099098901098901, 0.1623677654988376, 1.6486483516483519, 0.07151065562580643, 2.747747252747253, 0.013734685187320123], [0.5505504495504494, 1.0, 0.4132422360018353, 1.1011008991008988, 0.1618213562794395, 1.6516513486513489, 0.07115417691575908, 2.752752247752248, 0.013626165648776918], [0.5515514485514484, 1.0, 0.41267641304727776, 1.1031028971028969, 0.16127686072240194, 1.6546543456543459, 0.07079940397896449, 2.757757242757243, 0.0135184858567243], [0.5525524475524475, 1.0, 0.4121120471551859, 1.105104895104895, 0.1607342735901143, 1.6576573426573429, 0.07044632913699482, 2.762762237762238, 0.013411639337427199], [0.5535534465534464, 1.0, 0.41154913696837375, 1.1071068931068928, 0.16019358966332345, 1.6606603396603399, 0.07009494474817449, 2.767767232767233, 0.013305619667247106], [0.5545544455544454, 1.0, 0.41098768113315537, 1.1091088911088909, 0.15965480374108357, 1.6636633366633369, 0.06974524320741476, 2.772772227772228, 0.01320042047225588], [0.5555554445554445, 1.0, 0.4104276782993434, 1.111110889110889, 0.1591179106407062, 1.6666663336663339, 0.06939721694604918, 2.777777222777223, 0.013096035427852537], [0.5565564435564434, 1.0, 0.4098691271202441, 1.1131128871128868, 0.15858290519771026, 1.6696693306693309, 0.06905085843166972, 2.782782217782218, 0.01299245825838303], [0.5575574425574424, 1.0, 0.40931202625265456, 1.1151148851148849, 0.15804978226577232, 1.6726723276723279, 0.06870616016796369, 2.787787212787213, 0.01288968273676295], [0.5585584415584415, 1.0, 0.40875637435685974, 1.117116883116883, 0.15751853671667723, 1.6756753246753249, 0.06836311469455165, 2.792792207792208, 0.012787702684103149], [0.5595594405594405, 1.0, 0.408202170096629, 1.119118881118881, 0.15698916344026892, 1.6786783216783219, 0.06802171458682578, 2.797797202797203, 0.012686511969338253], [0.5605604395604394, 1.0, 0.4076494121392128, 1.1211208791208789, 0.15646165734440093, 1.6816813186813189, 0.06768195245578938, 2.802802197802198, 0.012586104508858095], [0.5615614385614385, 1.0, 0.4070980991553401, 1.123122877122877, 0.15593601335488766, 1.6846843156843159, 0.06734382094789672, 2.807807192807193, 0.01248647426614193], [0.5625624375624375, 1.0, 0.4065482298192145, 1.125124875124875, 0.1554122264154555, 1.6876873126873129, 0.06700731274489408, 2.812812187812188, 0.012387615251395537], [0.5635634365634364, 1.0, 0.4059998028085109, 1.1271268731268729, 0.15489029148769387, 1.6906903096903099, 0.06667242056366122, 2.817817182817183, 0.012289521521191098], [0.5645644355644355, 1.0, 0.4054528168043734, 1.129128871128871, 0.15437020355100758, 1.6936933066933069, 0.0663391371560539, 2.8228221778221783, 0.012192187178109902], [0.5655654345654345, 1.0, 0.4049072704914111, 1.131130869130869, 0.15385195760256754, 1.6966963036963039, 0.06600745530874678, 2.827827172827173, 0.012095606370387759], [0.5665664335664334, 1.0, 0.40436316255769533, 1.1331328671328669, 0.1533355486572634, 1.6996993006993009, 0.06567736784307765, 2.832832167832168, 0.011999773291563208], [0.5675674325674325, 1.0, 0.40382049169475603, 1.135134865134865, 0.15282097174765524, 1.7027022977022979, 0.06534886761489156, 2.8378371628371633, 0.011904682180128452], [0.5685684315684315, 1.0, 0.4032792565975796, 1.137136863136863, 0.15230822192392576, 1.7057052947052949, 0.06502194751438672, 2.842842157842158, 0.011810327319182913], [0.5695694305694304, 1.0, 0.4027394559646049, 1.1391388611388609, 0.15179729425383276, 1.7087082917082919, 0.06469660046596035, 2.847847152847153, 0.011716703036089612], [0.5705704295704295, 1.0, 0.4022010884977204, 1.141140859140859, 0.15128818382266193, 1.7117112887112889, 0.06437281942805548, 2.8528521478521482, 0.011623803702134054], [0.5715714285714285, 1.0, 0.401664152902261, 1.143142857142857, 0.15078088573317905, 1.7147142857142859, 0.06405059739300871, 2.857857142857143, 0.01153162373218588], [0.5725724275724274, 1.0, 0.40112864788700503, 1.1451448551448549, 0.15027539510558335, 1.7177172827172829, 0.06372992738689853, 2.862862137862138, 0.011440157584363064], [0.5735734265734265, 1.0, 0.4005945721641713, 1.147146853146853, 0.14977170707746035, 1.7207202797202799, 0.0634108024693942, 2.8678671328671332, 0.011349399759698732], [0.5745744255744255, 1.0, 0.4000619244494152, 1.149148851148851, 0.14926981680373505, 1.7237232767232769, 0.06309321573360577, 2.872872127872128, 0.01125934480181058], [0.5755754245754244, 1.0, 0.39953070346182695, 1.1511508491508489, 0.1487697194566255, 1.7267262737262739, 0.06277716030593448, 2.877877122877123, 0.01116998729657282], [0.5765764235764235, 1.0, 0.399000907923927, 1.153152847152847, 0.14827141022559623, 1.7297292707292709, 0.06246262934592398, 2.8828821178821182, 0.011081321871790676], [0.5775774225774225, 1.0, 0.39847253656166426, 1.155154845154845, 0.1477748843173121, 1.7327322677322679, 0.062149616046112285, 2.887887112887113, 0.010993343196877422], [0.5785784215784214, 1.0, 0.3979455881044121, 1.1571568431568429, 0.14728013695559186, 1.7357352647352648, 0.0618381136318845, 2.892892107892108, 0.01090604598253391], [0.5795794205794205, 1.0, 0.39742006128496593, 1.159158841158841, 0.1467871633813628, 1.7387382617382618, 0.06152811536132615, 2.8978971028971032, 0.010819424980430549], [0.5805804195804195, 1.0, 0.3968959548395396, 1.161160839160839, 0.14629595885261434, 1.7417412587412588, 0.06121961452507727, 2.902902097902098, 0.010733474982891802], [0.5815814185814184, 1.0, 0.3963732675077634, 1.1631628371628369, 0.14580651864435293, 1.7447442557442558, 0.06091260444618719, 2.907907092907093, 0.010648190822583094], [0.5825824175824175, 1.0, 0.3958519980326797, 1.165164835164835, 0.14531883804855608, 1.7477472527472528, 0.06060707847996998, 2.912912087912088, 0.010563567372200131], [0.5835834165834165, 1.0, 0.3953321451607406, 1.167166833166833, 0.14483291237412768, 1.7507502497502498, 0.06030303001386076, 2.917917082917083, 0.010479599544160662], [0.5845844155844154, 1.0, 0.39481370764180473, 1.1691688311688309, 0.14434873694685224, 1.7537532467532468, 0.06000045246727245, 2.9229220779220784, 0.010396282290298616], [0.5855854145854145, 1.0, 0.39429668422913455, 1.171170829170829, 0.14386630710935058, 1.7567562437562438, 0.05969933929145341, 2.927927072927073, 0.0103136106015606], [0.5865864135864135, 1.0, 0.3937810736793934, 1.173172827172827, 0.14338561822103435, 1.7597592407592408, 0.0593996839693457, 2.932932067932068, 0.010231579507704732], [0.5875874125874125, 1.0, 0.39326687475264205, 1.175174825174825, 0.14290666565806212, 1.7627622377622378, 0.05910148001544404, 2.9379370629370634, 0.010150184077001871], [0.5885884115884115, 1.0, 0.3927540862123356, 1.177176823176823, 0.14242944481329411, 1.765765234765235, 0.05880472097565541, 2.942942057942058, 0.01006941941593909], [0.5895894105894105, 1.0, 0.3922427068253216, 1.179178821178821, 0.14195395109624853, 1.768768231768232, 0.058509400427159394, 2.947947052947053, 0.009989280668925491], [0.5905904095904095, 1.0, 0.39173273536183567, 1.181180819180819, 0.1414801799330571, 1.771771228771229, 0.058215511978269165, 2.9529520479520484, 0.009909763018000272], [0.5915914085914085, 1.0, 0.3912241705954989, 1.183182817182817, 0.1410081267664211, 1.774774225774226, 0.05792304926829311, 2.957957042957043, 0.00983086168254307], [0.5925924075924075, 1.0, 0.3907170113033163, 1.185184815184815, 0.1405377870555677, 1.777777222777223, 0.05763200596739717, 2.962962037962038, 0.009752571918986578], [0.5935934065934065, 1.0, 0.39021125626567194, 1.187186813186813, 0.14006915627620595, 1.78078021978022, 0.05734237577646792, 2.9679670329670333, 0.009674889020531319], [0.5945944055944055, 1.0, 0.38970690426632715, 1.189188811188811, 0.1396022299204836, 1.783783216783217, 0.057054152426976174, 2.972972027972028, 0.009597808316862706], [0.5955954045954045, 1.0, 0.389203954092417, 1.191190809190809, 0.13913700349694352, 1.786786213786214, 0.05676732968084129, 2.977977022977023, 0.009521325173870237], [0.5965964035964035, 1.0, 0.3887024045344483, 1.193192807192807, 0.1386734725304806, 1.789789210789211, 0.056481901330296215, 2.9829820179820183, 0.009445434993368909], [0.5975974025974025, 1.0, 0.3882022543862954, 1.195194805194805, 0.13821163256229863, 1.792792207792208, 0.056197861197753086, 2.987987012987013, 0.009370133212822766], [0.5985984015984015, 1.0, 0.38770350244519836, 1.197196803196803, 0.13775147914986746, 1.795795204795205, 0.05591520313566956, 2.992992007992008, 0.009295415305070595], [0.5995994005994005, 1.0, 0.3872061475117592, 1.199198801198801, 0.13729300786688023, 1.798798201798202, 0.05563392102641578, 2.9979970029970033, 0.00922127677805377], [0.6006003996003995, 1.0, 0.38671018838994026, 1.201200799200799, 0.1368362143032109, 1.801801198801199, 0.055354008782141854, 3.003001998001998, 0.009147713174546154], [0.6016013986013985, 1.0, 0.38621562388705954, 1.203202797202797, 0.1363810940648717, 1.804804195804196, 0.05507546034464621, 3.008006993006993, 0.009074720071886165], [0.6026023976023975, 1.0, 0.3857224528137893, 1.205204795204795, 0.1359276427739707, 1.807807192807193, 0.05479826968524448, 3.0130119880119883, 0.009002293081710862], [0.6036033966033965, 1.0, 0.3852306739841525, 1.207206793206793, 0.13547585606867044, 1.81081018981019, 0.054522430804638915, 3.018016983016983, 0.008930427849692127], [0.6046043956043955, 1.0, 0.3847402862155209, 1.209208791208791, 0.13502572960314474, 1.813813186813187, 0.05424793773278861, 3.0230219780219785, 0.008859120055274882], [0.6056053946053945, 1.0, 0.3842512883286104, 1.211210789210789, 0.13457725904753823, 1.816816183816184, 0.05397478452878045, 3.0280269730269733, 0.008788365411417321], [0.6066063936063935, 1.0, 0.38376367914748033, 1.213212787212787, 0.1341304400879236, 1.819819180819181, 0.053702965280700135, 3.033031968031968, 0.008718159664333196], [0.6076073926073925, 1.0, 0.3832774574995288, 1.215214785214785, 0.13368526842626086, 1.822822177822178, 0.0534324741055046, 3.0380369630369635, 0.008648498593236046], [0.6086083916083915, 1.0, 0.3827926222154909, 1.217216783216783, 0.13324173978035556, 1.825825174825175, 0.05316330514889453, 3.0430419580419583, 0.00857937801008549], [0.6096093906093905, 1.0, 0.38230917212943605, 1.219218781218781, 0.13279984988381774, 1.828828171828172, 0.0528954525851877, 3.048046953046953, 0.008510793759335392], [0.6106103896103895, 1.0, 0.3818271060787636, 1.221220779220779, 0.1323595944860211, 1.831831168831169, 0.05262891061719282, 3.0530519480519485, 0.008442741717684048], [0.6116113886113885, 1.0, 0.3813464229042029, 1.223222777222777, 0.13192096935206163, 1.834834165834166, 0.05236367347608409, 3.0580569430569433, 0.008375217793826308], [0.6126123876123875, 1.0, 0.3808671214498074, 1.225224775224775, 0.1314839702627173, 1.837837162837163, 0.05209973542127643, 3.063061938061938, 0.008308217928207576], [0.6136133866133865, 1.0, 0.38038920056295406, 1.227226773226773, 0.1310485930144073, 1.84084015984016, 0.05183709074030111, 3.0680669330669335, 0.008241738092779772], [0.6146143856143855, 1.0, 0.37991265909433963, 1.229228771228771, 0.1306148334191516, 1.843843156843157, 0.05157573374868218, 3.0730719280719283, 0.008175774290759157], [0.6156153846153845, 1.0, 0.379437495897978, 1.231230769230769, 0.13018268730453075, 1.846846153846154, 0.05131565878981348, 3.078076923076923, 0.008110322556386043], [0.6166163836163835, 1.0, 0.37896370983119776, 1.233232767232767, 0.12975215051364566, 1.849849150849151, 0.05105686023483611, 3.0830819180819184, 0.00804537895468637], [0.6176173826173825, 1.0, 0.37849129975463924, 1.235234765234765, 0.1293232189050776, 1.852852147852148, 0.05079933248251665, 3.0880869130869133, 0.007980939581235144], [0.6186183816183816, 1.0, 0.37802026453225096, 1.2372367632367631, 0.12889588835284857, 1.855855144855145, 0.05054306995912601, 3.093091908091908, 0.007917000561921687], [0.6196193806193805, 1.0, 0.3775506030312889, 1.239238761238761, 0.12847015474638127, 1.858858141858142, 0.05028806711831861, 3.0980969030969034, 0.007853558052716736], [0.6206203796203795, 1.0, 0.37708231412231197, 1.241240759240759, 0.1280460139904597, 1.861861138861139, 0.050034318441012575, 3.1031018981018983, 0.007790608239441332], [0.6216213786213786, 1.0, 0.3766153966791794, 1.2432427572427571, 0.12762346200519004, 1.864864135864136, 0.049781818435270055, 3.108106893106893, 0.007728147337537522], [0.6226223776223775, 1.0, 0.3761498495790498, 1.245244755244755, 0.12720249472596093, 1.867867132867133, 0.049530561636178576, 3.1131118881118884, 0.007666171591840818], [0.6236233766233765, 1.0, 0.3756856717023759, 1.247246753246753, 0.12678310810340482, 1.87087012987013, 0.049280542605732565, 3.1181168831168833, 0.0076046772763544365], [0.6246243756243756, 1.0, 0.37522286193290366, 1.2492487512487511, 0.12636529810335861, 1.873873126873127, 0.0490317559327158, 3.1231218781218786, 0.007543660694025301], [0.6256253746253745, 1.0, 0.37476141915766914, 1.251250749250749, 0.12594906070682513, 1.876876123876124, 0.048784196232584204, 3.1281268731268734, 0.007483118176521767], [0.6266263736263735, 1.0, 0.37430134226699535, 1.253252747252747, 0.12553439190993448, 1.879879120879121, 0.048537858147349414, 3.1331318681318683, 0.007423046084013078], [0.6276273726273726, 1.0, 0.373842630154491, 1.2552547452547451, 0.12512128772390535, 1.882882117882118, 0.048292736345462606, 3.1381368631368636, 0.007363440804950537], [0.6286283716283715, 1.0, 0.3733852817170453, 1.257256743256743, 0.1247097441750066, 1.885885114885115, 0.04804882552169938, 3.1431418581418584, 0.007304298755850394], [0.6296293706293705, 1.0, 0.3729292958548283, 1.259258741258741, 0.12429975730451948, 1.888888111888112, 0.04780612039704471, 3.1481468531468533, 0.007245616381078394], [0.6306303696303696, 1.0, 0.37247467147128555, 1.2612607392607391, 0.12389132316869886, 1.891891108891109, 0.047564615718578826, 3.1531518481518486, 0.007187390152636005], [0.6316313686313685, 1.0, 0.3720214074731372, 1.263262737262737, 0.12348443783873606, 1.894894105894106, 0.04732430625936345, 3.1581568431568434, 0.007129616569948332], [0.6326323676323675, 1.0, 0.37156950277037504, 1.265264735264735, 0.12307909740072032, 1.897897102897103, 0.04708518681832875, 3.1631618381618383, 0.007072292159653643], [0.6336333666333666, 1.0, 0.37111895627625935, 1.2672667332667331, 0.12267529795560177, 1.9009000999001, 0.04684725222016062, 3.1681668331668336, 0.007015413475394578], [0.6346343656343655, 1.0, 0.37066976690731723, 1.269268731268731, 0.12227303561915348, 1.903903096903097, 0.04661049731518884, 3.1731718281718284, 0.0069589770976109105], [0.6356353646353645, 1.0, 0.3702219335833384, 1.271270729270729, 0.12187230652193448, 1.906906093906094, 0.04637491697927551, 3.1781768231768233, 0.006902979633333998], [0.6366363636363636, 1.0, 0.36977545522737454, 1.2732727272727271, 0.12147310680925205, 1.909909090909091, 0.04614050611370423, 3.1831818181818186, 0.006847417715982781], [0.6376373626373625, 1.0, 0.36933033076573535, 1.275274725274725, 0.12107543264112518, 1.912912087912088, 0.045907259645069615, 3.1881868131868134, 0.006792288005161385], [0.6386383616383615, 1.0, 0.3688865591279863, 1.277276723276723, 0.12067928019224718, 1.915915084915085, 0.04567517252516764, 3.1931918081918083, 0.0067375871864583025], [0.6396393606393606, 1.0, 0.36844413924694597, 1.279278721278721, 0.12028464565194917, 1.918918081918082, 0.045444239730886314, 3.1981968031968036, 0.006683311971247118], [0.6406403596403595, 1.0, 0.3680030700586837, 1.281280719280719, 0.11989152522416335, 1.9219210789210792, 0.045214456264096974, 3.2032017982017984, 0.006629459096488797], [0.6416413586413585, 1.0, 0.36756335050251765, 1.283282717282717, 0.11949991512738645, 1.9249240759240762, 0.04498581715154608, 3.2082067932067933, 0.006576025324535523], [0.6426423576423576, 1.0, 0.36712497952101086, 1.285284715284715, 0.11910981159464337, 1.9279270729270732, 0.04475831744474759, 3.2132117882117885, 0.006523007442936036], [0.6436433566433565, 1.0, 0.3666879560599699, 1.287286713286713, 0.11872121087345094, 1.9309300699300702, 0.04453195221987587, 3.2182167832167834, 0.0064704022642425125], [0.6446443556443555, 1.0, 0.3662522790684412, 1.289288711288711, 0.11833410922578187, 1.9339330669330672, 0.04430671657765916, 3.2232217782217782, 0.006418206625818908], [0.6456453546453546, 1.0, 0.3658179474987096, 1.291290709290709, 0.11794850292802862, 1.9369360639360642, 0.04408260564327347, 3.2282267732267735, 0.00636641738965086], [0.6466463536463535, 1.0, 0.36538496030629564, 1.293292707292707, 0.11756438827096792, 1.9399390609390612, 0.04385961456623715, 3.2332317682317684, 0.006315031442157001], [0.6476473526473525, 1.0, 0.36495331644995216, 1.295294705294705, 0.11718176155972479, 1.9429420579420582, 0.043637738520305794, 3.2382367632367637, 0.006264045694001765], [0.6486483516483516, 1.0, 0.3645230148916633, 1.297296703296703, 0.11680061911373694, 1.9459450549450552, 0.04341697270336792, 3.2432417582417585, 0.006213457079909681], [0.6496493506493506, 1.0, 0.36409405459664046, 1.2992987012987012, 0.11642095726671985, 1.9489480519480522, 0.04319731233734093, 3.2482467532467534, 0.006163262558481065], [0.6506503496503495, 1.0, 0.3636664345333207, 1.301300699300699, 0.11604277236663098, 1.9519510489510492, 0.04297875266806778, 3.2532517482517487, 0.006113459112009184], [0.6516513486513485, 1.0, 0.36324015367336404, 1.303302697302697, 0.1156660607756347, 1.9549540459540462, 0.042761288965214014, 3.2582567432567435, 0.006064043746298823], [0.6526523476523476, 1.0, 0.36281521099165137, 1.3053046953046952, 0.11529081887006777, 1.9579570429570432, 0.04254491652216542, 3.2632617382617384, 0.006015013490486274], [0.6536533466533465, 1.0, 0.3623916054662813, 1.307306693306693, 0.1149170430404038, 1.9609600399600402, 0.042329630655926175, 3.2682667332667337, 0.005966365396860734], [0.6546543456543455, 1.0, 0.36196933607856785, 1.309308691308691, 0.11454472969121916, 1.9639630369630372, 0.04211542670701746, 3.2732717282717285, 0.005918096540687078], [0.6556553446553446, 1.0, 0.3615484018130387, 1.3113106893106892, 0.11417387524115792, 1.9669660339660342, 0.041902300039376644, 3.2782767232767234, 0.005870204020030033], [0.6566563436563435, 1.0, 0.3611288016574315, 1.313312687312687, 0.11380447612289775, 1.9699690309690312, 0.0416902460402569, 3.2832817182817187, 0.005822684955579705], [0.6576573426573425, 1.0, 0.3607105346026928, 1.315314685314685, 0.11343652878311536, 1.9729720279720282, 0.041479260120127426, 3.2882867132867135, 0.00577553649047848], [0.6586583416583416, 1.0, 0.3602935996429747, 1.3173166833166832, 0.11307002968245224, 1.9759750249750252, 0.04126933771257408, 3.2932917082917084, 0.005728755790149263], [0.6596593406593405, 1.0, 0.35987799577563295, 1.319318681318681, 0.11270497529548103, 1.9789780219780222, 0.04106047427420055, 3.2982967032967037, 0.005682340042125066], [0.6606603396603395, 1.0, 0.359463722001224, 1.321320679320679, 0.1123413621106712, 1.9819810189810192, 0.040852665284530014, 3.3033016983016985, 0.005636286455879916], [0.6616613386613386, 1.0, 0.35905077732350327, 1.3233226773226772, 0.11197918663035554, 1.9849840159840162, 0.040645906245907346, 3.3083066933066934, 0.005590592262661105], [0.6626623376623375, 1.0, 0.35863916074942204, 1.325324675324675, 0.11161844537069632, 1.9879870129870132, 0.04044019268340168, 3.3133116883116887, 0.005545254715322713], [0.6636633366633365, 1.0, 0.35822887128912584, 1.327326673326673, 0.11125913486165193, 1.9909900099900102, 0.04023552014470969, 3.3183166833166835, 0.005500271088160463], [0.6646643356643356, 1.0, 0.3578199079559511, 1.3293286713286712, 0.11090125164694341, 1.9939930069930072, 0.0400318842000591, 3.3233216783216784, 0.005455638676747834], [0.6656653346653345, 1.0, 0.3574122697664237, 1.331330669330669, 0.11054479228402118, 1.9969960039960042, 0.03982928044211289, 3.3283266733266736, 0.005411354797773492], [0.6666663336663335, 1.0, 0.35700595574025623, 1.333332667332667, 0.11018975334403204, 1.9999990009990014, 0.03962770448587386, 3.3333316683316685, 0.005367416788879948], [0.6676673326673326, 1.0, 0.3566009649003454, 1.3353346653346652, 0.10983613141178612, 2.003001998001998, 0.03942715196858979, 3.338336663336664, 0.005323822008503513], [0.6686683316683315, 1.0, 0.35619729627277014, 1.337336663336663, 0.10948392308572391, 2.006004995004995, 0.03922761854965891, 3.3433416583416586, 0.005280567835715467], [0.6696693306693305, 1.0, 0.3557949488867883, 1.339338661338661, 0.10913312497788377, 2.009007992007992, 0.03902909991053606, 3.3483466533466535, 0.00523765167006452], [0.6706703296703296, 1.0, 0.35539392177483614, 1.3413406593406592, 0.10878373371386932, 2.012010989010989, 0.03883159175463912, 3.353351648351649, 0.005195070931420433], [0.6716713286713285, 1.0, 0.35499421397252456, 1.343342657342657, 0.10843574593281666, 2.015013986013986, 0.03863508980725621, 3.3583566433566436, 0.005152823059818934], [0.6726723276723275, 1.0, 0.3545958245186364, 1.345344655344655, 0.10808915828736243, 2.018016983016983, 0.03843958981545288, 3.3633616383616385, 0.0051109055153077875], [0.6736733266733266, 1.0, 0.35419875245512633, 1.3473466533466532, 0.1077439674436113, 2.02101998001998, 0.03824508754798037, 3.3683666333666338, 0.005069315777794111], [0.6746743256743255, 1.0, 0.3538029968271159, 1.349348651348651, 0.10740017008110424, 2.024022977022977, 0.03805157879518377, 3.3733716283716286, 0.005028051346892851], [0.6756753246753245, 1.0, 0.35340855668289284, 1.351350649350649, 0.10705776289278637, 2.027025974025974, 0.03785905936891107, 3.3783766233766235, 0.00498710974177647], [0.6766763236763236, 1.0, 0.35301543107390804, 1.3533526473526472, 0.10671674258497495, 2.030028971028971, 0.03766752510242249, 3.3833816183816188, 0.004946488501025795], [0.6776773226773226, 1.0, 0.3526236190547742, 1.3553546453546452, 0.10637710587732821, 2.033031968031968, 0.037476971850300224, 3.3883866133866136, 0.004906185182482034], [0.6786783216783215, 1.0, 0.35223311968326204, 1.357356643356643, 0.10603884950281332, 2.036034965034965, 0.03728739548835882, 3.3933916083916085, 0.004866197363099954], [0.6796793206793206, 1.0, 0.3518439320202996, 1.3593586413586412, 0.1057019702076752, 2.039037962037962, 0.03709879191355584, 3.3983966033966038, 0.004826522638802207], [0.6806803196803196, 1.0, 0.35145605512996897, 1.3613606393606392, 0.10536646475140525, 2.042040959040959, 0.03691115704390311, 3.4034015984015986, 0.004787158624334797], [0.6816813186813185, 1.0, 0.35106948807950455, 1.363362637362637, 0.10503232990670994, 2.045043956043956, 0.03672448681837836, 3.4084065934065935, 0.004748102953123683], [0.6826823176823176, 1.0, 0.35068422993929077, 1.3653646353646351, 0.10469956245948, 2.048046953046953, 0.036538777196837284, 3.4134115884115888, 0.004709353277132489], [0.6836833166833166, 1.0, 0.35030027978285916, 1.3673666333666332, 0.10436815920875943, 2.05104995004995, 0.03635402415992619, 3.4184165834165836, 0.00467090726672135], [0.6846843156843155, 1.0, 0.3499176366868876, 1.369368631368631, 0.10403811696671472, 2.054052947052947, 0.03617022370899494, 3.4234215784215785, 0.004632762610506847], [0.6856853146853146, 1.0, 0.3495362997311965, 1.3713706293706291, 0.10370943255860415, 2.057055944055944, 0.035987371866010365, 3.4284265734265738, 0.004594917015223045], [0.6866863136863136, 1.0, 0.34915626799874755, 1.3733726273726272, 0.10338210282274732, 2.060058941058941, 0.03580546467347031, 3.4334315684315686, 0.00455736820558363], [0.6876873126873125, 1.0, 0.3487775405756413, 1.375374625374625, 0.10305612461049465, 2.063061938061938, 0.03562449819431784, 3.438436563436564, 0.004520113924145107], [0.6886883116883116, 1.0, 0.34840011655111486, 1.3773766233766231, 0.10273149478619706, 2.066064935064935, 0.03544446851185607, 3.4434415584415587, 0.00448315193117109], [0.6896893106893106, 1.0, 0.3480239950175392, 1.3793786213786212, 0.10240821022717607, 2.069067932067932, 0.035265371729663486, 3.4484465534465536, 0.00444648000449765], [0.6906903096903095, 1.0, 0.3476491750704186, 1.381380619380619, 0.10208626782369341, 2.072070929070929, 0.03508720397150943, 3.453451548451549, 0.004410095939399706], [0.6916913086913086, 1.0, 0.34727565580838654, 1.3833826173826171, 0.10176566447892131, 2.075073926073926, 0.034909961381270435, 3.4584565434565437, 0.00437399754845849], [0.6926923076923076, 1.0, 0.34690343633320414, 1.3853846153846152, 0.10144639710891269, 2.078076923076923, 0.034733640122846555, 3.4634615384615386, 0.0043381826614300335], [0.6936933066933065, 1.0, 0.3465325157497596, 1.387386613386613, 0.1011284626425715, 2.08107992007992, 0.03455823638007845, 3.468466533466534, 0.004302649125114688], [0.6946943056943056, 1.0, 0.34616289316606313, 1.3893886113886111, 0.10081185802162308, 2.084082917082917, 0.034383746356664774, 3.4734715284715287, 0.004267394803227682], [0.6956953046953046, 1.0, 0.3457945676932471, 1.3913906093906092, 0.10049658020058488, 2.087085914085914, 0.03421016627608002, 3.4784765234765236, 0.004232417576270677], [0.6966963036963035, 1.0, 0.34542753844556334, 1.393392607392607, 0.10018262614673708, 2.090088911088911, 0.034037492381492736, 3.483481518481519, 0.004197715341404351], [0.6976973026973026, 1.0, 0.3450618045403806, 1.3953946053946051, 0.09986999284009349, 2.093091908091908, 0.0338657209356843, 3.4884865134865137, 0.004163286012321975], [0.6986983016983016, 1.0, 0.34469736509818244, 1.3973966033966032, 0.09955867727337231, 2.096094905094905, 0.03369484822096796, 3.4934915084915086, 0.004129127519123979], [0.6996993006993005, 1.0, 0.34433421924256596, 1.399398601398601, 0.09924867645196753, 2.099097902097902, 0.033524870539108416, 3.498496503496504, 0.004095237808193516], [0.7007002997002996, 1.0, 0.3439723661002383, 1.4014005994005991, 0.09893998739391972, 2.102100899100899, 0.0333557842112417, 3.5035014985014987, 0.004061614842072989], [0.7017012987012986, 1.0, 0.34361180480101583, 1.4034025974025972, 0.09863260712988774, 2.105103896103896, 0.03318758557779568, 3.5085064935064936, 0.004028256599341565], [0.7027022977022975, 1.0, 0.34325253447782145, 1.405404595404595, 0.09832653270311989, 2.108106893106893, 0.03302027099841075, 3.513511488511489, 0.0039951610744936444], [0.7037032967032966, 1.0, 0.34289455426668236, 1.4074065934065931, 0.0980217611694257, 2.11110989010989, 0.032853836851861065, 3.5185164835164837, 0.003962326277818292], [0.7047042957042956, 1.0, 0.3425378633067288, 1.4094085914085912, 0.09771828959714725, 2.114112887112887, 0.03268827953597626, 3.5235214785214786, 0.003929750235279611], [0.7057052947052945, 1.0, 0.3421824607401908, 1.411410589410589, 0.0974161150671315, 2.117115884115884, 0.03252359546756331, 3.528526473526474, 0.0038974309883980643], [0.7067062937062936, 1.0, 0.3418283457123972, 1.4134125874125871, 0.09711523467270176, 2.120118881118881, 0.03235978108232912, 3.5335314685314687, 0.0038653665941327372], [0.7077072927072926, 1.0, 0.3414755173717726, 1.4154145854145852, 0.09681564551962987, 2.123121878121878, 0.032196832834803325, 3.538536463536464, 0.0038335551247645106], [0.7087082917082916, 1.0, 0.3411239748698363, 1.4174165834165833, 0.09651734472610843, 2.126124875124875, 0.0320347471982616, 3.543541458541459, 0.0038019946677801723], [0.7097092907092906, 1.0, 0.3407737173611997, 1.4194185814185811, 0.09622032942272307, 2.129127872127872, 0.03187352066464925, 3.5485464535464537, 0.0037706833257574383], [0.7107102897102896, 1.0, 0.3404247440035638, 1.4214205794205792, 0.09592459675242465, 2.132130869130869, 0.03171314974450534, 3.553551448551449, 0.003739619216250871], [0.7117112887112886, 1.0, 0.3400770539577186, 1.4234225774225773, 0.0956301438705021, 2.135133866133866, 0.03155363096688719, 3.558556443556444, 0.0037088004716787164], [0.7127122877122876, 1.0, 0.3397306463875393, 1.4254245754245751, 0.09533696794455478, 2.138136863136863, 0.03139496087929521, 3.5635614385614387, 0.0036782252392106164], [0.7137132867132866, 1.0, 0.3393855204599856, 1.4274265734265732, 0.09504506615446537, 2.14113986013986, 0.031237136047598184, 3.568566433566434, 0.0036478916806562214], [0.7147142857142856, 1.0, 0.33904167534509955, 1.4294285714285713, 0.09475443569237277, 2.144142857142857, 0.031080153055958983, 3.573571428571429, 0.003617797972354674], [0.7157152847152846, 1.0, 0.33869911021600285, 1.4314305694305691, 0.09446507376264494, 2.147145854145854, 0.030924008506760556, 3.5785764235764237, 0.0035879423050649705], [0.7167162837162836, 1.0, 0.338357824248896, 1.4334325674325672, 0.09417697758185219, 2.150148851148851, 0.030768699020532492, 3.583581418581419, 0.003558322883857196], [0.7177172827172826, 1.0, 0.3380178166230547, 1.4354345654345653, 0.09389014437874028, 2.153151848151848, 0.030614221235877804, 3.588586413586414, 0.0035289379280045996], [0.7187182817182816, 1.0, 0.3376790865208295, 1.4374365634365631, 0.0936045713942038, 2.156154845154845, 0.030460571809400223, 3.5935914085914087, 0.0034997856708765514], [0.7197192807192806, 1.0, 0.337341633127643, 1.4394385614385612, 0.09332025588125956, 2.159157842157842, 0.03030774741563179, 3.598596403596404, 0.0034708643598323177], [0.7207202797202796, 1.0, 0.3370054556319878, 1.4414405594405593, 0.09303719510502041, 2.162160839160839, 0.030155744746960908, 3.603601398601399, 0.0034421722561157053], [0.7217212787212786, 1.0, 0.33667055322542483, 1.4434425574425571, 0.0927553863426686, 2.165163836163836, 0.030004560513560787, 3.6086063936063937, 0.003413707634750516], [0.7227222777222776, 1.0, 0.33633692510258173, 1.4454445554445552, 0.09247482688342985, 2.168166833166833, 0.029854191443318193, 3.613611388611389, 0.0033854687844368484], [0.7237232767232766, 1.0, 0.33600457046114995, 1.4474465534465533, 0.09219551402854716, 2.17116983016983, 0.02970463428176265, 3.618616383616384, 0.003357454007448211], [0.7247242757242756, 1.0, 0.33567348850188355, 1.4494485514485511, 0.09191744509125481, 2.174172827172827, 0.029555885791995973, 3.6236213786213787, 0.0033296616195294527], [0.7257252747252746, 1.0, 0.33534367842859747, 1.4514505494505492, 0.09164061739675262, 2.177175824175824, 0.029407942754622253, 3.628626373626374, 0.0033020899497955107], [0.7267262737262736, 1.0, 0.3350151394481653, 1.4534525474525473, 0.09136502828218022, 2.180178821178821, 0.029260801967678184, 3.633631368631369, 0.0032747373406309486], [0.7277272727272726, 1.0, 0.3346878707705167, 1.4554545454545451, 0.09109067509659124, 2.183181818181818, 0.029114460246563702, 3.638636363636364, 0.003247602147590305], [0.7287282717282716, 1.0, 0.33436187160863695, 1.4574565434565432, 0.09081755520092807, 2.186184815184815, 0.028968914423973126, 3.643641358641359, 0.003220682739299231], [0.7297292707292706, 1.0, 0.33403714117856376, 1.4594585414585413, 0.0905456659679963, 2.189187812187812, 0.028824161349826585, 3.648646353646354, 0.003193977497356405], [0.7307302697302696, 1.0, 0.3337136786993858, 1.461460539460539, 0.09027500478243954, 2.192190809190809, 0.02868019789120179, 3.653651348651349, 0.0031674848162362426], [0.7317312687312686, 1.0, 0.3333914833932412, 1.4634625374625372, 0.09000556904071423, 2.195193806193806, 0.028537020932266323, 3.658656343656344, 0.0031412031031923626], [0.7327322677322676, 1.0, 0.3330705544853154, 1.4654645354645353, 0.08973735615106462, 2.198196803196803, 0.028394627374210137, 3.663661338661339, 0.003115130778161839], [0.7337332667332666, 1.0, 0.3327508912038392, 1.467466533466533, 0.08947036353349776, 2.2011998001998, 0.028253014135178472, 3.668666333666334, 0.003089266273670201], [0.7347342657342656, 1.0, 0.33243249278008724, 1.4694685314685312, 0.08920458861975876, 2.204202797202797, 0.028112178150205197, 3.673671328671329, 0.0030636080347372025], [0.7357352647352646, 1.0, 0.332115358448375, 1.4714705294705293, 0.08894002885330611, 2.207205794205794, 0.027972116371146483, 3.678676323676324, 0.0030381545187833266], [0.7367362637362636, 1.0, 0.3317994874460589, 1.473472527472527, 0.08867668168928697, 2.210208791208791, 0.027832825766614794, 3.683681318681319, 0.0030129041955370577], [0.7377372627372626, 1.0, 0.3314848790135329, 1.4754745254745252, 0.08841454459451281, 2.213211788211788, 0.027694303321913284, 3.688686313686314, 0.002987855546942871], [0.7387382617382616, 1.0, 0.33117153239422714, 1.4774765234765233, 0.08815361504743499, 2.216214785214785, 0.027556546038970575, 3.693691308691309, 0.0029630070670699695], [0.7397392607392607, 1.0, 0.33085944683460633, 1.4794785214785213, 0.08789389053812045, 2.219217782217782, 0.027419550936275818, 3.698696303696304, 0.002938357262021753], [0.7407402597402596, 1.0, 0.3305486215841674, 1.4814805194805192, 0.08763536856822779, 2.222220779220779, 0.027283315048814216, 3.703701298701299, 0.0029139046498459936], [0.7417412587412586, 1.0, 0.3302390558954389, 1.4834825174825172, 0.08737804665098288, 2.225223776223776, 0.02714783542800287, 3.708706293706294, 0.0028896477604457515], [0.7427422577422577, 1.0, 0.3299307490239776, 1.4854845154845153, 0.08712192231115522, 2.228226773226773, 0.027013109141626863, 3.713711288711289, 0.0028655851354909847], [0.7437432567432566, 1.0, 0.3296237002283677, 1.4874865134865132, 0.08686699308503404, 2.23122977022977, 0.026879133273775873, 3.718716283716284, 0.0028417153283308754], [0.7447442557442556, 1.0, 0.32931790877021894, 1.4894885114885112, 0.08661325652040464, 2.234232767232767, 0.02674590492478109, 3.723721278721279, 0.0028180369039068607], [0.7457452547452547, 1.0, 0.3290133739141646, 1.4914905094905093, 0.08636071017652469, 2.237235764235764, 0.02661342121115235, 3.728726273726274, 0.002794548438666353], [0.7467462537462536, 1.0, 0.32871009492785963, 1.4934925074925072, 0.08610935162410085, 2.240238761238761, 0.02648167926551586, 3.733731268731269, 0.0027712485204771553], [0.7477472527472526, 1.0, 0.32840807108197967, 1.4954945054945052, 0.08585917844526547, 2.243241758241758, 0.026350676236552042, 3.738736263736264, 0.0027481357485425683], [0.7487482517482517, 1.0, 0.328107301650218, 1.4974965034965033, 0.08561018823355324, 2.246244755244755, 0.026220409288933856, 3.743741258741259, 0.0027252087333171663], [0.7497492507492506, 1.0, 0.3278077859092851, 1.4994985014985012, 0.08536237859387791, 2.249247752247752, 0.02609087560326542, 3.748746253746254, 0.002702466096423266], [0.7507502497502496, 1.0, 0.3275095231389062, 1.5015004995004992, 0.08511574714250951, 2.252250749250749, 0.025962072376021012, 3.753751248751249, 0.00267990647056805], [0.7517512487512487, 1.0, 0.32721251262181944, 1.5035024975024973, 0.08487029150705125, 2.255253746253746, 0.025833996819484388, 3.758756243756244, 0.0026575284994613717], [0.7527522477522476, 1.0, 0.32691675364377437, 1.5055044955044952, 0.08462600932641672, 2.258256743256743, 0.02570664616168844, 3.763761238761239, 0.00263533083773421], [0.7537532467532466, 1.0, 0.3266222454935304, 1.5075064935064932, 0.08438289825080718, 2.26125974025974, 0.02558001764635516, 3.768766233766234, 0.002613312150857787], [0.7547542457542457, 1.0, 0.326328987462855, 1.5095084915084913, 0.08414095594168923, 2.264262737262737, 0.02545410853283609, 3.773771228771229, 0.0025914711150633388], [0.7557552447552446, 1.0, 0.3260369788465218, 1.5115104895104892, 0.08390018007177165, 2.267265734265734, 0.025328916096052874, 3.778776223776224, 0.0025698064172625223], [0.7567562437562436, 1.0, 0.32574621894230893, 1.5135124875124872, 0.08366056832498375, 2.270268731268731, 0.0252044376264384, 3.783781218781219, 0.002548316754968484], [0.7577572427572427, 1.0, 0.32545670705099733, 1.5155144855144853, 0.0834221183964527, 2.273271728271728, 0.025080670429878098, 3.788786213786214, 0.0025270008362175407], [0.7587582417582416, 1.0, 0.3251684424763698, 1.5175164835164832, 0.08318482799248123, 2.276274725274725, 0.024957611827651587, 3.793791208791209, 0.0025058573794915157], [0.7597592407592406, 1.0, 0.32488142452520763, 1.5195184815184812, 0.08294869483052607, 2.279277722277722, 0.02483525915637482, 3.798796203796204, 0.0024848851136406902], [0.7607602397602397, 1.0, 0.32459565250729105, 1.5215204795204793, 0.08271371663917554, 2.282280719280719, 0.0247136097679423, 3.803801198801199, 0.002464082777807385], [0.7617612387612386, 1.0, 0.32431112573539606, 1.5235224775224772, 0.0824798911581278, 2.285283716283716, 0.02459266102946988, 3.808806193806194, 0.002443449121350151], [0.7627622377622376, 1.0, 0.3240278435252932, 1.5255244755244752, 0.08224721613816927, 2.288286713286713, 0.024472410323237694, 3.813811188811189, 0.0024229829037685844], [0.7637632367632367, 1.0, 0.3237458051957458, 1.5275264735264733, 0.08201568934115284, 2.29128971028971, 0.02435285504663358, 3.818816183816184, 0.00240268289462875], [0.7647642357642356, 1.0, 0.323465010068509, 1.5295284715284712, 0.0817853085399764, 2.294292707292707, 0.0242339926120967, 3.823821178821179, 0.0023825478734892], [0.7657652347652346, 1.0, 0.3231854574683268, 1.5315304695304692, 0.08155607151856135, 2.297295704295704, 0.024115820447061512, 3.828826173826174, 0.002362576629827608], [0.7667662337662337, 1.0, 0.3229071467229319, 1.5335324675324673, 0.08132797607183138, 2.300298701298701, 0.023998335993902154, 3.833831168831169, 0.002342767962967987], [0.7677672327672326, 1.0, 0.32263007716304304, 1.5355344655344652, 0.0811010200056912, 2.3033016983016985, 0.023881536709877083, 3.838836163836164, 0.0023231206820085084], [0.7687682317682316, 1.0, 0.3223542481223644, 1.5375364635364632, 0.08087520113700539, 2.3063046953046955, 0.023765420067073967, 3.843841158841159, 0.002303633605749902], [0.7697692307692307, 1.0, 0.32207965893758206, 1.5395384615384613, 0.08065051729357763, 2.3093076923076925, 0.02364998355235508, 3.848846153846154, 0.0022843055626244405], [0.7707702297702297, 1.0, 0.3218063089483647, 1.5415404595404594, 0.0804269663141294, 2.3123106893106895, 0.02353522466730283, 3.8538511488511493, 0.0022651353906255117], [0.7717712287712286, 1.0, 0.3215341974973609, 1.5435424575424572, 0.08020454604827965, 2.3153136863136865, 0.02342114092816572, 3.858856143856144, 0.00224612193723775], [0.7727722277722276, 1.0, 0.32126332393019735, 1.5455444555444553, 0.07998325435652368, 2.3183166833166835, 0.023307729865804556, 3.863861138861139, 0.002227264059367752], [0.7737732267732267, 1.0, 0.3209936875954782, 1.5475464535464534, 0.07976308911021292, 2.3213196803196805, 0.023194989025639087, 3.8688661338661343, 0.00220856062327535], [0.7747742257742256, 1.0, 0.32072528784478227, 1.5495484515484512, 0.07954404819153424, 2.3243226773226775, 0.023082915967594767, 3.873871128871129, 0.002190010504505458], [0.7757752247752246, 1.0, 0.32045812403266205, 1.5515504495504493, 0.07932612949348967, 2.3273256743256745, 0.02297150826605004, 3.878876123876124, 0.002171612587820457], [0.7767762237762237, 1.0, 0.32019219551664285, 1.5535524475524474, 0.07910933091987607, 2.3303286713286715, 0.02286076350978381, 3.8838811188811193, 0.0021533657671331625], [0.7777772227772226, 1.0, 0.3199275016572204, 1.5555544455544452, 0.07889365038526502, 2.3333316683316685, 0.022750679301923236, 3.888886113886114, 0.002135268945440311], [0.7787782217782216, 1.0, 0.31966404181785923, 1.5575564435564433, 0.07867908581498276, 2.3363346653346655, 0.022641253259891872, 3.893891108891109, 0.00211732103475662], [0.7797792207792207, 1.0, 0.3194018153649915, 1.5595584415584414, 0.0784656351450901, 2.3393376623376625, 0.022532483015358075, 3.8988961038961043, 0.002099520956049367], [0.7807802197802196, 1.0, 0.31914082166801583, 1.5615604395604392, 0.0782532963223628, 2.3423406593406595, 0.022424366214183807, 3.903901098901099, 0.0020818676391735286], [0.7817812187812186, 1.0, 0.3188810600992949, 1.5635624375624373, 0.07804206730427173, 2.3453436563436565, 0.02231690051637363, 3.908906093906094, 0.0020643600228074355], [0.7827822177822177, 1.0, 0.3186225300341548, 1.5655644355644354, 0.07783194605896296, 2.3483466533466535, 0.022210083596024076, 3.9139110889110893, 0.0020469970543889678], [0.7837832167832166, 1.0, 0.31836523085088253, 1.5675664335664332, 0.0776229305652387, 2.3513496503496505, 0.022103913141273322, 3.918916083916084, 0.002029777690052278], [0.7847842157842156, 1.0, 0.31810916193072575, 1.5695684315684313, 0.07741501881253751, 2.3543526473526475, 0.021998386854251126, 3.923921078921079, 0.0020127008945650298], [0.7857852147852147, 1.0, 0.31785432265789054, 1.5715704295704294, 0.07720820880091507, 2.3573556443556445, 0.021893502451029112, 3.9289260739260743, 0.001995765641266157], [0.7867862137862136, 1.0, 0.31760071241953985, 1.5735724275724272, 0.07700249854102488, 2.3603586413586415, 0.021789257661571332, 3.933931068931069, 0.0019789709120041485], [0.7877872127872126, 1.0, 0.3173483306057921, 1.5755744255744253, 0.0767978860540992, 2.3633616383616385, 0.021685650229685136, 3.938936063936064, 0.0019623156970758303], [0.7887882117882117, 1.0, 0.31709717660972, 1.5775764235764234, 0.07659436937192995, 2.3663646353646355, 0.021582677912972366, 3.9439410589410593, 0.0019457989951656616], [0.7897892107892106, 1.0, 0.3168472498273491, 1.5795784215784212, 0.0763919465368499, 2.3693676323676325, 0.02148033848278075, 3.948946053946054, 0.0019294198132855406], [0.7907902097902096, 1.0, 0.31659854965765577, 1.5815804195804193, 0.07619061560171361, 2.3723706293706295, 0.021378629724155784, 3.9539510489510494, 0.001913177166715101], [0.7917912087912087, 1.0, 0.31635107550256625, 1.5835824175824174, 0.07599037462987894, 2.3753736263736265, 0.02127754943579268, 3.9589560439560443, 0.0018970700789425143], [0.7927922077922076, 1.0, 0.3161048267669557, 1.5855844155844152, 0.07579122169518833, 2.3783766233766235, 0.021177095429988774, 3.963961038961039, 0.001881097581605778], [0.7937932067932066, 1.0, 0.315859802858645, 1.5875864135864133, 0.07559315488195031, 2.3813796203796205, 0.021077265532596163, 3.9689660339660344, 0.0018652587144345014], [0.7947942057942057, 1.0, 0.3156160031884016, 1.5895884115884114, 0.0753961722849209, 2.3843826173826175, 0.020978057582974698, 3.9739710289710293, 0.001849552525192168], [0.7957952047952046, 1.0, 0.3153734271699362, 1.5915904095904092, 0.07520027200928553, 2.3873856143856145, 0.02087946943394513, 3.978976023976024, 0.0018339780696188922], [0.7967962037962036, 1.0, 0.31513207421990275, 1.5935924075924073, 0.07500545217064063, 2.3903886113886115, 0.02078149895174273, 3.9839810189810194, 0.0018185344113746497], [0.7977972027972027, 1.0, 0.31489194375789586, 1.5955944055944054, 0.0748117108949755, 2.3933916083916085, 0.020684144015971045, 3.9889860139860143, 0.0018032206219829807], [0.7987982017982017, 1.0, 0.3146530352064507, 1.5975964035964034, 0.07461904631865457, 2.3963946053946055, 0.020587402519556024, 3.993991008991009, 0.0017880357807751733], [0.7997992007992006, 1.0, 0.3144153479910399, 1.5995984015984013, 0.07442745658839896, 2.3993976023976025, 0.02049127236870044, 3.9989960039960044, 0.0017729789748349113], [0.8008001998001997, 1.0, 0.3141788815400741, 1.6016003996003993, 0.07423693986126916, 2.4024005994005995, 0.02039575148283852, 4.004000999001, 0.0017580492989433911], [0.8018011988011987, 1.0, 0.31394363528489894, 1.6036023976023974, 0.07404749430464713, 2.4054035964035965, 0.020300837794590968, 4.009005994005994, 0.0017432458555248955], [0.8028021978021976, 1.0, 0.3137096086597947, 1.6056043956043953, 0.07385911809621837, 2.4084065934065935, 0.020206529249720183, 4.014010989010989, 0.0017285677545928366], [0.8038031968031967, 1.0, 0.31347680110197473, 1.6076063936063933, 0.07367180942395489, 2.4114095904095905, 0.02011282380708582, 4.019015984015985, 0.0017140141136962456], [0.8048041958041957, 1.0, 0.3132452120515835, 1.6096083916083914, 0.07348556648609744, 2.4144125874125875, 0.020019719438600626, 4.024020979020979, 0.0016995840578667213], [0.8058051948051946, 1.0, 0.3130148409516966, 1.6116103896103893, 0.0733003874911383, 2.4174155844155845, 0.019927214129186497, 4.029025974025974, 0.0016852767195658265], [0.8068061938061937, 1.0, 0.312785687248318, 1.6136123876123873, 0.073116270657804, 2.4204185814185815, 0.01983530587673091, 4.03403096903097, 0.001671091238632932], [0.8078071928071927, 1.0, 0.312557750390379, 1.6156143856143854, 0.0729332142150383, 2.4234215784215785, 0.019743992692043588, 4.039035964035964, 0.0016570267622335025], [0.8088081918081916, 1.0, 0.3123310298297378, 1.6176163836163833, 0.07275121640198501, 2.4264245754245755, 0.01965327259881341, 4.044040959040959, 0.001643082444807824], [0.8098091908091907, 1.0, 0.31210552502117733, 1.6196183816183813, 0.07257027546797111, 2.4294275724275725, 0.01956314363356566, 4.049045954045955, 0.0016292574480201707], [0.8108101898101897, 1.0, 0.3118812354224036, 1.6216203796203794, 0.0723903896724899, 2.4324305694305695, 0.019473603845619553, 4.054050949050949, 0.0016155509407084004], [0.8118111888111886, 1.0, 0.31165816049404566, 1.6236223776223773, 0.07221155728518427, 2.4354335664335665, 0.01938465129704601, 4.059055944055944, 0.0016019620988339872], [0.8128121878121877, 1.0, 0.3114362996996533, 1.6256243756243753, 0.07203377658583003, 2.4384365634365635, 0.019296284062625665, 4.06406093906094, 0.0015884901054324801], [0.8138131868131867, 1.0, 0.3112156525056962, 1.6276263736263734, 0.07185704586431944, 2.4414395604395605, 0.01920850022980724, 4.069065934065934, 0.0015751341505643862], [0.8148141858141856, 1.0, 0.31099621838156255, 1.6296283716283713, 0.07168136342064464, 2.4444425574425575, 0.01912129789866616, 4.074070929070929, 0.0015618934312664776], [0.8158151848151847, 1.0, 0.31077799679955725, 1.6316303696303693, 0.07150672756488143, 2.4474455544455544, 0.019034675181863418, 4.079075924075925, 0.0015487671515035171], [0.8168161838161837, 1.0, 0.31056098723490166, 1.6336323676323674, 0.07133313661717298, 2.4504485514485514, 0.018948630204604713, 4.084080919080919, 0.0015357545221203982], [0.8178171828171826, 1.0, 0.31034518916573167, 1.6356343656343653, 0.07116058890771347, 2.4534515484515484, 0.018863161104599898, 4.089085914085914, 0.0015228547607947036], [0.8188181818181817, 1.0, 0.31013060207309623, 1.6376363636363633, 0.07098908277673234, 2.4564545454545454, 0.01877826603202264, 4.09409090909091, 0.0015100670919896714], [0.8198191808191807, 1.0, 0.3099172254409568, 1.6396383616383614, 0.0708186165744782, 2.4594575424575424, 0.018693943149470444, 4.099095904095904, 0.0014973907469075698], [0.8208201798201796, 1.0, 0.309705058756186, 1.6416403596403593, 0.0706491886612028, 2.4624605394605394, 0.018610190631924817, 4.104100899100899, 0.0014848249634434737], [0.8218211788211787, 1.0, 0.3094941015085652, 1.6436423576423573, 0.07048079740714551, 2.4654635364635364, 0.018527006666711802, 4.109105894105895, 0.0014723689861394506], [0.8228221778221777, 1.0, 0.3092843531907851, 1.6456443556443554, 0.07031344119251749, 2.4684665334665334, 0.018444389453462776, 4.114110889110889, 0.0014600220661391402], [0.8238231768231766, 1.0, 0.3090758132984431, 1.6476463536463533, 0.07014711840748616, 2.4714695304695304, 0.018362337204075416, 4.119115884115884, 0.0014477834611427351], [0.8248241758241757, 1.0, 0.3088684813300431, 1.6496483516483513, 0.06998182745215968, 2.4744725274725274, 0.018280848142675055, 4.12412087912088, 0.0014356524353623496], [0.8258251748251747, 1.0, 0.30866235678699344, 1.6516503496503494, 0.06981756673657162, 2.4774755244755244, 0.018199920505576225, 4.129125874125874, 0.0014236282594777881], [0.8268261738261736, 1.0, 0.3084574391736063, 1.6536523476523473, 0.06965433468066566, 2.4804785214785214, 0.01811955254124445, 4.134130869130869, 0.001411710210592697], [0.8278271728271727, 1.0, 0.30825372799709627, 1.6556543456543453, 0.06949212971428016, 2.4834815184815184, 0.018039742510258416, 4.139135864135865, 0.0013998975721911022], [0.8288281718281717, 1.0, 0.30805122276757935, 1.6576563436563434, 0.0693309502771336, 2.4864845154845154, 0.01796048868527227, 4.144140859140859, 0.0013881896340943343], [0.8298291708291707, 1.0, 0.30784992299807074, 1.6596583416583415, 0.06917079481880896, 2.4894875124875124, 0.017881789350978266, 4.149145854145854, 0.0013765856924183289], [0.8308301698301697, 1.0, 0.30764982820448566, 1.6616603396603393, 0.06901166179873913, 2.4924905094905094, 0.017803642804069566, 4.15415084915085, 0.0013650850495313153], [0.8318311688311687, 1.0, 0.3074509379056362, 1.6636623376623374, 0.0688535496861921, 2.4954935064935064, 0.017726047353203492, 4.159155844155844, 0.0013536870140118684], [0.8328321678321677, 1.0, 0.3072532516232316, 1.6656643356643355, 0.06869645696025611, 2.4984965034965034, 0.01764900131896482, 4.164160839160839, 0.0013423909006073445], [0.8338331668331667, 1.0, 0.307056768881876, 1.6676663336663333, 0.06854038210982508, 2.5014995004995004, 0.017572503033829484, 4.169165834165835, 0.0013311960301926802], [0.8348341658341657, 1.0, 0.3068614892090685, 1.6696683316683314, 0.06838532363358422, 2.5045024975024974, 0.017496550842128446, 4.174170829170829, 0.0013201017297295656], [0.8358351648351647, 1.0, 0.30666741213520055, 1.6716703296703295, 0.06823128003999523, 2.5075054945054944, 0.017421143100011912, 4.179175824175824, 0.0013091073322259819], [0.8368361638361637, 1.0, 0.3064745371935565, 1.6736723276723273, 0.0680782498472823, 2.5105084915084914, 0.017346278175413735, 4.18418081918082, 0.0012982121766960983], [0.8378371628371627, 1.0, 0.3062828639203106, 1.6756743256743254, 0.06792623158341764, 2.5135114885114884, 0.01727195444801606, 4.189185814185814, 0.0012874156081205375], [0.8388381618381617, 1.0, 0.30609239185452786, 1.6776763236763235, 0.06777522378610745, 2.5165144855144854, 0.017198170309214295, 4.194190809190809, 0.0012767169774069922], [0.8398391608391607, 1.0, 0.305903120538161, 1.6796783216783213, 0.06762522500277786, 2.5195174825174824, 0.017124924162082295, 4.199195804195805, 0.0012661156413512034], [0.8408401598401597, 1.0, 0.30571504951605055, 1.6816803196803194, 0.06747623379056086, 2.5225204795204794, 0.01705221442133776, 4.2042007992008, 0.0012556109625982898], [0.8418411588411587, 1.0, 0.30552817833592394, 1.6836823176823175, 0.06732824871628047, 2.5255234765234764, 0.016980039513307968, 4.209205794205794, 0.0012452023096044312], [0.8428421578421577, 1.0, 0.30534250654839346, 1.6856843156843153, 0.06718126835643892, 2.5285264735264734, 0.016908397875895684, 4.21421078921079, 0.0012348890565988997], [0.8438431568431567, 1.0, 0.3051580337069562, 1.6876863136863134, 0.06703529129720297, 2.5315294705294704, 0.016837287958545374, 4.219215784215785, 0.0012246705835464362], [0.8448441558441557, 1.0, 0.3049747593679923, 1.6896883116883115, 0.06689031613439046, 2.5345324675324674, 0.01676670822220964, 4.224220779220779, 0.0012145462761099766], [0.8458451548451547, 1.0, 0.30479268309076346, 1.6916903096903093, 0.06674634147345652, 2.5375354645354644, 0.01669665713931588, 4.229225774225775, 0.0012045155256137157], [0.8468461538461537, 1.0, 0.3046118044374135, 1.6936923076923074, 0.06660336592948043, 2.5405384615384614, 0.016627133193733296, 4.23423076923077, 0.001194577729006514], [0.8478471528471527, 1.0, 0.30443212297296574, 1.6956943056943055, 0.0664613881271521, 2.5435414585414584, 0.016558134880740004, 4.239235764235764, 0.0011847322888256435], [0.8488481518481517, 1.0, 0.3042536382653226, 1.6976963036963033, 0.0663204067007589, 2.5465444555444554, 0.016489660706990514, 4.24424075924076, 0.0011749786131608649], [0.8498491508491507, 1.0, 0.3040763498852638, 1.6996983016983014, 0.06618042029417252, 2.5495474525474524, 0.01642170919048341, 4.249245754245755, 0.0011653161156188442], [0.8508501498501497, 1.0, 0.30390025740644716, 1.7017002997002995, 0.06604142756083602, 2.5525504495504494, 0.01635427886052923, 4.254250749250749, 0.0011557442152878997], [0.8518511488511487, 1.0, 0.30372536040540576, 1.7037022977022973, 0.06590342716375075, 2.5555534465534464, 0.016287368257718697, 4.259255744255745, 0.0011462623367030742], [0.8528521478521477, 1.0, 0.30355165846154725, 1.7057042957042954, 0.0657664177754635, 2.5585564435564434, 0.016220975933891067, 4.26426073926074, 0.00113686990981154], [0.8538531468531467, 1.0, 0.3033791511571536, 1.7077062937062935, 0.06563039807805394, 2.5615594405594404, 0.016155100452102854, 4.269265734265734, 0.0011275663699383267], [0.8548541458541457, 1.0, 0.30320783807737955, 1.7097082917082913, 0.06549536676312152, 2.5645624375624374, 0.016089740386596676, 4.27427072927073, 0.001118351157752373], [0.8558551448551447, 1.0, 0.30303771881025193, 1.7117102897102894, 0.06536132253177335, 2.5675654345654344, 0.016024894322770433, 4.279275724275725, 0.001109223719232901], [0.8568561438561437, 1.0, 0.30286879294666824, 1.7137122877122875, 0.06522826409461138, 2.5705684315684314, 0.015960560857146658, 4.284280719280719, 0.0011001835056361038], [0.8578571428571427, 1.0, 0.3027010600803956, 1.7157142857142853, 0.06509619017172018, 2.5735714285714284, 0.01589673859734216, 4.289285714285715, 0.0010912299734621594], [0.8588581418581417, 1.0, 0.3025345198080708, 1.7177162837162834, 0.06496509949265453, 2.5765744255744254, 0.015833426162037905, 4.29429070929071, 0.0010823625844225554], [0.8598591408591407, 1.0, 0.3023691717291978, 1.7197182817182814, 0.06483499079642713, 2.5795774225774224, 0.015770622180949084, 4.299295704295704, 0.001073580805407722], [0.8608601398601398, 1.0, 0.3022050154461482, 1.7217202797202795, 0.06470586283149679, 2.5825804195804194, 0.015708325294795485, 4.3043006993007, 0.0010648841084549884], [0.8618611388611387, 1.0, 0.3020420505641591, 1.7237222777222774, 0.06457771435575597, 2.5855834165834164, 0.015646534155272028, 4.309305694305695, 0.0010562719707168345], [0.8628621378621377, 1.0, 0.30188027669133305, 1.7257242757242754, 0.06445054413651903, 2.5885864135864134, 0.015585247425019669, 4.314310689310689, 0.0010477438744294632], [0.8638631368631368, 1.0, 0.3017196934386363, 1.7277262737262735, 0.06432435095051048, 2.5915894105894104, 0.015524463777596365, 4.319315684315685, 0.0010392993068816683], [0.8648641358641357, 1.0, 0.30156030041989856, 1.7297282717282714, 0.0641991335838531, 2.5945924075924074, 0.015464181897448434, 4.32432067932068, 0.0010309377603840127], [0.8658651348651347, 1.0, 0.3014020972518119, 1.7317302697302694, 0.06407489083205621, 2.5975954045954044, 0.015404400479882032, 4.329325674325674, 0.0010226587322383037], [0.8668661338661338, 1.0, 0.3012450835539298, 1.7337322677322675, 0.06395162150000412, 2.6005984015984014, 0.015345118231034939, 4.33433066933067, 0.001014461724707372], [0.8678671328671327, 1.0, 0.301089258948666, 1.7357342657342654, 0.06382932440194478, 2.6036013986013984, 0.015286333867848553, 4.339335664335665, 0.001006346244985148], [0.8688681318681317, 1.0, 0.3009346230612935, 1.7377362637362634, 0.06370799836147809, 2.6066043956043954, 0.01522804611804011, 4.344340659340659, 0.0009983118051670337], [0.8698691308691308, 1.0, 0.3007811755199442, 1.7397382617382615, 0.06358764221154492, 2.6096073926073924, 0.015170253720075173, 4.349345654345655, 0.0009903579222205682], [0.8708701298701297, 1.0, 0.3006289159556081, 1.7417402597402594, 0.06346825479441558, 2.61261038961039, 0.015112955423140315, 4.35435064935065, 0.0009824841179563912], [0.8718711288711287, 1.0, 0.3004778440021313, 1.7437422577422574, 0.06334983496167881, 2.615613386613387, 0.015056149987116033, 4.359355644355644, 0.0009746899189994904], [0.8728721278721278, 1.0, 0.3003279592962167, 1.7457442557442555, 0.06323238157423086, 2.618616383616384, 0.014999836182549924, 4.36436063936064, 0.0009669748567607449], [0.8738731268731267, 1.0, 0.3001792614774214, 1.7477462537462534, 0.0631158935022643, 2.621619380619381, 0.014944012790630075, 4.369365634365635, 0.000959338467408752], [0.8748741258741257, 1.0, 0.3000317501881574, 1.7497482517482514, 0.0630003696252573, 2.624622377622378, 0.014888678603158668, 4.374370629370629, 0.0009517802918419419], [0.8758751248751248, 1.0, 0.2998854250736897, 1.7517502497502495, 0.06288580883196274, 2.627625374625375, 0.01483383242252586, 4.3793756243756246, 0.0009442998756609764], [0.8768761238761237, 1.0, 0.29974028578213613, 1.7537522477522474, 0.06277221002039773, 2.630628371628372, 0.014779473061683833, 4.38438061938062, 0.0009368967691414309], [0.8778771228771227, 1.0, 0.2995963319644658, 1.7557542457542454, 0.06265957209783278, 2.633631368631369, 0.014725599344121126, 4.389385614385614, 0.0009295705272067549], [0.8788781218781218, 1.0, 0.2994535632744988, 1.7577562437562435, 0.06254789398078131, 2.636634365634366, 0.014672210103837149, 4.3943906093906095, 0.0009223207094015166], [0.8798791208791207, 1.0, 0.29931197936890575, 1.7597582417582414, 0.062437174594989486, 2.639637362637363, 0.014619304185316977, 4.399395604395605, 0.0009151468798649208], [0.8808801198801197, 1.0, 0.29917157990720544, 1.7617602397602394, 0.06232741287542557, 2.64264035964036, 0.014566880443506292, 4.4044005994006, 0.0009080486073046062], [0.8818811188811188, 1.0, 0.29903236455176563, 1.7637622377622375, 0.062218607766269876, 2.645643356643357, 0.01451493774378667, 4.4094055944055945, 0.0009010254649707137], [0.8828821178821177, 1.0, 0.29889433296780166, 1.7657642357642354, 0.06211075822090438, 2.648646353646354, 0.014463474961950948, 4.41441058941059, 0.0008940770306302328], [0.8838831168831167, 1.0, 0.2987574848233754, 1.7677662337662334, 0.06200386320190308, 2.651649350649351, 0.014412490984178957, 4.419415584415585, 0.0008872028865416144], [0.8848841158841158, 1.0, 0.2986218197893947, 1.7697682317682315, 0.06189792168102154, 2.654652347652348, 0.01436198470701338, 4.4244205794205795, 0.0008804026194296585], [0.8858851148851147, 1.0, 0.2984873375396127, 1.7717702297702294, 0.061792932639187226, 2.657655344655345, 0.014311955037335879, 4.429425574425575, 0.0008736758204606649], [0.8868861138861137, 1.0, 0.2983540377506263, 1.7737722277722274, 0.061688895066489856, 2.660658341658342, 0.014262400892343435, 4.43443056943057, 0.0008670220852178582], [0.8878871128871128, 1.0, 0.29822192010187637, 1.7757742257742255, 0.061585807962171404, 2.663661338661339, 0.014213321199524913, 4.4394355644355645, 0.0008604410136770705], [0.8888881118881118, 1.0, 0.2980909842756469, 1.7777762237762236, 0.06148367033461651, 2.666664335664336, 0.014164714896637858, 4.44444055944056, 0.0008539322101826929], [0.8898891108891107, 1.0, 0.29796122995706353, 1.7797782217782214, 0.061382481201343174, 2.669667332667333, 0.014116580931685488, 4.449445554445555, 0.0008474952834238908], [0.8908901098901097, 1.0, 0.29783265683409355, 1.7817802197802195, 0.06128223958899298, 2.67267032967033, 0.014068918262893916, 4.4544505494505495, 0.0008411298464110735], [0.8918911088911088, 1.0, 0.29770526459754465, 1.7837822177822176, 0.061182944533322105, 2.675673326673327, 0.014021725858689653, 4.459455544455545, 0.0008348355164526326], [0.8928921078921077, 1.0, 0.2975790529410642, 1.7857842157842154, 0.06108459507919167, 2.678676323676324, 0.013975002697677229, 4.46446053946054, 0.0008286119151319326], [0.8938931068931067, 1.0, 0.2974540215611382, 1.7877862137862135, 0.06098719028055882, 2.681679320679321, 0.013928747768617111, 4.4694655344655345, 0.0008224586682845617], [0.8948941058941058, 1.0, 0.29733017015709207, 1.7897882117882116, 0.06089072920046754, 2.684682317682318, 0.01388296007040382, 4.47447052947053, 0.0008163754059758344], [0.8958951048951047, 1.0, 0.2972074984310876, 1.7917902097902094, 0.060795210911039524, 2.687685314685315, 0.013837638612044234, 4.479475524475525, 0.0008103617624785537], [0.8968961038961037, 1.0, 0.29708600608812435, 1.7937922077922075, 0.06070063449346546, 2.690688311688312, 0.013792782412636184, 4.4844805194805195, 0.0008044173762510223], [0.8978971028971028, 1.0, 0.2969656928360375, 1.7957942057942056, 0.06060699903799606, 2.693691308691309, 0.013748390501347197, 4.489485514485515, 0.0007985418899153055], [0.8988981018981017, 1.0, 0.29684655838549834, 1.7977962037962034, 0.06051430364393329, 2.696694305694306, 0.013704461917393464, 4.49449050949051, 0.0007927349502357488], [0.8998991008991007, 1.0, 0.29672860245001237, 1.7997982017982015, 0.06042254741962183, 2.699697302697303, 0.013660995710019112, 4.4994955044955045, 0.0007869962080977378], [0.9009000999000998, 1.0, 0.29661182474591935, 1.8018001998001996, 0.06033172948244036, 2.7027002997003, 0.013617990938475556, 4.5045004995005, 0.0007813253184867107], [0.9019010989010987, 1.0, 0.29649622499239253, 1.8038021978021974, 0.06024184895879315, 2.705703296703297, 0.013575446672001163, 4.509505494505495, 0.000775721940467416], [0.9029020979020977, 1.0, 0.2963818029114382, 1.8058041958041955, 0.06015290498410163, 2.708706293706294, 0.01353336198980114, 4.5145104895104895, 0.000770185737163416], [0.9039030969030968, 1.0, 0.29626855822789394, 1.8078061938061936, 0.060064896702796085, 2.711709290709291, 0.01349173598102755, 4.519515484515485, 0.0007647163757368326], [0.9049040959040957, 1.0, 0.29615649066942945, 1.8098081918081914, 0.05997782326830743, 2.714712287712288, 0.013450567744759646, 4.52452047952048, 0.0007593135273683383], [0.9059050949050947, 1.0, 0.29604559996654467, 1.8118101898101895, 0.059891683843059075, 2.717715284715285, 0.013409856389984326, 4.5295254745254745, 0.0007539768672373853], [0.9069060939060938, 1.0, 0.29593588585257, 1.8138121878121876, 0.059806477598458745, 2.720718281718282, 0.013369601035576896, 4.53453046953047, 0.0007487060745026797], [0.9079070929070927, 1.0, 0.2958273480636648, 1.8158141858141854, 0.059722203714890794, 2.723721278721279, 0.013329800810281964, 4.539535464535465, 0.0007435008322828908], [0.9089080919080917, 1.0, 0.2957199863388175, 1.8178161838161835, 0.059638861381708, 2.726724275724276, 0.01329045485269461, 4.5445404595404595, 0.0007383608276376005], [0.9099090909090908, 1.0, 0.2956138004198454, 1.8198181818181816, 0.05955644979722389, 2.729727272727273, 0.013251562311241695, 4.549545454545455, 0.0007332857515484901], [0.9109100899100897, 1.0, 0.29550879005139263, 1.8218201798201794, 0.05947496816870522, 2.73273026973027, 0.013213122344163507, 4.55455044955045, 0.0007282752989007611], [0.9119110889110887, 1.0, 0.2954049549809304, 1.8238221778221775, 0.05939441571236403, 2.7357332667332668, 0.013175134119495478, 4.5595554445554445, 0.0007233291684647915], [0.9129120879120878, 1.0, 0.2953022949587565, 1.8258241758241756, 0.059314791653350234, 2.7387362637362638, 0.01313759681505019, 4.56456043956044, 0.000718447062878027], [0.9139130869130867, 1.0, 0.29520080973799373, 1.8278261738261734, 0.05923609522574427, 2.7417392607392608, 0.013100509618399607, 4.569565434565435, 0.0007136286886271015], [0.9149140859140857, 1.0, 0.2951004990745909, 1.8298281718281715, 0.05915832567254964, 2.7447422577422578, 0.013063871726857466, 4.5745704295704295, 0.0007088737560301925], [0.9159150849150848, 1.0, 0.29500136272732136, 1.8318301698301696, 0.05908148224568554, 2.7477452547452548, 0.013027682347461917, 4.579575424575425, 0.0007041819792196061], [0.9169160839160837, 1.0, 0.29490340045778207, 1.8338321678321674, 0.05900556420597985, 2.7507482517482518, 0.01299194069695835, 4.58458041958042, 0.0006995530761245882], [0.9179170829170827, 1.0, 0.2948066120303938, 1.8358341658341655, 0.0589305708231619, 2.7537512487512488, 0.012956646001782451, 4.5895854145854145, 0.0006949867684543685], [0.9189180819180818, 1.0, 0.2947109972123997, 1.8378361638361635, 0.05885650137585551, 2.7567542457542458, 0.01292179749804346, 4.59459040959041, 0.0006904827816814285], [0.9199190809190808, 1.0, 0.2946165557738654, 1.8398381618381616, 0.058783355151572, 2.7597572427572428, 0.012887394431507626, 4.599595404595405, 0.0006860408450249968], [0.9209200799200797, 1.0, 0.2945232874876781, 1.8418401598401595, 0.05871113144670327, 2.7627602397602398, 0.012853436057581906, 4.6046003996003995, 0.0006816606914347709], [0.9219210789210788, 1.0, 0.294431192129547, 1.8438421578421575, 0.05863982956651527, 2.7657632367632368, 0.012819921641297832, 4.609605394605395, 0.00067734205757486], [0.9229220779220778, 1.0, 0.29434026947800107, 1.8458441558441556, 0.058569448825140986, 2.7687662337662338, 0.012786850457295598, 4.61461038961039, 0.0006730846838079549], [0.9239230769230767, 1.0, 0.2942505193143895, 1.8478461538461535, 0.058499988545574234, 2.7717692307692308, 0.012754221789808382, 4.619615384615385, 0.0006688883141797181], [0.9249240759240758, 1.0, 0.2941619414228817, 1.8498481518481515, 0.058431448059662806, 2.7747722277722278, 0.01272203493264684, 4.62462037962038, 0.0006647526964033949], [0.9259250749250748, 1.0, 0.2940745355904656, 1.8518501498501496, 0.05836382670810216, 2.7777752247752248, 0.012690289189183822, 4.629625374625375, 0.000660677581844647], [0.9269260739260737, 1.0, 0.2939883016069476, 1.8538521478521475, 0.05829712384042909, 2.7807782217782218, 0.012658983872339304, 4.63463036963037, 0.0006566627255066045], [0.9279270729270728, 1.0, 0.29390323926495243, 1.8558541458541455, 0.05823133881501554, 2.7837812187812188, 0.0126281183045655, 4.639635364635365, 0.0006527078860151356], [0.9289280719280718, 1.0, 0.2938193483599222, 1.8578561438561436, 0.05816647099906231, 2.7867842157842158, 0.01259769181783221, 4.64464035964036, 0.0006488128256043368], [0.9299290709290707, 1.0, 0.2937366286901163, 1.8598581418581415, 0.05810251976859299, 2.7897872127872128, 0.012567703753612382, 4.649645354645355, 0.0006449773101022368], [0.9309300699300698, 1.0, 0.2936550800566108, 1.8618601398601395, 0.058039484508448126, 2.7927902097902098, 0.012538153462867808, 4.65465034965035, 0.0006412011089167172], [0.9319310689310688, 1.0, 0.29357470226329757, 1.8638621378621376, 0.057977364612278995, 2.7957932067932068, 0.012509040306035125, 4.659655344655345, 0.0006374839950216536], [0.9329320679320677, 1.0, 0.29349549511688433, 1.8658641358641355, 0.05791615948254199, 2.7987962037962038, 0.012480363653011958, 4.66466033966034, 0.0006338257449432606], [0.9339330669330668, 1.0, 0.29341745842689376, 1.8678661338661335, 0.057855868530492835, 2.8017992007992008, 0.012452122883143266, 4.669665334665335, 0.0006302261387466613], [0.9349340659340658, 1.0, 0.2933405920056636, 1.8698681318681316, 0.05779649117618094, 2.8048021978021977, 0.012424317385207922, 4.67467032967033, 0.0006266849600226632], [0.9359350649350647, 1.0, 0.2932648956683452, 1.8718701298701295, 0.05773802684844382, 2.8078051948051947, 0.012396946557405489, 4.679675324675325, 0.0006232019958747478], [0.9369360639360638, 1.0, 0.29319036923290465, 1.8738721278721275, 0.05768047498490145, 2.8108081918081917, 0.012370009807343199, 4.68468031968032, 0.0006197770369062692], [0.9379370629370628, 1.0, 0.29311701252012035, 1.8758741258741256, 0.0576238350319511, 2.8138111888111887, 0.012343506552023105, 4.689685314685315, 0.0006164098772078692], [0.9389380619380617, 1.0, 0.29304482535358467, 1.8778761238761235, 0.057568106444761825, 2.8168141858141857, 0.012317436217829497, 4.69469030969031, 0.0006131003143450941], [0.9399390609390608, 1.0, 0.29297380755970215, 1.8798781218781215, 0.0575132886872693, 2.8198171828171827, 0.012291798240516447, 4.699695304695305, 0.0006098481493462265], [0.9409400599400598, 1.0, 0.29290395896768906, 1.8818801198801196, 0.057459381232170675, 2.8228201798201797, 0.012266592065195647, 4.7047002997003, 0.0006066531866903222], [0.9419410589410587, 1.0, 0.2928352794095733, 1.8838821178821175, 0.057406383560919386, 2.8258231768231767, 0.012241817146324375, 4.709705294705295, 0.0006035152342954554], [0.9429420579420578, 1.0, 0.29276776872019505, 1.8858841158841155, 0.05735429516372043, 2.8288261738261737, 0.012217472947693656, 4.71471028971029, 0.0006004341035071712], [0.9439430569430568, 1.0, 0.2927014267372048, 1.8878861138861136, 0.05730311553952518, 2.8318291708291707, 0.012193558942416725, 4.719715284715285, 0.0005974096090871438], [0.9449440559440557, 1.0, 0.29263625330106313, 1.8898881118881115, 0.057252844196026664, 2.8348321678321677, 0.012170074612917546, 4.72472027972028, 0.0005944415692020395], [0.9459450549450548, 1.0, 0.29257224825504125, 1.8918901098901095, 0.05720348064965488, 2.8378351648351647, 0.012147019450919687, 4.729725274725275, 0.0005915298054125842], [0.9469460539460538, 1.0, 0.29250941144521986, 1.8938921078921076, 0.05715502442557208, 2.8408381618381617, 0.012124392957435257, 4.73473026973027, 0.0005886741426628365], [0.9479470529470527, 1.0, 0.2924477427204891, 1.8958941058941055, 0.05710747505766824, 2.8438411588411587, 0.012102194642754131, 4.739735264735265, 0.0005858744092696631], [0.9489480519480518, 1.0, 0.2923872419325482, 1.8978961038961035, 0.05706083208855663, 2.8468441558441557, 0.012080424026433364, 4.74474025974026, 0.0005831304369124172], [0.9499490509490508, 1.0, 0.292327908935905, 1.8998981018981016, 0.057015095069569276, 2.8498471528471527, 0.012059080637286775, 4.749745254745255, 0.0005804420606228185], [0.9509500499500498, 1.0, 0.29226974358787555, 1.9019000999000997, 0.05697026356075265, 2.8528501498501497, 0.01203816401337474, 4.75475024975025, 0.0005778091187750368], [0.9519510489510488, 1.0, 0.2922127457485838, 1.9039020979020975, 0.05692633713086369, 2.8558531468531467, 0.01201767370199423, 4.759755244755245, 0.0005752314530759719], [0.9529520479520478, 1.0, 0.29215691528096177, 1.9059040959040956, 0.056883315357365356, 2.8588561438561437, 0.011997609259668973, 4.76476023976024, 0.0005727089085557414], [0.9539530469530468, 1.0, 0.2921022520507486, 1.9079060939060937, 0.05684119782642264, 2.8618591408591407, 0.0119779702521399, 4.769765234765235, 0.0005702413335583595], [0.9549540459540458, 1.0, 0.29204875592648966, 1.9099080919080915, 0.05679998413289867, 2.8648621378621377, 0.011958756254355692, 4.77477022977023, 0.0005678285797326227], [0.9559550449550448, 1.0, 0.29199642677953797, 1.9119100899100896, 0.05675967388035078, 2.8678651348651347, 0.011939966850463604, 4.779775224775225, 0.0005654705020231886], [0.9569560439560438, 1.0, 0.2919452644840522, 1.9139120879120877, 0.056720266681026615, 2.8708681318681317, 0.011921601633800499, 4.78478021978022, 0.0005631669586618569], [0.9579570429570428, 1.0, 0.29189526891699774, 1.9159140859140855, 0.056681762155860564, 2.8738711288711287, 0.011903660206883986, 4.789785214785215, 0.0005609178111590449], [0.9589580419580418, 1.0, 0.2918464399581447, 1.9179160839160836, 0.05664415993446999, 2.8768741258741257, 0.01188614218140387, 4.79479020979021, 0.0005587229242954619], [0.9599590409590408, 1.0, 0.2917987774900701, 1.9199180819180817, 0.056607459655151605, 2.8798771228771227, 0.011869047178213719, 4.799795204795205, 0.0005565821661139815], [0.9609600399600398, 1.0, 0.2917522813981546, 1.9219200799200795, 0.05657166096487824, 2.8828801198801197, 0.011852374827322652, 4.8048001998002, 0.0005544954079117039], [0.9619610389610388, 1.0, 0.29170695157058507, 1.9239220779220776, 0.05653676351929517, 2.8858831168831167, 0.011836124767887358, 4.809805194805195, 0.0005524625242322235], [0.9629620379620378, 1.0, 0.29166278789835215, 1.9259240759240757, 0.05650276698271695, 2.8888861138861137, 0.011820296648204246, 4.81481018981019, 0.000550483392858083], [0.9639630369630368, 1.0, 0.2916197902752512, 1.9279260739260735, 0.056469671028124155, 2.8918891108891107, 0.011804890125701906, 4.819815184815186, 0.0005485578948034273], [0.9649640359640358, 1.0, 0.2915779585978818, 1.9299280719280716, 0.05643747533716021, 2.8948921078921077, 0.011789904866933612, 4.82482017982018, 0.0005466859143068484], [0.9659650349650348, 1.0, 0.29153729276564705, 1.9319300699300697, 0.05640617960012842, 2.8978951048951047, 0.011775340547570155, 4.829825174825175, 0.0005448673388244275], [0.9669660339660338, 1.0, 0.29149779268075393, 1.9339320679320675, 0.05637578351598884, 2.9008981018981017, 0.0117611968523928, 4.8348301698301706, 0.0005431020590229682], [0.9679670329670328, 1.0, 0.29145945824821246, 1.9359340659340656, 0.05634628679235557, 2.9039010989010987, 0.011747473475286473, 4.839835164835165, 0.0005413899687734221], [0.9689680319680318, 1.0, 0.29142228937583614, 1.9379360639360637, 0.05631768914549374, 2.9069040959040957, 0.01173417011923315, 4.84484015984016, 0.0005397309651445118], [0.9699690309690308, 1.0, 0.2913862859742415, 1.9399380619380615, 0.05628999030031693, 2.9099070929070927, 0.011721286496305397, 4.8498451548451555, 0.0005381249483965381], [0.9709700299700298, 1.0, 0.2913514479568478, 1.9419400599400596, 0.056263189990384495, 2.9129100899100897, 0.011708822327660165, 4.85485014985015, 0.0005365718219753865], [0.9719710289710288, 1.0, 0.2913177752398762, 1.9439420579420577, 0.05623728795789891, 2.9159130869130867, 0.011696777343532737, 4.859855144855145, 0.0005350714925067226], [0.9729720279720278, 1.0, 0.2912852677423509, 1.9459440559440555, 0.05621228395370344, 2.918916083916084, 0.011685151283230912, 4.8648601398601405, 0.0005336238697903763], [0.9739730269730268, 1.0, 0.29125392538609757, 1.9479460539460536, 0.056188177737279583, 2.921919080919081, 0.011673943895129317, 4.869865134865135, 0.0005322288667949215], [0.9749740259740258, 1.0, 0.29122374809574464, 1.9499480519480517, 0.056164969076744856, 2.924922077922078, 0.011663154936664038, 4.87487012987013, 0.0005308863996524409], [0.9759750249750248, 1.0, 0.2911947357987214, 1.9519500499500495, 0.05614265774885056, 2.927925074925075, 0.011652784174327293, 4.8798751248751255, 0.0005295963876534859], [0.9769760239760238, 1.0, 0.2911668884252591, 1.9539520479520476, 0.056121243538979675, 2.930928071928072, 0.011642831383662405, 4.88488011988012, 0.0005283587532422244], [0.9779770229770228, 1.0, 0.2911402059083908, 1.9559540459540457, 0.0561007262411446, 2.933931068931069, 0.011633296349258982, 4.889885114885115, 0.0005271734220117771], [0.9789780219780219, 1.0, 0.2911146881839498, 1.9579560439560437, 0.05608110565798546, 2.936934065934066, 0.011624178864748192, 4.8948901098901105, 0.0005260403226997444], [0.9799790209790208, 1.0, 0.2910903351905717, 1.9599580419580416, 0.056062381600767895, 2.939937062937063, 0.011615478732798331, 4.899895104895105, 0.0005249593871839227], [0.9809800199800198, 1.0, 0.29106714686969243, 1.9619600399600396, 0.0560445538893815, 2.94294005994006, 0.01160719576511057, 4.9049000999001, 0.0005239305504782083], [0.9819810189810189, 1.0, 0.2910451231655487, 1.9639620379620377, 0.056027622352338005, 2.945943056943057, 0.01159932978241481, 4.9099050949050955, 0.0005229537507286892], [0.9829820179820178, 1.0, 0.291024264025178, 1.9659640359640356, 0.056011586826769655, 2.948946053946054, 0.011591880614465892, 4.91491008991009, 0.0005220289292099299], [0.9839830169830168, 1.0, 0.29100456939841807, 1.9679660339660336, 0.055996447158427526, 2.951949050949051, 0.011584848100039853, 4.919915084915085, 0.0005211560303214375], [0.9849840159840159, 1.0, 0.29098603923790733, 1.9699680319680317, 0.05598220320168007, 2.954952047952048, 0.011578232086930455, 4.9249200799200805, 0.0005203350015843196], [0.9859850149850148, 1.0, 0.29096867349908484, 1.9719700299700296, 0.05596885481951196, 2.957955044955045, 0.01157203243194589, 4.929925074925075, 0.0005195657936381308], [0.9869860139860138, 1.0, 0.29095247214018927, 1.9739720279720276, 0.05595640188352232, 2.960958041958042, 0.011566249000905686, 4.93493006993007, 0.0005188483602379041], [0.9879870129870129, 1.0, 0.2909374351222597, 1.9759740259740257, 0.05594484427392397, 2.963961038961039, 0.011560881668637772, 4.9399350649350655, 0.0005181826582513705], [0.9889880119880118, 1.0, 0.29092356240913503, 1.9779760239760236, 0.05593418187954201, 2.966964035964036, 0.011555930318975808, 4.94494005994006, 0.0005175686476563654], [0.9899890109890108, 1.0, 0.29091085396745425, 1.9799780219780216, 0.055924414597812694, 2.969967032967033, 0.01155139484475667, 4.949945054945055, 0.0005170062915384241], [0.9909900099900099, 1.0, 0.2908993097666561, 1.9819800199800197, 0.055915542334782624, 2.97297002997003, 0.011547275147818089, 4.9549500499500505, 0.0005164955560885614], [0.9919910089910088, 1.0, 0.29088892977897945, 1.9839820179820176, 0.055907565005107754, 2.975973026973027, 0.011543571138996574, 4.959955044955045, 0.0005160364106012384], [0.9929920079920078, 1.0, 0.2908797139794621, 1.9859840159840156, 0.05590048253205257, 2.978976023976024, 0.011540282738125462, 4.96496003996004, 0.0005156288274725179], [0.9939930069930069, 1.0, 0.29087166234594164, 1.9879860139860137, 0.055894294847489354, 2.981979020979021, 0.011537409874033178, 4.9699650349650355, 0.0005152727821984042], [0.9949940059940058, 1.0, 0.2908647748590562, 1.9899880119880116, 0.05588900189189757, 2.984982017982018, 0.011534952484541705, 4.97497002997003, 0.0005149682533733695], [0.9959950049950048, 1.0, 0.2908590515022424, 1.9919900099900096, 0.05588460361436323, 2.987985014985015, 0.011532910516465222, 4.979975024975025, 0.0005147152226890667], [0.9969960039960039, 1.0, 0.29085449226173693, 1.9939920079920077, 0.055881099972578376, 2.990988011988012, 0.011531283925608959, 4.9849800199800205, 0.0005145136749332307], [0.9979970029970028, 1.0, 0.2908510971265756, 1.9959940059940056, 0.05587849093284079, 2.993991008991009, 0.011530072676768277, 4.989985014985015, 0.0005143635979887613], [0.9989980019980018, 1.0, 0.29084886608859367, 1.9979960039960036, 0.055876776470053645, 2.996994005994006, 0.011529276743727824, 4.99499000999001, 0.0005142649828329968], [0.9999990009990009, 1.0, 0.29084779914242603, 1.9999980019980017, 0.055875956567725156, 2.999997002997003, 0.011528896109261076, 4.9999950049950055, 0.0005142178235371697], [1.001, 0.0, 0.290847799142426, 2.002, 0.05587595656772514, 3.003, 0.011528896109261076, 5.005, 0.00051421782353717]]}, \"id\": \"el9520169581592\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "         \n",
        "         mpld3.draw_figure(\"fig_el95201695815921320083937\", {\"axes\": [{\"xlim\": [-1.0, 6.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$x$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520175869848\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$|\\\\psi|^2$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520169514096\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Norm square of wave function for varying barrier width and E = 0.7\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520168826696\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.93647093413978533, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el9520170365168\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.93647093413978533, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el9520170368976\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.93647093413978533, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el9520170516096\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.93647093413978533, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el9520170515032\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [-1.0, 6.0], \"ylim\": [0.0, 1.1000000000000001], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170367016\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 7, \"tickvalues\": null}], \"lines\": [{\"color\": \"#FF0000\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168751456\"}, {\"color\": \"#FF0000\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168631712\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 3, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170360392\"}, {\"color\": \"#0000FF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 3, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170360784\"}, {\"color\": \"#008000\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 5, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169553704\"}, {\"color\": \"#008000\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 5, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169550624\"}, {\"color\": \"#FFA500\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 7, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170341208\"}, {\"color\": \"#FFA500\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 7, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170343728\"}, {\"color\": \"#FF0000\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170365728\"}, {\"color\": \"#0000FF\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170515704\"}, {\"color\": \"#008000\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170463752\"}, {\"color\": \"#FFA500\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170463920\"}], \"markers\": [], \"id\": \"el9520169580024\", \"ydomain\": [0.0, 1.1000000000000001], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data02\": [[0.8916680667562725, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086], [0.9167576724910396, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086]], \"data03\": [[0.879123263888889, 0.8399044205495819], [0.9910394265232977, 0.8399044205495819], [0.9910394265232977, 0.9880525686977301], [0.879123263888889, 0.9880525686977301], [0.879123263888889, 0.8399044205495819]], \"data01\": [[-0.001, 0.0, 1.0, -0.002, 1.0, -0.003, 1.0, -0.005, 1.0], [9.990009990008038e-07, 1.0, 0.9983104963843705, 1.9980019980016077e-06, 0.9968026613469056, 2.997002997003062e-06, 0.9953268747517187, 4.995004995005103e-06, 0.9922819273137575], [0.0010019980019980016, 1.0, 0.9966235241632159, 0.0020039960039960033, 0.9936139322073837, 0.003005994005994006, 0.9906724513467232, 0.00500999000999001, 0.984615181374895], [0.0020029970029970022, 1.0, 0.9949394132794194, 0.0040059940059940045, 0.9904351179077963, 0.00600899100899101, 0.9860396350489311, 0.010014985014985014, 0.9770076512763524], [0.0030039960039960033, 1.0, 0.9932581596830351, 0.0060079920079920066, 0.9872661878704999, 0.009011988011988013, 0.9814283255892915, 0.01501998001998002, 0.9694588796515854], [0.004004995004995004, 1.0, 0.9915797593309861, 0.008009990009990009, 0.9841071116129285, 0.012014985014985016, 0.9768384231642308, 0.020024975024975026, 0.961968412666624], [0.0050059940059940045, 1.0, 0.9899042081870599, 0.010011988011988009, 0.9809578587473022, 0.015017982017982021, 0.972269828433493, 0.02502997002997003, 0.9545357999927858], [0.0060069930069930055, 1.0, 0.9882315022218942, 0.012013986013986011, 0.977818398980333, 0.018020979020979024, 0.967722442517989, 0.030034965034965038, 0.9471605947796035], [0.007007992007992007, 1.0, 0.9865616374129681, 0.014015984015984013, 0.9746887021129349, 0.021023976023976026, 0.963196166997657, 0.035039960039960044, 0.9398423536279628], [0.008008991008991006, 1.0, 0.9848946097445942, 0.016017982017982012, 0.9715687380399352, 0.024026973026973028, 0.9586909039093311, 0.04004495504495505, 0.9325806365634384], [0.009009990009990008, 1.0, 0.9832304152079078, 0.018019980019980016, 0.9684584767497803, 0.02702997002997003, 0.9542065557446231, 0.045049950049950056, 0.9253750070098493], [0.01001098901098901, 1.0, 0.9815690498008568, 0.02002197802197802, 0.9653578883242513, 0.030032967032967036, 0.9497430254478103, 0.05005494505494506, 0.9182250317630095], [0.011011988011988008, 1.0, 0.9799105095281934, 0.022023976023976016, 0.9622669429381733, 0.03303596403596404, 0.9453002164137365, 0.05505994005994006, 0.9111302809646818], [0.01201298701298701, 1.0, 0.9782547904014625, 0.02402597402597402, 0.9591856108591303, 0.03603896103896104, 0.9408780324857191, 0.060064935064935064, 0.9040903280767375], [0.013013986013986012, 1.0, 0.9766018884389942, 0.026027972027972024, 0.9561138624471793, 0.03904195804195804, 0.9364763779534707, 0.06506993006993007, 0.8971047498555103], [0.014014985014985014, 1.0, 0.9749517996658928, 0.028029970029970028, 0.9530516681545629, 0.04204495504495504, 0.9320951575510246, 0.07007492507492508, 0.8901731263263529], [0.015015984015984012, 1.0, 0.9733045201140288, 0.030031968031968025, 0.9499989985254279, 0.04504795204795205, 0.927734276454675, 0.07507992007992008, 0.8832950407583869], [0.016016983016983014, 1.0, 0.9716600458220267, 0.03203396603396603, 0.9469558241955406, 0.04805094905094905, 0.9233936402809239, 0.08008491508491508, 0.8764700796394485], [0.017017982017982013, 1.0, 0.9700183728352582, 0.034035964035964025, 0.9439221158920037, 0.05105394605394605, 0.9190731550844391, 0.08508991008991008, 0.8696978326512295], [0.018018981018981015, 1.0, 0.9683794972058312, 0.03603796203796203, 0.9408978444329769, 0.05405694305694306, 0.9147727273560203, 0.0900949050949051, 0.8629778926446069], [0.019019980019980016, 1.0, 0.9667434149925804, 0.03803996003996003, 0.937882980727393, 0.057059940059940056, 0.9104922640205746, 0.0950999000999001, 0.8563098556151669], [0.020020979020979015, 1.0, 0.9651101222610589, 0.04004195804195803, 0.9348774957746813, 0.06006293706293707, 0.9062316724351038, 0.1001048951048951, 0.8496933206789152], [0.021021978021978017, 1.0, 0.9634796150835273, 0.042043956043956034, 0.9318813606644856, 0.06306593406593407, 0.9019908603866974, 0.10510989010989011, 0.8431278900481752], [0.02202297702297702, 1.0, 0.9618518895389446, 0.04404595404595404, 0.9288945465763901, 0.06606893106893107, 0.8977697360905381, 0.11011488511488511, 0.836613169007674], [0.023023976023976017, 1.0, 0.9602269417129606, 0.046047952047952034, 0.9259170247796376, 0.06907192807192808, 0.8935682081879147, 0.11511988011988011, 0.8301487658908117], [0.02402497502497502, 1.0, 0.9586047676979031, 0.04804995004995004, 0.9229487666328569, 0.07207492507492508, 0.8893861857442458, 0.12012487512487513, 0.8237342920561131], [0.02502597402597402, 1.0, 0.9569853635927708, 0.05005194805194804, 0.9199897435837835, 0.07507792207792208, 0.8852235782471102, 0.12512987012987012, 0.8173693618638644], [0.026026973026973023, 1.0, 0.955368725503225, 0.052053946053946046, 0.9170399271689893, 0.07808091908091908, 0.8810802956042879, 0.13013486513486514, 0.8110535926529272], [0.02702797202797202, 1.0, 0.9537548495415765, 0.05405594405594404, 0.9140992890136064, 0.08108391608391609, 0.8769562481418125, 0.13513986013986015, 0.804786604717733], [0.028028971028971023, 1.0, 0.9521437318267794, 0.056057942057942046, 0.9111678008310526, 0.08408691308691309, 0.8728513466020283, 0.14014485514485514, 0.7985680212854555], [0.029029970029970025, 1.0, 0.9505353684844218, 0.05805994005994005, 0.9082454344227628, 0.08708991008991009, 0.8687655021416577, 0.14514985014985016, 0.7923974684933588], [0.030030969030969024, 1.0, 0.9489297556467137, 0.06006193806193805, 0.9053321616779155, 0.0900929070929071, 0.8646986263298819, 0.15015484515484515, 0.7862745753663207], [0.031031968031968026, 1.0, 0.9473268894524812, 0.06206393606393605, 0.9024279545731632, 0.0930959040959041, 0.8606506311464227, 0.15515984015984016, 0.7801989737945296], [0.03203296703296703, 1.0, 0.9457267660471539, 0.06406593406593405, 0.8995327851723626, 0.0960989010989011, 0.8566214289796403, 0.16016483516483518, 0.7741702985113538], [0.03303396603396603, 1.0, 0.944129381582759, 0.06606793206793206, 0.8966466256263058, 0.09910189810189811, 0.8526109326246365, 0.16516983016983017, 0.7681881870713809], [0.03403496503496503, 1.0, 0.9425347322179085, 0.06806993006993006, 0.8937694481724517, 0.10210489510489511, 0.848619055281366, 0.17017482517482518, 0.7622522798286283], [0.035035964035964026, 1.0, 0.9409428141177935, 0.07007192807192805, 0.8909012251346606, 0.1051078921078921, 0.8446457105527599, 0.17517982017982017, 0.7563622199149211], [0.03603696303696303, 1.0, 0.9393536234541724, 0.07207392607392606, 0.888041928922927, 0.10811088911088912, 0.8406908124428545, 0.1801848151848152, 0.7505176532184362], [0.03703796203796203, 1.0, 0.9377671564053619, 0.07407592407592406, 0.8851915320331141, 0.11111388611388612, 0.8367542753549293, 0.1851898101898102, 0.7447182283624141], [0.03803896103896103, 1.0, 0.9361834091562299, 0.07607792207792206, 0.8823500070466891, 0.11411688311688312, 0.8328360140896569, 0.1901948051948052, 0.7389635966840343], [0.039039960039960034, 1.0, 0.9346023778981836, 0.07807992007992007, 0.879517326630461, 0.11711988011988012, 0.8289359438432562, 0.1951998001998002, 0.7332534122134511], [0.040040959040959036, 1.0, 0.9330240588291621, 0.08008191808191807, 0.8766934635363147, 0.12012287712287713, 0.8250539802056589, 0.2002047952047952, 0.7275873316529978], [0.04104195804195803, 1.0, 0.9314484481536268, 0.08208391608391606, 0.8738783906009528, 0.12312587412587414, 0.8211900391586827, 0.20520979020979022, 0.721965014356544], [0.04204295704295703, 1.0, 0.9298755420825522, 0.08408591408591407, 0.8710720807456304, 0.12612887112887114, 0.8173440370742107, 0.21021478521478523, 0.716386122309018], [0.043043956043956035, 1.0, 0.9283053368334164, 0.08608791208791207, 0.8682745069758973, 0.12913186813186814, 0.8135158907123836, 0.21521978021978022, 0.7108503201060836], [0.044044955044955036, 1.0, 0.9267378286301935, 0.08808991008991007, 0.8654856423813366, 0.13213486513486514, 0.8097055172197976, 0.22022477522477524, 0.7053572749339775], [0.04504595404595404, 1.0, 0.9251730137033419, 0.09009190809190808, 0.8627054601353079, 0.13513786213786214, 0.8059128341277103, 0.22522977022977023, 0.6999066565494991], [0.04604695304695304, 1.0, 0.9236108882897978, 0.09209390609390608, 0.8599339334946874, 0.13814085914085913, 0.8021377593502578, 0.23023476523476524, 0.694498137260156], [0.047047952047952035, 1.0, 0.922051448632965, 0.09409590409590407, 0.8571710357996111, 0.14114385614385616, 0.7983802111826745, 0.23523976023976023, 0.6891313919044644], [0.04804895104895104, 1.0, 0.9204946909827066, 0.09609790209790207, 0.8544167404732183, 0.14414685314685316, 0.7946401082995298, 0.24024475524475525, 0.683806097832399], [0.04904995004995004, 1.0, 0.9189406115953349, 0.09809990009990008, 0.8516710210213971, 0.14714985014985016, 0.7909173697529626, 0.24524975024975026, 0.6785219348859958], [0.05005094905094904, 1.0, 0.9173892067336018, 0.10010189810189808, 0.848933851032528, 0.15015284715284716, 0.7872119149709335, 0.2502547452547453, 0.6732785853801035], [0.05105194805194804, 1.0, 0.9158404726666924, 0.10210389610389609, 0.8462052041772308, 0.15315584415584416, 0.783523663755479, 0.25525974025974024, 0.6680757340832851], [0.052052947052947045, 1.0, 0.9142944056702137, 0.10410589410589409, 0.8434850542081104, 0.15615884115884116, 0.7798525362809758, 0.26026473526473526, 0.6629130681988665], [0.05305394605394605, 1.0, 0.9127510020261875, 0.1061078921078921, 0.8407733749595059, 0.15916183816183815, 0.776198453092414, 0.2652697302697303, 0.6577902773461288], [0.05405494505494504, 1.0, 0.9112102580230395, 0.10810989010989008, 0.8380701403472377, 0.16216483516483518, 0.7725613351036765, 0.2702747252747253, 0.6527070535416508], [0.055055944055944044, 1.0, 0.9096721699555906, 0.11011188811188809, 0.8353753243683553, 0.16516783216783218, 0.7689411035958278, 0.2752797202797203, 0.647663091180791], [0.056056943056943045, 1.0, 0.9081367341250505, 0.11211388611388609, 0.8326889011008908, 0.16817082917082918, 0.7653376802154102, 0.28028471528471527, 0.6426580870193156], [0.05705794205794205, 1.0, 0.9066039468390058, 0.1141158841158841, 0.8300108447036064, 0.17117382617382618, 0.7617509869727477, 0.2852897102897103, 0.6376917401551669], [0.05805894105894105, 1.0, 0.9050738044114126, 0.1161178821178821, 0.8273411294157469, 0.17417682317682318, 0.7581809462402592, 0.2902947052947053, 0.6327637520103743], [0.05905994005994005, 1.0, 0.9035463031625867, 0.1181198801198801, 0.824679729556792, 0.17717982017982017, 0.7546274807507767, 0.2952997002997003, 0.6278738263131012], [0.060060939060939046, 1.0, 0.9020214394191962, 0.12012187812187809, 0.8220266195262094, 0.1801828171828172, 0.7510905135958736, 0.30030469530469533, 0.6230216690798357], [0.06106193806193805, 1.0, 0.9004992095142523, 0.1221238761238761, 0.819381773803208, 0.1831858141858142, 0.747569968224201, 0.3053096903096903, 0.6182069885977144], [0.06206293706293706, 1.0, 0.898979609787099, 0.12412587412587411, 0.8167451669464926, 0.1861888111888112, 0.7440657684398295, 0.3103146853146853, 0.6134294954069853], [0.06306393606393605, 1.0, 0.8974626365834062, 0.1261278721278721, 0.81411677359402, 0.1891918081918082, 0.7405778384006018, 0.31531968031968033, 0.6086889022836056], [0.06406493506493505, 1.0, 0.8959482862551592, 0.1281298701298701, 0.8114965684627536, 0.1921948051948052, 0.737106102616489, 0.32032467532467535, 0.6039849242219727], [0.06506593406593406, 1.0, 0.8944365551606517, 0.1301318681318681, 0.8088845263484215, 0.1951978021978022, 0.7336504859479591, 0.32532967032967036, 0.5993172784177921], [0.06606693306693305, 1.0, 0.8929274396644755, 0.1321338661338661, 0.8062806221252727, 0.1982007992007992, 0.7302109136043493, 0.3303346653346653, 0.5946856842510709], [0.06706793206793206, 1.0, 0.891420936137512, 0.13413586413586412, 0.8036848307458369, 0.20120379620379622, 0.7267873111422473, 0.33533966033966034, 0.5900898632692513], [0.06806893106893105, 1.0, 0.8899170409569249, 0.1361378621378621, 0.8010971272406824, 0.20420679320679322, 0.7233796044638807, 0.34034465534465536, 0.5855295391704675], [0.06906993006993006, 1.0, 0.8884157505061505, 0.13813986013986013, 0.7985174867181765, 0.20720979020979022, 0.7199877198155128, 0.34534965034965037, 0.5810044377869346], [0.07007092907092906, 1.0, 0.8869170611748877, 0.14014185814185812, 0.7959458843642463, 0.21021278721278722, 0.7166115837858468, 0.3503546453546454, 0.5765142870684656], [0.07107192807192805, 1.0, 0.8854209693590911, 0.1421438561438561, 0.7933822954421383, 0.21321578421578422, 0.713251123304436, 0.35535964035964035, 0.5720588170661169], [0.07207292707292706, 1.0, 0.8839274714609624, 0.14414585414585412, 0.7908266952921846, 0.21621878121878121, 0.7099062656401038, 0.36036463536463537, 0.5676377599159569], [0.07307392607392606, 1.0, 0.8824365638889402, 0.14614785214785211, 0.7882790593315592, 0.21922177822177824, 0.7065769383993686, 0.3653696303696304, 0.5632508498229637], [0.07407492507492507, 1.0, 0.8809482430576937, 0.14814985014985013, 0.7857393630540479, 0.22222477522477524, 0.703263069524877, 0.3703746253746254, 0.5588978230450441], [0.07507592407592406, 1.0, 0.8794625053881113, 0.15015184815184812, 0.7832075820298091, 0.22522777222777224, 0.6999645872938443, 0.3753796203796204, 0.5545784178771779], [0.07607692307692306, 1.0, 0.8779793473072941, 0.1521538461538461, 0.7806836919051392, 0.22823076923076924, 0.6966814203165025, 0.3803846153846154, 0.550292374635685], [0.07707792207792206, 1.0, 0.8764987652485463, 0.15415584415584413, 0.7781676684022395, 0.23123376623376624, 0.6934134975345546, 0.3853896103896104, 0.546039435642612], [0.07807892107892106, 1.0, 0.8750207556513672, 0.15615784215784212, 0.7756594873189809, 0.23423676323676323, 0.6901607482196377, 0.3903946053946054, 0.5418193452102402], [0.07907992007992007, 1.0, 0.8735453149614419, 0.15815984015984014, 0.7731591245286736, 0.23723976023976023, 0.686923101971791, 0.3953996003996004, 0.5376318496257158], [0.08008091908091906, 1.0, 0.8720724396306335, 0.16016183816183813, 0.7706665559798316, 0.24024275724275726, 0.6837004887179322, 0.40040459540459544, 0.5334766971357939], [0.08108191808191807, 1.0, 0.8706021261169743, 0.16216383616383614, 0.7681817576959449, 0.24324575424575426, 0.6804928387103425, 0.4054095904095904, 0.5293536379317045], [0.08208291708291707, 1.0, 0.8691343708846568, 0.16416583416583413, 0.7657047057752463, 0.24624875124875126, 0.677300082525155, 0.4104145854145854, 0.5252624241341342], [0.08308391608391606, 1.0, 0.8676691704040259, 0.16616783216783212, 0.7632353763904828, 0.24925174825174828, 0.6741221510608536, 0.41541958041958044, 0.5212028097783216], [0.08408491508491507, 1.0, 0.8662065211515709, 0.16816983016983014, 0.7607737457886856, 0.2522547452547453, 0.6709589755367762, 0.42042457542457545, 0.517174550799273], [0.08508591408591407, 1.0, 0.8647464196099152, 0.17017182817182813, 0.7583197902909421, 0.2552577422577423, 0.6678104874916282, 0.42542957042957047, 0.5131774050170871], [0.08608691308691307, 1.0, 0.8632888622678094, 0.17217382617382615, 0.7558734862921689, 0.2582607392607393, 0.664676618781997, 0.43043456543456543, 0.509211132122395], [0.08708791208791207, 1.0, 0.8618338456201228, 0.17417582417582414, 0.7534348102608825, 0.2612637362637363, 0.661557301580881, 0.43543956043956045, 0.5052754936619142], [0.08808891108891108, 1.0, 0.8603813661678343, 0.17617782217782216, 0.7510037387389755, 0.2642667332667333, 0.6584524683762203, 0.44044455544455546, 0.5013702530241105], [0.08908991008991007, 1.0, 0.8589314204180237, 0.17817982017982015, 0.7485802483414892, 0.2672697302697303, 0.6553620519694345, 0.4454495504495505, 0.4974951754249754], [0.09009090909090907, 1.0, 0.857484004883865, 0.18018181818181814, 0.7461643157563888, 0.2702727272727273, 0.652285985473969, 0.4504545454545455, 0.49365002789390866], [0.09109190809190808, 1.0, 0.8560391160846151, 0.18218381618381616, 0.7437559177443408, 0.2732757242757243, 0.6492242023138478, 0.45545954045954046, 0.48983457925971324], [0.09209290709290707, 1.0, 0.8545967505456086, 0.18418581418581415, 0.7413550311384871, 0.2762787212787213, 0.646176636222233, 0.4604645354645355, 0.48604860013669704], [0.09309390609390608, 1.0, 0.8531569047982479, 0.18618781218781216, 0.7389616328442247, 0.27928171828171827, 0.6431432212399883, 0.4654695304695305, 0.48229186291088205], [0.09409490509490508, 1.0, 0.8517195753799945, 0.18818981018981015, 0.7365756998389802, 0.28228471528471527, 0.6401238917142539, 0.4704745254745255, 0.47856414172631995], [0.09509590409590407, 1.0, 0.8502847588343608, 0.19019180819180814, 0.7341972091719919, 0.2852877122877123, 0.6371185822970241, 0.47547952047952047, 0.4748652124715141], [0.09609690309690308, 1.0, 0.8488524517109034, 0.19219380619380616, 0.7318261379640867, 0.2882907092907093, 0.6341272279437341, 0.4804845154845155, 0.4711948527659453], [0.09709790209790208, 1.0, 0.8474226505652127, 0.19419580419580415, 0.7294624634074609, 0.2912937062937063, 0.6311497639118511, 0.4854895104895105, 0.46755284194670327], [0.09809890109890108, 1.0, 0.8459953519589061, 0.19619780219780217, 0.7271061627654605, 0.2942967032967033, 0.628186125759473, 0.4904945054945055, 0.46393896105521876], [0.09909990009990008, 1.0, 0.844570552459618, 0.19819980019980016, 0.7247572133723629, 0.2972997002997003, 0.625236249343936, 0.49549950049950053, 0.4603529928241008], [0.10010089910089909, 1.0, 0.8431482486409934, 0.20020179820179818, 0.7224155926331589, 0.3003026973026973, 0.6223000708204224, 0.5005044955044955, 0.4567947216640747], [0.10110189810189808, 1.0, 0.8417284370826789, 0.20220379620379617, 0.7200812780233348, 0.3033056943056943, 0.6193775266405827, 0.5055094905094906, 0.4532639336510198], [0.10210289710289708, 1.0, 0.8403111143703144, 0.20420579420579416, 0.7177542470886554, 0.3063086913086913, 0.6164685535511575, 0.5105144855144855, 0.449760416513109], [0.10310389610389609, 1.0, 0.8388962770955256, 0.20620779220779217, 0.7154344774449493, 0.3093116883116883, 0.6135730885926097, 0.5155194805194805, 0.44628395961804723], [0.10410489510489508, 1.0, 0.8374839218559136, 0.20820979020979016, 0.7131219467778929, 0.3123146853146853, 0.6106910690977618, 0.5205244755244756, 0.44283435396040716], [0.10510589410589409, 1.0, 0.83607404525505, 0.21021178821178818, 0.7108166328427957, 0.3153176823176823, 0.6078224326904388, 0.5255294705294705, 0.43941139214906466], [0.10610689310689309, 1.0, 0.8346666439024654, 0.21221378621378617, 0.7085185134643857, 0.3183206793206793, 0.6049671172841197, 0.5305344655344656, 0.43601486839473], [0.1071078921078921, 1.0, 0.8332617144136443, 0.2142157842157842, 0.706227566536598, 0.3213236763236763, 0.6021250610805922, 0.5355394605394606, 0.432644578497576], [0.10810889110889109, 1.0, 0.8318592534100148, 0.21621778221778218, 0.7039437700223596, 0.32432667332667336, 0.5992962025686157, 0.5405444555444555, 0.429300319834961], [0.10910989010989008, 1.0, 0.8304592575189409, 0.21821978021978017, 0.70166710195338, 0.32732967032967036, 0.5964804805225905, 0.5455494505494506, 0.4259818913492478], [0.11011088911088909, 1.0, 0.8290617233737154, 0.22022177822177819, 0.6993975404299373, 0.33033266733266736, 0.5936778340012321, 0.5505544455544455, 0.42268909353571527], [0.11111188811188809, 1.0, 0.827666647613551, 0.22222377622377618, 0.6971350636206696, 0.33333566433566436, 0.5908882023462522, 0.5555594405594406, 0.4194217284305647], [0.1121128871128871, 1.0, 0.8262740268835725, 0.2242257742257742, 0.6948796497623649, 0.33633866133866136, 0.5881115251810465, 0.5605644355644356, 0.4161795995990177], [0.11311388611388609, 1.0, 0.8248838578348081, 0.22622777222777218, 0.6926312771597503, 0.33934165834165836, 0.5853477424093876, 0.5655694305694305, 0.41296251212350715], [0.1141148851148851, 1.0, 0.8234961371241819, 0.2282297702297702, 0.6903899241852838, 0.34234465534465536, 0.5825967942141236, 0.5705744255744256, 0.40977027259195753], [0.1151158841158841, 1.0, 0.822110861414506, 0.2302317682317682, 0.6881555692789472, 0.34534765234765236, 0.579858621055885, 0.5755794205794206, 0.40660268908615876], [0.11611688311688309, 1.0, 0.8207280273744718, 0.23223376623376618, 0.6859281909480385, 0.34835064935064936, 0.5771331636717943, 0.5805844155844156, 0.40345957117022646], [0.1171178821178821, 1.0, 0.8193476316786419, 0.2342357642357642, 0.6837077677669641, 0.35135364635364635, 0.574420363074185, 0.5855894105894106, 0.4003407298791529], [0.1181188811188811, 1.0, 0.8179696710074443, 0.2362377622377622, 0.6814942783770335, 0.35435664335664335, 0.5717201605493241, 0.5905944055944056, 0.3972459777074478], [0.1191198801198801, 1.0, 0.8165941420471617, 0.2382397602397602, 0.6792877014862537, 0.35735964035964035, 0.5690324976561407, 0.5955994005994006, 0.39417512859786424], [0.1201208791208791, 1.0, 0.8152210414899249, 0.2402417582417582, 0.6770880158691244, 0.36036263736263735, 0.5663573162249629, 0.6006043956043956, 0.39112799793021263], [0.1211218781218781, 1.0, 0.8138503660337036, 0.2422437562437562, 0.6748952003664338, 0.3633656343656344, 0.5636945583562569, 0.6056093906093907, 0.38810440251026246], [0.1221228771228771, 1.0, 0.8124821123823005, 0.2442457542457542, 0.6727092338850554, 0.3663686313686314, 0.5610441664193757, 0.6106143856143856, 0.38510416055872776], [0.1231238761238761, 1.0, 0.811116277245342, 0.2462477522477522, 0.6705300953977441, 0.3693716283716284, 0.5584060830513098, 0.6156193806193806, 0.3821270917003388], [0.1241248751248751, 1.0, 0.8097528573382705, 0.2482497502497502, 0.6683577639429351, 0.3723746253746254, 0.5557802511554472, 0.6206243756243757, 0.3791730169529978], [0.12512587412587411, 1.0, 0.808391849382336, 0.25025174825174823, 0.6661922186245424, 0.3753776223776224, 0.5531666139003374, 0.6256293706293706, 0.3762417587170185], [0.1261268731268731, 1.0, 0.8070332501045895, 0.2522537462537462, 0.6640334386117565, 0.3783806193806194, 0.5505651147184609, 0.6306343656343657, 0.3733331407644484], [0.1271278721278721, 1.0, 0.8056770562378736, 0.2542557442557442, 0.6618814031388445, 0.3813836163836164, 0.5479756973050056, 0.6356393606393607, 0.3704469882284748], [0.1281288711288711, 1.0, 0.8043232645208165, 0.2562577422577422, 0.6597360915049507, 0.3843866133866134, 0.545398305616647, 0.6406443556443556, 0.3675831275929113], [0.1291298701298701, 1.0, 0.8029718716978221, 0.2582597402597402, 0.6575974830738976, 0.3873896103896104, 0.5428328838703366, 0.6456493506493507, 0.3647413866817654], [0.1301308691308691, 1.0, 0.8016228745190634, 0.2602617382617382, 0.6554655572739874, 0.3903926073926074, 0.5402793765420937, 0.6506543456543457, 0.3619215946488884], [0.1311318681318681, 1.0, 0.800276269740475, 0.2622637362637362, 0.653340293597803, 0.3933956043956044, 0.5377377283658038, 0.6556593406593407, 0.3591235819677031], [0.13213286713286712, 1.0, 0.7989320541237438, 0.26426573426573424, 0.6512216716020129, 0.3963986013986014, 0.5352078843320232, 0.6606643356643357, 0.35634718042101216], [0.1331338661338661, 1.0, 0.7975902244363028, 0.2662677322677322, 0.6491096709071715, 0.3994015984015984, 0.5326897896867869, 0.6656693306693306, 0.3535922230908848], [0.1341348651348651, 1.0, 0.7962507774513232, 0.2682697302697302, 0.647004271197526, 0.40240459540459544, 0.5301833899304252, 0.6706743256743257, 0.3508585443486219], [0.13513586413586412, 1.0, 0.7949137099477048, 0.27027172827172824, 0.6449054522208191, 0.40540759240759244, 0.5276886308163832, 0.6756793206793207, 0.3481459798447982], [0.1361368631368631, 1.0, 0.79357901871007, 0.2722737262737262, 0.6428131937880958, 0.40841058941058944, 0.5252054583500466, 0.6806843156843158, 0.3454543664993814], [0.1371378621378621, 1.0, 0.7922467005287569, 0.2742757242757242, 0.6407274757735074, 0.41141358641358644, 0.5227338187875743, 0.6856893106893107, 0.34278354249192766], [0.13813886113886112, 1.0, 0.7909167521998083, 0.27627772227772224, 0.6386482781141194, 0.41441658341658344, 0.5202736586347336, 0.6906943056943057, 0.3401333472518539], [0.13913986013986013, 1.0, 0.7895891705249678, 0.27827972027972026, 0.6365755808097173, 0.41741958041958044, 0.517824924645743, 0.6956993006993007, 0.3375036214487828], [0.1401408591408591, 1.0, 0.788263952311669, 0.2802817182817182, 0.6345093639226154, 0.42042257742257744, 0.5153875638221209, 0.7007042957042957, 0.3348942069829649], [0.14114185814185812, 1.0, 0.7869410943730298, 0.28228371628371624, 0.6324496075774639, 0.42342557442557444, 0.512961523411537, 0.7057092907092908, 0.3323049469757729], [0.14214285714285713, 1.0, 0.7856205935278442, 0.28428571428571425, 0.6303962919610588, 0.42642857142857143, 0.5105467509066708, 0.7107142857142857, 0.3297356857602709], [0.1431438561438561, 1.0, 0.7843024466005738, 0.2862877122877122, 0.6283493973221498, 0.42943156843156843, 0.5081431940440763, 0.7157192807192807, 0.3271862688718546], [0.14414485514485512, 1.0, 0.7829866504213416, 0.28828971028971023, 0.6263089039712525, 0.43243456543456543, 0.5057508008030496, 0.7207242757242758, 0.324656543038966], [0.14514585414585413, 1.0, 0.7816732018259237, 0.29029170829170825, 0.6242747922804568, 0.43543756243756243, 0.5033695194045033, 0.7257292707292707, 0.32214635617387766], [0.14614685314685313, 1.0, 0.7803620976557415, 0.29229370629370627, 0.6222470426832396, 0.43844055944055943, 0.5009992983098465, 0.7307342657342658, 0.31965555736354995], [0.14714785214785212, 1.0, 0.7790533347578539, 0.29429570429570423, 0.6202256356742755, 0.4414435564435565, 0.49864008621986866, 0.7357392607392608, 0.31718399686055737], [0.14814885114885112, 1.0, 0.7777469099849502, 0.29629770229770225, 0.6182105518092499, 0.4444465534465535, 0.49629183207363003, 0.7407442557442557, 0.31473152607408655], [0.14914985014985013, 1.0, 0.7764428201953432, 0.29829970029970027, 0.616201771704672, 0.4474495504495505, 0.4939544850473546, 0.7457492507492508, 0.3122979975610024], [0.1501508491508491, 1.0, 0.7751410622529596, 0.3003016983016982, 0.6141992760376882, 0.4504525474525475, 0.4916279945533331, 0.7507542457542458, 0.30988326501698354], [0.15115184815184812, 1.0, 0.7738416330273349, 0.30230369630369625, 0.6122030455458957, 0.4534555444555445, 0.4893123102388258, 0.7557592407592408, 0.30748718326772717], [0.15215284715284713, 1.0, 0.772544529393604, 0.30430569430569426, 0.610213061027158, 0.4564585414585415, 0.4870073819849733, 0.7607642357642358, 0.3051096082602204], [0.1531538461538461, 1.0, 0.7712497482324946, 0.3063076923076922, 0.6082293033394199, 0.4594615384615385, 0.48471315990571245, 0.7657692307692308, 0.3027503970540804], [0.15415484515484512, 1.0, 0.7699572864303191, 0.30830969030969024, 0.606251753400523, 0.4624645354645355, 0.4824295943466961, 0.7707742257742258, 0.3004094078129603], [0.15515584415584413, 1.0, 0.7686671408789689, 0.31031168831168826, 0.6042803921880232, 0.4654675324675325, 0.480156635884218, 0.7757792207792208, 0.29808649979602236], [0.15615684315684314, 1.0, 0.767379308475903, 0.3123136863136863, 0.6023152007390058, 0.4684705294705295, 0.47789423532414393, 0.7807842157842159, 0.2957815333494761], [0.15715784215784212, 1.0, 0.7660937861241452, 0.31431568431568424, 0.6003561601499051, 0.47147352647352647, 0.47564234370084685, 0.7857892107892108, 0.29349436989818295], [0.15815884115884113, 1.0, 0.7648105707322742, 0.31631768231768226, 0.5984032515763212, 0.47447652347652347, 0.4734009122761466, 0.7907942057942058, 0.29122487193732466], [0.15915984015984014, 1.0, 0.7635296592144155, 0.3183196803196803, 0.5964564562328405, 0.47747952047952047, 0.47116989253825564, 0.7957992007992009, 0.28897290302413636], [0.16016083916083912, 1.0, 0.7622510484902357, 0.32032167832167824, 0.5945157553928525, 0.4804825174825175, 0.4689492362007283, 0.8008041958041958, 0.2867383277697039], [0.16116183816183813, 1.0, 0.7609747354849343, 0.32232367632367626, 0.592581130388371, 0.4834855144855145, 0.46673889520141687, 0.8058091908091909, 0.2845210118308238], [0.16216283716283714, 1.0, 0.7597007171292366, 0.3243256743256743, 0.5906525626098554, 0.4864885114885115, 0.46453882170143046, 0.8108141858141859, 0.28232082190192703], [0.16316383616383615, 1.0, 0.7584289903593854, 0.3263276723276723, 0.5887300335060303, 0.4894915084915085, 0.4623489680840999, 0.8158191808191808, 0.2801376257070645], [0.16416483516483513, 1.0, 0.7571595521171346, 0.32832967032967025, 0.5868135245837066, 0.4924945054945055, 0.4601692869539475, 0.8208241758241759, 0.2779712919919543], [0.16516583416583414, 1.0, 0.7558923993497413, 0.33033166833166827, 0.5849030174076056, 0.4954975024975025, 0.4579997311356601, 0.8258291708291708, 0.27582169051609096], [0.16616683316683314, 1.0, 0.7546275290099597, 0.3323336663336663, 0.5829984936001806, 0.49850049950049957, 0.45584025367307, 0.8308341658341659, 0.27368869204491525], [0.16716783216783213, 1.0, 0.7533649380560312, 0.33433566433566425, 0.5810999348414395, 0.5015034965034966, 0.45369080782813653, 0.8358391608391609, 0.27157216834204473], [0.16816883116883113, 1.0, 0.7521046234516797, 0.33633766233766227, 0.5792073228687694, 0.5045064935064936, 0.451551347079936, 0.8408441558441558, 0.2694719921615637], [0.16916983016983014, 1.0, 0.7508465821661032, 0.3383396603396603, 0.5773206394767612, 0.5075094905094906, 0.4494218251236541, 0.8458491508491509, 0.26738803724037363], [0.17017082917082915, 1.0, 0.7495908111739659, 0.3403416583416583, 0.575439866517033, 0.5105124875124876, 0.44730219586958414, 0.8508541458541459, 0.26532017829060217], [0.17117182817182813, 1.0, 0.748337307455393, 0.34234365634365627, 0.5735649858980579, 0.5135154845154846, 0.44519241344212956, 0.8558591408591409, 0.2632682909920703], [0.17217282717282714, 1.0, 0.7470860679959607, 0.3443456543456543, 0.5716959795849873, 0.5165184815184816, 0.44309243217881045, 0.8608641358641359, 0.26123225198481886], [0.17317382617382615, 1.0, 0.7458370897866907, 0.3463476523476523, 0.5698328295994791, 0.5195214785214786, 0.44100220662927553, 0.8658691308691309, 0.2592119388616916], [0.17417482517482513, 1.0, 0.7445903698240429, 0.34834965034965026, 0.5679755180195247, 0.5225244755244756, 0.4389216915543191, 0.8708741258741259, 0.25720723016097613], [0.17517582417582414, 1.0, 0.7433459051099071, 0.3503516483516483, 0.5661240269792762, 0.5255274725274726, 0.4368508419249005, 0.8758791208791209, 0.255218005359102], [0.17617682317682315, 1.0, 0.7421036926515968, 0.3523536463536463, 0.564278338668874, 0.5285304695304696, 0.43478961292117124, 0.880884115884116, 0.2532441448633943], [0.17717782217782216, 1.0, 0.7408637294618425, 0.3543556443556443, 0.5624384353342767, 0.5315334665334666, 0.43273795993150377, 0.8858891108891109, 0.2512855300048838], [0.17817882117882114, 1.0, 0.7396260125587827, 0.3563576423576423, 0.5606042992770899, 0.5345364635364636, 0.43069583855152627, 0.8908941058941059, 0.24934204303117308], [0.17917982017982015, 1.0, 0.7383905389659586, 0.3583596403596403, 0.5587759128543953, 0.5375394605394606, 0.42866320458316176, 0.895899100899101, 0.24741356709935614], [0.18018081918081916, 1.0, 0.7371573057123054, 0.3603616383616383, 0.5569532584785816, 0.5405424575424576, 0.42664001403367136, 0.9009040959040959, 0.24549998626899508], [0.18118181818181814, 1.0, 0.7359263098321457, 0.3623636363636363, 0.5551363186171756, 0.5435454545454546, 0.42462622311470194, 0.905909090909091, 0.2436011854951487], [0.18218281718281715, 1.0, 0.7346975483651838, 0.3643656343656343, 0.5533250757926725, 0.5465484515484516, 0.42262178824133895, 0.910914085914086, 0.24171705062145651], [0.18318381618381616, 1.0, 0.733471018356496, 0.3663676323676323, 0.5515195125823689, 0.5495514485514486, 0.42062666603116244, 0.9159190809190809, 0.23984746837327547], [0.18418481518481516, 1.0, 0.7322467168565251, 0.36836963036963033, 0.5497196116181944, 0.5525544455544456, 0.4186408133033085, 0.920924075924076, 0.2379923263508698], [0.18518581418581415, 1.0, 0.7310246409210737, 0.3703716283716283, 0.5479253555865451, 0.5555574425574425, 0.416664187077535, 0.925929070929071, 0.23615151302265375], [0.18618681318681315, 1.0, 0.729804787611296, 0.3723736263736263, 0.5461367272281173, 0.5585604395604395, 0.4146967445732906, 0.930934065934066, 0.23432491771848593], [0.18718781218781216, 1.0, 0.7285871539936906, 0.3743756243756243, 0.5443537093377402, 0.5615634365634365, 0.4127384432087894, 0.935939060939061, 0.23251243062301594], [0.18818881118881114, 1.0, 0.7273717371400951, 0.3763776223776223, 0.5425762847642114, 0.5645664335664335, 0.41078924060008926, 0.940944055944056, 0.2307139427690827], [0.18918981018981015, 1.0, 0.7261585341276767, 0.3783796203796203, 0.5408044364101314, 0.5675694305694305, 0.40884909456017415, 0.945949050949051, 0.22892934603116238], [0.19019080919080916, 1.0, 0.7249475420389272, 0.3803816183816183, 0.5390381472317403, 0.5705724275724275, 0.40691796309804135, 0.950954045954046, 0.2271585331188688], [0.19119180819180814, 1.0, 0.7237387579616559, 0.3823836163836163, 0.5372774002387528, 0.5735754245754247, 0.404995804417793, 0.9559590409590409, 0.22540139757050245], [0.19219280719280715, 1.0, 0.7225321789889803, 0.3843856143856143, 0.5355221784941945, 0.5765784215784217, 0.4030825769177306, 0.960964035964036, 0.22365783374665046], [0.19319380619380616, 1.0, 0.7213278022193219, 0.3863876123876123, 0.5337724651142396, 0.5795814185814187, 0.4011782391894552, 0.965969030969031, 0.22192773682383515], [0.19419480519480517, 1.0, 0.7201256247563974, 0.38838961038961034, 0.5320282432680487, 0.5825844155844156, 0.39928275001697183, 0.970974025974026, 0.22021100278821226], [0.19519580419580415, 1.0, 0.7189256437092134, 0.3903916083916083, 0.5302894961776059, 0.5855874125874126, 0.3973960683757957, 0.975979020979021, 0.21850752842931737], [0.19619680319680316, 1.0, 0.7177278561920575, 0.3923936063936063, 0.5285562071175588, 0.5885904095904096, 0.3955181534320658, 0.980984015984016, 0.21681721133386117], [0.19719780219780217, 1.0, 0.7165322593244923, 0.39439560439560434, 0.5268283594150563, 0.5915934065934066, 0.393648964541661, 0.985989010989011, 0.21513994987957213], [0.19819880119880115, 1.0, 0.7153388502313489, 0.3963976023976023, 0.525105936449589, 0.5945964035964036, 0.3917884612493196, 0.990994005994006, 0.21347564322908713], [0.19919980019980016, 1.0, 0.7141476260427193, 0.3983996003996003, 0.5233889216528298, 0.5975994005994006, 0.3899366032877642, 0.9959990009990011, 0.21182419132388883], [0.20020079920079917, 1.0, 0.7129585838939505, 0.40040159840159834, 0.5216772985084729, 0.6006023976023976, 0.3880933505768306, 1.0010039960039963, 0.21018549487829033], [0.20120179820179818, 1.0, 0.7117717209256351, 0.40240359640359635, 0.5199710505520759, 0.6036053946053946, 0.38625866322259933, 1.006008991008991, 0.20855945537346626], [0.20220279720279716, 1.0, 0.710587034283609, 0.4044055944055943, 0.518270161370902, 0.6066083916083916, 0.3844325015165328, 1.0110139860139862, 0.2069459750515292], [0.20320379620379617, 1.0, 0.7094045211189385, 0.40640759240759233, 0.5165746146037611, 0.6096113886113886, 0.38261482593461676, 1.0160189810189812, 0.20534495690965326], [0.20420479520479518, 1.0, 0.7082241785879182, 0.40840959040959035, 0.5148843939408527, 0.6126143856143856, 0.38080559713650297, 1.021023976023976, 0.2037563046942412], [0.20520579420579416, 1.0, 0.7070460038520635, 0.4104115884115883, 0.5131994831236093, 0.6156173826173826, 0.3790047759646593, 1.0260289710289712, 0.20217992289513909], [0.20620679320679317, 1.0, 0.7058699940781021, 0.41241358641358633, 0.5115198659445406, 0.6186203796203796, 0.3772123234435212, 1.0310339660339662, 0.20061571673989265], [0.20720779220779217, 1.0, 0.7046961464379675, 0.41441558441558435, 0.5098455262470752, 0.6216233766233766, 0.3754282007786493, 1.036038961038961, 0.19906359218805048], [0.20820879120879118, 1.0, 0.703524458108793, 0.41641758241758237, 0.5081764479254087, 0.6246263736263736, 0.373652369355889, 1.0410439560439562, 0.1975234559255104], [0.20920979020979016, 1.0, 0.7023549262729054, 0.41841958041958033, 0.5065126149243458, 0.6276293706293706, 0.3718847907405342, 1.0460489510489512, 0.19599521535890863], [0.21021078921078917, 1.0, 0.7011875481178159, 0.42042157842157835, 0.5048540112391475, 0.6306323676323676, 0.37012542667649717, 1.0510539460539463, 0.19447877861005383], [0.21121178821178818, 1.0, 0.7000223208362162, 0.42242357642357636, 0.5032006209153764, 0.6336353646353646, 0.36837423908547856, 1.0560589410589412, 0.19297405451040275], [0.21221278721278716, 1.0, 0.6988592416259699, 0.4244255744255743, 0.5015524280487429, 0.6366383616383616, 0.36663119006614475, 1.0610639360639362, 0.19148095259557965], [0.21321378621378617, 1.0, 0.6976983076901067, 0.42642757242757234, 0.4999094167849537, 0.6396413586413586, 0.3648962418933067, 1.0660689310689313, 0.18999938309993733], [0.21421478521478518, 1.0, 0.6965395162368144, 0.42842957042957036, 0.4982715713195578, 0.6426443556443556, 0.3631693570171039, 1.0710739260739262, 0.1885292569511603], [0.2152157842157842, 1.0, 0.6953828644794335, 0.4304315684315684, 0.49663887589779526, 0.6456473526473526, 0.3614504980621915, 1.0760789210789212, 0.1870704857649099], [0.21621678321678317, 1.0, 0.6942283496364505, 0.43243356643356634, 0.4950113148144454, 0.6486503496503496, 0.3597396278269312, 1.0810839160839163, 0.18562298183951054], [0.21721778221778218, 1.0, 0.6930759689314898, 0.43443556443556436, 0.49338887241367546, 0.6516533466533467, 0.3580367092825866, 1.0860889110889111, 0.184186658150677], [0.2182187812187812, 1.0, 0.6919257195933085, 0.4364375624375624, 0.49177153308889104, 0.6546563436563437, 0.3563417055725214, 1.0910939060939062, 0.18276142834628292], [0.21921978021978017, 1.0, 0.6907775988557899, 0.43843956043956034, 0.4901592812825843, 0.6576593406593407, 0.3546545800114019, 1.0960989010989013, 0.1813472067411684], [0.22022077922077918, 1.0, 0.689631603957935, 0.44044155844155836, 0.48855210148618594, 0.6606623376623377, 0.35297529608440265, 1.1011038961038964, 0.17994390831198964], [0.2212217782217782, 1.0, 0.6884877321438575, 0.4424435564435564, 0.4869499782399151, 0.6636653346653347, 0.35130381744641626, 1.1061088911088912, 0.17855144869210648], [0.2222227772227772, 1.0, 0.6873459806627766, 0.4444455544455544, 0.4853528961326307, 0.6666683316683317, 0.34964010792126754, 1.1111138861138863, 0.17716974416651077], [0.22322377622377618, 1.0, 0.6862063467690107, 0.44644755244755235, 0.4837608398016834, 0.6696713286713287, 0.34798413150092905, 1.1161188811188814, 0.1757987116667932], [0.22422477522477519, 1.0, 0.6850688277219703, 0.44844955044955037, 0.48217379393276816, 0.6726743256743257, 0.34633585234474346, 1.1211238761238762, 0.17443826876614912], [0.2252257742257742, 1.0, 0.6839334207861518, 0.4504515484515484, 0.4805917432597765, 0.6756773226773227, 0.34469523477864644, 1.1261288711288713, 0.1730883336744231], [0.22622677322677318, 1.0, 0.6828001232311307, 0.45245354645354635, 0.47901467256464914, 0.6786803196803197, 0.343062243294395, 1.1311338661338664, 0.17174882523319207], [0.22722777222777218, 1.0, 0.6816689323315553, 0.45445554445554437, 0.47744256667723123, 0.6816833166833167, 0.3414368425487999, 1.1361388611388612, 0.17041966291088523], [0.2282287712287712, 1.0, 0.6805398453671397, 0.4564575424575424, 0.4758754104751244, 0.6846863136863137, 0.3398189973629592, 1.1411438561438563, 0.16910076679794334], [0.2292297702297702, 1.0, 0.6794128596226582, 0.4584595404595404, 0.47431318888354285, 0.6876893106893107, 0.33820867272149757, 1.1461488511488513, 0.16779205760201382], [0.23023076923076918, 1.0, 0.6782879723879373, 0.46046153846153837, 0.47275588687516756, 0.6906923076923077, 0.3366058337718088, 1.1511538461538464, 0.16649345664318418], [0.2312317682317682, 1.0, 0.67716518095785, 0.4624635364635364, 0.47120348947000185, 0.6936953046953047, 0.3350104458233011, 1.1561588411588413, 0.16520488584925172], [0.2322327672327672, 1.0, 0.6760444826323102, 0.4644655344655344, 0.4696559817352273, 0.6966983016983017, 0.3334224743466458, 1.1611638361638363, 0.16392626775102917], [0.23323376623376618, 1.0, 0.6749258747162645, 0.46646753246753236, 0.46811334878506133, 0.6997012987012987, 0.33184188497303124, 1.1661688311688314, 0.16265752547768839], [0.2342347652347652, 1.0, 0.673809354519687, 0.4684695304695304, 0.4665755757806109, 0.7027042957042957, 0.330268643493418, 1.1711738261738263, 0.16139858275213773], [0.2352357642357642, 1.0, 0.6726949193575715, 0.4704715284715284, 0.46504264792973365, 0.7057072927072927, 0.3287027158577985, 1.1761788211788213, 0.16014936388643686], [0.23623676323676318, 1.0, 0.6715825665499269, 0.47247352647352636, 0.46351455048689266, 0.7087102897102897, 0.3271440681744603, 1.1811838161838164, 0.1589097937772462], [0.2372377622377622, 1.0, 0.6704722934217688, 0.4744755244755244, 0.4619912687530158, 0.7117132867132867, 0.32559266670925296, 1.1861888111888113, 0.15767979790131192], [0.2382387612387612, 1.0, 0.6693640973031151, 0.4764775224775224, 0.46047278807535447, 0.7147162837162837, 0.32404847788485713, 1.1911938061938063, 0.15645930231098523], [0.2392397602397602, 1.0, 0.6682579755289778, 0.4784795204795204, 0.458959093847342, 0.7177192807192807, 0.32251146828005833, 1.1961988011988014, 0.15524823362977694], [0.2402407592407592, 1.0, 0.667153925439357, 0.4804815184815184, 0.45745017150845374, 0.7207222777222777, 0.32098160462902353, 1.2012037962037965, 0.15404651904794564], [0.2412417582417582, 1.0, 0.6660519443792356, 0.4824835164835164, 0.455946006544067, 0.7237252747252747, 0.31945885382058103, 1.2062087912087913, 0.15285408631812109], [0.2422427572427572, 1.0, 0.6649520296985717, 0.4844855144855144, 0.4544465844853208, 0.7267282717282717, 0.31794318289750395, 1.2112137862137864, 0.15167086375095978], [0.2432437562437562, 1.0, 0.6638541787522922, 0.4864875124875124, 0.4529518909089774, 0.7297312687312688, 0.3164345590557968, 1.2162187812187815, 0.1504967802108355], [0.2442447552447552, 1.0, 0.6627583889002877, 0.4884895104895104, 0.4514619114372831, 0.7327342657342658, 0.3149329496439862, 1.2212237762237763, 0.14933176511156285], [0.2452457542457542, 1.0, 0.6616646575074044, 0.4904915084915084, 0.4499766317378303, 0.7357372627372628, 0.3134383221624127, 1.2262287712287714, 0.1481757484121528], [0.2462467532467532, 1.0, 0.6605729819434392, 0.4924935064935064, 0.44849603752341893, 0.7387402597402598, 0.3119506442625289, 1.2312337662337665, 0.14702866061260286], [0.2472477522477522, 1.0, 0.6594833595831329, 0.4944955044955044, 0.44702011455192053, 0.7417432567432568, 0.3104698837461985, 1.2362387612387613, 0.14589043274971755], [0.2482487512487512, 1.0, 0.6583957878061639, 0.4964975024975024, 0.4455488486261394, 0.7447462537462538, 0.3089960085649997, 1.2412437562437564, 0.14476099639296333], [0.2492497502497502, 1.0, 0.6573102639971417, 0.4984995004995004, 0.44408222559367694, 0.7477492507492508, 0.3075289868195312, 1.2462487512487515, 0.14364028364035406], [0.2502507492507492, 1.0, 0.6562267855456003, 0.5005014985014984, 0.4426202313467959, 0.7507522477522478, 0.3060687867587228, 1.2512537462537465, 0.14252822711436858], [0.25125174825174823, 1.0, 0.6551453498459932, 0.5025034965034965, 0.44116285182228376, 0.7537552447552448, 0.30461537677914685, 1.2562587412587414, 0.14142475995790052], [0.2522527472527472, 1.0, 0.6540659542976859, 0.5045054945054944, 0.4397100730013183, 0.7567582417582418, 0.3031687254243352, 1.2612637362637364, 0.14032981583023807], [0.2532537462537462, 1.0, 0.6529885963049495, 0.5065074925074924, 0.4382618809093323, 0.7597612387612388, 0.3017288013840978, 1.2662687312687315, 0.13924332890307628], [0.25425474525474523, 1.0, 0.6519132732769566, 0.5085094905094905, 0.4368182616158793, 0.7627642357642358, 0.3002955734938458, 1.2712737262737264, 0.13816523385655907], [0.2552557442557442, 1.0, 0.6508399826277715, 0.5105114885114884, 0.43537920123449864, 0.7657672327672328, 0.2988690107339163, 1.2762787212787214, 0.13709546587535218], [0.2562567432567432, 1.0, 0.649768721776347, 0.5125134865134864, 0.43394468592258395, 0.7687702297702298, 0.2974490822289012, 1.2812837162837165, 0.13603396064474652], [0.25725774225774223, 1.0, 0.6486994881465177, 0.5145154845154845, 0.43251470188124813, 0.7717732267732268, 0.29603575724697945, 1.2862887112887114, 0.13498065434679155], [0.2582587412587412, 1.0, 0.6476322791669915, 0.5165174825174824, 0.4310892353551918, 0.7747762237762238, 0.2946290051992508, 1.2912937062937064, 0.1339354836564586], [0.2592597402597402, 1.0, 0.6465670922713475, 0.5185194805194804, 0.4296682726325694, 0.7777792207792208, 0.29322879563907495, 1.2962987012987015, 0.1328983857378337], [0.2602607392607392, 1.0, 0.6455039248980255, 0.5205214785214785, 0.42825180004485897, 0.7807822177822178, 0.2918350982614119, 1.3013036963036964, 0.13186929824033974], [0.2612617382617382, 1.0, 0.6444427744903234, 0.5225234765234764, 0.4268398039667303, 0.7837852147852148, 0.29044788290216644, 1.3063086913086914, 0.1308481592949883], [0.2622627372627372, 1.0, 0.6433836384963878, 0.5245254745254744, 0.4254322708159136, 0.7867882117882118, 0.2890671195375348, 1.3113136863136865, 0.12983490751065968], [0.2632637362637362, 1.0, 0.6423265143692112, 0.5265274725274725, 0.42402918705306825, 0.7897912087912088, 0.2876927782833549, 1.3163186813186816, 0.12882948197041202], [0.2642647352647352, 1.0, 0.6412713995666234, 0.5285294705294704, 0.42263053918165366, 0.7927942057942058, 0.2863248293944609, 1.3213236763236764, 0.12783182222781958], [0.26526573426573424, 1.0, 0.6402182915512858, 0.5305314685314685, 0.4212363137477991, 0.7957972027972028, 0.28496324326403705, 1.3263286713286715, 0.12684186830333785], [0.2662667332667332, 1.0, 0.639167187790687, 0.5325334665334664, 0.4198464973401739, 0.7988001998001998, 0.28360799042297863, 1.3313336663336666, 0.12585956068069815], [0.2672677322677322, 1.0, 0.6381180857571346, 0.5345354645354644, 0.4184610765898585, 0.8018031968031968, 0.28225904153925396, 1.3363386613386614, 0.12488484030332922], [0.26826873126873124, 1.0, 0.6370709829277491, 0.5365374625374625, 0.4170800381702164, 0.8048061938061939, 0.2809163674172689, 1.3413436563436565, 0.12391764857080693], [0.2692697302697302, 1.0, 0.6360258767844608, 0.5385394605394604, 0.4157033687967652, 0.8078091908091909, 0.2795799389972357, 1.3463486513486516, 0.12295792733533095], [0.2702707292707292, 1.0, 0.6349827648140002, 0.5405414585414584, 0.4143310552270496, 0.8108121878121879, 0.278249727354543, 1.3513536463536464, 0.12200561889822921], [0.27127172827172824, 1.0, 0.6339416445078937, 0.5425434565434565, 0.4129630842605135, 0.8138151848151849, 0.2769257036991317, 1.3563586413586415, 0.12106066600648878], [0.2722727272727272, 1.0, 0.6329025133624568, 0.5445454545454544, 0.4115994427383731, 0.8168181818181819, 0.2756078393748692, 1.3613636363636366, 0.1201230118493138], [0.2732737262737262, 1.0, 0.6318653688787891, 0.5465474525474524, 0.4102401175434903, 0.8198211788211789, 0.27429610585893194, 1.3663686313686316, 0.11919260005471029], [0.27427472527472524, 1.0, 0.6308302085627677, 0.5485494505494505, 0.40888509560024705, 0.8228241758241759, 0.2729904747611858, 1.3713736263736265, 0.11826937468609663], [0.2752757242757242, 1.0, 0.6297970299250406, 0.5505514485514484, 0.4075343638744187, 0.8258271728271729, 0.27169091782357324, 1.3763786213786215, 0.11735328023894107], [0.2762767232767232, 1.0, 0.6287658304810223, 0.5525534465534464, 0.4061879093730492, 0.8288301698301699, 0.2703974069195009, 1.3813836163836166, 0.11644426163742438], [0.27727772227772224, 1.0, 0.627736607750886, 0.5545554445554445, 0.404845719144326, 0.8318331668331669, 0.2691099140532309, 1.3863886113886115, 0.11554226423112902], [0.2782787212787212, 1.0, 0.626709359259559, 0.5565574425574424, 0.403507780277455, 0.8348361638361639, 0.26782841135927543, 1.3913936063936065, 0.11464723379175339], [0.27927972027972026, 1.0, 0.6256840825367161, 0.5585594405594405, 0.4021740799025379, 0.8378391608391609, 0.2665528711017927, 1.3963986013986016, 0.11375911650985156], [0.28028071928071924, 1.0, 0.6246607751167741, 0.5605614385614385, 0.40084460519044623, 0.8408421578421579, 0.2652832656739878, 1.4014035964035965, 0.11287785899159831], [0.2812817182817182, 1.0, 0.6236394345388848, 0.5625634365634364, 0.3995193433526994, 0.8438451548451549, 0.2640195675975142, 1.4064085914085915, 0.11200340825557915], [0.28228271728271725, 1.0, 0.6226200583469309, 0.5645654345654345, 0.39819828164134125, 0.8468481518481519, 0.26276174952187986, 1.4114135864135866, 0.11113571172960483], [0.28328371628371624, 1.0, 0.6216026440895182, 0.5665674325674325, 0.3968814073488172, 0.8498511488511489, 0.2615097842238548, 1.4164185814185817, 0.11027471724755099], [0.2842847152847152, 1.0, 0.6205871893199705, 0.5685694305694304, 0.3955687078078531, 0.8528541458541459, 0.2602636446068814, 1.4214235764235765, 0.10942037304622168], [0.28528571428571425, 1.0, 0.6195736915963246, 0.5705714285714285, 0.39426017039133177, 0.8558571428571429, 0.25902330370048915, 1.4264285714285716, 0.10857262776223742], [0.28628671328671323, 1.0, 0.6185621484813226, 0.5725734265734265, 0.3929557825121724, 0.8588601398601399, 0.2577887346597102, 1.4314335664335667, 0.10773143042894728], [0.2872877122877122, 1.0, 0.6175525575424078, 0.5745754245754244, 0.3916555316232097, 0.8618631368631369, 0.25655991076449847, 1.4364385614385615, 0.10689673047336468], [0.28828871128871125, 1.0, 0.6165449163517182, 0.5765774225774225, 0.39035940521707274, 0.8648661338661339, 0.2553368054191511, 1.4414435564435566, 0.10606847771312693], [0.28928971028971023, 1.0, 0.6155392224860796, 0.5785794205794205, 0.3890673908260646, 0.8678691308691309, 0.2541193921517331, 1.4464485514485517, 0.10524662235347836], [0.2902907092907092, 1.0, 0.6145354735270017, 0.5805814185814184, 0.3877794760220433, 0.8708721278721279, 0.25290764461350457, 1.4514535464535465, 0.10443111498427653], [0.29129170829170825, 1.0, 0.6135336670606709, 0.5825834165834165, 0.3864956484163013, 0.8738751248751249, 0.25170153657835004, 1.4564585414585416, 0.10362190657702162], [0.29229270729270723, 1.0, 0.6125338006779449, 0.5845854145854145, 0.3852158956594461, 0.8768781218781219, 0.2505010419422108, 1.4614635364635367, 0.10281894848190898], [0.29329370629370627, 1.0, 0.6115358719743467, 0.5865874125874125, 0.38394020544128254, 0.8798811188811189, 0.24930613472252058, 1.4664685314685317, 0.10202219242490441], [0.29429470529470525, 1.0, 0.6105398785500596, 0.5885894105894105, 0.38266856549069367, 0.882884115884116, 0.24811678905764264, 1.4714735264735266, 0.1012315905048415], [0.29529570429570423, 1.0, 0.6095458180099204, 0.5905914085914085, 0.38140096357552306, 0.885887112887113, 0.24693297920631016, 1.4764785214785217, 0.10044709519054204], [0.29629670329670327, 1.0, 0.6085536879634138, 0.5925934065934065, 0.38013738750245635, 0.88889010989011, 0.24575467954706898, 1.4814835164835167, 0.0996686593179586], [0.29729770229770225, 1.0, 0.6075634860246681, 0.5945954045954045, 0.3788778251169052, 0.891893106893107, 0.24458186457772363, 1.4864885114885116, 0.09889623608733879], [0.29829870129870123, 1.0, 0.6065752098124472, 0.5965974025974025, 0.3776222643028895, 0.894896103896104, 0.2434145089147844, 1.4914935064935066, 0.09812977906041163], [0.29929970029970027, 1.0, 0.6055888569501463, 0.5985994005994005, 0.3763706929829209, 0.897899100899101, 0.24225258729291896, 1.4964985014985017, 0.09736924215759579], [0.30030069930069925, 1.0, 0.6046044250657865, 0.6006013986013985, 0.3751230991178871, 0.900902097902098, 0.24109607456440507, 1.5015034965034966, 0.09661457965522931], [0.30130169830169823, 1.0, 0.603621911792007, 0.6026033966033965, 0.3738794707069356, 0.903905094905095, 0.23994494569858632, 1.5065084915084916, 0.09586574618282043], [0.30230269730269727, 1.0, 0.6026413147660622, 0.6046053946053945, 0.37263979578735845, 0.906908091908092, 0.23879917578133028, 1.5115134865134867, 0.09512269672032019], [0.30330369630369625, 1.0, 0.6016626316298146, 0.6066073926073925, 0.3714040624344769, 0.909911088911089, 0.23765874001448958, 1.5165184815184818, 0.09438538659541564], [0.3043046953046952, 1.0, 0.6006858600297282, 0.6086093906093905, 0.3701722587615266, 0.912914085914086, 0.23652361371536482, 1.5215234765234766, 0.09365377148084428], [0.30530569430569426, 1.0, 0.5997109976168651, 0.6106113886113885, 0.36894437291954446, 0.915917082917083, 0.2353937723161708, 1.5265284715284717, 0.09292780739172894], [0.30630669330669325, 1.0, 0.5987380420468775, 0.6126133866133865, 0.36772039309725335, 0.91892007992008, 0.23426919136350446, 1.5315334665334668, 0.09220745068293348], [0.3073076923076922, 1.0, 0.5977669909800042, 0.6146153846153845, 0.3665003075209485, 0.921923076923077, 0.23314984651781565, 1.5365384615384616, 0.09149265804643883], [0.30830869130869126, 1.0, 0.5967978420810637, 0.6166173826173825, 0.3652841044543853, 0.924926073926074, 0.23203571355288052, 1.5415434565434567, 0.0907833865087392], [0.30930969030969024, 1.0, 0.5958305930194477, 0.6186193806193805, 0.36407177219866543, 0.927929070929071, 0.23092676835527698, 1.5465484515484518, 0.09007959342825872], [0.3103106893106893, 1.0, 0.5948652414691178, 0.6206213786213786, 0.3628632990921249, 0.930932067932068, 0.2298229869238631, 1.5515534465534466, 0.08938123649278763], [0.31131168831168826, 1.0, 0.5939017851085985, 0.6226233766233765, 0.3616586735102213, 0.933935064935065, 0.22872434536925731, 1.5565584415584417, 0.08868827371693853], [0.31231268731268724, 1.0, 0.5929402216209722, 0.6246253746253745, 0.3604578838654226, 0.936938061938062, 0.22763081991332146, 1.5615634365634368, 0.0880006634396222], [0.3133136863136863, 1.0, 0.5919805486938723, 0.6266273726273726, 0.35926091860709536, 0.939941058941059, 0.22654238688864659, 1.5665684315684318, 0.08731836432154294], [0.31431468531468526, 1.0, 0.5910227640194797, 0.6286293706293705, 0.35806776622139325, 0.942944055944056, 0.2254590227380398, 1.5715734265734267, 0.08664133534271314], [0.31531568431568424, 1.0, 0.5900668652945151, 0.6306313686313685, 0.3568784152311476, 0.945947052947053, 0.22438070401401541, 1.5765784215784218, 0.0859695357999873], [0.3163166833166833, 1.0, 0.5891128502202353, 0.6326333666333666, 0.3556928541957554, 0.94895004995005, 0.2233074073782868, 1.5815834165834168, 0.08530292530461495], [0.31731768231768226, 1.0, 0.5881607165024265, 0.6346353646353645, 0.3545110717110704, 0.9519530469530469, 0.2222391096012615, 1.5865884115884117, 0.08464146377981219], [0.31831868131868124, 1.0, 0.5872104618513999, 0.6366373626373625, 0.35333305640929247, 0.9549560439560439, 0.22117578756153844, 1.5915934065934068, 0.08398511145835272], [0.3193196803196803, 1.0, 0.5862620839819845, 0.6386393606393606, 0.35215879695885915, 0.9579590409590409, 0.2201174182454074, 1.5965984015984018, 0.08333382888017662], [0.32032067932067926, 1.0, 0.5853155806135233, 0.6406413586413585, 0.35098828206433624, 0.960962037962038, 0.21906397874635125, 1.6016033966033967, 0.08268757689001818], [0.32132167832167824, 1.0, 0.5843709494698661, 0.6426433566433565, 0.34982150046630867, 0.963965034965035, 0.21801544626454997, 1.6066083916083918, 0.0820463166350519], [0.3223226773226773, 1.0, 0.5834281882793665, 0.6446453546453546, 0.3486584409412734, 0.966968031968032, 0.21697179810638687, 1.6116133866133868, 0.08141000956255655], [0.32332367632367626, 1.0, 0.582487294774874, 0.6466473526473525, 0.3474990923015306, 0.969971028971029, 0.21593301168395798, 1.616618381618382, 0.08077861741759745], [0.3243246753246753, 1.0, 0.5815482666937298, 0.6486493506493506, 0.3463434433950757, 0.972974025974026, 0.21489906451458288, 1.6216233766233767, 0.08015210224072661], [0.3253256743256743, 1.0, 0.5806111017777611, 0.6506513486513485, 0.3451914831054931, 0.975977022977023, 0.21386993422031808, 1.6266283716283718, 0.07953042636570037], [0.32632667332667326, 1.0, 0.5796757977732752, 0.6526533466533465, 0.3440432003518486, 0.97898001998002, 0.212845598527473, 1.6316333666333669, 0.0789135524172153], [0.3273276723276723, 1.0, 0.5787423524310551, 0.6546553446553446, 0.34289858408858315, 0.981983016983017, 0.2118260352661275, 1.6366383616383617, 0.07830144330866069], [0.3283286713286713, 1.0, 0.577810763506353, 0.6566573426573425, 0.34175762330540543, 0.984986013986014, 0.2108112223696521, 1.6416433566433568, 0.07769406223988942], [0.32932967032967025, 1.0, 0.5768810287588859, 0.6586593406593405, 0.34062030702718815, 0.987989010989011, 0.20980113787423077, 1.6466483516483519, 0.07709137269500511], [0.3303306693306693, 1.0, 0.5759531459528293, 0.6606613386613386, 0.3394866243138607, 0.990992007992008, 0.20879575991838512, 1.6516533466533467, 0.07649333844016694], [0.33133166833166827, 1.0, 0.5750271128568125, 0.6626633366633365, 0.3383565642603042, 0.993995004995005, 0.20779506674250134, 1.6566583416583418, 0.07589992352141124], [0.33233266733266725, 1.0, 0.5741029272439125, 0.6646653346653345, 0.3372301159962473, 0.996998001998002, 0.20679903668835953, 1.6616633366633369, 0.07531109226248997], [0.3333336663336663, 1.0, 0.5731805868916502, 0.6666673326673326, 0.33610726868616086, 1.0000009990009993, 0.20580764819866473, 1.666668331668332, 0.07472680926272583], [0.33433466533466527, 1.0, 0.5722600895819829, 0.6686693306693305, 0.3349880115291544, 1.0030039960039963, 0.2048208798165801, 1.6716733266733268, 0.07414703939488392], [0.33533566433566425, 1.0, 0.5713414331013001, 0.6706713286713285, 0.3338723337588714, 1.0060069930069933, 0.20383871018526326, 1.6766783216783219, 0.07357174780306003], [0.3363366633366633, 1.0, 0.5704246152404188, 0.6726733266733266, 0.33276022464338656, 1.0090099900099903, 0.20286111804740306, 1.681683316683317, 0.07300089990058481], [0.33733766233766227, 1.0, 0.5695096337945771, 0.6746753246753245, 0.3316516734851018, 1.0120129870129873, 0.20188808224476026, 1.6866883116883118, 0.07243446136794474], [0.3383386613386613, 1.0, 0.5685964865634292, 0.6766773226773226, 0.33054666962064405, 1.0150159840159843, 0.20091958171770963, 1.6916933066933069, 0.07187239815071851], [0.3393396603396603, 1.0, 0.5676851713510404, 0.6786793206793206, 0.32944520242076214, 1.0180189810189813, 0.19995559550478353, 1.696698301698302, 0.07131467645753], [0.34034065934065927, 1.0, 0.5667756859658819, 0.6806813186813185, 0.32834726129022473, 1.0210219780219782, 0.19899610274221888, 1.7017032967032968, 0.07076126275801645], [0.3413416583416583, 1.0, 0.5658680282208248, 0.6826833166833166, 0.3272528356677191, 1.0240249750249752, 0.19804108266350504, 1.7067082917082919, 0.07021212378081283], [0.3423426573426573, 1.0, 0.5649621959331352, 0.6846853146853146, 0.32616191502574754, 1.0270279720279722, 0.19709051459893495, 1.711713286713287, 0.06966722651155131], [0.34334365634365627, 1.0, 0.5640581869244702, 0.6866873126873125, 0.32507448887052887, 1.0300309690309692, 0.19614437797515705, 1.716718281718282, 0.06912653819087665], [0.3443446553446553, 1.0, 0.5631559990208701, 0.6886893106893106, 0.32399054674189515, 1.0330339660339662, 0.19520265231473088, 1.7217232767232769, 0.0685900263124766], [0.3453456543456543, 1.0, 0.5622556300527556, 0.6906913086913086, 0.32291007821319256, 1.0360369630369632, 0.19426531723568316, 1.726728271728272, 0.06805765862112766], [0.34634665334665327, 1.0, 0.5613570778549204, 0.6926933066933065, 0.3218330728911801, 1.0390399600399602, 0.193332352451067, 1.731733266733267, 0.0675294031107558], [0.3473476523476523, 1.0, 0.5604603402665287, 0.6946953046953046, 0.3207595204159304, 1.0420429570429572, 0.19240373776852263, 1.7367382617382618, 0.0670052280225123], [0.3483486513486513, 1.0, 0.5595654151311075, 0.6966973026973026, 0.31968941046072946, 1.0450459540459542, 0.19147945308984066, 1.741743256743257, 0.06648510184286444], [0.34934965034965026, 1.0, 0.558672300296542, 0.6986993006993005, 0.31862273273197733, 1.0480489510489512, 0.19055947841052664, 1.746748251748252, 0.06596899330170083], [0.3503506493506493, 1.0, 0.5577809936150717, 0.7007012987012986, 0.31755947696909004, 1.0510519480519482, 0.1896437938193688, 1.7517532467532468, 0.06545687137045145], [0.3513516483516483, 1.0, 0.5568914929432841, 0.7027032967032966, 0.3164996329443995, 1.0540549450549452, 0.1887323794980062, 1.756758241758242, 0.06494870526022234], [0.35235264735264726, 1.0, 0.5560037961421098, 0.7047052947052945, 0.31544319046305613, 1.0570579420579422, 0.18782521572050065, 1.761763236763237, 0.06444446441994436], [0.3533536463536463, 1.0, 0.5551179010768169, 0.7067072927072926, 0.3143901393629305, 1.0600609390609392, 0.18692228285290907, 1.766768231768232, 0.06394411853453655], [0.3543546453546453, 1.0, 0.5542338056170073, 0.7087092907092906, 0.31334046951451533, 1.0630639360639362, 0.18602356135285927, 1.771773226773227, 0.0634476375230836], [0.3553556443556443, 1.0, 0.5533515076366088, 0.7107112887112886, 0.31229417082082844, 1.0660669330669332, 0.18512903176912637, 1.776778221778222, 0.06295499153702735], [0.3563566433566433, 1.0, 0.5524710050138736, 0.7127132867132866, 0.3112512332173153, 1.0690699300699302, 0.18423867474121208, 1.781783216783217, 0.062466150958372345], [0.3573576423576423, 1.0, 0.5515922956313706, 0.7147152847152846, 0.31021164667175266, 1.0720729270729272, 0.18335247099892568, 1.786788211788212, 0.06198108639790499], [0.3583586413586413, 1.0, 0.5507153773759811, 0.7167172827172826, 0.3091754011841514, 1.0750759240759242, 0.1824704013619667, 1.791793206793207, 0.06149976869342697], [0.3593596403596403, 1.0, 0.549840248138894, 0.7187192807192806, 0.30814248678666106, 1.0780789210789212, 0.18159244673951047, 1.796798201798202, 0.06102216890800178], [0.3603606393606393, 1.0, 0.5489669058155999, 0.7207212787212786, 0.30711289354347315, 1.0810819180819182, 0.18071858812979408, 1.801803196803197, 0.06054825832821511], [0.3613616383616383, 1.0, 0.548095348305887, 0.7227232767232766, 0.30608661155072664, 1.0840849150849152, 0.17984880661970548, 1.806808191808192, 0.0600780084624486], [0.3623626373626373, 1.0, 0.5472255735138355, 0.7247252747252746, 0.30506363093641153, 1.0870879120879122, 0.1789830833843746, 1.811813186813187, 0.05961139103916692], [0.3633636363636363, 1.0, 0.5463575793478123, 0.7267272727272726, 0.3040439418602747, 1.0900909090909092, 0.17812139968676502, 1.816818181818182, 0.059148378005218036], [0.3643646353646353, 1.0, 0.5454913637204671, 0.7287292707292706, 0.30302753451372505, 1.0930939060939062, 0.1772637368772691, 1.821823176823177, 0.05868894152414663], [0.3653656343656343, 1.0, 0.544626924548726, 0.7307312687312686, 0.30201439911973865, 1.0960969030969032, 0.17641007639330428, 1.826828171828172, 0.058233053974520686], [0.3663666333666333, 1.0, 0.5437642597537874, 0.7327332667332666, 0.3010045259327657, 1.0990999000999002, 0.17556039975891108, 1.831833166833167, 0.05778068794827071], [0.3673676323676323, 1.0, 0.5429033672611168, 0.7347352647352646, 0.2999979052386358, 1.1021028971028972, 0.17471468858435332, 1.836838161838162, 0.05733181624904212], [0.3683686313686313, 1.0, 0.5420442450004415, 0.7367372627372626, 0.2989945273544652, 1.1051058941058942, 0.17387292456572007, 1.841843156843157, 0.05688641189056014], [0.36936963036963033, 1.0, 0.5411868909057458, 0.7387392607392607, 0.29799438262856304, 1.1081088911088912, 0.17303508948452978, 1.846848151848152, 0.05644444809500722], [0.3703706293706293, 1.0, 0.5403313029152663, 0.7407412587412586, 0.29699746144033906, 1.1111118881118882, 0.1722011652073356, 1.851853146853147, 0.056005898291413454], [0.3713716283716283, 1.0, 0.5394774789714866, 0.7427432567432566, 0.2960037542002112, 1.1141148851148852, 0.171371133685333, 1.856858141858142, 0.055570736114058814], [0.37237262737262733, 1.0, 0.5386254170211328, 0.7447452547452547, 0.2950132513495123, 1.1171178821178822, 0.17054497695396933, 1.861863136863137, 0.05513893540088825], [0.3733736263736263, 1.0, 0.5377751150151677, 0.7467472527472526, 0.29402594336039956, 1.1201208791208792, 0.16972267713255465, 1.8668681318681322, 0.05471047019193874], [0.3743746253746253, 1.0, 0.5369265709087867, 0.7487492507492506, 0.29304182073576146, 1.1231238761238762, 0.1689042164238753, 1.871873126873127, 0.05428531472777853], [0.37537562437562433, 1.0, 0.5360797826614127, 0.7507512487512487, 0.29206087400912756, 1.1261268731268732, 0.1680895771138082, 1.876878121878122, 0.0538634434479586], [0.3763766233766233, 1.0, 0.5352347482366908, 0.7527532467532466, 0.29108309374457725, 1.1291298701298702, 0.16727874157093758, 1.8818831168831172, 0.05344483098947585], [0.3773776223776223, 1.0, 0.534391465602484, 0.7547552447552446, 0.2901084705366481, 1.1321328671328672, 0.16647169224617353, 1.886888111888112, 0.0530294521852483], [0.3783786213786213, 1.0, 0.5335499327308675, 0.7567572427572427, 0.28913699501024664, 1.1351358641358642, 0.16566841167237195, 1.891893106893107, 0.05261728206260206], [0.3793796203796203, 1.0, 0.5327101475981246, 0.7587592407592406, 0.28816865782055723, 1.1381388611388612, 0.16486888246395687, 1.8968981018981022, 0.05220829584176993], [0.3803806193806193, 1.0, 0.5318721081847423, 0.7607612387612386, 0.2872034496529525, 1.1411418581418582, 0.16407308731654363, 1.901903096903097, 0.051802468934401706], [0.3813816183816183, 1.0, 0.5310358124754049, 0.7627632367632367, 0.2862413612229041, 1.1441448551448552, 0.16328100900656484, 1.906908091908092, 0.05139977694208574], [0.3823826173826173, 1.0, 0.5302012584589892, 0.7647652347652346, 0.2852823832758927, 1.1471478521478522, 0.16249263039089742, 1.9119130869130871, 0.05100019565488237], [0.3833836163836163, 1.0, 0.5293684441285622, 0.7667672327672326, 0.2843265065873194, 1.1501508491508494, 0.16170793440649156, 1.916918081918082, 0.05060370104986825], [0.3843846153846153, 1.0, 0.5285373674813728, 0.7687692307692306, 0.2833737219624171, 1.1531538461538464, 0.1609269040700015, 1.921923076923077, 0.05021026928969203], [0.3853856143856143, 1.0, 0.5277080265188501, 0.7707712287712286, 0.28242402023616153, 1.1561568431568434, 0.16014952247741782, 1.9269280719280721, 0.04981987672114148], [0.38638661338661334, 1.0, 0.5268804192465961, 0.7727732267732267, 0.281477392273184, 1.1591598401598404, 0.15937577280370172, 1.9319330669330672, 0.049432499873721183], [0.3873876123876123, 1.0, 0.5260545436743831, 0.7747752247752246, 0.2805338289676821, 1.1621628371628374, 0.1586056383024207, 1.936938061938062, 0.049048115458241594], [0.3883886113886113, 1.0, 0.5252303978161464, 0.7767772227772226, 0.27959332124333397, 1.1651658341658344, 0.1578391023053863, 1.9419430569430571, 0.048666700365418994], [0.38938961038961034, 1.0, 0.524407979689982, 0.7787792207792207, 0.278655860053209, 1.1681688311688314, 0.15707614822229324, 1.9469480519480522, 0.048288231664486016], [0.3903906093906093, 1.0, 0.5235872873181406, 0.7807812187812186, 0.2777214363796828, 1.1711718281718284, 0.15631675954036053, 1.951953046953047, 0.04791268660181302], [0.3913916083916083, 1.0, 0.5227683187270221, 0.7827832167832166, 0.2767900412343484, 1.1741748251748254, 0.15556091982397355, 1.9569580419580421, 0.04754004259954031], [0.39239260739260734, 1.0, 0.521951071947173, 0.7847852147852147, 0.27586166565793174, 1.1771778221778224, 0.15480861271432927, 1.9619630369630372, 0.04717027725422058], [0.3933936063936063, 1.0, 0.5211355450132794, 0.7867872127872126, 0.27493630072020436, 1.1801808191808194, 0.1540598219290813, 1.966968031968032, 0.04680336833547203], [0.3943946053946053, 1.0, 0.5203217359641642, 0.7887892107892106, 0.27401393751989717, 1.1831838161838164, 0.1533145312619877, 1.9719730269730271, 0.046439293784642025], [0.39539560439560434, 1.0, 0.5195096428427807, 0.7907912087912087, 0.2730945671846161, 1.1861868131868134, 0.15257272458256066, 1.9769780219780222, 0.0460780317134807], [0.3963966033966033, 1.0, 0.5186992636962087, 0.7927932067932066, 0.2721781808707556, 1.1891898101898104, 0.15183438583571676, 1.9819830169830173, 0.04571956040282525], [0.3973976023976023, 1.0, 0.5178905965756498, 0.7947952047952046, 0.27126476976341446, 1.1921928071928074, 0.15109949904143008, 1.9869880119880121, 0.04536385830129399], [0.39839860139860134, 1.0, 0.5170836395364236, 0.7967972027972027, 0.2703543250763098, 1.1951958041958044, 0.15036804829438594, 1.9919930069930072, 0.04501090402399078], [0.3993996003996003, 1.0, 0.5162783906379608, 0.7987992007992006, 0.26944683805169417, 1.1981988011988014, 0.14964001776363664, 1.9969980019980023, 0.04466067635121933], [0.40040059940059936, 1.0, 0.5154748479438005, 0.8008011988011987, 0.26854229996027, 1.2012017982017984, 0.14891539169225926, 2.002002997002997, 0.04431315422720747], [0.40140159840159834, 1.0, 0.5146730095215848, 0.8028031968031967, 0.26764070210110624, 1.2042047952047954, 0.14819415439701408, 2.0070079920079924, 0.04396831675884133], [0.4024025974025973, 1.0, 0.5138728734430545, 0.8048051948051946, 0.26674203580155453, 1.2072077922077924, 0.14747629026800566, 2.0120129870129873, 0.04362614321440909], [0.40340359640359635, 1.0, 0.5130744377840433, 0.8068071928071927, 0.2658462924171653, 1.2102107892107894, 0.14676178376834445, 2.017017982017982, 0.04328661302235472], [0.40440459540459534, 1.0, 0.5122777006244751, 0.8088091908091907, 0.264953463331606, 1.2132137862137864, 0.1460506194338109, 2.0220229770229774, 0.0429497057700412], [0.4054055944055943, 1.0, 0.5114826600483575, 0.8108111888111886, 0.26406353995657633, 1.2162167832167834, 0.14534278187252073, 2.0270279720279722, 0.042615401202523266], [0.40640659340659335, 1.0, 0.5106893141437785, 0.8128131868131867, 0.26317651373172735, 1.2192197802197804, 0.14463825576459166, 2.032032967032967, 0.042283679221329626], [0.40740759240759233, 1.0, 0.509897661002902, 0.8148151848151847, 0.2622923761245782, 1.2222227772227774, 0.14393702586181198, 2.0370379620379624, 0.04195451988325483], [0.4084085914085913, 1.0, 0.5091076987219615, 0.8168171828171826, 0.26141111863043354, 1.2252257742257744, 0.1432390769873105, 2.0420429570429572, 0.04162790339916004], [0.40940959040959035, 1.0, 0.5083194254012577, 0.8188191808191807, 0.26053273277230343, 1.2282287712287714, 0.14254439403522778, 2.047047952047952, 0.04130381013278348], [0.41041058941058933, 1.0, 0.507532839145152, 0.8208211788211787, 0.2596572101008202, 1.2312317682317684, 0.14185296197038985, 2.0520529470529474, 0.040982220599559784], [0.4114115884115883, 1.0, 0.5067479380620638, 0.8228231768231766, 0.2587845421941577, 1.2342347652347654, 0.14116476582798204, 2.0570579420579422, 0.04066311546544862], [0.41241258741258735, 1.0, 0.5059647202644636, 0.8248251748251747, 0.25791472065795057, 1.2372377622377624, 0.1404797907132257, 2.062062937062937, 0.04034647554577242], [0.41341358641358633, 1.0, 0.5051831838688715, 0.8268271728271727, 0.257047737125213, 1.2402407592407594, 0.13979802180105538, 2.0670679320679324, 0.04003228180406277], [0.41441458541458537, 1.0, 0.5044033269958497, 0.8288291708291707, 0.25618358325625873, 1.2432437562437564, 0.13911944433579831, 2.0720729270729272, 0.03972051535091617], [0.41541558441558435, 1.0, 0.5036251477700003, 0.8308311688311687, 0.2553222507386206, 1.2462467532467534, 0.13844404363085486, 2.077077922077922, 0.03941115744285825], [0.41641658341658333, 1.0, 0.5028486443199593, 0.8328331668331667, 0.2544637312869701, 1.2492497502497504, 0.13777180506838071, 2.0820829170829174, 0.039104189481216974], [0.41741758241758237, 1.0, 0.5020738147783925, 0.8348351648351647, 0.25360801664303884, 1.2522527472527474, 0.13710271409897046, 2.0870879120879122, 0.03879959301100443], [0.41841858141858135, 1.0, 0.5013006572819914, 0.8368371628371627, 0.25275509857553813, 1.2552557442557444, 0.13643675624134277, 2.092092907092907, 0.03849734971980737], [0.41941958041958033, 1.0, 0.5005291699714688, 0.8388391608391607, 0.25190496888008, 1.2582587412587414, 0.13577391708202705, 2.0970979020979024, 0.03819744143668622], [0.42042057942057937, 1.0, 0.4997593509915527, 0.8408411588411587, 0.25105761937909865, 1.2612617382617384, 0.13511418227505112, 2.102102897102897, 0.037899850131082644], [0.42142157842157835, 1.0, 0.4989911984909845, 0.8428431568431567, 0.2502130419217711, 1.2642647352647354, 0.13445753754163112, 2.1071078921078925, 0.03760455791173563], [0.42242257742257733, 1.0, 0.49822471062251256, 0.8448451548451547, 0.24937122838393966, 1.2672677322677324, 0.13380396866986238, 2.1121128871128874, 0.037311547025605664], [0.42342357642357636, 1.0, 0.49745988554288795, 0.8468471528471527, 0.24853217066803313, 1.2702707292707294, 0.13315346151441163, 2.117117882117882, 0.03702079985680761], [0.42442457542457535, 1.0, 0.49669672141286075, 0.8488491508491507, 0.24769586070298907, 1.2732737262737264, 0.1325060019962111, 2.1221228771228775, 0.03673229892555159], [0.4254255744255743, 1.0, 0.4959352163971758, 0.8508511488511487, 0.24686229044417624, 1.2762767232767234, 0.13186157610215365, 2.1271278721278724, 0.03644602688709197], [0.42642657342657336, 1.0, 0.49517536866456685, 0.8528531468531467, 0.2460314518733171, 1.2792797202797204, 0.13122016988478952, 2.132132867132867, 0.0361619665306848], [0.42742757242757234, 1.0, 0.49441717638775334, 0.8548551448551447, 0.24520333699841107, 1.2822827172827174, 0.13058176946202452, 2.1371378621378625, 0.035880100778552894], [0.4284285714285713, 1.0, 0.4936606377434364, 0.8568571428571427, 0.244377937853657, 1.2852857142857144, 0.12994636101681947, 2.1421428571428573, 0.035600412684859285], [0.42942957042957036, 1.0, 0.492905750912293, 0.8588591408591407, 0.24355524649937688, 1.2882887112887114, 0.12931393079689124, 2.147147852147852, 0.03532288543468828], [0.43043056943056934, 1.0, 0.49215251407897326, 0.8608611388611387, 0.2427352550219398, 1.2912917082917084, 0.128684465114415, 2.1521528471528475, 0.03504750234303468], [0.4314315684315684, 1.0, 0.4914009254320941, 0.8628631368631368, 0.2419179555336852, 1.2942947052947054, 0.12805795034572812, 2.1571578421578423, 0.034774246853800594], [0.43243256743256736, 1.0, 0.4906509831642368, 0.8648651348651347, 0.2411033401728473, 1.2972977022977024, 0.1274343729310353, 2.162162837162837, 0.03450310253880009], [0.43343356643356634, 1.0, 0.489902685471942, 0.8668671328671327, 0.2402914011034795, 1.3003006993006994, 0.1268137193741149, 2.1671678321678325, 0.03423405309677158], [0.4344345654345654, 1.0, 0.4891560305557043, 0.8688691308691308, 0.2394821305153793, 1.3033036963036964, 0.12619597624202708, 2.1721728271728273, 0.03396708235239766], [0.43543556443556436, 1.0, 0.48841101661996966, 0.8708711288711287, 0.23867552062401243, 1.3063066933066936, 0.12558113016482295, 2.177177822177822, 0.03370217425533281], [0.43643656343656334, 1.0, 0.4876676418731303, 0.8728731268731267, 0.23787156367043866, 1.3093096903096906, 0.1249691678352551, 2.1821828171828175, 0.03343931287923836], [0.4374375624375624, 1.0, 0.48692590452751944, 0.8748751248751248, 0.23707025192123665, 1.3123126873126876, 0.12436007600848979, 2.1871878121878123, 0.03317848242082497], [0.43843856143856136, 1.0, 0.4861858027994093, 0.8768771228771227, 0.23627157766842993, 1.3153156843156846, 0.12375384150182017, 2.192192807192807, 0.03291966719890255], [0.43943956043956034, 1.0, 0.4854473349090044, 0.8788791208791207, 0.23547553322941275, 1.3183186813186816, 0.12315045119438102, 2.1971978021978025, 0.03266285165343751], [0.4404405594405594, 1.0, 0.4847104990804382, 0.8808811188811188, 0.23468211094687574, 1.3213216783216786, 0.1225498920268647, 2.2022027972027973, 0.03240802034461738], [0.44144155844155836, 1.0, 0.48397529354176955, 0.8828831168831167, 0.23389130318873314, 1.3243246753246756, 0.12195215100123857, 2.2072077922077926, 0.03215515795192234], [0.44244255744255734, 1.0, 0.48324171652497766, 0.8848851148851147, 0.23310310234804793, 1.3273276723276726, 0.12135721518046359, 2.2122127872127875, 0.0319042492732044], [0.4434435564435564, 1.0, 0.48250976626595754, 0.8868871128871127, 0.23231750084296052, 1.3303306693306696, 0.12076507168821443, 2.2172177822177823, 0.03165527922377324], [0.44444455544455536, 1.0, 0.48177944100451714, 0.8888891108891107, 0.23153449111661425, 1.3333336663336666, 0.12017570770860082, 2.2222227772227776, 0.031408232835489464], [0.4454455544455544, 1.0, 0.4810507389843715, 0.8908911088911088, 0.2307540656370835, 1.3363366633366636, 0.11958911048588998, 2.2272277722277725, 0.031163095255864606], [0.4464465534465534, 1.0, 0.4803236584531393, 0.8928931068931067, 0.22997621689730083, 1.3393396603396606, 0.1190052673242306, 2.2322327672327673, 0.03091985174716825], [0.44744755244755235, 1.0, 0.4795981976623385, 0.8948951048951047, 0.22920093741498507, 1.3423426573426576, 0.11842416558737831, 2.2372377622377626, 0.03067848768554197], [0.4484485514485514, 1.0, 0.4788743548673825, 0.8968971028971028, 0.22842821973256947, 1.3453456543456546, 0.11784579269842183, 2.2422427572427575, 0.03043898856012018], [0.4494495504495504, 1.0, 0.47815212832757564, 0.8988991008991007, 0.22765805641712958, 1.3483486513486516, 0.11727013613951082, 2.2472477522477523, 0.030201339972157706], [0.45045054945054935, 1.0, 0.4774315163061084, 0.9009010989010987, 0.22689044006031192, 1.3513516483516486, 0.11669718345158528, 2.2522527472527476, 0.029965527634164095], [0.4514515484515484, 1.0, 0.47671251707005485, 0.9029030969030968, 0.2261253632782625, 1.3543546453546456, 0.11612692223410574, 2.2572577422577424, 0.029731537369044724], [0.45245254745254737, 1.0, 0.47599512889036705, 0.9049050949050947, 0.22536281871155622, 1.3573576423576426, 0.11555934014478451, 2.2622627372627373, 0.029499355109248403], [0.45345354645354635, 1.0, 0.47527935004187144, 0.9069070929070927, 0.22460279902512598, 1.3603606393606396, 0.11499442489931916, 2.2672677322677326, 0.029268966895921657], [0.4544545454545454, 1.0, 0.4745651788032642, 0.9089090909090908, 0.22384529690819174, 1.3633636363636366, 0.11443216427112607, 2.2722727272727274, 0.029040358878069574], [0.45545554445554437, 1.0, 0.4738526134571078, 0.9109110889110887, 0.22309030507419056, 1.3663666333666336, 0.11387254609107629, 2.2772777222777223, 0.028813517311722922], [0.45645654345654335, 1.0, 0.4731416522898266, 0.9129130869130867, 0.22233781626070645, 1.3693696303696306, 0.1133155582472318, 2.2822827172827176, 0.02858842855911207], [0.4574575424575424, 1.0, 0.472432293591702, 0.9149150849150848, 0.22158782322940032, 1.3723726273726276, 0.11276118868458365, 2.2872877122877124, 0.028365079087846898], [0.45845854145854137, 1.0, 0.4717245356568699, 0.9169170829170827, 0.22084031876594074, 1.3753756243756246, 0.11220942540479076, 2.2922927072927073, 0.02814345547010333], [0.4594595404595404, 1.0, 0.4710183767833155, 0.9189190809190808, 0.22009529567993422, 1.3783786213786215, 0.11166025646592061, 2.2972977022977026, 0.027923544381816014], [0.4604605394605394, 1.0, 0.47031381527286903, 0.9209210789210788, 0.219352746804856, 1.3813816183816185, 0.11111366998219041, 2.3023026973026974, 0.027705332601877283], [0.46146153846153837, 1.0, 0.4696108494312024, 0.9229230769230767, 0.21861266499798138, 1.3843846153846155, 0.11056965412370998, 2.3073076923076927, 0.027488807011342282], [0.4624625374625374, 1.0, 0.4689094775678248, 0.9249250749250748, 0.21787504314031686, 1.3873876123876125, 0.11002819711622587, 2.3123126873126876, 0.02727395459264029], [0.4634635364635364, 1.0, 0.46820969799607864, 0.9269270729270728, 0.21713987413653169, 1.3903906093906095, 0.10948928724086636, 2.3173176823176824, 0.027060762428792063], [0.46446453546453537, 1.0, 0.4675115090331351, 0.9289290709290707, 0.2164071509148895, 1.3933936063936065, 0.1089529128338878, 2.3223226773226777, 0.026849217702633276], [0.4654655344655344, 1.0, 0.4668149089999906, 0.9309310689310688, 0.21567686642718042, 1.3963966033966035, 0.10841906228642219, 2.3273276723276726, 0.026639307696043994], [0.4664665334665334, 1.0, 0.4661198962214629, 0.9329330669330668, 0.2149490136486535, 1.3993996003996005, 0.10788772404422614, 2.3323326673326674, 0.026431019789183982], [0.46746753246753237, 1.0, 0.4654264690261865, 0.9349350649350647, 0.2142235855779484, 1.4024025974025975, 0.10735888660743048, 2.3373376623376627, 0.026224341459734037], [0.4684685314685314, 1.0, 0.464734625746609, 0.9369370629370628, 0.21350057523702903, 1.4054055944055945, 0.1068325385302917, 2.3423426573426576, 0.02601926028214313], [0.4694695304695304, 1.0, 0.46404436471898725, 0.9389390609390608, 0.21277997567111548, 1.4084085914085915, 0.10630866842094384, 2.3473476523476524, 0.025815763926881424], [0.47047052947052936, 1.0, 0.4633556842833826, 0.9409410589410587, 0.21206177994861797, 1.4114115884115885, 0.10578726494115225, 2.3523526473526477, 0.025613840159698933], [0.4714715284715284, 1.0, 0.4626685827836579, 0.9429430569430568, 0.21134598116106948, 1.4144145854145855, 0.10526831680606806, 2.3573576423576426, 0.025413476840890077], [0.4724725274725274, 1.0, 0.46198305856747246, 0.9449450549450548, 0.21063257242305958, 1.4174175824175825, 0.10475181278398386, 2.3623626373626374, 0.025214661924563796], [0.47347352647352636, 1.0, 0.46129910998627965, 0.9469470529470527, 0.2099215468721684, 1.4204205794205795, 0.10423774169609089, 2.3673676323676327, 0.025017383457919377], [0.4744745254745254, 1.0, 0.46061673539532055, 0.9489490509490508, 0.20921289766890014, 1.4234235764235765, 0.1037260924162367, 2.3723726273726276, 0.0248216295805278], [0.4754755244755244, 1.0, 0.4599359331536224, 0.9509510489510488, 0.20850661799661793, 1.4264265734265735, 0.10321685387068472, 2.3773776223776224, 0.02462738852361875], [0.4764765234765234, 1.0, 0.4592567016239932, 0.9529530469530468, 0.20780270106147758, 1.4294295704295705, 0.10271001503787439, 2.3823826173826177, 0.024434648609373045], [0.4774775224775224, 1.0, 0.4585790391730183, 0.9549550449550448, 0.20710114009236258, 1.4324325674325675, 0.10220556494818264, 2.3873876123876125, 0.024243398250220535], [0.4784785214785214, 1.0, 0.4579029441710565, 0.9569570429570428, 0.20640192834081897, 1.4354355644355645, 0.10170349268368652, 2.3923926073926074, 0.024053625948143503], [0.4794795204795204, 1.0, 0.45722841499223565, 0.9589590409590408, 0.20570505908099052, 1.4384385614385615, 0.10120378737792682, 2.3973976023976027, 0.023865320293985397], [0.4804805194805194, 1.0, 0.45655545001444897, 0.9609610389610388, 0.20501052560955368, 1.4414415584415585, 0.10070643821567299, 2.4024025974025975, 0.02367846996676484], [0.4814815184815184, 1.0, 0.45588404761935203, 0.9629630369630368, 0.20431832124565344, 1.4444445554445555, 0.10021143443268891, 2.407407592407593, 0.023493063732995097], [0.4824825174825174, 1.0, 0.45521420619235714, 0.9649650349650348, 0.20362843933083882, 1.4474475524475525, 0.09971876531550013, 2.4124125874125877, 0.023309090446008686], [0.4834835164835164, 1.0, 0.45454592412263095, 0.9669670329670328, 0.20294087322899895, 1.4504505494505495, 0.09922842020116183, 2.4174175824175825, 0.023126539045287206], [0.4844845154845154, 1.0, 0.45387919980309044, 0.9689690309690308, 0.2022556163262994, 1.4534535464535465, 0.09874038847702807, 2.422422577422578, 0.02294539855579643], [0.4854855144855144, 1.0, 0.45321403163039803, 0.9709710289710288, 0.2015726620311183, 1.4564565434565435, 0.098254659580522, 2.4274275724275727, 0.022765658087326408], [0.4864865134865134, 1.0, 0.45255041800495877, 0.9729730269730268, 0.20089200377398292, 1.4594595404595407, 0.09777122299890761, 2.4324325674325675, 0.02258730683383686], [0.4874875124875124, 1.0, 0.45188835733091554, 0.9749750249750248, 0.20021363500750664, 1.4624625374625377, 0.09729006826906196, 2.437437562437563, 0.022410334072807382], [0.4884885114885114, 1.0, 0.45122784801614646, 0.9769770229770228, 0.1995375492063258, 1.4654655344655347, 0.09681118497724842, 2.4424425574425577, 0.02223472916459291], [0.4894895104895104, 1.0, 0.45056888847225934, 0.9789790209790208, 0.1988637398670373, 1.4684685314685317, 0.09633456275889185, 2.4474475524475525, 0.02206048155178399], [0.49049050949050943, 1.0, 0.44991147711459, 0.9809810189810189, 0.19819220050813552, 1.4714715284715287, 0.095860191298354, 2.452452547452548, 0.021887580758572132], [0.4914915084915084, 1.0, 0.4492556123621972, 0.9829830169830168, 0.19752292466995036, 1.4744745254745257, 0.09538806032871013, 2.4574575424575427, 0.021716016390119924], [0.4924925074925074, 1.0, 0.44860129263785814, 0.9849850149850148, 0.19685590591458493, 1.4774775224775227, 0.09491815963152701, 2.4624625374625375, 0.02154577813193615], [0.49349350649350643, 1.0, 0.4479485163680661, 0.9869870129870129, 0.1961911378258537, 1.4804805194805197, 0.09445047903664165, 2.467467532467533, 0.021376855749255696], [0.4944945054945054, 1.0, 0.4472972819830258, 0.9889890109890108, 0.1955286140092208, 1.4834835164835167, 0.09398500842194131, 2.4724725274725277, 0.021209239086424154], [0.4954955044955044, 1.0, 0.4466475879166502, 0.9909910089910088, 0.1948683280917384, 1.4864865134865137, 0.09352173771314423, 2.4774775224775225, 0.02104291806628732], [0.4964965034965034, 1.0, 0.44599943260655656, 0.9929930069930069, 0.19421027372198538, 1.4894895104895107, 0.09306065688358175, 2.482482517482518, 0.02087788268958536], [0.4974975024975024, 1.0, 0.44535281449406167, 0.9949950049950048, 0.19355444457000637, 1.4924925074925077, 0.09260175595398124, 2.4874875124875127, 0.020714123034351613], [0.4984985014985014, 1.0, 0.4447077320241803, 0.9969970029970028, 0.19290083432725097, 1.4954955044955047, 0.09214502499225005, 2.4924925074925075, 0.020551629255316096], [0.4994995004995004, 1.0, 0.44406418364561884, 0.9989990009990009, 0.19224943670651248, 1.4984985014985017, 0.09169045411326068, 2.497497502497503, 0.020390391583313613], [0.5005004995004995, 1.0, 0.44342216781077326, 1.001000999000999, 0.19160024544186846, 1.5015014985014987, 0.09123803347863672, 2.5025024975024976, 0.02023040032469646], [0.5015014985014984, 1.0, 0.44278168297572573, 1.0030029970029968, 0.19095325428861937, 1.5045044955044957, 0.09078775329654006, 2.507507492507493, 0.02007164586075156], [0.5025024975024974, 1.0, 0.442142727600239, 1.0050049950049948, 0.19030845702322913, 1.5075074925074927, 0.09033960382145882, 2.512512487512488, 0.019914118647122264], [0.5035034965034965, 1.0, 0.4415053001477549, 1.007006993006993, 0.18966584744326515, 1.5105104895104897, 0.08989357535399646, 2.5175174825174826, 0.019757809213234476], [0.5045044955044954, 1.0, 0.44086939908538864, 1.0090089910089908, 0.18902541936733858, 1.5135134865134867, 0.08944965824066183, 2.522522477522478, 0.019602708161727347], [0.5055054945054944, 1.0, 0.44023502288392685, 1.0110109890109888, 0.1883871666350448, 1.5165164835164837, 0.08900784287366037, 2.527527472527473, 0.019448806167888244], [0.5065064935064935, 1.0, 0.43960217001782276, 1.013012987012987, 0.18775108310690444, 1.5195194805194807, 0.08856811969068602, 2.5325324675324676, 0.01929609397909216], [0.5075074925074924, 1.0, 0.438970838965193, 1.0150149850149848, 0.1871171626643039, 1.5225224775224777, 0.08813047917471432, 2.537537462537463, 0.01914456241424548], [0.5085084915084914, 1.0, 0.4383410282078138, 1.0170169830169828, 0.1864853992094369, 1.5255254745254747, 0.0876949118537964, 2.542542457542458, 0.018994202363233983], [0.5095094905094905, 1.0, 0.4377127362311176, 1.019018981018981, 0.18585578666524558, 1.5285284715284717, 0.08726140830085398, 2.5475474525474526, 0.018845004786375123], [0.5105104895104894, 1.0, 0.4370859615241888, 1.0210209790209788, 0.18522831897536224, 1.5315314685314687, 0.08682995913347549, 2.552552447552448, 0.018696960713874604], [0.5115114885114884, 1.0, 0.4364607025797607, 1.0230229770229768, 0.18460299010405062, 1.5345344655344657, 0.08640055501371276, 2.5575574425574428, 0.018550061245287082], [0.5125124875124875, 1.0, 0.4358369578942125, 1.025024975024975, 0.18397979403614872, 1.5375374625374627, 0.08597318664787905, 2.5625624375624376, 0.01840429754898106], [0.5135134865134864, 1.0, 0.43521472596756366, 1.0270269730269728, 0.18335872477700993, 1.5405404595404597, 0.08554784478634789, 2.567567432567433, 0.018259660861607966], [0.5145144855144854, 1.0, 0.43459400530347214, 1.0290289710289708, 0.1827397763524461, 1.5435434565434567, 0.08512452022335293, 2.5725724275724278, 0.018116142487575267], [0.5155154845154845, 1.0, 0.43397479440923, 1.031030969030969, 0.18212294280866964, 1.5465464535464537, 0.08470320379678854, 2.5775774225774226, 0.017973733798523694], [0.5165164835164834, 1.0, 0.43335709179576065, 1.0330329670329668, 0.18150821821223645, 1.5495494505494507, 0.08428388638801176, 2.582582417582418, 0.01783242623280852], [0.5175174825174824, 1.0, 0.43274089597761306, 1.0350349650349648, 0.18089559664998894, 1.5525524475524477, 0.08386655892164467, 2.5875874125874128, 0.017692211294984803], [0.5185184815184815, 1.0, 0.4321262054729611, 1.037036963036963, 0.180285072228999, 1.5555554445554447, 0.0834512123653782, 2.5925924075924076, 0.017553080555296665], [0.5195194805194804, 1.0, 0.4315130188035981, 1.0390389610389608, 0.17967663907651119, 1.5585584415584417, 0.08303783772977646, 2.597597402597403, 0.017415025649170475], [0.5205204795204794, 1.0, 0.43090133449493423, 1.0410409590409588, 0.17907029133988658, 1.5615614385614387, 0.08262642606808253, 2.6026023976023978, 0.017278038276711972], [0.5215214785214785, 1.0, 0.43029115107599186, 1.043042957042957, 0.17846602318654609, 1.5645644355644357, 0.08221696847602417, 2.6076073926073926, 0.01714211020220729], [0.5225224775224774, 1.0, 0.42968246707940333, 1.0450449550449548, 0.17786382880391471, 1.5675674325674327, 0.08180945609162174, 2.612612387612388, 0.017007233253627813], [0.5235234765234764, 1.0, 0.42907528104140646, 1.0470469530469528, 0.17726370239936523, 1.5705704295704297, 0.08140388009499613, 2.6176173826173827, 0.016873399322138837], [0.5245244755244755, 1.0, 0.4284695915018416, 1.049048951048951, 0.17666563820016296, 1.5735734265734267, 0.08100023170817777, 2.622622377622378, 0.016740600361612137], [0.5255254745254744, 1.0, 0.4278653970041476, 1.0510509490509488, 0.17606963045340987, 1.5765764235764237, 0.0805985021949169, 2.627627372627373, 0.01660882838814216], [0.5265264735264734, 1.0, 0.4272626960953588, 1.0530529470529468, 0.17547567342598927, 1.5795794205794207, 0.08019868286049439, 2.6326323676323677, 0.01647807547956608], [0.5275274725274725, 1.0, 0.426661487326101, 1.055054945054945, 0.17488376140451095, 1.5825824175824177, 0.07980076505153338, 2.637637362637363, 0.016348333774987508], [0.5285284715284715, 1.0, 0.4260617692505883, 1.057056943056943, 0.1742938886952559, 1.5855854145854147, 0.07940474015581221, 2.642642357642358, 0.016219595474303874], [0.5295294705294704, 1.0, 0.4254635404266203, 1.0590589410589408, 0.17370604962412164, 1.5885884115884117, 0.07901059960207794, 2.6476473526473527, 0.01609185283773747], [0.5305304695304695, 1.0, 0.42486679941557726, 1.061060939060939, 0.17312023853656772, 1.5915914085914087, 0.07861833485986087, 2.652652347652348, 0.01596509818537018], [0.5315314685314685, 1.0, 0.4242715447824174, 1.063062937062937, 0.17253644979756125, 1.5945944055944057, 0.07822793743928996, 2.657657342657343, 0.015839323896681752], [0.5325324675324674, 1.0, 0.4236777750956739, 1.0650649350649348, 0.17195467779152268, 1.5975974025974027, 0.07783939889090889, 2.6626623376623377, 0.01571452241009158], [0.5335334665334664, 1.0, 0.42308548892745035, 1.067066933066933, 0.17137491692227183, 1.6006003996003997, 0.07745271080549344, 2.667667332667333, 0.015590686222504202], [0.5345344655344655, 1.0, 0.42249468485341773, 1.069068931068931, 0.17079716161297412, 1.6036033966033967, 0.07706786481386922, 2.672672327672328, 0.015467807888858147], [0.5355354645354644, 1.0, 0.42190536145281204, 1.0710709290709288, 0.17022140630608668, 1.6066063936063937, 0.07668485258673079, 2.6776773226773227, 0.01534588002167837], [0.5365364635364634, 1.0, 0.421317517308429, 1.073072927072927, 0.1696476454633051, 1.6096093906093907, 0.07630366583446119, 2.682682317682318, 0.015224895290632076], [0.5375374625374625, 1.0, 0.4207311510066225, 1.075074925074925, 0.16907587356551032, 1.612612387612388, 0.07592429630695269, 2.687687312687313, 0.015104846422088045], [0.5385384615384614, 1.0, 0.4201462611372998, 1.0770769230769228, 0.16850608511271495, 1.615615384615385, 0.0755467357934281, 2.6926923076923077, 0.014985726198679362], [0.5395394605394604, 1.0, 0.41956284629391905, 1.079078921078921, 0.16793827462401117, 1.618618381618382, 0.07517097612226312, 2.697697302697303, 0.014867527458869458], [0.5405404595404595, 1.0, 0.4189809050734853, 1.081080919080919, 0.16737243663751739, 1.621621378621379, 0.07479700916080952, 2.702702297702298, 0.01475024309652158], [0.5415414585414584, 1.0, 0.4184004360765475, 1.0830829170829168, 0.16680856571032587, 1.624624375624376, 0.07442482681521902, 2.7077072927072927, 0.014633866060471597], [0.5425424575424574, 1.0, 0.41782143790719495, 1.085084915084915, 0.1662466564184505, 1.627627372627373, 0.07405442103026821, 2.712712287712288, 0.014518389354104], [0.5435434565434565, 1.0, 0.417243909173054, 1.087086913086913, 0.1656867033567744, 1.63063036963037, 0.0736857837891841, 2.717717282717283, 0.014403806034931368], [0.5445444555444554, 1.0, 0.41666784848528476, 1.0890889110889108, 0.1651287011389982, 1.633633366633367, 0.0733189071134707, 2.722722277722278, 0.014290109214176894], [0.5455454545454544, 1.0, 0.41609325445857703, 1.091090909090909, 0.16457264439758795, 1.6366363636363639, 0.07295378306273645, 2.727727272727273, 0.014177292056360308], [0.5465464535464535, 1.0, 0.41552012571114855, 1.093092907092907, 0.16401852778372392, 1.6396393606393609, 0.07259040373452202, 2.732732267732268, 0.014065347778886862], [0.5475474525474524, 1.0, 0.41494846086474046, 1.0950949050949048, 0.16346634596724824, 1.6426423576423579, 0.07222876126412968, 2.737737262737263, 0.013954269651639609], [0.5485484515484514, 1.0, 0.41437825854461435, 1.0970969030969029, 0.16291609363661486, 1.6456453546453549, 0.07186884782445277, 2.742742257742258, 0.013844050996574734], [0.5495494505494505, 1.0, 0.41380951737954846, 1.099098901098901, 0.1623677654988376, 1.6486483516483519, 0.07151065562580643, 2.747747252747253, 0.013734685187320123], [0.5505504495504494, 1.0, 0.4132422360018353, 1.1011008991008988, 0.1618213562794395, 1.6516513486513489, 0.07115417691575908, 2.752752247752248, 0.013626165648776918], [0.5515514485514484, 1.0, 0.41267641304727776, 1.1031028971028969, 0.16127686072240194, 1.6546543456543459, 0.07079940397896449, 2.757757242757243, 0.0135184858567243], [0.5525524475524475, 1.0, 0.4121120471551859, 1.105104895104895, 0.1607342735901143, 1.6576573426573429, 0.07044632913699482, 2.762762237762238, 0.013411639337427199], [0.5535534465534464, 1.0, 0.41154913696837375, 1.1071068931068928, 0.16019358966332345, 1.6606603396603399, 0.07009494474817449, 2.767767232767233, 0.013305619667247106], [0.5545544455544454, 1.0, 0.41098768113315537, 1.1091088911088909, 0.15965480374108357, 1.6636633366633369, 0.06974524320741476, 2.772772227772228, 0.01320042047225588], [0.5555554445554445, 1.0, 0.4104276782993434, 1.111110889110889, 0.1591179106407062, 1.6666663336663339, 0.06939721694604918, 2.777777222777223, 0.013096035427852537], [0.5565564435564434, 1.0, 0.4098691271202441, 1.1131128871128868, 0.15858290519771026, 1.6696693306693309, 0.06905085843166972, 2.782782217782218, 0.01299245825838303], [0.5575574425574424, 1.0, 0.40931202625265456, 1.1151148851148849, 0.15804978226577232, 1.6726723276723279, 0.06870616016796369, 2.787787212787213, 0.01288968273676295], [0.5585584415584415, 1.0, 0.40875637435685974, 1.117116883116883, 0.15751853671667723, 1.6756753246753249, 0.06836311469455165, 2.792792207792208, 0.012787702684103149], [0.5595594405594405, 1.0, 0.408202170096629, 1.119118881118881, 0.15698916344026892, 1.6786783216783219, 0.06802171458682578, 2.797797202797203, 0.012686511969338253], [0.5605604395604394, 1.0, 0.4076494121392128, 1.1211208791208789, 0.15646165734440093, 1.6816813186813189, 0.06768195245578938, 2.802802197802198, 0.012586104508858095], [0.5615614385614385, 1.0, 0.4070980991553401, 1.123122877122877, 0.15593601335488766, 1.6846843156843159, 0.06734382094789672, 2.807807192807193, 0.01248647426614193], [0.5625624375624375, 1.0, 0.4065482298192145, 1.125124875124875, 0.1554122264154555, 1.6876873126873129, 0.06700731274489408, 2.812812187812188, 0.012387615251395537], [0.5635634365634364, 1.0, 0.4059998028085109, 1.1271268731268729, 0.15489029148769387, 1.6906903096903099, 0.06667242056366122, 2.817817182817183, 0.012289521521191098], [0.5645644355644355, 1.0, 0.4054528168043734, 1.129128871128871, 0.15437020355100758, 1.6936933066933069, 0.0663391371560539, 2.8228221778221783, 0.012192187178109902], [0.5655654345654345, 1.0, 0.4049072704914111, 1.131130869130869, 0.15385195760256754, 1.6966963036963039, 0.06600745530874678, 2.827827172827173, 0.012095606370387759], [0.5665664335664334, 1.0, 0.40436316255769533, 1.1331328671328669, 0.1533355486572634, 1.6996993006993009, 0.06567736784307765, 2.832832167832168, 0.011999773291563208], [0.5675674325674325, 1.0, 0.40382049169475603, 1.135134865134865, 0.15282097174765524, 1.7027022977022979, 0.06534886761489156, 2.8378371628371633, 0.011904682180128452], [0.5685684315684315, 1.0, 0.4032792565975796, 1.137136863136863, 0.15230822192392576, 1.7057052947052949, 0.06502194751438672, 2.842842157842158, 0.011810327319182913], [0.5695694305694304, 1.0, 0.4027394559646049, 1.1391388611388609, 0.15179729425383276, 1.7087082917082919, 0.06469660046596035, 2.847847152847153, 0.011716703036089612], [0.5705704295704295, 1.0, 0.4022010884977204, 1.141140859140859, 0.15128818382266193, 1.7117112887112889, 0.06437281942805548, 2.8528521478521482, 0.011623803702134054], [0.5715714285714285, 1.0, 0.401664152902261, 1.143142857142857, 0.15078088573317905, 1.7147142857142859, 0.06405059739300871, 2.857857142857143, 0.01153162373218588], [0.5725724275724274, 1.0, 0.40112864788700503, 1.1451448551448549, 0.15027539510558335, 1.7177172827172829, 0.06372992738689853, 2.862862137862138, 0.011440157584363064], [0.5735734265734265, 1.0, 0.4005945721641713, 1.147146853146853, 0.14977170707746035, 1.7207202797202799, 0.0634108024693942, 2.8678671328671332, 0.011349399759698732], [0.5745744255744255, 1.0, 0.4000619244494152, 1.149148851148851, 0.14926981680373505, 1.7237232767232769, 0.06309321573360577, 2.872872127872128, 0.01125934480181058], [0.5755754245754244, 1.0, 0.39953070346182695, 1.1511508491508489, 0.1487697194566255, 1.7267262737262739, 0.06277716030593448, 2.877877122877123, 0.01116998729657282], [0.5765764235764235, 1.0, 0.399000907923927, 1.153152847152847, 0.14827141022559623, 1.7297292707292709, 0.06246262934592398, 2.8828821178821182, 0.011081321871790676], [0.5775774225774225, 1.0, 0.39847253656166426, 1.155154845154845, 0.1477748843173121, 1.7327322677322679, 0.062149616046112285, 2.887887112887113, 0.010993343196877422], [0.5785784215784214, 1.0, 0.3979455881044121, 1.1571568431568429, 0.14728013695559186, 1.7357352647352648, 0.0618381136318845, 2.892892107892108, 0.01090604598253391], [0.5795794205794205, 1.0, 0.39742006128496593, 1.159158841158841, 0.1467871633813628, 1.7387382617382618, 0.06152811536132615, 2.8978971028971032, 0.010819424980430549], [0.5805804195804195, 1.0, 0.3968959548395396, 1.161160839160839, 0.14629595885261434, 1.7417412587412588, 0.06121961452507727, 2.902902097902098, 0.010733474982891802], [0.5815814185814184, 1.0, 0.3963732675077634, 1.1631628371628369, 0.14580651864435293, 1.7447442557442558, 0.06091260444618719, 2.907907092907093, 0.010648190822583094], [0.5825824175824175, 1.0, 0.3958519980326797, 1.165164835164835, 0.14531883804855608, 1.7477472527472528, 0.06060707847996998, 2.912912087912088, 0.010563567372200131], [0.5835834165834165, 1.0, 0.3953321451607406, 1.167166833166833, 0.14483291237412768, 1.7507502497502498, 0.06030303001386076, 2.917917082917083, 0.010479599544160662], [0.5845844155844154, 1.0, 0.39481370764180473, 1.1691688311688309, 0.14434873694685224, 1.7537532467532468, 0.06000045246727245, 2.9229220779220784, 0.010396282290298616], [0.5855854145854145, 1.0, 0.39429668422913455, 1.171170829170829, 0.14386630710935058, 1.7567562437562438, 0.05969933929145341, 2.927927072927073, 0.0103136106015606], [0.5865864135864135, 1.0, 0.3937810736793934, 1.173172827172827, 0.14338561822103435, 1.7597592407592408, 0.0593996839693457, 2.932932067932068, 0.010231579507704732], [0.5875874125874125, 1.0, 0.39326687475264205, 1.175174825174825, 0.14290666565806212, 1.7627622377622378, 0.05910148001544404, 2.9379370629370634, 0.010150184077001871], [0.5885884115884115, 1.0, 0.3927540862123356, 1.177176823176823, 0.14242944481329411, 1.765765234765235, 0.05880472097565541, 2.942942057942058, 0.01006941941593909], [0.5895894105894105, 1.0, 0.3922427068253216, 1.179178821178821, 0.14195395109624853, 1.768768231768232, 0.058509400427159394, 2.947947052947053, 0.009989280668925491], [0.5905904095904095, 1.0, 0.39173273536183567, 1.181180819180819, 0.1414801799330571, 1.771771228771229, 0.058215511978269165, 2.9529520479520484, 0.009909763018000272], [0.5915914085914085, 1.0, 0.3912241705954989, 1.183182817182817, 0.1410081267664211, 1.774774225774226, 0.05792304926829311, 2.957957042957043, 0.00983086168254307], [0.5925924075924075, 1.0, 0.3907170113033163, 1.185184815184815, 0.1405377870555677, 1.777777222777223, 0.05763200596739717, 2.962962037962038, 0.009752571918986578], [0.5935934065934065, 1.0, 0.39021125626567194, 1.187186813186813, 0.14006915627620595, 1.78078021978022, 0.05734237577646792, 2.9679670329670333, 0.009674889020531319], [0.5945944055944055, 1.0, 0.38970690426632715, 1.189188811188811, 0.1396022299204836, 1.783783216783217, 0.057054152426976174, 2.972972027972028, 0.009597808316862706], [0.5955954045954045, 1.0, 0.389203954092417, 1.191190809190809, 0.13913700349694352, 1.786786213786214, 0.05676732968084129, 2.977977022977023, 0.009521325173870237], [0.5965964035964035, 1.0, 0.3887024045344483, 1.193192807192807, 0.1386734725304806, 1.789789210789211, 0.056481901330296215, 2.9829820179820183, 0.009445434993368909], [0.5975974025974025, 1.0, 0.3882022543862954, 1.195194805194805, 0.13821163256229863, 1.792792207792208, 0.056197861197753086, 2.987987012987013, 0.009370133212822766], [0.5985984015984015, 1.0, 0.38770350244519836, 1.197196803196803, 0.13775147914986746, 1.795795204795205, 0.05591520313566956, 2.992992007992008, 0.009295415305070595], [0.5995994005994005, 1.0, 0.3872061475117592, 1.199198801198801, 0.13729300786688023, 1.798798201798202, 0.05563392102641578, 2.9979970029970033, 0.00922127677805377], [0.6006003996003995, 1.0, 0.38671018838994026, 1.201200799200799, 0.1368362143032109, 1.801801198801199, 0.055354008782141854, 3.003001998001998, 0.009147713174546154], [0.6016013986013985, 1.0, 0.38621562388705954, 1.203202797202797, 0.1363810940648717, 1.804804195804196, 0.05507546034464621, 3.008006993006993, 0.009074720071886165], [0.6026023976023975, 1.0, 0.3857224528137893, 1.205204795204795, 0.1359276427739707, 1.807807192807193, 0.05479826968524448, 3.0130119880119883, 0.009002293081710862], [0.6036033966033965, 1.0, 0.3852306739841525, 1.207206793206793, 0.13547585606867044, 1.81081018981019, 0.054522430804638915, 3.018016983016983, 0.008930427849692127], [0.6046043956043955, 1.0, 0.3847402862155209, 1.209208791208791, 0.13502572960314474, 1.813813186813187, 0.05424793773278861, 3.0230219780219785, 0.008859120055274882], [0.6056053946053945, 1.0, 0.3842512883286104, 1.211210789210789, 0.13457725904753823, 1.816816183816184, 0.05397478452878045, 3.0280269730269733, 0.008788365411417321], [0.6066063936063935, 1.0, 0.38376367914748033, 1.213212787212787, 0.1341304400879236, 1.819819180819181, 0.053702965280700135, 3.033031968031968, 0.008718159664333196], [0.6076073926073925, 1.0, 0.3832774574995288, 1.215214785214785, 0.13368526842626086, 1.822822177822178, 0.0534324741055046, 3.0380369630369635, 0.008648498593236046], [0.6086083916083915, 1.0, 0.3827926222154909, 1.217216783216783, 0.13324173978035556, 1.825825174825175, 0.05316330514889453, 3.0430419580419583, 0.00857937801008549], [0.6096093906093905, 1.0, 0.38230917212943605, 1.219218781218781, 0.13279984988381774, 1.828828171828172, 0.0528954525851877, 3.048046953046953, 0.008510793759335392], [0.6106103896103895, 1.0, 0.3818271060787636, 1.221220779220779, 0.1323595944860211, 1.831831168831169, 0.05262891061719282, 3.0530519480519485, 0.008442741717684048], [0.6116113886113885, 1.0, 0.3813464229042029, 1.223222777222777, 0.13192096935206163, 1.834834165834166, 0.05236367347608409, 3.0580569430569433, 0.008375217793826308], [0.6126123876123875, 1.0, 0.3808671214498074, 1.225224775224775, 0.1314839702627173, 1.837837162837163, 0.05209973542127643, 3.063061938061938, 0.008308217928207576], [0.6136133866133865, 1.0, 0.38038920056295406, 1.227226773226773, 0.1310485930144073, 1.84084015984016, 0.05183709074030111, 3.0680669330669335, 0.008241738092779772], [0.6146143856143855, 1.0, 0.37991265909433963, 1.229228771228771, 0.1306148334191516, 1.843843156843157, 0.05157573374868218, 3.0730719280719283, 0.008175774290759157], [0.6156153846153845, 1.0, 0.379437495897978, 1.231230769230769, 0.13018268730453075, 1.846846153846154, 0.05131565878981348, 3.078076923076923, 0.008110322556386043], [0.6166163836163835, 1.0, 0.37896370983119776, 1.233232767232767, 0.12975215051364566, 1.849849150849151, 0.05105686023483611, 3.0830819180819184, 0.00804537895468637], [0.6176173826173825, 1.0, 0.37849129975463924, 1.235234765234765, 0.1293232189050776, 1.852852147852148, 0.05079933248251665, 3.0880869130869133, 0.007980939581235144], [0.6186183816183816, 1.0, 0.37802026453225096, 1.2372367632367631, 0.12889588835284857, 1.855855144855145, 0.05054306995912601, 3.093091908091908, 0.007917000561921687], [0.6196193806193805, 1.0, 0.3775506030312889, 1.239238761238761, 0.12847015474638127, 1.858858141858142, 0.05028806711831861, 3.0980969030969034, 0.007853558052716736], [0.6206203796203795, 1.0, 0.37708231412231197, 1.241240759240759, 0.1280460139904597, 1.861861138861139, 0.050034318441012575, 3.1031018981018983, 0.007790608239441332], [0.6216213786213786, 1.0, 0.3766153966791794, 1.2432427572427571, 0.12762346200519004, 1.864864135864136, 0.049781818435270055, 3.108106893106893, 0.007728147337537522], [0.6226223776223775, 1.0, 0.3761498495790498, 1.245244755244755, 0.12720249472596093, 1.867867132867133, 0.049530561636178576, 3.1131118881118884, 0.007666171591840818], [0.6236233766233765, 1.0, 0.3756856717023759, 1.247246753246753, 0.12678310810340482, 1.87087012987013, 0.049280542605732565, 3.1181168831168833, 0.0076046772763544365], [0.6246243756243756, 1.0, 0.37522286193290366, 1.2492487512487511, 0.12636529810335861, 1.873873126873127, 0.0490317559327158, 3.1231218781218786, 0.007543660694025301], [0.6256253746253745, 1.0, 0.37476141915766914, 1.251250749250749, 0.12594906070682513, 1.876876123876124, 0.048784196232584204, 3.1281268731268734, 0.007483118176521767], [0.6266263736263735, 1.0, 0.37430134226699535, 1.253252747252747, 0.12553439190993448, 1.879879120879121, 0.048537858147349414, 3.1331318681318683, 0.007423046084013078], [0.6276273726273726, 1.0, 0.373842630154491, 1.2552547452547451, 0.12512128772390535, 1.882882117882118, 0.048292736345462606, 3.1381368631368636, 0.007363440804950537], [0.6286283716283715, 1.0, 0.3733852817170453, 1.257256743256743, 0.1247097441750066, 1.885885114885115, 0.04804882552169938, 3.1431418581418584, 0.007304298755850394], [0.6296293706293705, 1.0, 0.3729292958548283, 1.259258741258741, 0.12429975730451948, 1.888888111888112, 0.04780612039704471, 3.1481468531468533, 0.007245616381078394], [0.6306303696303696, 1.0, 0.37247467147128555, 1.2612607392607391, 0.12389132316869886, 1.891891108891109, 0.047564615718578826, 3.1531518481518486, 0.007187390152636005], [0.6316313686313685, 1.0, 0.3720214074731372, 1.263262737262737, 0.12348443783873606, 1.894894105894106, 0.04732430625936345, 3.1581568431568434, 0.007129616569948332], [0.6326323676323675, 1.0, 0.37156950277037504, 1.265264735264735, 0.12307909740072032, 1.897897102897103, 0.04708518681832875, 3.1631618381618383, 0.007072292159653643], [0.6336333666333666, 1.0, 0.37111895627625935, 1.2672667332667331, 0.12267529795560177, 1.9009000999001, 0.04684725222016062, 3.1681668331668336, 0.007015413475394578], [0.6346343656343655, 1.0, 0.37066976690731723, 1.269268731268731, 0.12227303561915348, 1.903903096903097, 0.04661049731518884, 3.1731718281718284, 0.0069589770976109105], [0.6356353646353645, 1.0, 0.3702219335833384, 1.271270729270729, 0.12187230652193448, 1.906906093906094, 0.04637491697927551, 3.1781768231768233, 0.006902979633333998], [0.6366363636363636, 1.0, 0.36977545522737454, 1.2732727272727271, 0.12147310680925205, 1.909909090909091, 0.04614050611370423, 3.1831818181818186, 0.006847417715982781], [0.6376373626373625, 1.0, 0.36933033076573535, 1.275274725274725, 0.12107543264112518, 1.912912087912088, 0.045907259645069615, 3.1881868131868134, 0.006792288005161385], [0.6386383616383615, 1.0, 0.3688865591279863, 1.277276723276723, 0.12067928019224718, 1.915915084915085, 0.04567517252516764, 3.1931918081918083, 0.0067375871864583025], [0.6396393606393606, 1.0, 0.36844413924694597, 1.279278721278721, 0.12028464565194917, 1.918918081918082, 0.045444239730886314, 3.1981968031968036, 0.006683311971247118], [0.6406403596403595, 1.0, 0.3680030700586837, 1.281280719280719, 0.11989152522416335, 1.9219210789210792, 0.045214456264096974, 3.2032017982017984, 0.006629459096488797], [0.6416413586413585, 1.0, 0.36756335050251765, 1.283282717282717, 0.11949991512738645, 1.9249240759240762, 0.04498581715154608, 3.2082067932067933, 0.006576025324535523], [0.6426423576423576, 1.0, 0.36712497952101086, 1.285284715284715, 0.11910981159464337, 1.9279270729270732, 0.04475831744474759, 3.2132117882117885, 0.006523007442936036], [0.6436433566433565, 1.0, 0.3666879560599699, 1.287286713286713, 0.11872121087345094, 1.9309300699300702, 0.04453195221987587, 3.2182167832167834, 0.0064704022642425125], [0.6446443556443555, 1.0, 0.3662522790684412, 1.289288711288711, 0.11833410922578187, 1.9339330669330672, 0.04430671657765916, 3.2232217782217782, 0.006418206625818908], [0.6456453546453546, 1.0, 0.3658179474987096, 1.291290709290709, 0.11794850292802862, 1.9369360639360642, 0.04408260564327347, 3.2282267732267735, 0.00636641738965086], [0.6466463536463535, 1.0, 0.36538496030629564, 1.293292707292707, 0.11756438827096792, 1.9399390609390612, 0.04385961456623715, 3.2332317682317684, 0.006315031442157001], [0.6476473526473525, 1.0, 0.36495331644995216, 1.295294705294705, 0.11718176155972479, 1.9429420579420582, 0.043637738520305794, 3.2382367632367637, 0.006264045694001765], [0.6486483516483516, 1.0, 0.3645230148916633, 1.297296703296703, 0.11680061911373694, 1.9459450549450552, 0.04341697270336792, 3.2432417582417585, 0.006213457079909681], [0.6496493506493506, 1.0, 0.36409405459664046, 1.2992987012987012, 0.11642095726671985, 1.9489480519480522, 0.04319731233734093, 3.2482467532467534, 0.006163262558481065], [0.6506503496503495, 1.0, 0.3636664345333207, 1.301300699300699, 0.11604277236663098, 1.9519510489510492, 0.04297875266806778, 3.2532517482517487, 0.006113459112009184], [0.6516513486513485, 1.0, 0.36324015367336404, 1.303302697302697, 0.1156660607756347, 1.9549540459540462, 0.042761288965214014, 3.2582567432567435, 0.006064043746298823], [0.6526523476523476, 1.0, 0.36281521099165137, 1.3053046953046952, 0.11529081887006777, 1.9579570429570432, 0.04254491652216542, 3.2632617382617384, 0.006015013490486274], [0.6536533466533465, 1.0, 0.3623916054662813, 1.307306693306693, 0.1149170430404038, 1.9609600399600402, 0.042329630655926175, 3.2682667332667337, 0.005966365396860734], [0.6546543456543455, 1.0, 0.36196933607856785, 1.309308691308691, 0.11454472969121916, 1.9639630369630372, 0.04211542670701746, 3.2732717282717285, 0.005918096540687078], [0.6556553446553446, 1.0, 0.3615484018130387, 1.3113106893106892, 0.11417387524115792, 1.9669660339660342, 0.041902300039376644, 3.2782767232767234, 0.005870204020030033], [0.6566563436563435, 1.0, 0.3611288016574315, 1.313312687312687, 0.11380447612289775, 1.9699690309690312, 0.0416902460402569, 3.2832817182817187, 0.005822684955579705], [0.6576573426573425, 1.0, 0.3607105346026928, 1.315314685314685, 0.11343652878311536, 1.9729720279720282, 0.041479260120127426, 3.2882867132867135, 0.00577553649047848], [0.6586583416583416, 1.0, 0.3602935996429747, 1.3173166833166832, 0.11307002968245224, 1.9759750249750252, 0.04126933771257408, 3.2932917082917084, 0.005728755790149263], [0.6596593406593405, 1.0, 0.35987799577563295, 1.319318681318681, 0.11270497529548103, 1.9789780219780222, 0.04106047427420055, 3.2982967032967037, 0.005682340042125066], [0.6606603396603395, 1.0, 0.359463722001224, 1.321320679320679, 0.1123413621106712, 1.9819810189810192, 0.040852665284530014, 3.3033016983016985, 0.005636286455879916], [0.6616613386613386, 1.0, 0.35905077732350327, 1.3233226773226772, 0.11197918663035554, 1.9849840159840162, 0.040645906245907346, 3.3083066933066934, 0.005590592262661105], [0.6626623376623375, 1.0, 0.35863916074942204, 1.325324675324675, 0.11161844537069632, 1.9879870129870132, 0.04044019268340168, 3.3133116883116887, 0.005545254715322713], [0.6636633366633365, 1.0, 0.35822887128912584, 1.327326673326673, 0.11125913486165193, 1.9909900099900102, 0.04023552014470969, 3.3183166833166835, 0.005500271088160463], [0.6646643356643356, 1.0, 0.3578199079559511, 1.3293286713286712, 0.11090125164694341, 1.9939930069930072, 0.0400318842000591, 3.3233216783216784, 0.005455638676747834], [0.6656653346653345, 1.0, 0.3574122697664237, 1.331330669330669, 0.11054479228402118, 1.9969960039960042, 0.03982928044211289, 3.3283266733266736, 0.005411354797773492], [0.6666663336663335, 1.0, 0.35700595574025623, 1.333332667332667, 0.11018975334403204, 1.9999990009990014, 0.03962770448587386, 3.3333316683316685, 0.005367416788879948], [0.6676673326673326, 1.0, 0.3566009649003454, 1.3353346653346652, 0.10983613141178612, 2.003001998001998, 0.03942715196858979, 3.338336663336664, 0.005323822008503513], [0.6686683316683315, 1.0, 0.35619729627277014, 1.337336663336663, 0.10948392308572391, 2.006004995004995, 0.03922761854965891, 3.3433416583416586, 0.005280567835715467], [0.6696693306693305, 1.0, 0.3557949488867883, 1.339338661338661, 0.10913312497788377, 2.009007992007992, 0.03902909991053606, 3.3483466533466535, 0.00523765167006452], [0.6706703296703296, 1.0, 0.35539392177483614, 1.3413406593406592, 0.10878373371386932, 2.012010989010989, 0.03883159175463912, 3.353351648351649, 0.005195070931420433], [0.6716713286713285, 1.0, 0.35499421397252456, 1.343342657342657, 0.10843574593281666, 2.015013986013986, 0.03863508980725621, 3.3583566433566436, 0.005152823059818934], [0.6726723276723275, 1.0, 0.3545958245186364, 1.345344655344655, 0.10808915828736243, 2.018016983016983, 0.03843958981545288, 3.3633616383616385, 0.0051109055153077875], [0.6736733266733266, 1.0, 0.35419875245512633, 1.3473466533466532, 0.1077439674436113, 2.02101998001998, 0.03824508754798037, 3.3683666333666338, 0.005069315777794111], [0.6746743256743255, 1.0, 0.3538029968271159, 1.349348651348651, 0.10740017008110424, 2.024022977022977, 0.03805157879518377, 3.3733716283716286, 0.005028051346892851], [0.6756753246753245, 1.0, 0.35340855668289284, 1.351350649350649, 0.10705776289278637, 2.027025974025974, 0.03785905936891107, 3.3783766233766235, 0.00498710974177647], [0.6766763236763236, 1.0, 0.35301543107390804, 1.3533526473526472, 0.10671674258497495, 2.030028971028971, 0.03766752510242249, 3.3833816183816188, 0.004946488501025795], [0.6776773226773226, 1.0, 0.3526236190547742, 1.3553546453546452, 0.10637710587732821, 2.033031968031968, 0.037476971850300224, 3.3883866133866136, 0.004906185182482034], [0.6786783216783215, 1.0, 0.35223311968326204, 1.357356643356643, 0.10603884950281332, 2.036034965034965, 0.03728739548835882, 3.3933916083916085, 0.004866197363099954], [0.6796793206793206, 1.0, 0.3518439320202996, 1.3593586413586412, 0.1057019702076752, 2.039037962037962, 0.03709879191355584, 3.3983966033966038, 0.004826522638802207], [0.6806803196803196, 1.0, 0.35145605512996897, 1.3613606393606392, 0.10536646475140525, 2.042040959040959, 0.03691115704390311, 3.4034015984015986, 0.004787158624334797], [0.6816813186813185, 1.0, 0.35106948807950455, 1.363362637362637, 0.10503232990670994, 2.045043956043956, 0.03672448681837836, 3.4084065934065935, 0.004748102953123683], [0.6826823176823176, 1.0, 0.35068422993929077, 1.3653646353646351, 0.10469956245948, 2.048046953046953, 0.036538777196837284, 3.4134115884115888, 0.004709353277132489], [0.6836833166833166, 1.0, 0.35030027978285916, 1.3673666333666332, 0.10436815920875943, 2.05104995004995, 0.03635402415992619, 3.4184165834165836, 0.00467090726672135], [0.6846843156843155, 1.0, 0.3499176366868876, 1.369368631368631, 0.10403811696671472, 2.054052947052947, 0.03617022370899494, 3.4234215784215785, 0.004632762610506847], [0.6856853146853146, 1.0, 0.3495362997311965, 1.3713706293706291, 0.10370943255860415, 2.057055944055944, 0.035987371866010365, 3.4284265734265738, 0.004594917015223045], [0.6866863136863136, 1.0, 0.34915626799874755, 1.3733726273726272, 0.10338210282274732, 2.060058941058941, 0.03580546467347031, 3.4334315684315686, 0.00455736820558363], [0.6876873126873125, 1.0, 0.3487775405756413, 1.375374625374625, 0.10305612461049465, 2.063061938061938, 0.03562449819431784, 3.438436563436564, 0.004520113924145107], [0.6886883116883116, 1.0, 0.34840011655111486, 1.3773766233766231, 0.10273149478619706, 2.066064935064935, 0.03544446851185607, 3.4434415584415587, 0.00448315193117109], [0.6896893106893106, 1.0, 0.3480239950175392, 1.3793786213786212, 0.10240821022717607, 2.069067932067932, 0.035265371729663486, 3.4484465534465536, 0.00444648000449765], [0.6906903096903095, 1.0, 0.3476491750704186, 1.381380619380619, 0.10208626782369341, 2.072070929070929, 0.03508720397150943, 3.453451548451549, 0.004410095939399706], [0.6916913086913086, 1.0, 0.34727565580838654, 1.3833826173826171, 0.10176566447892131, 2.075073926073926, 0.034909961381270435, 3.4584565434565437, 0.00437399754845849], [0.6926923076923076, 1.0, 0.34690343633320414, 1.3853846153846152, 0.10144639710891269, 2.078076923076923, 0.034733640122846555, 3.4634615384615386, 0.0043381826614300335], [0.6936933066933065, 1.0, 0.3465325157497596, 1.387386613386613, 0.1011284626425715, 2.08107992007992, 0.03455823638007845, 3.468466533466534, 0.004302649125114688], [0.6946943056943056, 1.0, 0.34616289316606313, 1.3893886113886111, 0.10081185802162308, 2.084082917082917, 0.034383746356664774, 3.4734715284715287, 0.004267394803227682], [0.6956953046953046, 1.0, 0.3457945676932471, 1.3913906093906092, 0.10049658020058488, 2.087085914085914, 0.03421016627608002, 3.4784765234765236, 0.004232417576270677], [0.6966963036963035, 1.0, 0.34542753844556334, 1.393392607392607, 0.10018262614673708, 2.090088911088911, 0.034037492381492736, 3.483481518481519, 0.004197715341404351], [0.6976973026973026, 1.0, 0.3450618045403806, 1.3953946053946051, 0.09986999284009349, 2.093091908091908, 0.0338657209356843, 3.4884865134865137, 0.004163286012321975], [0.6986983016983016, 1.0, 0.34469736509818244, 1.3973966033966032, 0.09955867727337231, 2.096094905094905, 0.03369484822096796, 3.4934915084915086, 0.004129127519123979], [0.6996993006993005, 1.0, 0.34433421924256596, 1.399398601398601, 0.09924867645196753, 2.099097902097902, 0.033524870539108416, 3.498496503496504, 0.004095237808193516], [0.7007002997002996, 1.0, 0.3439723661002383, 1.4014005994005991, 0.09893998739391972, 2.102100899100899, 0.0333557842112417, 3.5035014985014987, 0.004061614842072989], [0.7017012987012986, 1.0, 0.34361180480101583, 1.4034025974025972, 0.09863260712988774, 2.105103896103896, 0.03318758557779568, 3.5085064935064936, 0.004028256599341565], [0.7027022977022975, 1.0, 0.34325253447782145, 1.405404595404595, 0.09832653270311989, 2.108106893106893, 0.03302027099841075, 3.513511488511489, 0.0039951610744936444], [0.7037032967032966, 1.0, 0.34289455426668236, 1.4074065934065931, 0.0980217611694257, 2.11110989010989, 0.032853836851861065, 3.5185164835164837, 0.003962326277818292], [0.7047042957042956, 1.0, 0.3425378633067288, 1.4094085914085912, 0.09771828959714725, 2.114112887112887, 0.03268827953597626, 3.5235214785214786, 0.003929750235279611], [0.7057052947052945, 1.0, 0.3421824607401908, 1.411410589410589, 0.0974161150671315, 2.117115884115884, 0.03252359546756331, 3.528526473526474, 0.0038974309883980643], [0.7067062937062936, 1.0, 0.3418283457123972, 1.4134125874125871, 0.09711523467270176, 2.120118881118881, 0.03235978108232912, 3.5335314685314687, 0.0038653665941327372], [0.7077072927072926, 1.0, 0.3414755173717726, 1.4154145854145852, 0.09681564551962987, 2.123121878121878, 0.032196832834803325, 3.538536463536464, 0.0038335551247645106], [0.7087082917082916, 1.0, 0.3411239748698363, 1.4174165834165833, 0.09651734472610843, 2.126124875124875, 0.0320347471982616, 3.543541458541459, 0.0038019946677801723], [0.7097092907092906, 1.0, 0.3407737173611997, 1.4194185814185811, 0.09622032942272307, 2.129127872127872, 0.03187352066464925, 3.5485464535464537, 0.0037706833257574383], [0.7107102897102896, 1.0, 0.3404247440035638, 1.4214205794205792, 0.09592459675242465, 2.132130869130869, 0.03171314974450534, 3.553551448551449, 0.003739619216250871], [0.7117112887112886, 1.0, 0.3400770539577186, 1.4234225774225773, 0.0956301438705021, 2.135133866133866, 0.03155363096688719, 3.558556443556444, 0.0037088004716787164], [0.7127122877122876, 1.0, 0.3397306463875393, 1.4254245754245751, 0.09533696794455478, 2.138136863136863, 0.03139496087929521, 3.5635614385614387, 0.0036782252392106164], [0.7137132867132866, 1.0, 0.3393855204599856, 1.4274265734265732, 0.09504506615446537, 2.14113986013986, 0.031237136047598184, 3.568566433566434, 0.0036478916806562214], [0.7147142857142856, 1.0, 0.33904167534509955, 1.4294285714285713, 0.09475443569237277, 2.144142857142857, 0.031080153055958983, 3.573571428571429, 0.003617797972354674], [0.7157152847152846, 1.0, 0.33869911021600285, 1.4314305694305691, 0.09446507376264494, 2.147145854145854, 0.030924008506760556, 3.5785764235764237, 0.0035879423050649705], [0.7167162837162836, 1.0, 0.338357824248896, 1.4334325674325672, 0.09417697758185219, 2.150148851148851, 0.030768699020532492, 3.583581418581419, 0.003558322883857196], [0.7177172827172826, 1.0, 0.3380178166230547, 1.4354345654345653, 0.09389014437874028, 2.153151848151848, 0.030614221235877804, 3.588586413586414, 0.0035289379280045996], [0.7187182817182816, 1.0, 0.3376790865208295, 1.4374365634365631, 0.0936045713942038, 2.156154845154845, 0.030460571809400223, 3.5935914085914087, 0.0034997856708765514], [0.7197192807192806, 1.0, 0.337341633127643, 1.4394385614385612, 0.09332025588125956, 2.159157842157842, 0.03030774741563179, 3.598596403596404, 0.0034708643598323177], [0.7207202797202796, 1.0, 0.3370054556319878, 1.4414405594405593, 0.09303719510502041, 2.162160839160839, 0.030155744746960908, 3.603601398601399, 0.0034421722561157053], [0.7217212787212786, 1.0, 0.33667055322542483, 1.4434425574425571, 0.0927553863426686, 2.165163836163836, 0.030004560513560787, 3.6086063936063937, 0.003413707634750516], [0.7227222777222776, 1.0, 0.33633692510258173, 1.4454445554445552, 0.09247482688342985, 2.168166833166833, 0.029854191443318193, 3.613611388611389, 0.0033854687844368484], [0.7237232767232766, 1.0, 0.33600457046114995, 1.4474465534465533, 0.09219551402854716, 2.17116983016983, 0.02970463428176265, 3.618616383616384, 0.003357454007448211], [0.7247242757242756, 1.0, 0.33567348850188355, 1.4494485514485511, 0.09191744509125481, 2.174172827172827, 0.029555885791995973, 3.6236213786213787, 0.0033296616195294527], [0.7257252747252746, 1.0, 0.33534367842859747, 1.4514505494505492, 0.09164061739675262, 2.177175824175824, 0.029407942754622253, 3.628626373626374, 0.0033020899497955107], [0.7267262737262736, 1.0, 0.3350151394481653, 1.4534525474525473, 0.09136502828218022, 2.180178821178821, 0.029260801967678184, 3.633631368631369, 0.0032747373406309486], [0.7277272727272726, 1.0, 0.3346878707705167, 1.4554545454545451, 0.09109067509659124, 2.183181818181818, 0.029114460246563702, 3.638636363636364, 0.003247602147590305], [0.7287282717282716, 1.0, 0.33436187160863695, 1.4574565434565432, 0.09081755520092807, 2.186184815184815, 0.028968914423973126, 3.643641358641359, 0.003220682739299231], [0.7297292707292706, 1.0, 0.33403714117856376, 1.4594585414585413, 0.0905456659679963, 2.189187812187812, 0.028824161349826585, 3.648646353646354, 0.003193977497356405], [0.7307302697302696, 1.0, 0.3337136786993858, 1.461460539460539, 0.09027500478243954, 2.192190809190809, 0.02868019789120179, 3.653651348651349, 0.0031674848162362426], [0.7317312687312686, 1.0, 0.3333914833932412, 1.4634625374625372, 0.09000556904071423, 2.195193806193806, 0.028537020932266323, 3.658656343656344, 0.0031412031031923626], [0.7327322677322676, 1.0, 0.3330705544853154, 1.4654645354645353, 0.08973735615106462, 2.198196803196803, 0.028394627374210137, 3.663661338661339, 0.003115130778161839], [0.7337332667332666, 1.0, 0.3327508912038392, 1.467466533466533, 0.08947036353349776, 2.2011998001998, 0.028253014135178472, 3.668666333666334, 0.003089266273670201], [0.7347342657342656, 1.0, 0.33243249278008724, 1.4694685314685312, 0.08920458861975876, 2.204202797202797, 0.028112178150205197, 3.673671328671329, 0.0030636080347372025], [0.7357352647352646, 1.0, 0.332115358448375, 1.4714705294705293, 0.08894002885330611, 2.207205794205794, 0.027972116371146483, 3.678676323676324, 0.0030381545187833266], [0.7367362637362636, 1.0, 0.3317994874460589, 1.473472527472527, 0.08867668168928697, 2.210208791208791, 0.027832825766614794, 3.683681318681319, 0.0030129041955370577], [0.7377372627372626, 1.0, 0.3314848790135329, 1.4754745254745252, 0.08841454459451281, 2.213211788211788, 0.027694303321913284, 3.688686313686314, 0.002987855546942871], [0.7387382617382616, 1.0, 0.33117153239422714, 1.4774765234765233, 0.08815361504743499, 2.216214785214785, 0.027556546038970575, 3.693691308691309, 0.0029630070670699695], [0.7397392607392607, 1.0, 0.33085944683460633, 1.4794785214785213, 0.08789389053812045, 2.219217782217782, 0.027419550936275818, 3.698696303696304, 0.002938357262021753], [0.7407402597402596, 1.0, 0.3305486215841674, 1.4814805194805192, 0.08763536856822779, 2.222220779220779, 0.027283315048814216, 3.703701298701299, 0.0029139046498459936], [0.7417412587412586, 1.0, 0.3302390558954389, 1.4834825174825172, 0.08737804665098288, 2.225223776223776, 0.02714783542800287, 3.708706293706294, 0.0028896477604457515], [0.7427422577422577, 1.0, 0.3299307490239776, 1.4854845154845153, 0.08712192231115522, 2.228226773226773, 0.027013109141626863, 3.713711288711289, 0.0028655851354909847], [0.7437432567432566, 1.0, 0.3296237002283677, 1.4874865134865132, 0.08686699308503404, 2.23122977022977, 0.026879133273775873, 3.718716283716284, 0.0028417153283308754], [0.7447442557442556, 1.0, 0.32931790877021894, 1.4894885114885112, 0.08661325652040464, 2.234232767232767, 0.02674590492478109, 3.723721278721279, 0.0028180369039068607], [0.7457452547452547, 1.0, 0.3290133739141646, 1.4914905094905093, 0.08636071017652469, 2.237235764235764, 0.02661342121115235, 3.728726273726274, 0.002794548438666353], [0.7467462537462536, 1.0, 0.32871009492785963, 1.4934925074925072, 0.08610935162410085, 2.240238761238761, 0.02648167926551586, 3.733731268731269, 0.0027712485204771553], [0.7477472527472526, 1.0, 0.32840807108197967, 1.4954945054945052, 0.08585917844526547, 2.243241758241758, 0.026350676236552042, 3.738736263736264, 0.0027481357485425683], [0.7487482517482517, 1.0, 0.328107301650218, 1.4974965034965033, 0.08561018823355324, 2.246244755244755, 0.026220409288933856, 3.743741258741259, 0.0027252087333171663], [0.7497492507492506, 1.0, 0.3278077859092851, 1.4994985014985012, 0.08536237859387791, 2.249247752247752, 0.02609087560326542, 3.748746253746254, 0.002702466096423266], [0.7507502497502496, 1.0, 0.3275095231389062, 1.5015004995004992, 0.08511574714250951, 2.252250749250749, 0.025962072376021012, 3.753751248751249, 0.00267990647056805], [0.7517512487512487, 1.0, 0.32721251262181944, 1.5035024975024973, 0.08487029150705125, 2.255253746253746, 0.025833996819484388, 3.758756243756244, 0.0026575284994613717], [0.7527522477522476, 1.0, 0.32691675364377437, 1.5055044955044952, 0.08462600932641672, 2.258256743256743, 0.02570664616168844, 3.763761238761239, 0.00263533083773421], [0.7537532467532466, 1.0, 0.3266222454935304, 1.5075064935064932, 0.08438289825080718, 2.26125974025974, 0.02558001764635516, 3.768766233766234, 0.002613312150857787], [0.7547542457542457, 1.0, 0.326328987462855, 1.5095084915084913, 0.08414095594168923, 2.264262737262737, 0.02545410853283609, 3.773771228771229, 0.0025914711150633388], [0.7557552447552446, 1.0, 0.3260369788465218, 1.5115104895104892, 0.08390018007177165, 2.267265734265734, 0.025328916096052874, 3.778776223776224, 0.0025698064172625223], [0.7567562437562436, 1.0, 0.32574621894230893, 1.5135124875124872, 0.08366056832498375, 2.270268731268731, 0.0252044376264384, 3.783781218781219, 0.002548316754968484], [0.7577572427572427, 1.0, 0.32545670705099733, 1.5155144855144853, 0.0834221183964527, 2.273271728271728, 0.025080670429878098, 3.788786213786214, 0.0025270008362175407], [0.7587582417582416, 1.0, 0.3251684424763698, 1.5175164835164832, 0.08318482799248123, 2.276274725274725, 0.024957611827651587, 3.793791208791209, 0.0025058573794915157], [0.7597592407592406, 1.0, 0.32488142452520763, 1.5195184815184812, 0.08294869483052607, 2.279277722277722, 0.02483525915637482, 3.798796203796204, 0.0024848851136406902], [0.7607602397602397, 1.0, 0.32459565250729105, 1.5215204795204793, 0.08271371663917554, 2.282280719280719, 0.0247136097679423, 3.803801198801199, 0.002464082777807385], [0.7617612387612386, 1.0, 0.32431112573539606, 1.5235224775224772, 0.0824798911581278, 2.285283716283716, 0.02459266102946988, 3.808806193806194, 0.002443449121350151], [0.7627622377622376, 1.0, 0.3240278435252932, 1.5255244755244752, 0.08224721613816927, 2.288286713286713, 0.024472410323237694, 3.813811188811189, 0.0024229829037685844], [0.7637632367632367, 1.0, 0.3237458051957458, 1.5275264735264733, 0.08201568934115284, 2.29128971028971, 0.02435285504663358, 3.818816183816184, 0.00240268289462875], [0.7647642357642356, 1.0, 0.323465010068509, 1.5295284715284712, 0.0817853085399764, 2.294292707292707, 0.0242339926120967, 3.823821178821179, 0.0023825478734892], [0.7657652347652346, 1.0, 0.3231854574683268, 1.5315304695304692, 0.08155607151856135, 2.297295704295704, 0.024115820447061512, 3.828826173826174, 0.002362576629827608], [0.7667662337662337, 1.0, 0.3229071467229319, 1.5335324675324673, 0.08132797607183138, 2.300298701298701, 0.023998335993902154, 3.833831168831169, 0.002342767962967987], [0.7677672327672326, 1.0, 0.32263007716304304, 1.5355344655344652, 0.0811010200056912, 2.3033016983016985, 0.023881536709877083, 3.838836163836164, 0.0023231206820085084], [0.7687682317682316, 1.0, 0.3223542481223644, 1.5375364635364632, 0.08087520113700539, 2.3063046953046955, 0.023765420067073967, 3.843841158841159, 0.002303633605749902], [0.7697692307692307, 1.0, 0.32207965893758206, 1.5395384615384613, 0.08065051729357763, 2.3093076923076925, 0.02364998355235508, 3.848846153846154, 0.0022843055626244405], [0.7707702297702297, 1.0, 0.3218063089483647, 1.5415404595404594, 0.0804269663141294, 2.3123106893106895, 0.02353522466730283, 3.8538511488511493, 0.0022651353906255117], [0.7717712287712286, 1.0, 0.3215341974973609, 1.5435424575424572, 0.08020454604827965, 2.3153136863136865, 0.02342114092816572, 3.858856143856144, 0.00224612193723775], [0.7727722277722276, 1.0, 0.32126332393019735, 1.5455444555444553, 0.07998325435652368, 2.3183166833166835, 0.023307729865804556, 3.863861138861139, 0.002227264059367752], [0.7737732267732267, 1.0, 0.3209936875954782, 1.5475464535464534, 0.07976308911021292, 2.3213196803196805, 0.023194989025639087, 3.8688661338661343, 0.00220856062327535], [0.7747742257742256, 1.0, 0.32072528784478227, 1.5495484515484512, 0.07954404819153424, 2.3243226773226775, 0.023082915967594767, 3.873871128871129, 0.002190010504505458], [0.7757752247752246, 1.0, 0.32045812403266205, 1.5515504495504493, 0.07932612949348967, 2.3273256743256745, 0.02297150826605004, 3.878876123876124, 0.002171612587820457], [0.7767762237762237, 1.0, 0.32019219551664285, 1.5535524475524474, 0.07910933091987607, 2.3303286713286715, 0.02286076350978381, 3.8838811188811193, 0.0021533657671331625], [0.7777772227772226, 1.0, 0.3199275016572204, 1.5555544455544452, 0.07889365038526502, 2.3333316683316685, 0.022750679301923236, 3.888886113886114, 0.002135268945440311], [0.7787782217782216, 1.0, 0.31966404181785923, 1.5575564435564433, 0.07867908581498276, 2.3363346653346655, 0.022641253259891872, 3.893891108891109, 0.00211732103475662], [0.7797792207792207, 1.0, 0.3194018153649915, 1.5595584415584414, 0.0784656351450901, 2.3393376623376625, 0.022532483015358075, 3.8988961038961043, 0.002099520956049367], [0.7807802197802196, 1.0, 0.31914082166801583, 1.5615604395604392, 0.0782532963223628, 2.3423406593406595, 0.022424366214183807, 3.903901098901099, 0.0020818676391735286], [0.7817812187812186, 1.0, 0.3188810600992949, 1.5635624375624373, 0.07804206730427173, 2.3453436563436565, 0.02231690051637363, 3.908906093906094, 0.0020643600228074355], [0.7827822177822177, 1.0, 0.3186225300341548, 1.5655644355644354, 0.07783194605896296, 2.3483466533466535, 0.022210083596024076, 3.9139110889110893, 0.0020469970543889678], [0.7837832167832166, 1.0, 0.31836523085088253, 1.5675664335664332, 0.0776229305652387, 2.3513496503496505, 0.022103913141273322, 3.918916083916084, 0.002029777690052278], [0.7847842157842156, 1.0, 0.31810916193072575, 1.5695684315684313, 0.07741501881253751, 2.3543526473526475, 0.021998386854251126, 3.923921078921079, 0.0020127008945650298], [0.7857852147852147, 1.0, 0.31785432265789054, 1.5715704295704294, 0.07720820880091507, 2.3573556443556445, 0.021893502451029112, 3.9289260739260743, 0.001995765641266157], [0.7867862137862136, 1.0, 0.31760071241953985, 1.5735724275724272, 0.07700249854102488, 2.3603586413586415, 0.021789257661571332, 3.933931068931069, 0.0019789709120041485], [0.7877872127872126, 1.0, 0.3173483306057921, 1.5755744255744253, 0.0767978860540992, 2.3633616383616385, 0.021685650229685136, 3.938936063936064, 0.0019623156970758303], [0.7887882117882117, 1.0, 0.31709717660972, 1.5775764235764234, 0.07659436937192995, 2.3663646353646355, 0.021582677912972366, 3.9439410589410593, 0.0019457989951656616], [0.7897892107892106, 1.0, 0.3168472498273491, 1.5795784215784212, 0.0763919465368499, 2.3693676323676325, 0.02148033848278075, 3.948946053946054, 0.0019294198132855406], [0.7907902097902096, 1.0, 0.31659854965765577, 1.5815804195804193, 0.07619061560171361, 2.3723706293706295, 0.021378629724155784, 3.9539510489510494, 0.001913177166715101], [0.7917912087912087, 1.0, 0.31635107550256625, 1.5835824175824174, 0.07599037462987894, 2.3753736263736265, 0.02127754943579268, 3.9589560439560443, 0.0018970700789425143], [0.7927922077922076, 1.0, 0.3161048267669557, 1.5855844155844152, 0.07579122169518833, 2.3783766233766235, 0.021177095429988774, 3.963961038961039, 0.001881097581605778], [0.7937932067932066, 1.0, 0.315859802858645, 1.5875864135864133, 0.07559315488195031, 2.3813796203796205, 0.021077265532596163, 3.9689660339660344, 0.0018652587144345014], [0.7947942057942057, 1.0, 0.3156160031884016, 1.5895884115884114, 0.0753961722849209, 2.3843826173826175, 0.020978057582974698, 3.9739710289710293, 0.001849552525192168], [0.7957952047952046, 1.0, 0.3153734271699362, 1.5915904095904092, 0.07520027200928553, 2.3873856143856145, 0.02087946943394513, 3.978976023976024, 0.0018339780696188922], [0.7967962037962036, 1.0, 0.31513207421990275, 1.5935924075924073, 0.07500545217064063, 2.3903886113886115, 0.02078149895174273, 3.9839810189810194, 0.0018185344113746497], [0.7977972027972027, 1.0, 0.31489194375789586, 1.5955944055944054, 0.0748117108949755, 2.3933916083916085, 0.020684144015971045, 3.9889860139860143, 0.0018032206219829807], [0.7987982017982017, 1.0, 0.3146530352064507, 1.5975964035964034, 0.07461904631865457, 2.3963946053946055, 0.020587402519556024, 3.993991008991009, 0.0017880357807751733], [0.7997992007992006, 1.0, 0.3144153479910399, 1.5995984015984013, 0.07442745658839896, 2.3993976023976025, 0.02049127236870044, 3.9989960039960044, 0.0017729789748349113], [0.8008001998001997, 1.0, 0.3141788815400741, 1.6016003996003993, 0.07423693986126916, 2.4024005994005995, 0.02039575148283852, 4.004000999001, 0.0017580492989433911], [0.8018011988011987, 1.0, 0.31394363528489894, 1.6036023976023974, 0.07404749430464713, 2.4054035964035965, 0.020300837794590968, 4.009005994005994, 0.0017432458555248955], [0.8028021978021976, 1.0, 0.3137096086597947, 1.6056043956043953, 0.07385911809621837, 2.4084065934065935, 0.020206529249720183, 4.014010989010989, 0.0017285677545928366], [0.8038031968031967, 1.0, 0.31347680110197473, 1.6076063936063933, 0.07367180942395489, 2.4114095904095905, 0.02011282380708582, 4.019015984015985, 0.0017140141136962456], [0.8048041958041957, 1.0, 0.3132452120515835, 1.6096083916083914, 0.07348556648609744, 2.4144125874125875, 0.020019719438600626, 4.024020979020979, 0.0016995840578667213], [0.8058051948051946, 1.0, 0.3130148409516966, 1.6116103896103893, 0.0733003874911383, 2.4174155844155845, 0.019927214129186497, 4.029025974025974, 0.0016852767195658265], [0.8068061938061937, 1.0, 0.312785687248318, 1.6136123876123873, 0.073116270657804, 2.4204185814185815, 0.01983530587673091, 4.03403096903097, 0.001671091238632932], [0.8078071928071927, 1.0, 0.312557750390379, 1.6156143856143854, 0.0729332142150383, 2.4234215784215785, 0.019743992692043588, 4.039035964035964, 0.0016570267622335025], [0.8088081918081916, 1.0, 0.3123310298297378, 1.6176163836163833, 0.07275121640198501, 2.4264245754245755, 0.01965327259881341, 4.044040959040959, 0.001643082444807824], [0.8098091908091907, 1.0, 0.31210552502117733, 1.6196183816183813, 0.07257027546797111, 2.4294275724275725, 0.01956314363356566, 4.049045954045955, 0.0016292574480201707], [0.8108101898101897, 1.0, 0.3118812354224036, 1.6216203796203794, 0.0723903896724899, 2.4324305694305695, 0.019473603845619553, 4.054050949050949, 0.0016155509407084004], [0.8118111888111886, 1.0, 0.31165816049404566, 1.6236223776223773, 0.07221155728518427, 2.4354335664335665, 0.01938465129704601, 4.059055944055944, 0.0016019620988339872], [0.8128121878121877, 1.0, 0.3114362996996533, 1.6256243756243753, 0.07203377658583003, 2.4384365634365635, 0.019296284062625665, 4.06406093906094, 0.0015884901054324801], [0.8138131868131867, 1.0, 0.3112156525056962, 1.6276263736263734, 0.07185704586431944, 2.4414395604395605, 0.01920850022980724, 4.069065934065934, 0.0015751341505643862], [0.8148141858141856, 1.0, 0.31099621838156255, 1.6296283716283713, 0.07168136342064464, 2.4444425574425575, 0.01912129789866616, 4.074070929070929, 0.0015618934312664776], [0.8158151848151847, 1.0, 0.31077799679955725, 1.6316303696303693, 0.07150672756488143, 2.4474455544455544, 0.019034675181863418, 4.079075924075925, 0.0015487671515035171], [0.8168161838161837, 1.0, 0.31056098723490166, 1.6336323676323674, 0.07133313661717298, 2.4504485514485514, 0.018948630204604713, 4.084080919080919, 0.0015357545221203982], [0.8178171828171826, 1.0, 0.31034518916573167, 1.6356343656343653, 0.07116058890771347, 2.4534515484515484, 0.018863161104599898, 4.089085914085914, 0.0015228547607947036], [0.8188181818181817, 1.0, 0.31013060207309623, 1.6376363636363633, 0.07098908277673234, 2.4564545454545454, 0.01877826603202264, 4.09409090909091, 0.0015100670919896714], [0.8198191808191807, 1.0, 0.3099172254409568, 1.6396383616383614, 0.0708186165744782, 2.4594575424575424, 0.018693943149470444, 4.099095904095904, 0.0014973907469075698], [0.8208201798201796, 1.0, 0.309705058756186, 1.6416403596403593, 0.0706491886612028, 2.4624605394605394, 0.018610190631924817, 4.104100899100899, 0.0014848249634434737], [0.8218211788211787, 1.0, 0.3094941015085652, 1.6436423576423573, 0.07048079740714551, 2.4654635364635364, 0.018527006666711802, 4.109105894105895, 0.0014723689861394506], [0.8228221778221777, 1.0, 0.3092843531907851, 1.6456443556443554, 0.07031344119251749, 2.4684665334665334, 0.018444389453462776, 4.114110889110889, 0.0014600220661391402], [0.8238231768231766, 1.0, 0.3090758132984431, 1.6476463536463533, 0.07014711840748616, 2.4714695304695304, 0.018362337204075416, 4.119115884115884, 0.0014477834611427351], [0.8248241758241757, 1.0, 0.3088684813300431, 1.6496483516483513, 0.06998182745215968, 2.4744725274725274, 0.018280848142675055, 4.12412087912088, 0.0014356524353623496], [0.8258251748251747, 1.0, 0.30866235678699344, 1.6516503496503494, 0.06981756673657162, 2.4774755244755244, 0.018199920505576225, 4.129125874125874, 0.0014236282594777881], [0.8268261738261736, 1.0, 0.3084574391736063, 1.6536523476523473, 0.06965433468066566, 2.4804785214785214, 0.01811955254124445, 4.134130869130869, 0.001411710210592697], [0.8278271728271727, 1.0, 0.30825372799709627, 1.6556543456543453, 0.06949212971428016, 2.4834815184815184, 0.018039742510258416, 4.139135864135865, 0.0013998975721911022], [0.8288281718281717, 1.0, 0.30805122276757935, 1.6576563436563434, 0.0693309502771336, 2.4864845154845154, 0.01796048868527227, 4.144140859140859, 0.0013881896340943343], [0.8298291708291707, 1.0, 0.30784992299807074, 1.6596583416583415, 0.06917079481880896, 2.4894875124875124, 0.017881789350978266, 4.149145854145854, 0.0013765856924183289], [0.8308301698301697, 1.0, 0.30764982820448566, 1.6616603396603393, 0.06901166179873913, 2.4924905094905094, 0.017803642804069566, 4.15415084915085, 0.0013650850495313153], [0.8318311688311687, 1.0, 0.3074509379056362, 1.6636623376623374, 0.0688535496861921, 2.4954935064935064, 0.017726047353203492, 4.159155844155844, 0.0013536870140118684], [0.8328321678321677, 1.0, 0.3072532516232316, 1.6656643356643355, 0.06869645696025611, 2.4984965034965034, 0.01764900131896482, 4.164160839160839, 0.0013423909006073445], [0.8338331668331667, 1.0, 0.307056768881876, 1.6676663336663333, 0.06854038210982508, 2.5014995004995004, 0.017572503033829484, 4.169165834165835, 0.0013311960301926802], [0.8348341658341657, 1.0, 0.3068614892090685, 1.6696683316683314, 0.06838532363358422, 2.5045024975024974, 0.017496550842128446, 4.174170829170829, 0.0013201017297295656], [0.8358351648351647, 1.0, 0.30666741213520055, 1.6716703296703295, 0.06823128003999523, 2.5075054945054944, 0.017421143100011912, 4.179175824175824, 0.0013091073322259819], [0.8368361638361637, 1.0, 0.3064745371935565, 1.6736723276723273, 0.0680782498472823, 2.5105084915084914, 0.017346278175413735, 4.18418081918082, 0.0012982121766960983], [0.8378371628371627, 1.0, 0.3062828639203106, 1.6756743256743254, 0.06792623158341764, 2.5135114885114884, 0.01727195444801606, 4.189185814185814, 0.0012874156081205375], [0.8388381618381617, 1.0, 0.30609239185452786, 1.6776763236763235, 0.06777522378610745, 2.5165144855144854, 0.017198170309214295, 4.194190809190809, 0.0012767169774069922], [0.8398391608391607, 1.0, 0.305903120538161, 1.6796783216783213, 0.06762522500277786, 2.5195174825174824, 0.017124924162082295, 4.199195804195805, 0.0012661156413512034], [0.8408401598401597, 1.0, 0.30571504951605055, 1.6816803196803194, 0.06747623379056086, 2.5225204795204794, 0.01705221442133776, 4.2042007992008, 0.0012556109625982898], [0.8418411588411587, 1.0, 0.30552817833592394, 1.6836823176823175, 0.06732824871628047, 2.5255234765234764, 0.016980039513307968, 4.209205794205794, 0.0012452023096044312], [0.8428421578421577, 1.0, 0.30534250654839346, 1.6856843156843153, 0.06718126835643892, 2.5285264735264734, 0.016908397875895684, 4.21421078921079, 0.0012348890565988997], [0.8438431568431567, 1.0, 0.3051580337069562, 1.6876863136863134, 0.06703529129720297, 2.5315294705294704, 0.016837287958545374, 4.219215784215785, 0.0012246705835464362], [0.8448441558441557, 1.0, 0.3049747593679923, 1.6896883116883115, 0.06689031613439046, 2.5345324675324674, 0.01676670822220964, 4.224220779220779, 0.0012145462761099766], [0.8458451548451547, 1.0, 0.30479268309076346, 1.6916903096903093, 0.06674634147345652, 2.5375354645354644, 0.01669665713931588, 4.229225774225775, 0.0012045155256137157], [0.8468461538461537, 1.0, 0.3046118044374135, 1.6936923076923074, 0.06660336592948043, 2.5405384615384614, 0.016627133193733296, 4.23423076923077, 0.001194577729006514], [0.8478471528471527, 1.0, 0.30443212297296574, 1.6956943056943055, 0.0664613881271521, 2.5435414585414584, 0.016558134880740004, 4.239235764235764, 0.0011847322888256435], [0.8488481518481517, 1.0, 0.3042536382653226, 1.6976963036963033, 0.0663204067007589, 2.5465444555444554, 0.016489660706990514, 4.24424075924076, 0.0011749786131608649], [0.8498491508491507, 1.0, 0.3040763498852638, 1.6996983016983014, 0.06618042029417252, 2.5495474525474524, 0.01642170919048341, 4.249245754245755, 0.0011653161156188442], [0.8508501498501497, 1.0, 0.30390025740644716, 1.7017002997002995, 0.06604142756083602, 2.5525504495504494, 0.01635427886052923, 4.254250749250749, 0.0011557442152878997], [0.8518511488511487, 1.0, 0.30372536040540576, 1.7037022977022973, 0.06590342716375075, 2.5555534465534464, 0.016287368257718697, 4.259255744255745, 0.0011462623367030742], [0.8528521478521477, 1.0, 0.30355165846154725, 1.7057042957042954, 0.0657664177754635, 2.5585564435564434, 0.016220975933891067, 4.26426073926074, 0.00113686990981154], [0.8538531468531467, 1.0, 0.3033791511571536, 1.7077062937062935, 0.06563039807805394, 2.5615594405594404, 0.016155100452102854, 4.269265734265734, 0.0011275663699383267], [0.8548541458541457, 1.0, 0.30320783807737955, 1.7097082917082913, 0.06549536676312152, 2.5645624375624374, 0.016089740386596676, 4.27427072927073, 0.001118351157752373], [0.8558551448551447, 1.0, 0.30303771881025193, 1.7117102897102894, 0.06536132253177335, 2.5675654345654344, 0.016024894322770433, 4.279275724275725, 0.001109223719232901], [0.8568561438561437, 1.0, 0.30286879294666824, 1.7137122877122875, 0.06522826409461138, 2.5705684315684314, 0.015960560857146658, 4.284280719280719, 0.0011001835056361038], [0.8578571428571427, 1.0, 0.3027010600803956, 1.7157142857142853, 0.06509619017172018, 2.5735714285714284, 0.01589673859734216, 4.289285714285715, 0.0010912299734621594], [0.8588581418581417, 1.0, 0.3025345198080708, 1.7177162837162834, 0.06496509949265453, 2.5765744255744254, 0.015833426162037905, 4.29429070929071, 0.0010823625844225554], [0.8598591408591407, 1.0, 0.3023691717291978, 1.7197182817182814, 0.06483499079642713, 2.5795774225774224, 0.015770622180949084, 4.299295704295704, 0.001073580805407722], [0.8608601398601398, 1.0, 0.3022050154461482, 1.7217202797202795, 0.06470586283149679, 2.5825804195804194, 0.015708325294795485, 4.3043006993007, 0.0010648841084549884], [0.8618611388611387, 1.0, 0.3020420505641591, 1.7237222777222774, 0.06457771435575597, 2.5855834165834164, 0.015646534155272028, 4.309305694305695, 0.0010562719707168345], [0.8628621378621377, 1.0, 0.30188027669133305, 1.7257242757242754, 0.06445054413651903, 2.5885864135864134, 0.015585247425019669, 4.314310689310689, 0.0010477438744294632], [0.8638631368631368, 1.0, 0.3017196934386363, 1.7277262737262735, 0.06432435095051048, 2.5915894105894104, 0.015524463777596365, 4.319315684315685, 0.0010392993068816683], [0.8648641358641357, 1.0, 0.30156030041989856, 1.7297282717282714, 0.0641991335838531, 2.5945924075924074, 0.015464181897448434, 4.32432067932068, 0.0010309377603840127], [0.8658651348651347, 1.0, 0.3014020972518119, 1.7317302697302694, 0.06407489083205621, 2.5975954045954044, 0.015404400479882032, 4.329325674325674, 0.0010226587322383037], [0.8668661338661338, 1.0, 0.3012450835539298, 1.7337322677322675, 0.06395162150000412, 2.6005984015984014, 0.015345118231034939, 4.33433066933067, 0.001014461724707372], [0.8678671328671327, 1.0, 0.301089258948666, 1.7357342657342654, 0.06382932440194478, 2.6036013986013984, 0.015286333867848553, 4.339335664335665, 0.001006346244985148], [0.8688681318681317, 1.0, 0.3009346230612935, 1.7377362637362634, 0.06370799836147809, 2.6066043956043954, 0.01522804611804011, 4.344340659340659, 0.0009983118051670337], [0.8698691308691308, 1.0, 0.3007811755199442, 1.7397382617382615, 0.06358764221154492, 2.6096073926073924, 0.015170253720075173, 4.349345654345655, 0.0009903579222205682], [0.8708701298701297, 1.0, 0.3006289159556081, 1.7417402597402594, 0.06346825479441558, 2.61261038961039, 0.015112955423140315, 4.35435064935065, 0.0009824841179563912], [0.8718711288711287, 1.0, 0.3004778440021313, 1.7437422577422574, 0.06334983496167881, 2.615613386613387, 0.015056149987116033, 4.359355644355644, 0.0009746899189994904], [0.8728721278721278, 1.0, 0.3003279592962167, 1.7457442557442555, 0.06323238157423086, 2.618616383616384, 0.014999836182549924, 4.36436063936064, 0.0009669748567607449], [0.8738731268731267, 1.0, 0.3001792614774214, 1.7477462537462534, 0.0631158935022643, 2.621619380619381, 0.014944012790630075, 4.369365634365635, 0.000959338467408752], [0.8748741258741257, 1.0, 0.3000317501881574, 1.7497482517482514, 0.0630003696252573, 2.624622377622378, 0.014888678603158668, 4.374370629370629, 0.0009517802918419419], [0.8758751248751248, 1.0, 0.2998854250736897, 1.7517502497502495, 0.06288580883196274, 2.627625374625375, 0.01483383242252586, 4.3793756243756246, 0.0009442998756609764], [0.8768761238761237, 1.0, 0.29974028578213613, 1.7537522477522474, 0.06277221002039773, 2.630628371628372, 0.014779473061683833, 4.38438061938062, 0.0009368967691414309], [0.8778771228771227, 1.0, 0.2995963319644658, 1.7557542457542454, 0.06265957209783278, 2.633631368631369, 0.014725599344121126, 4.389385614385614, 0.0009295705272067549], [0.8788781218781218, 1.0, 0.2994535632744988, 1.7577562437562435, 0.06254789398078131, 2.636634365634366, 0.014672210103837149, 4.3943906093906095, 0.0009223207094015166], [0.8798791208791207, 1.0, 0.29931197936890575, 1.7597582417582414, 0.062437174594989486, 2.639637362637363, 0.014619304185316977, 4.399395604395605, 0.0009151468798649208], [0.8808801198801197, 1.0, 0.29917157990720544, 1.7617602397602394, 0.06232741287542557, 2.64264035964036, 0.014566880443506292, 4.4044005994006, 0.0009080486073046062], [0.8818811188811188, 1.0, 0.29903236455176563, 1.7637622377622375, 0.062218607766269876, 2.645643356643357, 0.01451493774378667, 4.4094055944055945, 0.0009010254649707137], [0.8828821178821177, 1.0, 0.29889433296780166, 1.7657642357642354, 0.06211075822090438, 2.648646353646354, 0.014463474961950948, 4.41441058941059, 0.0008940770306302328], [0.8838831168831167, 1.0, 0.2987574848233754, 1.7677662337662334, 0.06200386320190308, 2.651649350649351, 0.014412490984178957, 4.419415584415585, 0.0008872028865416144], [0.8848841158841158, 1.0, 0.2986218197893947, 1.7697682317682315, 0.06189792168102154, 2.654652347652348, 0.01436198470701338, 4.4244205794205795, 0.0008804026194296585], [0.8858851148851147, 1.0, 0.2984873375396127, 1.7717702297702294, 0.061792932639187226, 2.657655344655345, 0.014311955037335879, 4.429425574425575, 0.0008736758204606649], [0.8868861138861137, 1.0, 0.2983540377506263, 1.7737722277722274, 0.061688895066489856, 2.660658341658342, 0.014262400892343435, 4.43443056943057, 0.0008670220852178582], [0.8878871128871128, 1.0, 0.29822192010187637, 1.7757742257742255, 0.061585807962171404, 2.663661338661339, 0.014213321199524913, 4.4394355644355645, 0.0008604410136770705], [0.8888881118881118, 1.0, 0.2980909842756469, 1.7777762237762236, 0.06148367033461651, 2.666664335664336, 0.014164714896637858, 4.44444055944056, 0.0008539322101826929], [0.8898891108891107, 1.0, 0.29796122995706353, 1.7797782217782214, 0.061382481201343174, 2.669667332667333, 0.014116580931685488, 4.449445554445555, 0.0008474952834238908], [0.8908901098901097, 1.0, 0.29783265683409355, 1.7817802197802195, 0.06128223958899298, 2.67267032967033, 0.014068918262893916, 4.4544505494505495, 0.0008411298464110735], [0.8918911088911088, 1.0, 0.29770526459754465, 1.7837822177822176, 0.061182944533322105, 2.675673326673327, 0.014021725858689653, 4.459455544455545, 0.0008348355164526326], [0.8928921078921077, 1.0, 0.2975790529410642, 1.7857842157842154, 0.06108459507919167, 2.678676323676324, 0.013975002697677229, 4.46446053946054, 0.0008286119151319326], [0.8938931068931067, 1.0, 0.2974540215611382, 1.7877862137862135, 0.06098719028055882, 2.681679320679321, 0.013928747768617111, 4.4694655344655345, 0.0008224586682845617], [0.8948941058941058, 1.0, 0.29733017015709207, 1.7897882117882116, 0.06089072920046754, 2.684682317682318, 0.01388296007040382, 4.47447052947053, 0.0008163754059758344], [0.8958951048951047, 1.0, 0.2972074984310876, 1.7917902097902094, 0.060795210911039524, 2.687685314685315, 0.013837638612044234, 4.479475524475525, 0.0008103617624785537], [0.8968961038961037, 1.0, 0.29708600608812435, 1.7937922077922075, 0.06070063449346546, 2.690688311688312, 0.013792782412636184, 4.4844805194805195, 0.0008044173762510223], [0.8978971028971028, 1.0, 0.2969656928360375, 1.7957942057942056, 0.06060699903799606, 2.693691308691309, 0.013748390501347197, 4.489485514485515, 0.0007985418899153055], [0.8988981018981017, 1.0, 0.29684655838549834, 1.7977962037962034, 0.06051430364393329, 2.696694305694306, 0.013704461917393464, 4.49449050949051, 0.0007927349502357488], [0.8998991008991007, 1.0, 0.29672860245001237, 1.7997982017982015, 0.06042254741962183, 2.699697302697303, 0.013660995710019112, 4.4994955044955045, 0.0007869962080977378], [0.9009000999000998, 1.0, 0.29661182474591935, 1.8018001998001996, 0.06033172948244036, 2.7027002997003, 0.013617990938475556, 4.5045004995005, 0.0007813253184867107], [0.9019010989010987, 1.0, 0.29649622499239253, 1.8038021978021974, 0.06024184895879315, 2.705703296703297, 0.013575446672001163, 4.509505494505495, 0.000775721940467416], [0.9029020979020977, 1.0, 0.2963818029114382, 1.8058041958041955, 0.06015290498410163, 2.708706293706294, 0.01353336198980114, 4.5145104895104895, 0.000770185737163416], [0.9039030969030968, 1.0, 0.29626855822789394, 1.8078061938061936, 0.060064896702796085, 2.711709290709291, 0.01349173598102755, 4.519515484515485, 0.0007647163757368326], [0.9049040959040957, 1.0, 0.29615649066942945, 1.8098081918081914, 0.05997782326830743, 2.714712287712288, 0.013450567744759646, 4.52452047952048, 0.0007593135273683383], [0.9059050949050947, 1.0, 0.29604559996654467, 1.8118101898101895, 0.059891683843059075, 2.717715284715285, 0.013409856389984326, 4.5295254745254745, 0.0007539768672373853], [0.9069060939060938, 1.0, 0.29593588585257, 1.8138121878121876, 0.059806477598458745, 2.720718281718282, 0.013369601035576896, 4.53453046953047, 0.0007487060745026797], [0.9079070929070927, 1.0, 0.2958273480636648, 1.8158141858141854, 0.059722203714890794, 2.723721278721279, 0.013329800810281964, 4.539535464535465, 0.0007435008322828908], [0.9089080919080917, 1.0, 0.2957199863388175, 1.8178161838161835, 0.059638861381708, 2.726724275724276, 0.01329045485269461, 4.5445404595404595, 0.0007383608276376005], [0.9099090909090908, 1.0, 0.2956138004198454, 1.8198181818181816, 0.05955644979722389, 2.729727272727273, 0.013251562311241695, 4.549545454545455, 0.0007332857515484901], [0.9109100899100897, 1.0, 0.29550879005139263, 1.8218201798201794, 0.05947496816870522, 2.73273026973027, 0.013213122344163507, 4.55455044955045, 0.0007282752989007611], [0.9119110889110887, 1.0, 0.2954049549809304, 1.8238221778221775, 0.05939441571236403, 2.7357332667332668, 0.013175134119495478, 4.5595554445554445, 0.0007233291684647915], [0.9129120879120878, 1.0, 0.2953022949587565, 1.8258241758241756, 0.059314791653350234, 2.7387362637362638, 0.01313759681505019, 4.56456043956044, 0.000718447062878027], [0.9139130869130867, 1.0, 0.29520080973799373, 1.8278261738261734, 0.05923609522574427, 2.7417392607392608, 0.013100509618399607, 4.569565434565435, 0.0007136286886271015], [0.9149140859140857, 1.0, 0.2951004990745909, 1.8298281718281715, 0.05915832567254964, 2.7447422577422578, 0.013063871726857466, 4.5745704295704295, 0.0007088737560301925], [0.9159150849150848, 1.0, 0.29500136272732136, 1.8318301698301696, 0.05908148224568554, 2.7477452547452548, 0.013027682347461917, 4.579575424575425, 0.0007041819792196061], [0.9169160839160837, 1.0, 0.29490340045778207, 1.8338321678321674, 0.05900556420597985, 2.7507482517482518, 0.01299194069695835, 4.58458041958042, 0.0006995530761245882], [0.9179170829170827, 1.0, 0.2948066120303938, 1.8358341658341655, 0.0589305708231619, 2.7537512487512488, 0.012956646001782451, 4.5895854145854145, 0.0006949867684543685], [0.9189180819180818, 1.0, 0.2947109972123997, 1.8378361638361635, 0.05885650137585551, 2.7567542457542458, 0.01292179749804346, 4.59459040959041, 0.0006904827816814285], [0.9199190809190808, 1.0, 0.2946165557738654, 1.8398381618381616, 0.058783355151572, 2.7597572427572428, 0.012887394431507626, 4.599595404595405, 0.0006860408450249968], [0.9209200799200797, 1.0, 0.2945232874876781, 1.8418401598401595, 0.05871113144670327, 2.7627602397602398, 0.012853436057581906, 4.6046003996003995, 0.0006816606914347709], [0.9219210789210788, 1.0, 0.294431192129547, 1.8438421578421575, 0.05863982956651527, 2.7657632367632368, 0.012819921641297832, 4.609605394605395, 0.00067734205757486], [0.9229220779220778, 1.0, 0.29434026947800107, 1.8458441558441556, 0.058569448825140986, 2.7687662337662338, 0.012786850457295598, 4.61461038961039, 0.0006730846838079549], [0.9239230769230767, 1.0, 0.2942505193143895, 1.8478461538461535, 0.058499988545574234, 2.7717692307692308, 0.012754221789808382, 4.619615384615385, 0.0006688883141797181], [0.9249240759240758, 1.0, 0.2941619414228817, 1.8498481518481515, 0.058431448059662806, 2.7747722277722278, 0.01272203493264684, 4.62462037962038, 0.0006647526964033949], [0.9259250749250748, 1.0, 0.2940745355904656, 1.8518501498501496, 0.05836382670810216, 2.7777752247752248, 0.012690289189183822, 4.629625374625375, 0.000660677581844647], [0.9269260739260737, 1.0, 0.2939883016069476, 1.8538521478521475, 0.05829712384042909, 2.7807782217782218, 0.012658983872339304, 4.63463036963037, 0.0006566627255066045], [0.9279270729270728, 1.0, 0.29390323926495243, 1.8558541458541455, 0.05823133881501554, 2.7837812187812188, 0.0126281183045655, 4.639635364635365, 0.0006527078860151356], [0.9289280719280718, 1.0, 0.2938193483599222, 1.8578561438561436, 0.05816647099906231, 2.7867842157842158, 0.01259769181783221, 4.64464035964036, 0.0006488128256043368], [0.9299290709290707, 1.0, 0.2937366286901163, 1.8598581418581415, 0.05810251976859299, 2.7897872127872128, 0.012567703753612382, 4.649645354645355, 0.0006449773101022368], [0.9309300699300698, 1.0, 0.2936550800566108, 1.8618601398601395, 0.058039484508448126, 2.7927902097902098, 0.012538153462867808, 4.65465034965035, 0.0006412011089167172], [0.9319310689310688, 1.0, 0.29357470226329757, 1.8638621378621376, 0.057977364612278995, 2.7957932067932068, 0.012509040306035125, 4.659655344655345, 0.0006374839950216536], [0.9329320679320677, 1.0, 0.29349549511688433, 1.8658641358641355, 0.05791615948254199, 2.7987962037962038, 0.012480363653011958, 4.66466033966034, 0.0006338257449432606], [0.9339330669330668, 1.0, 0.29341745842689376, 1.8678661338661335, 0.057855868530492835, 2.8017992007992008, 0.012452122883143266, 4.669665334665335, 0.0006302261387466613], [0.9349340659340658, 1.0, 0.2933405920056636, 1.8698681318681316, 0.05779649117618094, 2.8048021978021977, 0.012424317385207922, 4.67467032967033, 0.0006266849600226632], [0.9359350649350647, 1.0, 0.2932648956683452, 1.8718701298701295, 0.05773802684844382, 2.8078051948051947, 0.012396946557405489, 4.679675324675325, 0.0006232019958747478], [0.9369360639360638, 1.0, 0.29319036923290465, 1.8738721278721275, 0.05768047498490145, 2.8108081918081917, 0.012370009807343199, 4.68468031968032, 0.0006197770369062692], [0.9379370629370628, 1.0, 0.29311701252012035, 1.8758741258741256, 0.0576238350319511, 2.8138111888111887, 0.012343506552023105, 4.689685314685315, 0.0006164098772078692], [0.9389380619380617, 1.0, 0.29304482535358467, 1.8778761238761235, 0.057568106444761825, 2.8168141858141857, 0.012317436217829497, 4.69469030969031, 0.0006131003143450941], [0.9399390609390608, 1.0, 0.29297380755970215, 1.8798781218781215, 0.0575132886872693, 2.8198171828171827, 0.012291798240516447, 4.699695304695305, 0.0006098481493462265], [0.9409400599400598, 1.0, 0.29290395896768906, 1.8818801198801196, 0.057459381232170675, 2.8228201798201797, 0.012266592065195647, 4.7047002997003, 0.0006066531866903222], [0.9419410589410587, 1.0, 0.2928352794095733, 1.8838821178821175, 0.057406383560919386, 2.8258231768231767, 0.012241817146324375, 4.709705294705295, 0.0006035152342954554], [0.9429420579420578, 1.0, 0.29276776872019505, 1.8858841158841155, 0.05735429516372043, 2.8288261738261737, 0.012217472947693656, 4.71471028971029, 0.0006004341035071712], [0.9439430569430568, 1.0, 0.2927014267372048, 1.8878861138861136, 0.05730311553952518, 2.8318291708291707, 0.012193558942416725, 4.719715284715285, 0.0005974096090871438], [0.9449440559440557, 1.0, 0.29263625330106313, 1.8898881118881115, 0.057252844196026664, 2.8348321678321677, 0.012170074612917546, 4.72472027972028, 0.0005944415692020395], [0.9459450549450548, 1.0, 0.29257224825504125, 1.8918901098901095, 0.05720348064965488, 2.8378351648351647, 0.012147019450919687, 4.729725274725275, 0.0005915298054125842], [0.9469460539460538, 1.0, 0.29250941144521986, 1.8938921078921076, 0.05715502442557208, 2.8408381618381617, 0.012124392957435257, 4.73473026973027, 0.0005886741426628365], [0.9479470529470527, 1.0, 0.2924477427204891, 1.8958941058941055, 0.05710747505766824, 2.8438411588411587, 0.012102194642754131, 4.739735264735265, 0.0005858744092696631], [0.9489480519480518, 1.0, 0.2923872419325482, 1.8978961038961035, 0.05706083208855663, 2.8468441558441557, 0.012080424026433364, 4.74474025974026, 0.0005831304369124172], [0.9499490509490508, 1.0, 0.292327908935905, 1.8998981018981016, 0.057015095069569276, 2.8498471528471527, 0.012059080637286775, 4.749745254745255, 0.0005804420606228185], [0.9509500499500498, 1.0, 0.29226974358787555, 1.9019000999000997, 0.05697026356075265, 2.8528501498501497, 0.01203816401337474, 4.75475024975025, 0.0005778091187750368], [0.9519510489510488, 1.0, 0.2922127457485838, 1.9039020979020975, 0.05692633713086369, 2.8558531468531467, 0.01201767370199423, 4.759755244755245, 0.0005752314530759719], [0.9529520479520478, 1.0, 0.29215691528096177, 1.9059040959040956, 0.056883315357365356, 2.8588561438561437, 0.011997609259668973, 4.76476023976024, 0.0005727089085557414], [0.9539530469530468, 1.0, 0.2921022520507486, 1.9079060939060937, 0.05684119782642264, 2.8618591408591407, 0.0119779702521399, 4.769765234765235, 0.0005702413335583595], [0.9549540459540458, 1.0, 0.29204875592648966, 1.9099080919080915, 0.05679998413289867, 2.8648621378621377, 0.011958756254355692, 4.77477022977023, 0.0005678285797326227], [0.9559550449550448, 1.0, 0.29199642677953797, 1.9119100899100896, 0.05675967388035078, 2.8678651348651347, 0.011939966850463604, 4.779775224775225, 0.0005654705020231886], [0.9569560439560438, 1.0, 0.2919452644840522, 1.9139120879120877, 0.056720266681026615, 2.8708681318681317, 0.011921601633800499, 4.78478021978022, 0.0005631669586618569], [0.9579570429570428, 1.0, 0.29189526891699774, 1.9159140859140855, 0.056681762155860564, 2.8738711288711287, 0.011903660206883986, 4.789785214785215, 0.0005609178111590449], [0.9589580419580418, 1.0, 0.2918464399581447, 1.9179160839160836, 0.05664415993446999, 2.8768741258741257, 0.01188614218140387, 4.79479020979021, 0.0005587229242954619], [0.9599590409590408, 1.0, 0.2917987774900701, 1.9199180819180817, 0.056607459655151605, 2.8798771228771227, 0.011869047178213719, 4.799795204795205, 0.0005565821661139815], [0.9609600399600398, 1.0, 0.2917522813981546, 1.9219200799200795, 0.05657166096487824, 2.8828801198801197, 0.011852374827322652, 4.8048001998002, 0.0005544954079117039], [0.9619610389610388, 1.0, 0.29170695157058507, 1.9239220779220776, 0.05653676351929517, 2.8858831168831167, 0.011836124767887358, 4.809805194805195, 0.0005524625242322235], [0.9629620379620378, 1.0, 0.29166278789835215, 1.9259240759240757, 0.05650276698271695, 2.8888861138861137, 0.011820296648204246, 4.81481018981019, 0.000550483392858083], [0.9639630369630368, 1.0, 0.2916197902752512, 1.9279260739260735, 0.056469671028124155, 2.8918891108891107, 0.011804890125701906, 4.819815184815186, 0.0005485578948034273], [0.9649640359640358, 1.0, 0.2915779585978818, 1.9299280719280716, 0.05643747533716021, 2.8948921078921077, 0.011789904866933612, 4.82482017982018, 0.0005466859143068484], [0.9659650349650348, 1.0, 0.29153729276564705, 1.9319300699300697, 0.05640617960012842, 2.8978951048951047, 0.011775340547570155, 4.829825174825175, 0.0005448673388244275], [0.9669660339660338, 1.0, 0.29149779268075393, 1.9339320679320675, 0.05637578351598884, 2.9008981018981017, 0.0117611968523928, 4.8348301698301706, 0.0005431020590229682], [0.9679670329670328, 1.0, 0.29145945824821246, 1.9359340659340656, 0.05634628679235557, 2.9039010989010987, 0.011747473475286473, 4.839835164835165, 0.0005413899687734221], [0.9689680319680318, 1.0, 0.29142228937583614, 1.9379360639360637, 0.05631768914549374, 2.9069040959040957, 0.01173417011923315, 4.84484015984016, 0.0005397309651445118], [0.9699690309690308, 1.0, 0.2913862859742415, 1.9399380619380615, 0.05628999030031693, 2.9099070929070927, 0.011721286496305397, 4.8498451548451555, 0.0005381249483965381], [0.9709700299700298, 1.0, 0.2913514479568478, 1.9419400599400596, 0.056263189990384495, 2.9129100899100897, 0.011708822327660165, 4.85485014985015, 0.0005365718219753865], [0.9719710289710288, 1.0, 0.2913177752398762, 1.9439420579420577, 0.05623728795789891, 2.9159130869130867, 0.011696777343532737, 4.859855144855145, 0.0005350714925067226], [0.9729720279720278, 1.0, 0.2912852677423509, 1.9459440559440555, 0.05621228395370344, 2.918916083916084, 0.011685151283230912, 4.8648601398601405, 0.0005336238697903763], [0.9739730269730268, 1.0, 0.29125392538609757, 1.9479460539460536, 0.056188177737279583, 2.921919080919081, 0.011673943895129317, 4.869865134865135, 0.0005322288667949215], [0.9749740259740258, 1.0, 0.29122374809574464, 1.9499480519480517, 0.056164969076744856, 2.924922077922078, 0.011663154936664038, 4.87487012987013, 0.0005308863996524409], [0.9759750249750248, 1.0, 0.2911947357987214, 1.9519500499500495, 0.05614265774885056, 2.927925074925075, 0.011652784174327293, 4.8798751248751255, 0.0005295963876534859], [0.9769760239760238, 1.0, 0.2911668884252591, 1.9539520479520476, 0.056121243538979675, 2.930928071928072, 0.011642831383662405, 4.88488011988012, 0.0005283587532422244], [0.9779770229770228, 1.0, 0.2911402059083908, 1.9559540459540457, 0.0561007262411446, 2.933931068931069, 0.011633296349258982, 4.889885114885115, 0.0005271734220117771], [0.9789780219780219, 1.0, 0.2911146881839498, 1.9579560439560437, 0.05608110565798546, 2.936934065934066, 0.011624178864748192, 4.8948901098901105, 0.0005260403226997444], [0.9799790209790208, 1.0, 0.2910903351905717, 1.9599580419580416, 0.056062381600767895, 2.939937062937063, 0.011615478732798331, 4.899895104895105, 0.0005249593871839227], [0.9809800199800198, 1.0, 0.29106714686969243, 1.9619600399600396, 0.0560445538893815, 2.94294005994006, 0.01160719576511057, 4.9049000999001, 0.0005239305504782083], [0.9819810189810189, 1.0, 0.2910451231655487, 1.9639620379620377, 0.056027622352338005, 2.945943056943057, 0.01159932978241481, 4.9099050949050955, 0.0005229537507286892], [0.9829820179820178, 1.0, 0.291024264025178, 1.9659640359640356, 0.056011586826769655, 2.948946053946054, 0.011591880614465892, 4.91491008991009, 0.0005220289292099299], [0.9839830169830168, 1.0, 0.29100456939841807, 1.9679660339660336, 0.055996447158427526, 2.951949050949051, 0.011584848100039853, 4.919915084915085, 0.0005211560303214375], [0.9849840159840159, 1.0, 0.29098603923790733, 1.9699680319680317, 0.05598220320168007, 2.954952047952048, 0.011578232086930455, 4.9249200799200805, 0.0005203350015843196], [0.9859850149850148, 1.0, 0.29096867349908484, 1.9719700299700296, 0.05596885481951196, 2.957955044955045, 0.01157203243194589, 4.929925074925075, 0.0005195657936381308], [0.9869860139860138, 1.0, 0.29095247214018927, 1.9739720279720276, 0.05595640188352232, 2.960958041958042, 0.011566249000905686, 4.93493006993007, 0.0005188483602379041], [0.9879870129870129, 1.0, 0.2909374351222597, 1.9759740259740257, 0.05594484427392397, 2.963961038961039, 0.011560881668637772, 4.9399350649350655, 0.0005181826582513705], [0.9889880119880118, 1.0, 0.29092356240913503, 1.9779760239760236, 0.05593418187954201, 2.966964035964036, 0.011555930318975808, 4.94494005994006, 0.0005175686476563654], [0.9899890109890108, 1.0, 0.29091085396745425, 1.9799780219780216, 0.055924414597812694, 2.969967032967033, 0.01155139484475667, 4.949945054945055, 0.0005170062915384241], [0.9909900099900099, 1.0, 0.2908993097666561, 1.9819800199800197, 0.055915542334782624, 2.97297002997003, 0.011547275147818089, 4.9549500499500505, 0.0005164955560885614], [0.9919910089910088, 1.0, 0.29088892977897945, 1.9839820179820176, 0.055907565005107754, 2.975973026973027, 0.011543571138996574, 4.959955044955045, 0.0005160364106012384], [0.9929920079920078, 1.0, 0.2908797139794621, 1.9859840159840156, 0.05590048253205257, 2.978976023976024, 0.011540282738125462, 4.96496003996004, 0.0005156288274725179], [0.9939930069930069, 1.0, 0.29087166234594164, 1.9879860139860137, 0.055894294847489354, 2.981979020979021, 0.011537409874033178, 4.9699650349650355, 0.0005152727821984042], [0.9949940059940058, 1.0, 0.2908647748590562, 1.9899880119880116, 0.05588900189189757, 2.984982017982018, 0.011534952484541705, 4.97497002997003, 0.0005149682533733695], [0.9959950049950048, 1.0, 0.2908590515022424, 1.9919900099900096, 0.05588460361436323, 2.987985014985015, 0.011532910516465222, 4.979975024975025, 0.0005147152226890667], [0.9969960039960039, 1.0, 0.29085449226173693, 1.9939920079920077, 0.055881099972578376, 2.990988011988012, 0.011531283925608959, 4.9849800199800205, 0.0005145136749332307], [0.9979970029970028, 1.0, 0.2908510971265756, 1.9959940059940056, 0.05587849093284079, 2.993991008991009, 0.011530072676768277, 4.989985014985015, 0.0005143635979887613], [0.9989980019980018, 1.0, 0.29084886608859367, 1.9979960039960036, 0.055876776470053645, 2.996994005994006, 0.011529276743727824, 4.99499000999001, 0.0005142649828329968], [0.9999990009990009, 1.0, 0.29084779914242603, 1.9999980019980017, 0.055875956567725156, 2.999997002997003, 0.011528896109261076, 4.9999950049950055, 0.0005142178235371697], [1.001, 0.0, 0.290847799142426, 2.002, 0.05587595656772514, 3.003, 0.011528896109261076, 5.005, 0.00051421782353717]]}, \"id\": \"el9520169581592\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "                 \n",
        "                 mpld3.draw_figure(\"fig_el95201695815921320083937\", {\"axes\": [{\"xlim\": [-1.0, 6.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$x$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520175869848\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$|\\\\psi|^2$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520169514096\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Norm square of wave function for varying barrier width and E = 0.7\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520168826696\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.93647093413978533, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el9520170365168\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.93647093413978533, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el9520170368976\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.93647093413978533, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el9520170516096\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.93647093413978533, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el9520170515032\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [-1.0, 6.0], \"ylim\": [0.0, 1.1000000000000001], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170367016\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 7, \"tickvalues\": null}], \"lines\": [{\"color\": \"#FF0000\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168751456\"}, {\"color\": \"#FF0000\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168631712\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 3, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170360392\"}, {\"color\": \"#0000FF\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 3, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170360784\"}, {\"color\": \"#008000\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 5, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169553704\"}, {\"color\": \"#008000\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 5, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169550624\"}, {\"color\": \"#FFA500\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 7, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170341208\"}, {\"color\": \"#FFA500\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 7, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170343728\"}, {\"color\": \"#FF0000\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170365728\"}, {\"color\": \"#0000FF\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170515704\"}, {\"color\": \"#008000\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170463752\"}, {\"color\": \"#FFA500\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170463920\"}], \"markers\": [], \"id\": \"el9520169580024\", \"ydomain\": [0.0, 1.1000000000000001], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data02\": [[0.8916680667562725, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086], [0.9167576724910396, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086]], \"data03\": [[0.879123263888889, 0.8399044205495819], [0.9910394265232977, 0.8399044205495819], [0.9910394265232977, 0.9880525686977301], [0.879123263888889, 0.9880525686977301], [0.879123263888889, 0.8399044205495819]], \"data01\": [[-0.001, 0.0, 1.0, -0.002, 1.0, -0.003, 1.0, -0.005, 1.0], [9.990009990008038e-07, 1.0, 0.9983104963843705, 1.9980019980016077e-06, 0.9968026613469056, 2.997002997003062e-06, 0.9953268747517187, 4.995004995005103e-06, 0.9922819273137575], [0.0010019980019980016, 1.0, 0.9966235241632159, 0.0020039960039960033, 0.9936139322073837, 0.003005994005994006, 0.9906724513467232, 0.00500999000999001, 0.984615181374895], [0.0020029970029970022, 1.0, 0.9949394132794194, 0.0040059940059940045, 0.9904351179077963, 0.00600899100899101, 0.9860396350489311, 0.010014985014985014, 0.9770076512763524], [0.0030039960039960033, 1.0, 0.9932581596830351, 0.0060079920079920066, 0.9872661878704999, 0.009011988011988013, 0.9814283255892915, 0.01501998001998002, 0.9694588796515854], [0.004004995004995004, 1.0, 0.9915797593309861, 0.008009990009990009, 0.9841071116129285, 0.012014985014985016, 0.9768384231642308, 0.020024975024975026, 0.961968412666624], [0.0050059940059940045, 1.0, 0.9899042081870599, 0.010011988011988009, 0.9809578587473022, 0.015017982017982021, 0.972269828433493, 0.02502997002997003, 0.9545357999927858], [0.0060069930069930055, 1.0, 0.9882315022218942, 0.012013986013986011, 0.977818398980333, 0.018020979020979024, 0.967722442517989, 0.030034965034965038, 0.9471605947796035], [0.007007992007992007, 1.0, 0.9865616374129681, 0.014015984015984013, 0.9746887021129349, 0.021023976023976026, 0.963196166997657, 0.035039960039960044, 0.9398423536279628], [0.008008991008991006, 1.0, 0.9848946097445942, 0.016017982017982012, 0.9715687380399352, 0.024026973026973028, 0.9586909039093311, 0.04004495504495505, 0.9325806365634384], [0.009009990009990008, 1.0, 0.9832304152079078, 0.018019980019980016, 0.9684584767497803, 0.02702997002997003, 0.9542065557446231, 0.045049950049950056, 0.9253750070098493], [0.01001098901098901, 1.0, 0.9815690498008568, 0.02002197802197802, 0.9653578883242513, 0.030032967032967036, 0.9497430254478103, 0.05005494505494506, 0.9182250317630095], [0.011011988011988008, 1.0, 0.9799105095281934, 0.022023976023976016, 0.9622669429381733, 0.03303596403596404, 0.9453002164137365, 0.05505994005994006, 0.9111302809646818], [0.01201298701298701, 1.0, 0.9782547904014625, 0.02402597402597402, 0.9591856108591303, 0.03603896103896104, 0.9408780324857191, 0.060064935064935064, 0.9040903280767375], [0.013013986013986012, 1.0, 0.9766018884389942, 0.026027972027972024, 0.9561138624471793, 0.03904195804195804, 0.9364763779534707, 0.06506993006993007, 0.8971047498555103], [0.014014985014985014, 1.0, 0.9749517996658928, 0.028029970029970028, 0.9530516681545629, 0.04204495504495504, 0.9320951575510246, 0.07007492507492508, 0.8901731263263529], [0.015015984015984012, 1.0, 0.9733045201140288, 0.030031968031968025, 0.9499989985254279, 0.04504795204795205, 0.927734276454675, 0.07507992007992008, 0.8832950407583869], [0.016016983016983014, 1.0, 0.9716600458220267, 0.03203396603396603, 0.9469558241955406, 0.04805094905094905, 0.9233936402809239, 0.08008491508491508, 0.8764700796394485], [0.017017982017982013, 1.0, 0.9700183728352582, 0.034035964035964025, 0.9439221158920037, 0.05105394605394605, 0.9190731550844391, 0.08508991008991008, 0.8696978326512295], [0.018018981018981015, 1.0, 0.9683794972058312, 0.03603796203796203, 0.9408978444329769, 0.05405694305694306, 0.9147727273560203, 0.0900949050949051, 0.8629778926446069], [0.019019980019980016, 1.0, 0.9667434149925804, 0.03803996003996003, 0.937882980727393, 0.057059940059940056, 0.9104922640205746, 0.0950999000999001, 0.8563098556151669], [0.020020979020979015, 1.0, 0.9651101222610589, 0.04004195804195803, 0.9348774957746813, 0.06006293706293707, 0.9062316724351038, 0.1001048951048951, 0.8496933206789152], [0.021021978021978017, 1.0, 0.9634796150835273, 0.042043956043956034, 0.9318813606644856, 0.06306593406593407, 0.9019908603866974, 0.10510989010989011, 0.8431278900481752], [0.02202297702297702, 1.0, 0.9618518895389446, 0.04404595404595404, 0.9288945465763901, 0.06606893106893107, 0.8977697360905381, 0.11011488511488511, 0.836613169007674], [0.023023976023976017, 1.0, 0.9602269417129606, 0.046047952047952034, 0.9259170247796376, 0.06907192807192808, 0.8935682081879147, 0.11511988011988011, 0.8301487658908117], [0.02402497502497502, 1.0, 0.9586047676979031, 0.04804995004995004, 0.9229487666328569, 0.07207492507492508, 0.8893861857442458, 0.12012487512487513, 0.8237342920561131], [0.02502597402597402, 1.0, 0.9569853635927708, 0.05005194805194804, 0.9199897435837835, 0.07507792207792208, 0.8852235782471102, 0.12512987012987012, 0.8173693618638644], [0.026026973026973023, 1.0, 0.955368725503225, 0.052053946053946046, 0.9170399271689893, 0.07808091908091908, 0.8810802956042879, 0.13013486513486514, 0.8110535926529272], [0.02702797202797202, 1.0, 0.9537548495415765, 0.05405594405594404, 0.9140992890136064, 0.08108391608391609, 0.8769562481418125, 0.13513986013986015, 0.804786604717733], [0.028028971028971023, 1.0, 0.9521437318267794, 0.056057942057942046, 0.9111678008310526, 0.08408691308691309, 0.8728513466020283, 0.14014485514485514, 0.7985680212854555], [0.029029970029970025, 1.0, 0.9505353684844218, 0.05805994005994005, 0.9082454344227628, 0.08708991008991009, 0.8687655021416577, 0.14514985014985016, 0.7923974684933588], [0.030030969030969024, 1.0, 0.9489297556467137, 0.06006193806193805, 0.9053321616779155, 0.0900929070929071, 0.8646986263298819, 0.15015484515484515, 0.7862745753663207], [0.031031968031968026, 1.0, 0.9473268894524812, 0.06206393606393605, 0.9024279545731632, 0.0930959040959041, 0.8606506311464227, 0.15515984015984016, 0.7801989737945296], [0.03203296703296703, 1.0, 0.9457267660471539, 0.06406593406593405, 0.8995327851723626, 0.0960989010989011, 0.8566214289796403, 0.16016483516483518, 0.7741702985113538], [0.03303396603396603, 1.0, 0.944129381582759, 0.06606793206793206, 0.8966466256263058, 0.09910189810189811, 0.8526109326246365, 0.16516983016983017, 0.7681881870713809], [0.03403496503496503, 1.0, 0.9425347322179085, 0.06806993006993006, 0.8937694481724517, 0.10210489510489511, 0.848619055281366, 0.17017482517482518, 0.7622522798286283], [0.035035964035964026, 1.0, 0.9409428141177935, 0.07007192807192805, 0.8909012251346606, 0.1051078921078921, 0.8446457105527599, 0.17517982017982017, 0.7563622199149211], [0.03603696303696303, 1.0, 0.9393536234541724, 0.07207392607392606, 0.888041928922927, 0.10811088911088912, 0.8406908124428545, 0.1801848151848152, 0.7505176532184362], [0.03703796203796203, 1.0, 0.9377671564053619, 0.07407592407592406, 0.8851915320331141, 0.11111388611388612, 0.8367542753549293, 0.1851898101898102, 0.7447182283624141], [0.03803896103896103, 1.0, 0.9361834091562299, 0.07607792207792206, 0.8823500070466891, 0.11411688311688312, 0.8328360140896569, 0.1901948051948052, 0.7389635966840343], [0.039039960039960034, 1.0, 0.9346023778981836, 0.07807992007992007, 0.879517326630461, 0.11711988011988012, 0.8289359438432562, 0.1951998001998002, 0.7332534122134511], [0.040040959040959036, 1.0, 0.9330240588291621, 0.08008191808191807, 0.8766934635363147, 0.12012287712287713, 0.8250539802056589, 0.2002047952047952, 0.7275873316529978], [0.04104195804195803, 1.0, 0.9314484481536268, 0.08208391608391606, 0.8738783906009528, 0.12312587412587414, 0.8211900391586827, 0.20520979020979022, 0.721965014356544], [0.04204295704295703, 1.0, 0.9298755420825522, 0.08408591408591407, 0.8710720807456304, 0.12612887112887114, 0.8173440370742107, 0.21021478521478523, 0.716386122309018], [0.043043956043956035, 1.0, 0.9283053368334164, 0.08608791208791207, 0.8682745069758973, 0.12913186813186814, 0.8135158907123836, 0.21521978021978022, 0.7108503201060836], [0.044044955044955036, 1.0, 0.9267378286301935, 0.08808991008991007, 0.8654856423813366, 0.13213486513486514, 0.8097055172197976, 0.22022477522477524, 0.7053572749339775], [0.04504595404595404, 1.0, 0.9251730137033419, 0.09009190809190808, 0.8627054601353079, 0.13513786213786214, 0.8059128341277103, 0.22522977022977023, 0.6999066565494991], [0.04604695304695304, 1.0, 0.9236108882897978, 0.09209390609390608, 0.8599339334946874, 0.13814085914085913, 0.8021377593502578, 0.23023476523476524, 0.694498137260156], [0.047047952047952035, 1.0, 0.922051448632965, 0.09409590409590407, 0.8571710357996111, 0.14114385614385616, 0.7983802111826745, 0.23523976023976023, 0.6891313919044644], [0.04804895104895104, 1.0, 0.9204946909827066, 0.09609790209790207, 0.8544167404732183, 0.14414685314685316, 0.7946401082995298, 0.24024475524475525, 0.683806097832399], [0.04904995004995004, 1.0, 0.9189406115953349, 0.09809990009990008, 0.8516710210213971, 0.14714985014985016, 0.7909173697529626, 0.24524975024975026, 0.6785219348859958], [0.05005094905094904, 1.0, 0.9173892067336018, 0.10010189810189808, 0.848933851032528, 0.15015284715284716, 0.7872119149709335, 0.2502547452547453, 0.6732785853801035], [0.05105194805194804, 1.0, 0.9158404726666924, 0.10210389610389609, 0.8462052041772308, 0.15315584415584416, 0.783523663755479, 0.25525974025974024, 0.6680757340832851], [0.052052947052947045, 1.0, 0.9142944056702137, 0.10410589410589409, 0.8434850542081104, 0.15615884115884116, 0.7798525362809758, 0.26026473526473526, 0.6629130681988665], [0.05305394605394605, 1.0, 0.9127510020261875, 0.1061078921078921, 0.8407733749595059, 0.15916183816183815, 0.776198453092414, 0.2652697302697303, 0.6577902773461288], [0.05405494505494504, 1.0, 0.9112102580230395, 0.10810989010989008, 0.8380701403472377, 0.16216483516483518, 0.7725613351036765, 0.2702747252747253, 0.6527070535416508], [0.055055944055944044, 1.0, 0.9096721699555906, 0.11011188811188809, 0.8353753243683553, 0.16516783216783218, 0.7689411035958278, 0.2752797202797203, 0.647663091180791], [0.056056943056943045, 1.0, 0.9081367341250505, 0.11211388611388609, 0.8326889011008908, 0.16817082917082918, 0.7653376802154102, 0.28028471528471527, 0.6426580870193156], [0.05705794205794205, 1.0, 0.9066039468390058, 0.1141158841158841, 0.8300108447036064, 0.17117382617382618, 0.7617509869727477, 0.2852897102897103, 0.6376917401551669], [0.05805894105894105, 1.0, 0.9050738044114126, 0.1161178821178821, 0.8273411294157469, 0.17417682317682318, 0.7581809462402592, 0.2902947052947053, 0.6327637520103743], [0.05905994005994005, 1.0, 0.9035463031625867, 0.1181198801198801, 0.824679729556792, 0.17717982017982017, 0.7546274807507767, 0.2952997002997003, 0.6278738263131012], [0.060060939060939046, 1.0, 0.9020214394191962, 0.12012187812187809, 0.8220266195262094, 0.1801828171828172, 0.7510905135958736, 0.30030469530469533, 0.6230216690798357], [0.06106193806193805, 1.0, 0.9004992095142523, 0.1221238761238761, 0.819381773803208, 0.1831858141858142, 0.747569968224201, 0.3053096903096903, 0.6182069885977144], [0.06206293706293706, 1.0, 0.898979609787099, 0.12412587412587411, 0.8167451669464926, 0.1861888111888112, 0.7440657684398295, 0.3103146853146853, 0.6134294954069853], [0.06306393606393605, 1.0, 0.8974626365834062, 0.1261278721278721, 0.81411677359402, 0.1891918081918082, 0.7405778384006018, 0.31531968031968033, 0.6086889022836056], [0.06406493506493505, 1.0, 0.8959482862551592, 0.1281298701298701, 0.8114965684627536, 0.1921948051948052, 0.737106102616489, 0.32032467532467535, 0.6039849242219727], [0.06506593406593406, 1.0, 0.8944365551606517, 0.1301318681318681, 0.8088845263484215, 0.1951978021978022, 0.7336504859479591, 0.32532967032967036, 0.5993172784177921], [0.06606693306693305, 1.0, 0.8929274396644755, 0.1321338661338661, 0.8062806221252727, 0.1982007992007992, 0.7302109136043493, 0.3303346653346653, 0.5946856842510709], [0.06706793206793206, 1.0, 0.891420936137512, 0.13413586413586412, 0.8036848307458369, 0.20120379620379622, 0.7267873111422473, 0.33533966033966034, 0.5900898632692513], [0.06806893106893105, 1.0, 0.8899170409569249, 0.1361378621378621, 0.8010971272406824, 0.20420679320679322, 0.7233796044638807, 0.34034465534465536, 0.5855295391704675], [0.06906993006993006, 1.0, 0.8884157505061505, 0.13813986013986013, 0.7985174867181765, 0.20720979020979022, 0.7199877198155128, 0.34534965034965037, 0.5810044377869346], [0.07007092907092906, 1.0, 0.8869170611748877, 0.14014185814185812, 0.7959458843642463, 0.21021278721278722, 0.7166115837858468, 0.3503546453546454, 0.5765142870684656], [0.07107192807192805, 1.0, 0.8854209693590911, 0.1421438561438561, 0.7933822954421383, 0.21321578421578422, 0.713251123304436, 0.35535964035964035, 0.5720588170661169], [0.07207292707292706, 1.0, 0.8839274714609624, 0.14414585414585412, 0.7908266952921846, 0.21621878121878121, 0.7099062656401038, 0.36036463536463537, 0.5676377599159569], [0.07307392607392606, 1.0, 0.8824365638889402, 0.14614785214785211, 0.7882790593315592, 0.21922177822177824, 0.7065769383993686, 0.3653696303696304, 0.5632508498229637], [0.07407492507492507, 1.0, 0.8809482430576937, 0.14814985014985013, 0.7857393630540479, 0.22222477522477524, 0.703263069524877, 0.3703746253746254, 0.5588978230450441], [0.07507592407592406, 1.0, 0.8794625053881113, 0.15015184815184812, 0.7832075820298091, 0.22522777222777224, 0.6999645872938443, 0.3753796203796204, 0.5545784178771779], [0.07607692307692306, 1.0, 0.8779793473072941, 0.1521538461538461, 0.7806836919051392, 0.22823076923076924, 0.6966814203165025, 0.3803846153846154, 0.550292374635685], [0.07707792207792206, 1.0, 0.8764987652485463, 0.15415584415584413, 0.7781676684022395, 0.23123376623376624, 0.6934134975345546, 0.3853896103896104, 0.546039435642612], [0.07807892107892106, 1.0, 0.8750207556513672, 0.15615784215784212, 0.7756594873189809, 0.23423676323676323, 0.6901607482196377, 0.3903946053946054, 0.5418193452102402], [0.07907992007992007, 1.0, 0.8735453149614419, 0.15815984015984014, 0.7731591245286736, 0.23723976023976023, 0.686923101971791, 0.3953996003996004, 0.5376318496257158], [0.08008091908091906, 1.0, 0.8720724396306335, 0.16016183816183813, 0.7706665559798316, 0.24024275724275726, 0.6837004887179322, 0.40040459540459544, 0.5334766971357939], [0.08108191808191807, 1.0, 0.8706021261169743, 0.16216383616383614, 0.7681817576959449, 0.24324575424575426, 0.6804928387103425, 0.4054095904095904, 0.5293536379317045], [0.08208291708291707, 1.0, 0.8691343708846568, 0.16416583416583413, 0.7657047057752463, 0.24624875124875126, 0.677300082525155, 0.4104145854145854, 0.5252624241341342], [0.08308391608391606, 1.0, 0.8676691704040259, 0.16616783216783212, 0.7632353763904828, 0.24925174825174828, 0.6741221510608536, 0.41541958041958044, 0.5212028097783216], [0.08408491508491507, 1.0, 0.8662065211515709, 0.16816983016983014, 0.7607737457886856, 0.2522547452547453, 0.6709589755367762, 0.42042457542457545, 0.517174550799273], [0.08508591408591407, 1.0, 0.8647464196099152, 0.17017182817182813, 0.7583197902909421, 0.2552577422577423, 0.6678104874916282, 0.42542957042957047, 0.5131774050170871], [0.08608691308691307, 1.0, 0.8632888622678094, 0.17217382617382615, 0.7558734862921689, 0.2582607392607393, 0.664676618781997, 0.43043456543456543, 0.509211132122395], [0.08708791208791207, 1.0, 0.8618338456201228, 0.17417582417582414, 0.7534348102608825, 0.2612637362637363, 0.661557301580881, 0.43543956043956045, 0.5052754936619142], [0.08808891108891108, 1.0, 0.8603813661678343, 0.17617782217782216, 0.7510037387389755, 0.2642667332667333, 0.6584524683762203, 0.44044455544455546, 0.5013702530241105], [0.08908991008991007, 1.0, 0.8589314204180237, 0.17817982017982015, 0.7485802483414892, 0.2672697302697303, 0.6553620519694345, 0.4454495504495505, 0.4974951754249754], [0.09009090909090907, 1.0, 0.857484004883865, 0.18018181818181814, 0.7461643157563888, 0.2702727272727273, 0.652285985473969, 0.4504545454545455, 0.49365002789390866], [0.09109190809190808, 1.0, 0.8560391160846151, 0.18218381618381616, 0.7437559177443408, 0.2732757242757243, 0.6492242023138478, 0.45545954045954046, 0.48983457925971324], [0.09209290709290707, 1.0, 0.8545967505456086, 0.18418581418581415, 0.7413550311384871, 0.2762787212787213, 0.646176636222233, 0.4604645354645355, 0.48604860013669704], [0.09309390609390608, 1.0, 0.8531569047982479, 0.18618781218781216, 0.7389616328442247, 0.27928171828171827, 0.6431432212399883, 0.4654695304695305, 0.48229186291088205], [0.09409490509490508, 1.0, 0.8517195753799945, 0.18818981018981015, 0.7365756998389802, 0.28228471528471527, 0.6401238917142539, 0.4704745254745255, 0.47856414172631995], [0.09509590409590407, 1.0, 0.8502847588343608, 0.19019180819180814, 0.7341972091719919, 0.2852877122877123, 0.6371185822970241, 0.47547952047952047, 0.4748652124715141], [0.09609690309690308, 1.0, 0.8488524517109034, 0.19219380619380616, 0.7318261379640867, 0.2882907092907093, 0.6341272279437341, 0.4804845154845155, 0.4711948527659453], [0.09709790209790208, 1.0, 0.8474226505652127, 0.19419580419580415, 0.7294624634074609, 0.2912937062937063, 0.6311497639118511, 0.4854895104895105, 0.46755284194670327], [0.09809890109890108, 1.0, 0.8459953519589061, 0.19619780219780217, 0.7271061627654605, 0.2942967032967033, 0.628186125759473, 0.4904945054945055, 0.46393896105521876], [0.09909990009990008, 1.0, 0.844570552459618, 0.19819980019980016, 0.7247572133723629, 0.2972997002997003, 0.625236249343936, 0.49549950049950053, 0.4603529928241008], [0.10010089910089909, 1.0, 0.8431482486409934, 0.20020179820179818, 0.7224155926331589, 0.3003026973026973, 0.6223000708204224, 0.5005044955044955, 0.4567947216640747], [0.10110189810189808, 1.0, 0.8417284370826789, 0.20220379620379617, 0.7200812780233348, 0.3033056943056943, 0.6193775266405827, 0.5055094905094906, 0.4532639336510198], [0.10210289710289708, 1.0, 0.8403111143703144, 0.20420579420579416, 0.7177542470886554, 0.3063086913086913, 0.6164685535511575, 0.5105144855144855, 0.449760416513109], [0.10310389610389609, 1.0, 0.8388962770955256, 0.20620779220779217, 0.7154344774449493, 0.3093116883116883, 0.6135730885926097, 0.5155194805194805, 0.44628395961804723], [0.10410489510489508, 1.0, 0.8374839218559136, 0.20820979020979016, 0.7131219467778929, 0.3123146853146853, 0.6106910690977618, 0.5205244755244756, 0.44283435396040716], [0.10510589410589409, 1.0, 0.83607404525505, 0.21021178821178818, 0.7108166328427957, 0.3153176823176823, 0.6078224326904388, 0.5255294705294705, 0.43941139214906466], [0.10610689310689309, 1.0, 0.8346666439024654, 0.21221378621378617, 0.7085185134643857, 0.3183206793206793, 0.6049671172841197, 0.5305344655344656, 0.43601486839473], [0.1071078921078921, 1.0, 0.8332617144136443, 0.2142157842157842, 0.706227566536598, 0.3213236763236763, 0.6021250610805922, 0.5355394605394606, 0.432644578497576], [0.10810889110889109, 1.0, 0.8318592534100148, 0.21621778221778218, 0.7039437700223596, 0.32432667332667336, 0.5992962025686157, 0.5405444555444555, 0.429300319834961], [0.10910989010989008, 1.0, 0.8304592575189409, 0.21821978021978017, 0.70166710195338, 0.32732967032967036, 0.5964804805225905, 0.5455494505494506, 0.4259818913492478], [0.11011088911088909, 1.0, 0.8290617233737154, 0.22022177822177819, 0.6993975404299373, 0.33033266733266736, 0.5936778340012321, 0.5505544455544455, 0.42268909353571527], [0.11111188811188809, 1.0, 0.827666647613551, 0.22222377622377618, 0.6971350636206696, 0.33333566433566436, 0.5908882023462522, 0.5555594405594406, 0.4194217284305647], [0.1121128871128871, 1.0, 0.8262740268835725, 0.2242257742257742, 0.6948796497623649, 0.33633866133866136, 0.5881115251810465, 0.5605644355644356, 0.4161795995990177], [0.11311388611388609, 1.0, 0.8248838578348081, 0.22622777222777218, 0.6926312771597503, 0.33934165834165836, 0.5853477424093876, 0.5655694305694305, 0.41296251212350715], [0.1141148851148851, 1.0, 0.8234961371241819, 0.2282297702297702, 0.6903899241852838, 0.34234465534465536, 0.5825967942141236, 0.5705744255744256, 0.40977027259195753], [0.1151158841158841, 1.0, 0.822110861414506, 0.2302317682317682, 0.6881555692789472, 0.34534765234765236, 0.579858621055885, 0.5755794205794206, 0.40660268908615876], [0.11611688311688309, 1.0, 0.8207280273744718, 0.23223376623376618, 0.6859281909480385, 0.34835064935064936, 0.5771331636717943, 0.5805844155844156, 0.40345957117022646], [0.1171178821178821, 1.0, 0.8193476316786419, 0.2342357642357642, 0.6837077677669641, 0.35135364635364635, 0.574420363074185, 0.5855894105894106, 0.4003407298791529], [0.1181188811188811, 1.0, 0.8179696710074443, 0.2362377622377622, 0.6814942783770335, 0.35435664335664335, 0.5717201605493241, 0.5905944055944056, 0.3972459777074478], [0.1191198801198801, 1.0, 0.8165941420471617, 0.2382397602397602, 0.6792877014862537, 0.35735964035964035, 0.5690324976561407, 0.5955994005994006, 0.39417512859786424], [0.1201208791208791, 1.0, 0.8152210414899249, 0.2402417582417582, 0.6770880158691244, 0.36036263736263735, 0.5663573162249629, 0.6006043956043956, 0.39112799793021263], [0.1211218781218781, 1.0, 0.8138503660337036, 0.2422437562437562, 0.6748952003664338, 0.3633656343656344, 0.5636945583562569, 0.6056093906093907, 0.38810440251026246], [0.1221228771228771, 1.0, 0.8124821123823005, 0.2442457542457542, 0.6727092338850554, 0.3663686313686314, 0.5610441664193757, 0.6106143856143856, 0.38510416055872776], [0.1231238761238761, 1.0, 0.811116277245342, 0.2462477522477522, 0.6705300953977441, 0.3693716283716284, 0.5584060830513098, 0.6156193806193806, 0.3821270917003388], [0.1241248751248751, 1.0, 0.8097528573382705, 0.2482497502497502, 0.6683577639429351, 0.3723746253746254, 0.5557802511554472, 0.6206243756243757, 0.3791730169529978], [0.12512587412587411, 1.0, 0.808391849382336, 0.25025174825174823, 0.6661922186245424, 0.3753776223776224, 0.5531666139003374, 0.6256293706293706, 0.3762417587170185], [0.1261268731268731, 1.0, 0.8070332501045895, 0.2522537462537462, 0.6640334386117565, 0.3783806193806194, 0.5505651147184609, 0.6306343656343657, 0.3733331407644484], [0.1271278721278721, 1.0, 0.8056770562378736, 0.2542557442557442, 0.6618814031388445, 0.3813836163836164, 0.5479756973050056, 0.6356393606393607, 0.3704469882284748], [0.1281288711288711, 1.0, 0.8043232645208165, 0.2562577422577422, 0.6597360915049507, 0.3843866133866134, 0.545398305616647, 0.6406443556443556, 0.3675831275929113], [0.1291298701298701, 1.0, 0.8029718716978221, 0.2582597402597402, 0.6575974830738976, 0.3873896103896104, 0.5428328838703366, 0.6456493506493507, 0.3647413866817654], [0.1301308691308691, 1.0, 0.8016228745190634, 0.2602617382617382, 0.6554655572739874, 0.3903926073926074, 0.5402793765420937, 0.6506543456543457, 0.3619215946488884], [0.1311318681318681, 1.0, 0.800276269740475, 0.2622637362637362, 0.653340293597803, 0.3933956043956044, 0.5377377283658038, 0.6556593406593407, 0.3591235819677031], [0.13213286713286712, 1.0, 0.7989320541237438, 0.26426573426573424, 0.6512216716020129, 0.3963986013986014, 0.5352078843320232, 0.6606643356643357, 0.35634718042101216], [0.1331338661338661, 1.0, 0.7975902244363028, 0.2662677322677322, 0.6491096709071715, 0.3994015984015984, 0.5326897896867869, 0.6656693306693306, 0.3535922230908848], [0.1341348651348651, 1.0, 0.7962507774513232, 0.2682697302697302, 0.647004271197526, 0.40240459540459544, 0.5301833899304252, 0.6706743256743257, 0.3508585443486219], [0.13513586413586412, 1.0, 0.7949137099477048, 0.27027172827172824, 0.6449054522208191, 0.40540759240759244, 0.5276886308163832, 0.6756793206793207, 0.3481459798447982], [0.1361368631368631, 1.0, 0.79357901871007, 0.2722737262737262, 0.6428131937880958, 0.40841058941058944, 0.5252054583500466, 0.6806843156843158, 0.3454543664993814], [0.1371378621378621, 1.0, 0.7922467005287569, 0.2742757242757242, 0.6407274757735074, 0.41141358641358644, 0.5227338187875743, 0.6856893106893107, 0.34278354249192766], [0.13813886113886112, 1.0, 0.7909167521998083, 0.27627772227772224, 0.6386482781141194, 0.41441658341658344, 0.5202736586347336, 0.6906943056943057, 0.3401333472518539], [0.13913986013986013, 1.0, 0.7895891705249678, 0.27827972027972026, 0.6365755808097173, 0.41741958041958044, 0.517824924645743, 0.6956993006993007, 0.3375036214487828], [0.1401408591408591, 1.0, 0.788263952311669, 0.2802817182817182, 0.6345093639226154, 0.42042257742257744, 0.5153875638221209, 0.7007042957042957, 0.3348942069829649], [0.14114185814185812, 1.0, 0.7869410943730298, 0.28228371628371624, 0.6324496075774639, 0.42342557442557444, 0.512961523411537, 0.7057092907092908, 0.3323049469757729], [0.14214285714285713, 1.0, 0.7856205935278442, 0.28428571428571425, 0.6303962919610588, 0.42642857142857143, 0.5105467509066708, 0.7107142857142857, 0.3297356857602709], [0.1431438561438561, 1.0, 0.7843024466005738, 0.2862877122877122, 0.6283493973221498, 0.42943156843156843, 0.5081431940440763, 0.7157192807192807, 0.3271862688718546], [0.14414485514485512, 1.0, 0.7829866504213416, 0.28828971028971023, 0.6263089039712525, 0.43243456543456543, 0.5057508008030496, 0.7207242757242758, 0.324656543038966], [0.14514585414585413, 1.0, 0.7816732018259237, 0.29029170829170825, 0.6242747922804568, 0.43543756243756243, 0.5033695194045033, 0.7257292707292707, 0.32214635617387766], [0.14614685314685313, 1.0, 0.7803620976557415, 0.29229370629370627, 0.6222470426832396, 0.43844055944055943, 0.5009992983098465, 0.7307342657342658, 0.31965555736354995], [0.14714785214785212, 1.0, 0.7790533347578539, 0.29429570429570423, 0.6202256356742755, 0.4414435564435565, 0.49864008621986866, 0.7357392607392608, 0.31718399686055737], [0.14814885114885112, 1.0, 0.7777469099849502, 0.29629770229770225, 0.6182105518092499, 0.4444465534465535, 0.49629183207363003, 0.7407442557442557, 0.31473152607408655], [0.14914985014985013, 1.0, 0.7764428201953432, 0.29829970029970027, 0.616201771704672, 0.4474495504495505, 0.4939544850473546, 0.7457492507492508, 0.3122979975610024], [0.1501508491508491, 1.0, 0.7751410622529596, 0.3003016983016982, 0.6141992760376882, 0.4504525474525475, 0.4916279945533331, 0.7507542457542458, 0.30988326501698354], [0.15115184815184812, 1.0, 0.7738416330273349, 0.30230369630369625, 0.6122030455458957, 0.4534555444555445, 0.4893123102388258, 0.7557592407592408, 0.30748718326772717], [0.15215284715284713, 1.0, 0.772544529393604, 0.30430569430569426, 0.610213061027158, 0.4564585414585415, 0.4870073819849733, 0.7607642357642358, 0.3051096082602204], [0.1531538461538461, 1.0, 0.7712497482324946, 0.3063076923076922, 0.6082293033394199, 0.4594615384615385, 0.48471315990571245, 0.7657692307692308, 0.3027503970540804], [0.15415484515484512, 1.0, 0.7699572864303191, 0.30830969030969024, 0.606251753400523, 0.4624645354645355, 0.4824295943466961, 0.7707742257742258, 0.3004094078129603], [0.15515584415584413, 1.0, 0.7686671408789689, 0.31031168831168826, 0.6042803921880232, 0.4654675324675325, 0.480156635884218, 0.7757792207792208, 0.29808649979602236], [0.15615684315684314, 1.0, 0.767379308475903, 0.3123136863136863, 0.6023152007390058, 0.4684705294705295, 0.47789423532414393, 0.7807842157842159, 0.2957815333494761], [0.15715784215784212, 1.0, 0.7660937861241452, 0.31431568431568424, 0.6003561601499051, 0.47147352647352647, 0.47564234370084685, 0.7857892107892108, 0.29349436989818295], [0.15815884115884113, 1.0, 0.7648105707322742, 0.31631768231768226, 0.5984032515763212, 0.47447652347652347, 0.4734009122761466, 0.7907942057942058, 0.29122487193732466], [0.15915984015984014, 1.0, 0.7635296592144155, 0.3183196803196803, 0.5964564562328405, 0.47747952047952047, 0.47116989253825564, 0.7957992007992009, 0.28897290302413636], [0.16016083916083912, 1.0, 0.7622510484902357, 0.32032167832167824, 0.5945157553928525, 0.4804825174825175, 0.4689492362007283, 0.8008041958041958, 0.2867383277697039], [0.16116183816183813, 1.0, 0.7609747354849343, 0.32232367632367626, 0.592581130388371, 0.4834855144855145, 0.46673889520141687, 0.8058091908091909, 0.2845210118308238], [0.16216283716283714, 1.0, 0.7597007171292366, 0.3243256743256743, 0.5906525626098554, 0.4864885114885115, 0.46453882170143046, 0.8108141858141859, 0.28232082190192703], [0.16316383616383615, 1.0, 0.7584289903593854, 0.3263276723276723, 0.5887300335060303, 0.4894915084915085, 0.4623489680840999, 0.8158191808191808, 0.2801376257070645], [0.16416483516483513, 1.0, 0.7571595521171346, 0.32832967032967025, 0.5868135245837066, 0.4924945054945055, 0.4601692869539475, 0.8208241758241759, 0.2779712919919543], [0.16516583416583414, 1.0, 0.7558923993497413, 0.33033166833166827, 0.5849030174076056, 0.4954975024975025, 0.4579997311356601, 0.8258291708291708, 0.27582169051609096], [0.16616683316683314, 1.0, 0.7546275290099597, 0.3323336663336663, 0.5829984936001806, 0.49850049950049957, 0.45584025367307, 0.8308341658341659, 0.27368869204491525], [0.16716783216783213, 1.0, 0.7533649380560312, 0.33433566433566425, 0.5810999348414395, 0.5015034965034966, 0.45369080782813653, 0.8358391608391609, 0.27157216834204473], [0.16816883116883113, 1.0, 0.7521046234516797, 0.33633766233766227, 0.5792073228687694, 0.5045064935064936, 0.451551347079936, 0.8408441558441558, 0.2694719921615637], [0.16916983016983014, 1.0, 0.7508465821661032, 0.3383396603396603, 0.5773206394767612, 0.5075094905094906, 0.4494218251236541, 0.8458491508491509, 0.26738803724037363], [0.17017082917082915, 1.0, 0.7495908111739659, 0.3403416583416583, 0.575439866517033, 0.5105124875124876, 0.44730219586958414, 0.8508541458541459, 0.26532017829060217], [0.17117182817182813, 1.0, 0.748337307455393, 0.34234365634365627, 0.5735649858980579, 0.5135154845154846, 0.44519241344212956, 0.8558591408591409, 0.2632682909920703], [0.17217282717282714, 1.0, 0.7470860679959607, 0.3443456543456543, 0.5716959795849873, 0.5165184815184816, 0.44309243217881045, 0.8608641358641359, 0.26123225198481886], [0.17317382617382615, 1.0, 0.7458370897866907, 0.3463476523476523, 0.5698328295994791, 0.5195214785214786, 0.44100220662927553, 0.8658691308691309, 0.2592119388616916], [0.17417482517482513, 1.0, 0.7445903698240429, 0.34834965034965026, 0.5679755180195247, 0.5225244755244756, 0.4389216915543191, 0.8708741258741259, 0.25720723016097613], [0.17517582417582414, 1.0, 0.7433459051099071, 0.3503516483516483, 0.5661240269792762, 0.5255274725274726, 0.4368508419249005, 0.8758791208791209, 0.255218005359102], [0.17617682317682315, 1.0, 0.7421036926515968, 0.3523536463536463, 0.564278338668874, 0.5285304695304696, 0.43478961292117124, 0.880884115884116, 0.2532441448633943], [0.17717782217782216, 1.0, 0.7408637294618425, 0.3543556443556443, 0.5624384353342767, 0.5315334665334666, 0.43273795993150377, 0.8858891108891109, 0.2512855300048838], [0.17817882117882114, 1.0, 0.7396260125587827, 0.3563576423576423, 0.5606042992770899, 0.5345364635364636, 0.43069583855152627, 0.8908941058941059, 0.24934204303117308], [0.17917982017982015, 1.0, 0.7383905389659586, 0.3583596403596403, 0.5587759128543953, 0.5375394605394606, 0.42866320458316176, 0.895899100899101, 0.24741356709935614], [0.18018081918081916, 1.0, 0.7371573057123054, 0.3603616383616383, 0.5569532584785816, 0.5405424575424576, 0.42664001403367136, 0.9009040959040959, 0.24549998626899508], [0.18118181818181814, 1.0, 0.7359263098321457, 0.3623636363636363, 0.5551363186171756, 0.5435454545454546, 0.42462622311470194, 0.905909090909091, 0.2436011854951487], [0.18218281718281715, 1.0, 0.7346975483651838, 0.3643656343656343, 0.5533250757926725, 0.5465484515484516, 0.42262178824133895, 0.910914085914086, 0.24171705062145651], [0.18318381618381616, 1.0, 0.733471018356496, 0.3663676323676323, 0.5515195125823689, 0.5495514485514486, 0.42062666603116244, 0.9159190809190809, 0.23984746837327547], [0.18418481518481516, 1.0, 0.7322467168565251, 0.36836963036963033, 0.5497196116181944, 0.5525544455544456, 0.4186408133033085, 0.920924075924076, 0.2379923263508698], [0.18518581418581415, 1.0, 0.7310246409210737, 0.3703716283716283, 0.5479253555865451, 0.5555574425574425, 0.416664187077535, 0.925929070929071, 0.23615151302265375], [0.18618681318681315, 1.0, 0.729804787611296, 0.3723736263736263, 0.5461367272281173, 0.5585604395604395, 0.4146967445732906, 0.930934065934066, 0.23432491771848593], [0.18718781218781216, 1.0, 0.7285871539936906, 0.3743756243756243, 0.5443537093377402, 0.5615634365634365, 0.4127384432087894, 0.935939060939061, 0.23251243062301594], [0.18818881118881114, 1.0, 0.7273717371400951, 0.3763776223776223, 0.5425762847642114, 0.5645664335664335, 0.41078924060008926, 0.940944055944056, 0.2307139427690827], [0.18918981018981015, 1.0, 0.7261585341276767, 0.3783796203796203, 0.5408044364101314, 0.5675694305694305, 0.40884909456017415, 0.945949050949051, 0.22892934603116238], [0.19019080919080916, 1.0, 0.7249475420389272, 0.3803816183816183, 0.5390381472317403, 0.5705724275724275, 0.40691796309804135, 0.950954045954046, 0.2271585331188688], [0.19119180819180814, 1.0, 0.7237387579616559, 0.3823836163836163, 0.5372774002387528, 0.5735754245754247, 0.404995804417793, 0.9559590409590409, 0.22540139757050245], [0.19219280719280715, 1.0, 0.7225321789889803, 0.3843856143856143, 0.5355221784941945, 0.5765784215784217, 0.4030825769177306, 0.960964035964036, 0.22365783374665046], [0.19319380619380616, 1.0, 0.7213278022193219, 0.3863876123876123, 0.5337724651142396, 0.5795814185814187, 0.4011782391894552, 0.965969030969031, 0.22192773682383515], [0.19419480519480517, 1.0, 0.7201256247563974, 0.38838961038961034, 0.5320282432680487, 0.5825844155844156, 0.39928275001697183, 0.970974025974026, 0.22021100278821226], [0.19519580419580415, 1.0, 0.7189256437092134, 0.3903916083916083, 0.5302894961776059, 0.5855874125874126, 0.3973960683757957, 0.975979020979021, 0.21850752842931737], [0.19619680319680316, 1.0, 0.7177278561920575, 0.3923936063936063, 0.5285562071175588, 0.5885904095904096, 0.3955181534320658, 0.980984015984016, 0.21681721133386117], [0.19719780219780217, 1.0, 0.7165322593244923, 0.39439560439560434, 0.5268283594150563, 0.5915934065934066, 0.393648964541661, 0.985989010989011, 0.21513994987957213], [0.19819880119880115, 1.0, 0.7153388502313489, 0.3963976023976023, 0.525105936449589, 0.5945964035964036, 0.3917884612493196, 0.990994005994006, 0.21347564322908713], [0.19919980019980016, 1.0, 0.7141476260427193, 0.3983996003996003, 0.5233889216528298, 0.5975994005994006, 0.3899366032877642, 0.9959990009990011, 0.21182419132388883], [0.20020079920079917, 1.0, 0.7129585838939505, 0.40040159840159834, 0.5216772985084729, 0.6006023976023976, 0.3880933505768306, 1.0010039960039963, 0.21018549487829033], [0.20120179820179818, 1.0, 0.7117717209256351, 0.40240359640359635, 0.5199710505520759, 0.6036053946053946, 0.38625866322259933, 1.006008991008991, 0.20855945537346626], [0.20220279720279716, 1.0, 0.710587034283609, 0.4044055944055943, 0.518270161370902, 0.6066083916083916, 0.3844325015165328, 1.0110139860139862, 0.2069459750515292], [0.20320379620379617, 1.0, 0.7094045211189385, 0.40640759240759233, 0.5165746146037611, 0.6096113886113886, 0.38261482593461676, 1.0160189810189812, 0.20534495690965326], [0.20420479520479518, 1.0, 0.7082241785879182, 0.40840959040959035, 0.5148843939408527, 0.6126143856143856, 0.38080559713650297, 1.021023976023976, 0.2037563046942412], [0.20520579420579416, 1.0, 0.7070460038520635, 0.4104115884115883, 0.5131994831236093, 0.6156173826173826, 0.3790047759646593, 1.0260289710289712, 0.20217992289513909], [0.20620679320679317, 1.0, 0.7058699940781021, 0.41241358641358633, 0.5115198659445406, 0.6186203796203796, 0.3772123234435212, 1.0310339660339662, 0.20061571673989265], [0.20720779220779217, 1.0, 0.7046961464379675, 0.41441558441558435, 0.5098455262470752, 0.6216233766233766, 0.3754282007786493, 1.036038961038961, 0.19906359218805048], [0.20820879120879118, 1.0, 0.703524458108793, 0.41641758241758237, 0.5081764479254087, 0.6246263736263736, 0.373652369355889, 1.0410439560439562, 0.1975234559255104], [0.20920979020979016, 1.0, 0.7023549262729054, 0.41841958041958033, 0.5065126149243458, 0.6276293706293706, 0.3718847907405342, 1.0460489510489512, 0.19599521535890863], [0.21021078921078917, 1.0, 0.7011875481178159, 0.42042157842157835, 0.5048540112391475, 0.6306323676323676, 0.37012542667649717, 1.0510539460539463, 0.19447877861005383], [0.21121178821178818, 1.0, 0.7000223208362162, 0.42242357642357636, 0.5032006209153764, 0.6336353646353646, 0.36837423908547856, 1.0560589410589412, 0.19297405451040275], [0.21221278721278716, 1.0, 0.6988592416259699, 0.4244255744255743, 0.5015524280487429, 0.6366383616383616, 0.36663119006614475, 1.0610639360639362, 0.19148095259557965], [0.21321378621378617, 1.0, 0.6976983076901067, 0.42642757242757234, 0.4999094167849537, 0.6396413586413586, 0.3648962418933067, 1.0660689310689313, 0.18999938309993733], [0.21421478521478518, 1.0, 0.6965395162368144, 0.42842957042957036, 0.4982715713195578, 0.6426443556443556, 0.3631693570171039, 1.0710739260739262, 0.1885292569511603], [0.2152157842157842, 1.0, 0.6953828644794335, 0.4304315684315684, 0.49663887589779526, 0.6456473526473526, 0.3614504980621915, 1.0760789210789212, 0.1870704857649099], [0.21621678321678317, 1.0, 0.6942283496364505, 0.43243356643356634, 0.4950113148144454, 0.6486503496503496, 0.3597396278269312, 1.0810839160839163, 0.18562298183951054], [0.21721778221778218, 1.0, 0.6930759689314898, 0.43443556443556436, 0.49338887241367546, 0.6516533466533467, 0.3580367092825866, 1.0860889110889111, 0.184186658150677], [0.2182187812187812, 1.0, 0.6919257195933085, 0.4364375624375624, 0.49177153308889104, 0.6546563436563437, 0.3563417055725214, 1.0910939060939062, 0.18276142834628292], [0.21921978021978017, 1.0, 0.6907775988557899, 0.43843956043956034, 0.4901592812825843, 0.6576593406593407, 0.3546545800114019, 1.0960989010989013, 0.1813472067411684], [0.22022077922077918, 1.0, 0.689631603957935, 0.44044155844155836, 0.48855210148618594, 0.6606623376623377, 0.35297529608440265, 1.1011038961038964, 0.17994390831198964], [0.2212217782217782, 1.0, 0.6884877321438575, 0.4424435564435564, 0.4869499782399151, 0.6636653346653347, 0.35130381744641626, 1.1061088911088912, 0.17855144869210648], [0.2222227772227772, 1.0, 0.6873459806627766, 0.4444455544455544, 0.4853528961326307, 0.6666683316683317, 0.34964010792126754, 1.1111138861138863, 0.17716974416651077], [0.22322377622377618, 1.0, 0.6862063467690107, 0.44644755244755235, 0.4837608398016834, 0.6696713286713287, 0.34798413150092905, 1.1161188811188814, 0.1757987116667932], [0.22422477522477519, 1.0, 0.6850688277219703, 0.44844955044955037, 0.48217379393276816, 0.6726743256743257, 0.34633585234474346, 1.1211238761238762, 0.17443826876614912], [0.2252257742257742, 1.0, 0.6839334207861518, 0.4504515484515484, 0.4805917432597765, 0.6756773226773227, 0.34469523477864644, 1.1261288711288713, 0.1730883336744231], [0.22622677322677318, 1.0, 0.6828001232311307, 0.45245354645354635, 0.47901467256464914, 0.6786803196803197, 0.343062243294395, 1.1311338661338664, 0.17174882523319207], [0.22722777222777218, 1.0, 0.6816689323315553, 0.45445554445554437, 0.47744256667723123, 0.6816833166833167, 0.3414368425487999, 1.1361388611388612, 0.17041966291088523], [0.2282287712287712, 1.0, 0.6805398453671397, 0.4564575424575424, 0.4758754104751244, 0.6846863136863137, 0.3398189973629592, 1.1411438561438563, 0.16910076679794334], [0.2292297702297702, 1.0, 0.6794128596226582, 0.4584595404595404, 0.47431318888354285, 0.6876893106893107, 0.33820867272149757, 1.1461488511488513, 0.16779205760201382], [0.23023076923076918, 1.0, 0.6782879723879373, 0.46046153846153837, 0.47275588687516756, 0.6906923076923077, 0.3366058337718088, 1.1511538461538464, 0.16649345664318418], [0.2312317682317682, 1.0, 0.67716518095785, 0.4624635364635364, 0.47120348947000185, 0.6936953046953047, 0.3350104458233011, 1.1561588411588413, 0.16520488584925172], [0.2322327672327672, 1.0, 0.6760444826323102, 0.4644655344655344, 0.4696559817352273, 0.6966983016983017, 0.3334224743466458, 1.1611638361638363, 0.16392626775102917], [0.23323376623376618, 1.0, 0.6749258747162645, 0.46646753246753236, 0.46811334878506133, 0.6997012987012987, 0.33184188497303124, 1.1661688311688314, 0.16265752547768839], [0.2342347652347652, 1.0, 0.673809354519687, 0.4684695304695304, 0.4665755757806109, 0.7027042957042957, 0.330268643493418, 1.1711738261738263, 0.16139858275213773], [0.2352357642357642, 1.0, 0.6726949193575715, 0.4704715284715284, 0.46504264792973365, 0.7057072927072927, 0.3287027158577985, 1.1761788211788213, 0.16014936388643686], [0.23623676323676318, 1.0, 0.6715825665499269, 0.47247352647352636, 0.46351455048689266, 0.7087102897102897, 0.3271440681744603, 1.1811838161838164, 0.1589097937772462], [0.2372377622377622, 1.0, 0.6704722934217688, 0.4744755244755244, 0.4619912687530158, 0.7117132867132867, 0.32559266670925296, 1.1861888111888113, 0.15767979790131192], [0.2382387612387612, 1.0, 0.6693640973031151, 0.4764775224775224, 0.46047278807535447, 0.7147162837162837, 0.32404847788485713, 1.1911938061938063, 0.15645930231098523], [0.2392397602397602, 1.0, 0.6682579755289778, 0.4784795204795204, 0.458959093847342, 0.7177192807192807, 0.32251146828005833, 1.1961988011988014, 0.15524823362977694], [0.2402407592407592, 1.0, 0.667153925439357, 0.4804815184815184, 0.45745017150845374, 0.7207222777222777, 0.32098160462902353, 1.2012037962037965, 0.15404651904794564], [0.2412417582417582, 1.0, 0.6660519443792356, 0.4824835164835164, 0.455946006544067, 0.7237252747252747, 0.31945885382058103, 1.2062087912087913, 0.15285408631812109], [0.2422427572427572, 1.0, 0.6649520296985717, 0.4844855144855144, 0.4544465844853208, 0.7267282717282717, 0.31794318289750395, 1.2112137862137864, 0.15167086375095978], [0.2432437562437562, 1.0, 0.6638541787522922, 0.4864875124875124, 0.4529518909089774, 0.7297312687312688, 0.3164345590557968, 1.2162187812187815, 0.1504967802108355], [0.2442447552447552, 1.0, 0.6627583889002877, 0.4884895104895104, 0.4514619114372831, 0.7327342657342658, 0.3149329496439862, 1.2212237762237763, 0.14933176511156285], [0.2452457542457542, 1.0, 0.6616646575074044, 0.4904915084915084, 0.4499766317378303, 0.7357372627372628, 0.3134383221624127, 1.2262287712287714, 0.1481757484121528], [0.2462467532467532, 1.0, 0.6605729819434392, 0.4924935064935064, 0.44849603752341893, 0.7387402597402598, 0.3119506442625289, 1.2312337662337665, 0.14702866061260286], [0.2472477522477522, 1.0, 0.6594833595831329, 0.4944955044955044, 0.44702011455192053, 0.7417432567432568, 0.3104698837461985, 1.2362387612387613, 0.14589043274971755], [0.2482487512487512, 1.0, 0.6583957878061639, 0.4964975024975024, 0.4455488486261394, 0.7447462537462538, 0.3089960085649997, 1.2412437562437564, 0.14476099639296333], [0.2492497502497502, 1.0, 0.6573102639971417, 0.4984995004995004, 0.44408222559367694, 0.7477492507492508, 0.3075289868195312, 1.2462487512487515, 0.14364028364035406], [0.2502507492507492, 1.0, 0.6562267855456003, 0.5005014985014984, 0.4426202313467959, 0.7507522477522478, 0.3060687867587228, 1.2512537462537465, 0.14252822711436858], [0.25125174825174823, 1.0, 0.6551453498459932, 0.5025034965034965, 0.44116285182228376, 0.7537552447552448, 0.30461537677914685, 1.2562587412587414, 0.14142475995790052], [0.2522527472527472, 1.0, 0.6540659542976859, 0.5045054945054944, 0.4397100730013183, 0.7567582417582418, 0.3031687254243352, 1.2612637362637364, 0.14032981583023807], [0.2532537462537462, 1.0, 0.6529885963049495, 0.5065074925074924, 0.4382618809093323, 0.7597612387612388, 0.3017288013840978, 1.2662687312687315, 0.13924332890307628], [0.25425474525474523, 1.0, 0.6519132732769566, 0.5085094905094905, 0.4368182616158793, 0.7627642357642358, 0.3002955734938458, 1.2712737262737264, 0.13816523385655907], [0.2552557442557442, 1.0, 0.6508399826277715, 0.5105114885114884, 0.43537920123449864, 0.7657672327672328, 0.2988690107339163, 1.2762787212787214, 0.13709546587535218], [0.2562567432567432, 1.0, 0.649768721776347, 0.5125134865134864, 0.43394468592258395, 0.7687702297702298, 0.2974490822289012, 1.2812837162837165, 0.13603396064474652], [0.25725774225774223, 1.0, 0.6486994881465177, 0.5145154845154845, 0.43251470188124813, 0.7717732267732268, 0.29603575724697945, 1.2862887112887114, 0.13498065434679155], [0.2582587412587412, 1.0, 0.6476322791669915, 0.5165174825174824, 0.4310892353551918, 0.7747762237762238, 0.2946290051992508, 1.2912937062937064, 0.1339354836564586], [0.2592597402597402, 1.0, 0.6465670922713475, 0.5185194805194804, 0.4296682726325694, 0.7777792207792208, 0.29322879563907495, 1.2962987012987015, 0.1328983857378337], [0.2602607392607392, 1.0, 0.6455039248980255, 0.5205214785214785, 0.42825180004485897, 0.7807822177822178, 0.2918350982614119, 1.3013036963036964, 0.13186929824033974], [0.2612617382617382, 1.0, 0.6444427744903234, 0.5225234765234764, 0.4268398039667303, 0.7837852147852148, 0.29044788290216644, 1.3063086913086914, 0.1308481592949883], [0.2622627372627372, 1.0, 0.6433836384963878, 0.5245254745254744, 0.4254322708159136, 0.7867882117882118, 0.2890671195375348, 1.3113136863136865, 0.12983490751065968], [0.2632637362637362, 1.0, 0.6423265143692112, 0.5265274725274725, 0.42402918705306825, 0.7897912087912088, 0.2876927782833549, 1.3163186813186816, 0.12882948197041202], [0.2642647352647352, 1.0, 0.6412713995666234, 0.5285294705294704, 0.42263053918165366, 0.7927942057942058, 0.2863248293944609, 1.3213236763236764, 0.12783182222781958], [0.26526573426573424, 1.0, 0.6402182915512858, 0.5305314685314685, 0.4212363137477991, 0.7957972027972028, 0.28496324326403705, 1.3263286713286715, 0.12684186830333785], [0.2662667332667332, 1.0, 0.639167187790687, 0.5325334665334664, 0.4198464973401739, 0.7988001998001998, 0.28360799042297863, 1.3313336663336666, 0.12585956068069815], [0.2672677322677322, 1.0, 0.6381180857571346, 0.5345354645354644, 0.4184610765898585, 0.8018031968031968, 0.28225904153925396, 1.3363386613386614, 0.12488484030332922], [0.26826873126873124, 1.0, 0.6370709829277491, 0.5365374625374625, 0.4170800381702164, 0.8048061938061939, 0.2809163674172689, 1.3413436563436565, 0.12391764857080693], [0.2692697302697302, 1.0, 0.6360258767844608, 0.5385394605394604, 0.4157033687967652, 0.8078091908091909, 0.2795799389972357, 1.3463486513486516, 0.12295792733533095], [0.2702707292707292, 1.0, 0.6349827648140002, 0.5405414585414584, 0.4143310552270496, 0.8108121878121879, 0.278249727354543, 1.3513536463536464, 0.12200561889822921], [0.27127172827172824, 1.0, 0.6339416445078937, 0.5425434565434565, 0.4129630842605135, 0.8138151848151849, 0.2769257036991317, 1.3563586413586415, 0.12106066600648878], [0.2722727272727272, 1.0, 0.6329025133624568, 0.5445454545454544, 0.4115994427383731, 0.8168181818181819, 0.2756078393748692, 1.3613636363636366, 0.1201230118493138], [0.2732737262737262, 1.0, 0.6318653688787891, 0.5465474525474524, 0.4102401175434903, 0.8198211788211789, 0.27429610585893194, 1.3663686313686316, 0.11919260005471029], [0.27427472527472524, 1.0, 0.6308302085627677, 0.5485494505494505, 0.40888509560024705, 0.8228241758241759, 0.2729904747611858, 1.3713736263736265, 0.11826937468609663], [0.2752757242757242, 1.0, 0.6297970299250406, 0.5505514485514484, 0.4075343638744187, 0.8258271728271729, 0.27169091782357324, 1.3763786213786215, 0.11735328023894107], [0.2762767232767232, 1.0, 0.6287658304810223, 0.5525534465534464, 0.4061879093730492, 0.8288301698301699, 0.2703974069195009, 1.3813836163836166, 0.11644426163742438], [0.27727772227772224, 1.0, 0.627736607750886, 0.5545554445554445, 0.404845719144326, 0.8318331668331669, 0.2691099140532309, 1.3863886113886115, 0.11554226423112902], [0.2782787212787212, 1.0, 0.626709359259559, 0.5565574425574424, 0.403507780277455, 0.8348361638361639, 0.26782841135927543, 1.3913936063936065, 0.11464723379175339], [0.27927972027972026, 1.0, 0.6256840825367161, 0.5585594405594405, 0.4021740799025379, 0.8378391608391609, 0.2665528711017927, 1.3963986013986016, 0.11375911650985156], [0.28028071928071924, 1.0, 0.6246607751167741, 0.5605614385614385, 0.40084460519044623, 0.8408421578421579, 0.2652832656739878, 1.4014035964035965, 0.11287785899159831], [0.2812817182817182, 1.0, 0.6236394345388848, 0.5625634365634364, 0.3995193433526994, 0.8438451548451549, 0.2640195675975142, 1.4064085914085915, 0.11200340825557915], [0.28228271728271725, 1.0, 0.6226200583469309, 0.5645654345654345, 0.39819828164134125, 0.8468481518481519, 0.26276174952187986, 1.4114135864135866, 0.11113571172960483], [0.28328371628371624, 1.0, 0.6216026440895182, 0.5665674325674325, 0.3968814073488172, 0.8498511488511489, 0.2615097842238548, 1.4164185814185817, 0.11027471724755099], [0.2842847152847152, 1.0, 0.6205871893199705, 0.5685694305694304, 0.3955687078078531, 0.8528541458541459, 0.2602636446068814, 1.4214235764235765, 0.10942037304622168], [0.28528571428571425, 1.0, 0.6195736915963246, 0.5705714285714285, 0.39426017039133177, 0.8558571428571429, 0.25902330370048915, 1.4264285714285716, 0.10857262776223742], [0.28628671328671323, 1.0, 0.6185621484813226, 0.5725734265734265, 0.3929557825121724, 0.8588601398601399, 0.2577887346597102, 1.4314335664335667, 0.10773143042894728], [0.2872877122877122, 1.0, 0.6175525575424078, 0.5745754245754244, 0.3916555316232097, 0.8618631368631369, 0.25655991076449847, 1.4364385614385615, 0.10689673047336468], [0.28828871128871125, 1.0, 0.6165449163517182, 0.5765774225774225, 0.39035940521707274, 0.8648661338661339, 0.2553368054191511, 1.4414435564435566, 0.10606847771312693], [0.28928971028971023, 1.0, 0.6155392224860796, 0.5785794205794205, 0.3890673908260646, 0.8678691308691309, 0.2541193921517331, 1.4464485514485517, 0.10524662235347836], [0.2902907092907092, 1.0, 0.6145354735270017, 0.5805814185814184, 0.3877794760220433, 0.8708721278721279, 0.25290764461350457, 1.4514535464535465, 0.10443111498427653], [0.29129170829170825, 1.0, 0.6135336670606709, 0.5825834165834165, 0.3864956484163013, 0.8738751248751249, 0.25170153657835004, 1.4564585414585416, 0.10362190657702162], [0.29229270729270723, 1.0, 0.6125338006779449, 0.5845854145854145, 0.3852158956594461, 0.8768781218781219, 0.2505010419422108, 1.4614635364635367, 0.10281894848190898], [0.29329370629370627, 1.0, 0.6115358719743467, 0.5865874125874125, 0.38394020544128254, 0.8798811188811189, 0.24930613472252058, 1.4664685314685317, 0.10202219242490441], [0.29429470529470525, 1.0, 0.6105398785500596, 0.5885894105894105, 0.38266856549069367, 0.882884115884116, 0.24811678905764264, 1.4714735264735266, 0.1012315905048415], [0.29529570429570423, 1.0, 0.6095458180099204, 0.5905914085914085, 0.38140096357552306, 0.885887112887113, 0.24693297920631016, 1.4764785214785217, 0.10044709519054204], [0.29629670329670327, 1.0, 0.6085536879634138, 0.5925934065934065, 0.38013738750245635, 0.88889010989011, 0.24575467954706898, 1.4814835164835167, 0.0996686593179586], [0.29729770229770225, 1.0, 0.6075634860246681, 0.5945954045954045, 0.3788778251169052, 0.891893106893107, 0.24458186457772363, 1.4864885114885116, 0.09889623608733879], [0.29829870129870123, 1.0, 0.6065752098124472, 0.5965974025974025, 0.3776222643028895, 0.894896103896104, 0.2434145089147844, 1.4914935064935066, 0.09812977906041163], [0.29929970029970027, 1.0, 0.6055888569501463, 0.5985994005994005, 0.3763706929829209, 0.897899100899101, 0.24225258729291896, 1.4964985014985017, 0.09736924215759579], [0.30030069930069925, 1.0, 0.6046044250657865, 0.6006013986013985, 0.3751230991178871, 0.900902097902098, 0.24109607456440507, 1.5015034965034966, 0.09661457965522931], [0.30130169830169823, 1.0, 0.603621911792007, 0.6026033966033965, 0.3738794707069356, 0.903905094905095, 0.23994494569858632, 1.5065084915084916, 0.09586574618282043], [0.30230269730269727, 1.0, 0.6026413147660622, 0.6046053946053945, 0.37263979578735845, 0.906908091908092, 0.23879917578133028, 1.5115134865134867, 0.09512269672032019], [0.30330369630369625, 1.0, 0.6016626316298146, 0.6066073926073925, 0.3714040624344769, 0.909911088911089, 0.23765874001448958, 1.5165184815184818, 0.09438538659541564], [0.3043046953046952, 1.0, 0.6006858600297282, 0.6086093906093905, 0.3701722587615266, 0.912914085914086, 0.23652361371536482, 1.5215234765234766, 0.09365377148084428], [0.30530569430569426, 1.0, 0.5997109976168651, 0.6106113886113885, 0.36894437291954446, 0.915917082917083, 0.2353937723161708, 1.5265284715284717, 0.09292780739172894], [0.30630669330669325, 1.0, 0.5987380420468775, 0.6126133866133865, 0.36772039309725335, 0.91892007992008, 0.23426919136350446, 1.5315334665334668, 0.09220745068293348], [0.3073076923076922, 1.0, 0.5977669909800042, 0.6146153846153845, 0.3665003075209485, 0.921923076923077, 0.23314984651781565, 1.5365384615384616, 0.09149265804643883], [0.30830869130869126, 1.0, 0.5967978420810637, 0.6166173826173825, 0.3652841044543853, 0.924926073926074, 0.23203571355288052, 1.5415434565434567, 0.0907833865087392], [0.30930969030969024, 1.0, 0.5958305930194477, 0.6186193806193805, 0.36407177219866543, 0.927929070929071, 0.23092676835527698, 1.5465484515484518, 0.09007959342825872], [0.3103106893106893, 1.0, 0.5948652414691178, 0.6206213786213786, 0.3628632990921249, 0.930932067932068, 0.2298229869238631, 1.5515534465534466, 0.08938123649278763], [0.31131168831168826, 1.0, 0.5939017851085985, 0.6226233766233765, 0.3616586735102213, 0.933935064935065, 0.22872434536925731, 1.5565584415584417, 0.08868827371693853], [0.31231268731268724, 1.0, 0.5929402216209722, 0.6246253746253745, 0.3604578838654226, 0.936938061938062, 0.22763081991332146, 1.5615634365634368, 0.0880006634396222], [0.3133136863136863, 1.0, 0.5919805486938723, 0.6266273726273726, 0.35926091860709536, 0.939941058941059, 0.22654238688864659, 1.5665684315684318, 0.08731836432154294], [0.31431468531468526, 1.0, 0.5910227640194797, 0.6286293706293705, 0.35806776622139325, 0.942944055944056, 0.2254590227380398, 1.5715734265734267, 0.08664133534271314], [0.31531568431568424, 1.0, 0.5900668652945151, 0.6306313686313685, 0.3568784152311476, 0.945947052947053, 0.22438070401401541, 1.5765784215784218, 0.0859695357999873], [0.3163166833166833, 1.0, 0.5891128502202353, 0.6326333666333666, 0.3556928541957554, 0.94895004995005, 0.2233074073782868, 1.5815834165834168, 0.08530292530461495], [0.31731768231768226, 1.0, 0.5881607165024265, 0.6346353646353645, 0.3545110717110704, 0.9519530469530469, 0.2222391096012615, 1.5865884115884117, 0.08464146377981219], [0.31831868131868124, 1.0, 0.5872104618513999, 0.6366373626373625, 0.35333305640929247, 0.9549560439560439, 0.22117578756153844, 1.5915934065934068, 0.08398511145835272], [0.3193196803196803, 1.0, 0.5862620839819845, 0.6386393606393606, 0.35215879695885915, 0.9579590409590409, 0.2201174182454074, 1.5965984015984018, 0.08333382888017662], [0.32032067932067926, 1.0, 0.5853155806135233, 0.6406413586413585, 0.35098828206433624, 0.960962037962038, 0.21906397874635125, 1.6016033966033967, 0.08268757689001818], [0.32132167832167824, 1.0, 0.5843709494698661, 0.6426433566433565, 0.34982150046630867, 0.963965034965035, 0.21801544626454997, 1.6066083916083918, 0.0820463166350519], [0.3223226773226773, 1.0, 0.5834281882793665, 0.6446453546453546, 0.3486584409412734, 0.966968031968032, 0.21697179810638687, 1.6116133866133868, 0.08141000956255655], [0.32332367632367626, 1.0, 0.582487294774874, 0.6466473526473525, 0.3474990923015306, 0.969971028971029, 0.21593301168395798, 1.616618381618382, 0.08077861741759745], [0.3243246753246753, 1.0, 0.5815482666937298, 0.6486493506493506, 0.3463434433950757, 0.972974025974026, 0.21489906451458288, 1.6216233766233767, 0.08015210224072661], [0.3253256743256743, 1.0, 0.5806111017777611, 0.6506513486513485, 0.3451914831054931, 0.975977022977023, 0.21386993422031808, 1.6266283716283718, 0.07953042636570037], [0.32632667332667326, 1.0, 0.5796757977732752, 0.6526533466533465, 0.3440432003518486, 0.97898001998002, 0.212845598527473, 1.6316333666333669, 0.0789135524172153], [0.3273276723276723, 1.0, 0.5787423524310551, 0.6546553446553446, 0.34289858408858315, 0.981983016983017, 0.2118260352661275, 1.6366383616383617, 0.07830144330866069], [0.3283286713286713, 1.0, 0.577810763506353, 0.6566573426573425, 0.34175762330540543, 0.984986013986014, 0.2108112223696521, 1.6416433566433568, 0.07769406223988942], [0.32932967032967025, 1.0, 0.5768810287588859, 0.6586593406593405, 0.34062030702718815, 0.987989010989011, 0.20980113787423077, 1.6466483516483519, 0.07709137269500511], [0.3303306693306693, 1.0, 0.5759531459528293, 0.6606613386613386, 0.3394866243138607, 0.990992007992008, 0.20879575991838512, 1.6516533466533467, 0.07649333844016694], [0.33133166833166827, 1.0, 0.5750271128568125, 0.6626633366633365, 0.3383565642603042, 0.993995004995005, 0.20779506674250134, 1.6566583416583418, 0.07589992352141124], [0.33233266733266725, 1.0, 0.5741029272439125, 0.6646653346653345, 0.3372301159962473, 0.996998001998002, 0.20679903668835953, 1.6616633366633369, 0.07531109226248997], [0.3333336663336663, 1.0, 0.5731805868916502, 0.6666673326673326, 0.33610726868616086, 1.0000009990009993, 0.20580764819866473, 1.666668331668332, 0.07472680926272583], [0.33433466533466527, 1.0, 0.5722600895819829, 0.6686693306693305, 0.3349880115291544, 1.0030039960039963, 0.2048208798165801, 1.6716733266733268, 0.07414703939488392], [0.33533566433566425, 1.0, 0.5713414331013001, 0.6706713286713285, 0.3338723337588714, 1.0060069930069933, 0.20383871018526326, 1.6766783216783219, 0.07357174780306003], [0.3363366633366633, 1.0, 0.5704246152404188, 0.6726733266733266, 0.33276022464338656, 1.0090099900099903, 0.20286111804740306, 1.681683316683317, 0.07300089990058481], [0.33733766233766227, 1.0, 0.5695096337945771, 0.6746753246753245, 0.3316516734851018, 1.0120129870129873, 0.20188808224476026, 1.6866883116883118, 0.07243446136794474], [0.3383386613386613, 1.0, 0.5685964865634292, 0.6766773226773226, 0.33054666962064405, 1.0150159840159843, 0.20091958171770963, 1.6916933066933069, 0.07187239815071851], [0.3393396603396603, 1.0, 0.5676851713510404, 0.6786793206793206, 0.32944520242076214, 1.0180189810189813, 0.19995559550478353, 1.696698301698302, 0.07131467645753], [0.34034065934065927, 1.0, 0.5667756859658819, 0.6806813186813185, 0.32834726129022473, 1.0210219780219782, 0.19899610274221888, 1.7017032967032968, 0.07076126275801645], [0.3413416583416583, 1.0, 0.5658680282208248, 0.6826833166833166, 0.3272528356677191, 1.0240249750249752, 0.19804108266350504, 1.7067082917082919, 0.07021212378081283], [0.3423426573426573, 1.0, 0.5649621959331352, 0.6846853146853146, 0.32616191502574754, 1.0270279720279722, 0.19709051459893495, 1.711713286713287, 0.06966722651155131], [0.34334365634365627, 1.0, 0.5640581869244702, 0.6866873126873125, 0.32507448887052887, 1.0300309690309692, 0.19614437797515705, 1.716718281718282, 0.06912653819087665], [0.3443446553446553, 1.0, 0.5631559990208701, 0.6886893106893106, 0.32399054674189515, 1.0330339660339662, 0.19520265231473088, 1.7217232767232769, 0.0685900263124766], [0.3453456543456543, 1.0, 0.5622556300527556, 0.6906913086913086, 0.32291007821319256, 1.0360369630369632, 0.19426531723568316, 1.726728271728272, 0.06805765862112766], [0.34634665334665327, 1.0, 0.5613570778549204, 0.6926933066933065, 0.3218330728911801, 1.0390399600399602, 0.193332352451067, 1.731733266733267, 0.0675294031107558], [0.3473476523476523, 1.0, 0.5604603402665287, 0.6946953046953046, 0.3207595204159304, 1.0420429570429572, 0.19240373776852263, 1.7367382617382618, 0.0670052280225123], [0.3483486513486513, 1.0, 0.5595654151311075, 0.6966973026973026, 0.31968941046072946, 1.0450459540459542, 0.19147945308984066, 1.741743256743257, 0.06648510184286444], [0.34934965034965026, 1.0, 0.558672300296542, 0.6986993006993005, 0.31862273273197733, 1.0480489510489512, 0.19055947841052664, 1.746748251748252, 0.06596899330170083], [0.3503506493506493, 1.0, 0.5577809936150717, 0.7007012987012986, 0.31755947696909004, 1.0510519480519482, 0.1896437938193688, 1.7517532467532468, 0.06545687137045145], [0.3513516483516483, 1.0, 0.5568914929432841, 0.7027032967032966, 0.3164996329443995, 1.0540549450549452, 0.1887323794980062, 1.756758241758242, 0.06494870526022234], [0.35235264735264726, 1.0, 0.5560037961421098, 0.7047052947052945, 0.31544319046305613, 1.0570579420579422, 0.18782521572050065, 1.761763236763237, 0.06444446441994436], [0.3533536463536463, 1.0, 0.5551179010768169, 0.7067072927072926, 0.3143901393629305, 1.0600609390609392, 0.18692228285290907, 1.766768231768232, 0.06394411853453655], [0.3543546453546453, 1.0, 0.5542338056170073, 0.7087092907092906, 0.31334046951451533, 1.0630639360639362, 0.18602356135285927, 1.771773226773227, 0.0634476375230836], [0.3553556443556443, 1.0, 0.5533515076366088, 0.7107112887112886, 0.31229417082082844, 1.0660669330669332, 0.18512903176912637, 1.776778221778222, 0.06295499153702735], [0.3563566433566433, 1.0, 0.5524710050138736, 0.7127132867132866, 0.3112512332173153, 1.0690699300699302, 0.18423867474121208, 1.781783216783217, 0.062466150958372345], [0.3573576423576423, 1.0, 0.5515922956313706, 0.7147152847152846, 0.31021164667175266, 1.0720729270729272, 0.18335247099892568, 1.786788211788212, 0.06198108639790499], [0.3583586413586413, 1.0, 0.5507153773759811, 0.7167172827172826, 0.3091754011841514, 1.0750759240759242, 0.1824704013619667, 1.791793206793207, 0.06149976869342697], [0.3593596403596403, 1.0, 0.549840248138894, 0.7187192807192806, 0.30814248678666106, 1.0780789210789212, 0.18159244673951047, 1.796798201798202, 0.06102216890800178], [0.3603606393606393, 1.0, 0.5489669058155999, 0.7207212787212786, 0.30711289354347315, 1.0810819180819182, 0.18071858812979408, 1.801803196803197, 0.06054825832821511], [0.3613616383616383, 1.0, 0.548095348305887, 0.7227232767232766, 0.30608661155072664, 1.0840849150849152, 0.17984880661970548, 1.806808191808192, 0.0600780084624486], [0.3623626373626373, 1.0, 0.5472255735138355, 0.7247252747252746, 0.30506363093641153, 1.0870879120879122, 0.1789830833843746, 1.811813186813187, 0.05961139103916692], [0.3633636363636363, 1.0, 0.5463575793478123, 0.7267272727272726, 0.3040439418602747, 1.0900909090909092, 0.17812139968676502, 1.816818181818182, 0.059148378005218036], [0.3643646353646353, 1.0, 0.5454913637204671, 0.7287292707292706, 0.30302753451372505, 1.0930939060939062, 0.1772637368772691, 1.821823176823177, 0.05868894152414663], [0.3653656343656343, 1.0, 0.544626924548726, 0.7307312687312686, 0.30201439911973865, 1.0960969030969032, 0.17641007639330428, 1.826828171828172, 0.058233053974520686], [0.3663666333666333, 1.0, 0.5437642597537874, 0.7327332667332666, 0.3010045259327657, 1.0990999000999002, 0.17556039975891108, 1.831833166833167, 0.05778068794827071], [0.3673676323676323, 1.0, 0.5429033672611168, 0.7347352647352646, 0.2999979052386358, 1.1021028971028972, 0.17471468858435332, 1.836838161838162, 0.05733181624904212], [0.3683686313686313, 1.0, 0.5420442450004415, 0.7367372627372626, 0.2989945273544652, 1.1051058941058942, 0.17387292456572007, 1.841843156843157, 0.05688641189056014], [0.36936963036963033, 1.0, 0.5411868909057458, 0.7387392607392607, 0.29799438262856304, 1.1081088911088912, 0.17303508948452978, 1.846848151848152, 0.05644444809500722], [0.3703706293706293, 1.0, 0.5403313029152663, 0.7407412587412586, 0.29699746144033906, 1.1111118881118882, 0.1722011652073356, 1.851853146853147, 0.056005898291413454], [0.3713716283716283, 1.0, 0.5394774789714866, 0.7427432567432566, 0.2960037542002112, 1.1141148851148852, 0.171371133685333, 1.856858141858142, 0.055570736114058814], [0.37237262737262733, 1.0, 0.5386254170211328, 0.7447452547452547, 0.2950132513495123, 1.1171178821178822, 0.17054497695396933, 1.861863136863137, 0.05513893540088825], [0.3733736263736263, 1.0, 0.5377751150151677, 0.7467472527472526, 0.29402594336039956, 1.1201208791208792, 0.16972267713255465, 1.8668681318681322, 0.05471047019193874], [0.3743746253746253, 1.0, 0.5369265709087867, 0.7487492507492506, 0.29304182073576146, 1.1231238761238762, 0.1689042164238753, 1.871873126873127, 0.05428531472777853], [0.37537562437562433, 1.0, 0.5360797826614127, 0.7507512487512487, 0.29206087400912756, 1.1261268731268732, 0.1680895771138082, 1.876878121878122, 0.0538634434479586], [0.3763766233766233, 1.0, 0.5352347482366908, 0.7527532467532466, 0.29108309374457725, 1.1291298701298702, 0.16727874157093758, 1.8818831168831172, 0.05344483098947585], [0.3773776223776223, 1.0, 0.534391465602484, 0.7547552447552446, 0.2901084705366481, 1.1321328671328672, 0.16647169224617353, 1.886888111888112, 0.0530294521852483], [0.3783786213786213, 1.0, 0.5335499327308675, 0.7567572427572427, 0.28913699501024664, 1.1351358641358642, 0.16566841167237195, 1.891893106893107, 0.05261728206260206], [0.3793796203796203, 1.0, 0.5327101475981246, 0.7587592407592406, 0.28816865782055723, 1.1381388611388612, 0.16486888246395687, 1.8968981018981022, 0.05220829584176993], [0.3803806193806193, 1.0, 0.5318721081847423, 0.7607612387612386, 0.2872034496529525, 1.1411418581418582, 0.16407308731654363, 1.901903096903097, 0.051802468934401706], [0.3813816183816183, 1.0, 0.5310358124754049, 0.7627632367632367, 0.2862413612229041, 1.1441448551448552, 0.16328100900656484, 1.906908091908092, 0.05139977694208574], [0.3823826173826173, 1.0, 0.5302012584589892, 0.7647652347652346, 0.2852823832758927, 1.1471478521478522, 0.16249263039089742, 1.9119130869130871, 0.05100019565488237], [0.3833836163836163, 1.0, 0.5293684441285622, 0.7667672327672326, 0.2843265065873194, 1.1501508491508494, 0.16170793440649156, 1.916918081918082, 0.05060370104986825], [0.3843846153846153, 1.0, 0.5285373674813728, 0.7687692307692306, 0.2833737219624171, 1.1531538461538464, 0.1609269040700015, 1.921923076923077, 0.05021026928969203], [0.3853856143856143, 1.0, 0.5277080265188501, 0.7707712287712286, 0.28242402023616153, 1.1561568431568434, 0.16014952247741782, 1.9269280719280721, 0.04981987672114148], [0.38638661338661334, 1.0, 0.5268804192465961, 0.7727732267732267, 0.281477392273184, 1.1591598401598404, 0.15937577280370172, 1.9319330669330672, 0.049432499873721183], [0.3873876123876123, 1.0, 0.5260545436743831, 0.7747752247752246, 0.2805338289676821, 1.1621628371628374, 0.1586056383024207, 1.936938061938062, 0.049048115458241594], [0.3883886113886113, 1.0, 0.5252303978161464, 0.7767772227772226, 0.27959332124333397, 1.1651658341658344, 0.1578391023053863, 1.9419430569430571, 0.048666700365418994], [0.38938961038961034, 1.0, 0.524407979689982, 0.7787792207792207, 0.278655860053209, 1.1681688311688314, 0.15707614822229324, 1.9469480519480522, 0.048288231664486016], [0.3903906093906093, 1.0, 0.5235872873181406, 0.7807812187812186, 0.2777214363796828, 1.1711718281718284, 0.15631675954036053, 1.951953046953047, 0.04791268660181302], [0.3913916083916083, 1.0, 0.5227683187270221, 0.7827832167832166, 0.2767900412343484, 1.1741748251748254, 0.15556091982397355, 1.9569580419580421, 0.04754004259954031], [0.39239260739260734, 1.0, 0.521951071947173, 0.7847852147852147, 0.27586166565793174, 1.1771778221778224, 0.15480861271432927, 1.9619630369630372, 0.04717027725422058], [0.3933936063936063, 1.0, 0.5211355450132794, 0.7867872127872126, 0.27493630072020436, 1.1801808191808194, 0.1540598219290813, 1.966968031968032, 0.04680336833547203], [0.3943946053946053, 1.0, 0.5203217359641642, 0.7887892107892106, 0.27401393751989717, 1.1831838161838164, 0.1533145312619877, 1.9719730269730271, 0.046439293784642025], [0.39539560439560434, 1.0, 0.5195096428427807, 0.7907912087912087, 0.2730945671846161, 1.1861868131868134, 0.15257272458256066, 1.9769780219780222, 0.0460780317134807], [0.3963966033966033, 1.0, 0.5186992636962087, 0.7927932067932066, 0.2721781808707556, 1.1891898101898104, 0.15183438583571676, 1.9819830169830173, 0.04571956040282525], [0.3973976023976023, 1.0, 0.5178905965756498, 0.7947952047952046, 0.27126476976341446, 1.1921928071928074, 0.15109949904143008, 1.9869880119880121, 0.04536385830129399], [0.39839860139860134, 1.0, 0.5170836395364236, 0.7967972027972027, 0.2703543250763098, 1.1951958041958044, 0.15036804829438594, 1.9919930069930072, 0.04501090402399078], [0.3993996003996003, 1.0, 0.5162783906379608, 0.7987992007992006, 0.26944683805169417, 1.1981988011988014, 0.14964001776363664, 1.9969980019980023, 0.04466067635121933], [0.40040059940059936, 1.0, 0.5154748479438005, 0.8008011988011987, 0.26854229996027, 1.2012017982017984, 0.14891539169225926, 2.002002997002997, 0.04431315422720747], [0.40140159840159834, 1.0, 0.5146730095215848, 0.8028031968031967, 0.26764070210110624, 1.2042047952047954, 0.14819415439701408, 2.0070079920079924, 0.04396831675884133], [0.4024025974025973, 1.0, 0.5138728734430545, 0.8048051948051946, 0.26674203580155453, 1.2072077922077924, 0.14747629026800566, 2.0120129870129873, 0.04362614321440909], [0.40340359640359635, 1.0, 0.5130744377840433, 0.8068071928071927, 0.2658462924171653, 1.2102107892107894, 0.14676178376834445, 2.017017982017982, 0.04328661302235472], [0.40440459540459534, 1.0, 0.5122777006244751, 0.8088091908091907, 0.264953463331606, 1.2132137862137864, 0.1460506194338109, 2.0220229770229774, 0.0429497057700412], [0.4054055944055943, 1.0, 0.5114826600483575, 0.8108111888111886, 0.26406353995657633, 1.2162167832167834, 0.14534278187252073, 2.0270279720279722, 0.042615401202523266], [0.40640659340659335, 1.0, 0.5106893141437785, 0.8128131868131867, 0.26317651373172735, 1.2192197802197804, 0.14463825576459166, 2.032032967032967, 0.042283679221329626], [0.40740759240759233, 1.0, 0.509897661002902, 0.8148151848151847, 0.2622923761245782, 1.2222227772227774, 0.14393702586181198, 2.0370379620379624, 0.04195451988325483], [0.4084085914085913, 1.0, 0.5091076987219615, 0.8168171828171826, 0.26141111863043354, 1.2252257742257744, 0.1432390769873105, 2.0420429570429572, 0.04162790339916004], [0.40940959040959035, 1.0, 0.5083194254012577, 0.8188191808191807, 0.26053273277230343, 1.2282287712287714, 0.14254439403522778, 2.047047952047952, 0.04130381013278348], [0.41041058941058933, 1.0, 0.507532839145152, 0.8208211788211787, 0.2596572101008202, 1.2312317682317684, 0.14185296197038985, 2.0520529470529474, 0.040982220599559784], [0.4114115884115883, 1.0, 0.5067479380620638, 0.8228231768231766, 0.2587845421941577, 1.2342347652347654, 0.14116476582798204, 2.0570579420579422, 0.04066311546544862], [0.41241258741258735, 1.0, 0.5059647202644636, 0.8248251748251747, 0.25791472065795057, 1.2372377622377624, 0.1404797907132257, 2.062062937062937, 0.04034647554577242], [0.41341358641358633, 1.0, 0.5051831838688715, 0.8268271728271727, 0.257047737125213, 1.2402407592407594, 0.13979802180105538, 2.0670679320679324, 0.04003228180406277], [0.41441458541458537, 1.0, 0.5044033269958497, 0.8288291708291707, 0.25618358325625873, 1.2432437562437564, 0.13911944433579831, 2.0720729270729272, 0.03972051535091617], [0.41541558441558435, 1.0, 0.5036251477700003, 0.8308311688311687, 0.2553222507386206, 1.2462467532467534, 0.13844404363085486, 2.077077922077922, 0.03941115744285825], [0.41641658341658333, 1.0, 0.5028486443199593, 0.8328331668331667, 0.2544637312869701, 1.2492497502497504, 0.13777180506838071, 2.0820829170829174, 0.039104189481216974], [0.41741758241758237, 1.0, 0.5020738147783925, 0.8348351648351647, 0.25360801664303884, 1.2522527472527474, 0.13710271409897046, 2.0870879120879122, 0.03879959301100443], [0.41841858141858135, 1.0, 0.5013006572819914, 0.8368371628371627, 0.25275509857553813, 1.2552557442557444, 0.13643675624134277, 2.092092907092907, 0.03849734971980737], [0.41941958041958033, 1.0, 0.5005291699714688, 0.8388391608391607, 0.25190496888008, 1.2582587412587414, 0.13577391708202705, 2.0970979020979024, 0.03819744143668622], [0.42042057942057937, 1.0, 0.4997593509915527, 0.8408411588411587, 0.25105761937909865, 1.2612617382617384, 0.13511418227505112, 2.102102897102897, 0.037899850131082644], [0.42142157842157835, 1.0, 0.4989911984909845, 0.8428431568431567, 0.2502130419217711, 1.2642647352647354, 0.13445753754163112, 2.1071078921078925, 0.03760455791173563], [0.42242257742257733, 1.0, 0.49822471062251256, 0.8448451548451547, 0.24937122838393966, 1.2672677322677324, 0.13380396866986238, 2.1121128871128874, 0.037311547025605664], [0.42342357642357636, 1.0, 0.49745988554288795, 0.8468471528471527, 0.24853217066803313, 1.2702707292707294, 0.13315346151441163, 2.117117882117882, 0.03702079985680761], [0.42442457542457535, 1.0, 0.49669672141286075, 0.8488491508491507, 0.24769586070298907, 1.2732737262737264, 0.1325060019962111, 2.1221228771228775, 0.03673229892555159], [0.4254255744255743, 1.0, 0.4959352163971758, 0.8508511488511487, 0.24686229044417624, 1.2762767232767234, 0.13186157610215365, 2.1271278721278724, 0.03644602688709197], [0.42642657342657336, 1.0, 0.49517536866456685, 0.8528531468531467, 0.2460314518733171, 1.2792797202797204, 0.13122016988478952, 2.132132867132867, 0.0361619665306848], [0.42742757242757234, 1.0, 0.49441717638775334, 0.8548551448551447, 0.24520333699841107, 1.2822827172827174, 0.13058176946202452, 2.1371378621378625, 0.035880100778552894], [0.4284285714285713, 1.0, 0.4936606377434364, 0.8568571428571427, 0.244377937853657, 1.2852857142857144, 0.12994636101681947, 2.1421428571428573, 0.035600412684859285], [0.42942957042957036, 1.0, 0.492905750912293, 0.8588591408591407, 0.24355524649937688, 1.2882887112887114, 0.12931393079689124, 2.147147852147852, 0.03532288543468828], [0.43043056943056934, 1.0, 0.49215251407897326, 0.8608611388611387, 0.2427352550219398, 1.2912917082917084, 0.128684465114415, 2.1521528471528475, 0.03504750234303468], [0.4314315684315684, 1.0, 0.4914009254320941, 0.8628631368631368, 0.2419179555336852, 1.2942947052947054, 0.12805795034572812, 2.1571578421578423, 0.034774246853800594], [0.43243256743256736, 1.0, 0.4906509831642368, 0.8648651348651347, 0.2411033401728473, 1.2972977022977024, 0.1274343729310353, 2.162162837162837, 0.03450310253880009], [0.43343356643356634, 1.0, 0.489902685471942, 0.8668671328671327, 0.2402914011034795, 1.3003006993006994, 0.1268137193741149, 2.1671678321678325, 0.03423405309677158], [0.4344345654345654, 1.0, 0.4891560305557043, 0.8688691308691308, 0.2394821305153793, 1.3033036963036964, 0.12619597624202708, 2.1721728271728273, 0.03396708235239766], [0.43543556443556436, 1.0, 0.48841101661996966, 0.8708711288711287, 0.23867552062401243, 1.3063066933066936, 0.12558113016482295, 2.177177822177822, 0.03370217425533281], [0.43643656343656334, 1.0, 0.4876676418731303, 0.8728731268731267, 0.23787156367043866, 1.3093096903096906, 0.1249691678352551, 2.1821828171828175, 0.03343931287923836], [0.4374375624375624, 1.0, 0.48692590452751944, 0.8748751248751248, 0.23707025192123665, 1.3123126873126876, 0.12436007600848979, 2.1871878121878123, 0.03317848242082497], [0.43843856143856136, 1.0, 0.4861858027994093, 0.8768771228771227, 0.23627157766842993, 1.3153156843156846, 0.12375384150182017, 2.192192807192807, 0.03291966719890255], [0.43943956043956034, 1.0, 0.4854473349090044, 0.8788791208791207, 0.23547553322941275, 1.3183186813186816, 0.12315045119438102, 2.1971978021978025, 0.03266285165343751], [0.4404405594405594, 1.0, 0.4847104990804382, 0.8808811188811188, 0.23468211094687574, 1.3213216783216786, 0.1225498920268647, 2.2022027972027973, 0.03240802034461738], [0.44144155844155836, 1.0, 0.48397529354176955, 0.8828831168831167, 0.23389130318873314, 1.3243246753246756, 0.12195215100123857, 2.2072077922077926, 0.03215515795192234], [0.44244255744255734, 1.0, 0.48324171652497766, 0.8848851148851147, 0.23310310234804793, 1.3273276723276726, 0.12135721518046359, 2.2122127872127875, 0.0319042492732044], [0.4434435564435564, 1.0, 0.48250976626595754, 0.8868871128871127, 0.23231750084296052, 1.3303306693306696, 0.12076507168821443, 2.2172177822177823, 0.03165527922377324], [0.44444455544455536, 1.0, 0.48177944100451714, 0.8888891108891107, 0.23153449111661425, 1.3333336663336666, 0.12017570770860082, 2.2222227772227776, 0.031408232835489464], [0.4454455544455544, 1.0, 0.4810507389843715, 0.8908911088911088, 0.2307540656370835, 1.3363366633366636, 0.11958911048588998, 2.2272277722277725, 0.031163095255864606], [0.4464465534465534, 1.0, 0.4803236584531393, 0.8928931068931067, 0.22997621689730083, 1.3393396603396606, 0.1190052673242306, 2.2322327672327673, 0.03091985174716825], [0.44744755244755235, 1.0, 0.4795981976623385, 0.8948951048951047, 0.22920093741498507, 1.3423426573426576, 0.11842416558737831, 2.2372377622377626, 0.03067848768554197], [0.4484485514485514, 1.0, 0.4788743548673825, 0.8968971028971028, 0.22842821973256947, 1.3453456543456546, 0.11784579269842183, 2.2422427572427575, 0.03043898856012018], [0.4494495504495504, 1.0, 0.47815212832757564, 0.8988991008991007, 0.22765805641712958, 1.3483486513486516, 0.11727013613951082, 2.2472477522477523, 0.030201339972157706], [0.45045054945054935, 1.0, 0.4774315163061084, 0.9009010989010987, 0.22689044006031192, 1.3513516483516486, 0.11669718345158528, 2.2522527472527476, 0.029965527634164095], [0.4514515484515484, 1.0, 0.47671251707005485, 0.9029030969030968, 0.2261253632782625, 1.3543546453546456, 0.11612692223410574, 2.2572577422577424, 0.029731537369044724], [0.45245254745254737, 1.0, 0.47599512889036705, 0.9049050949050947, 0.22536281871155622, 1.3573576423576426, 0.11555934014478451, 2.2622627372627373, 0.029499355109248403], [0.45345354645354635, 1.0, 0.47527935004187144, 0.9069070929070927, 0.22460279902512598, 1.3603606393606396, 0.11499442489931916, 2.2672677322677326, 0.029268966895921657], [0.4544545454545454, 1.0, 0.4745651788032642, 0.9089090909090908, 0.22384529690819174, 1.3633636363636366, 0.11443216427112607, 2.2722727272727274, 0.029040358878069574], [0.45545554445554437, 1.0, 0.4738526134571078, 0.9109110889110887, 0.22309030507419056, 1.3663666333666336, 0.11387254609107629, 2.2772777222777223, 0.028813517311722922], [0.45645654345654335, 1.0, 0.4731416522898266, 0.9129130869130867, 0.22233781626070645, 1.3693696303696306, 0.1133155582472318, 2.2822827172827176, 0.02858842855911207], [0.4574575424575424, 1.0, 0.472432293591702, 0.9149150849150848, 0.22158782322940032, 1.3723726273726276, 0.11276118868458365, 2.2872877122877124, 0.028365079087846898], [0.45845854145854137, 1.0, 0.4717245356568699, 0.9169170829170827, 0.22084031876594074, 1.3753756243756246, 0.11220942540479076, 2.2922927072927073, 0.02814345547010333], [0.4594595404595404, 1.0, 0.4710183767833155, 0.9189190809190808, 0.22009529567993422, 1.3783786213786215, 0.11166025646592061, 2.2972977022977026, 0.027923544381816014], [0.4604605394605394, 1.0, 0.47031381527286903, 0.9209210789210788, 0.219352746804856, 1.3813816183816185, 0.11111366998219041, 2.3023026973026974, 0.027705332601877283], [0.46146153846153837, 1.0, 0.4696108494312024, 0.9229230769230767, 0.21861266499798138, 1.3843846153846155, 0.11056965412370998, 2.3073076923076927, 0.027488807011342282], [0.4624625374625374, 1.0, 0.4689094775678248, 0.9249250749250748, 0.21787504314031686, 1.3873876123876125, 0.11002819711622587, 2.3123126873126876, 0.02727395459264029], [0.4634635364635364, 1.0, 0.46820969799607864, 0.9269270729270728, 0.21713987413653169, 1.3903906093906095, 0.10948928724086636, 2.3173176823176824, 0.027060762428792063], [0.46446453546453537, 1.0, 0.4675115090331351, 0.9289290709290707, 0.2164071509148895, 1.3933936063936065, 0.1089529128338878, 2.3223226773226777, 0.026849217702633276], [0.4654655344655344, 1.0, 0.4668149089999906, 0.9309310689310688, 0.21567686642718042, 1.3963966033966035, 0.10841906228642219, 2.3273276723276726, 0.026639307696043994], [0.4664665334665334, 1.0, 0.4661198962214629, 0.9329330669330668, 0.2149490136486535, 1.3993996003996005, 0.10788772404422614, 2.3323326673326674, 0.026431019789183982], [0.46746753246753237, 1.0, 0.4654264690261865, 0.9349350649350647, 0.2142235855779484, 1.4024025974025975, 0.10735888660743048, 2.3373376623376627, 0.026224341459734037], [0.4684685314685314, 1.0, 0.464734625746609, 0.9369370629370628, 0.21350057523702903, 1.4054055944055945, 0.1068325385302917, 2.3423426573426576, 0.02601926028214313], [0.4694695304695304, 1.0, 0.46404436471898725, 0.9389390609390608, 0.21277997567111548, 1.4084085914085915, 0.10630866842094384, 2.3473476523476524, 0.025815763926881424], [0.47047052947052936, 1.0, 0.4633556842833826, 0.9409410589410587, 0.21206177994861797, 1.4114115884115885, 0.10578726494115225, 2.3523526473526477, 0.025613840159698933], [0.4714715284715284, 1.0, 0.4626685827836579, 0.9429430569430568, 0.21134598116106948, 1.4144145854145855, 0.10526831680606806, 2.3573576423576426, 0.025413476840890077], [0.4724725274725274, 1.0, 0.46198305856747246, 0.9449450549450548, 0.21063257242305958, 1.4174175824175825, 0.10475181278398386, 2.3623626373626374, 0.025214661924563796], [0.47347352647352636, 1.0, 0.46129910998627965, 0.9469470529470527, 0.2099215468721684, 1.4204205794205795, 0.10423774169609089, 2.3673676323676327, 0.025017383457919377], [0.4744745254745254, 1.0, 0.46061673539532055, 0.9489490509490508, 0.20921289766890014, 1.4234235764235765, 0.1037260924162367, 2.3723726273726276, 0.0248216295805278], [0.4754755244755244, 1.0, 0.4599359331536224, 0.9509510489510488, 0.20850661799661793, 1.4264265734265735, 0.10321685387068472, 2.3773776223776224, 0.02462738852361875], [0.4764765234765234, 1.0, 0.4592567016239932, 0.9529530469530468, 0.20780270106147758, 1.4294295704295705, 0.10271001503787439, 2.3823826173826177, 0.024434648609373045], [0.4774775224775224, 1.0, 0.4585790391730183, 0.9549550449550448, 0.20710114009236258, 1.4324325674325675, 0.10220556494818264, 2.3873876123876125, 0.024243398250220535], [0.4784785214785214, 1.0, 0.4579029441710565, 0.9569570429570428, 0.20640192834081897, 1.4354355644355645, 0.10170349268368652, 2.3923926073926074, 0.024053625948143503], [0.4794795204795204, 1.0, 0.45722841499223565, 0.9589590409590408, 0.20570505908099052, 1.4384385614385615, 0.10120378737792682, 2.3973976023976027, 0.023865320293985397], [0.4804805194805194, 1.0, 0.45655545001444897, 0.9609610389610388, 0.20501052560955368, 1.4414415584415585, 0.10070643821567299, 2.4024025974025975, 0.02367846996676484], [0.4814815184815184, 1.0, 0.45588404761935203, 0.9629630369630368, 0.20431832124565344, 1.4444445554445555, 0.10021143443268891, 2.407407592407593, 0.023493063732995097], [0.4824825174825174, 1.0, 0.45521420619235714, 0.9649650349650348, 0.20362843933083882, 1.4474475524475525, 0.09971876531550013, 2.4124125874125877, 0.023309090446008686], [0.4834835164835164, 1.0, 0.45454592412263095, 0.9669670329670328, 0.20294087322899895, 1.4504505494505495, 0.09922842020116183, 2.4174175824175825, 0.023126539045287206], [0.4844845154845154, 1.0, 0.45387919980309044, 0.9689690309690308, 0.2022556163262994, 1.4534535464535465, 0.09874038847702807, 2.422422577422578, 0.02294539855579643], [0.4854855144855144, 1.0, 0.45321403163039803, 0.9709710289710288, 0.2015726620311183, 1.4564565434565435, 0.098254659580522, 2.4274275724275727, 0.022765658087326408], [0.4864865134865134, 1.0, 0.45255041800495877, 0.9729730269730268, 0.20089200377398292, 1.4594595404595407, 0.09777122299890761, 2.4324325674325675, 0.02258730683383686], [0.4874875124875124, 1.0, 0.45188835733091554, 0.9749750249750248, 0.20021363500750664, 1.4624625374625377, 0.09729006826906196, 2.437437562437563, 0.022410334072807382], [0.4884885114885114, 1.0, 0.45122784801614646, 0.9769770229770228, 0.1995375492063258, 1.4654655344655347, 0.09681118497724842, 2.4424425574425577, 0.02223472916459291], [0.4894895104895104, 1.0, 0.45056888847225934, 0.9789790209790208, 0.1988637398670373, 1.4684685314685317, 0.09633456275889185, 2.4474475524475525, 0.02206048155178399], [0.49049050949050943, 1.0, 0.44991147711459, 0.9809810189810189, 0.19819220050813552, 1.4714715284715287, 0.095860191298354, 2.452452547452548, 0.021887580758572132], [0.4914915084915084, 1.0, 0.4492556123621972, 0.9829830169830168, 0.19752292466995036, 1.4744745254745257, 0.09538806032871013, 2.4574575424575427, 0.021716016390119924], [0.4924925074925074, 1.0, 0.44860129263785814, 0.9849850149850148, 0.19685590591458493, 1.4774775224775227, 0.09491815963152701, 2.4624625374625375, 0.02154577813193615], [0.49349350649350643, 1.0, 0.4479485163680661, 0.9869870129870129, 0.1961911378258537, 1.4804805194805197, 0.09445047903664165, 2.467467532467533, 0.021376855749255696], [0.4944945054945054, 1.0, 0.4472972819830258, 0.9889890109890108, 0.1955286140092208, 1.4834835164835167, 0.09398500842194131, 2.4724725274725277, 0.021209239086424154], [0.4954955044955044, 1.0, 0.4466475879166502, 0.9909910089910088, 0.1948683280917384, 1.4864865134865137, 0.09352173771314423, 2.4774775224775225, 0.02104291806628732], [0.4964965034965034, 1.0, 0.44599943260655656, 0.9929930069930069, 0.19421027372198538, 1.4894895104895107, 0.09306065688358175, 2.482482517482518, 0.02087788268958536], [0.4974975024975024, 1.0, 0.44535281449406167, 0.9949950049950048, 0.19355444457000637, 1.4924925074925077, 0.09260175595398124, 2.4874875124875127, 0.020714123034351613], [0.4984985014985014, 1.0, 0.4447077320241803, 0.9969970029970028, 0.19290083432725097, 1.4954955044955047, 0.09214502499225005, 2.4924925074925075, 0.020551629255316096], [0.4994995004995004, 1.0, 0.44406418364561884, 0.9989990009990009, 0.19224943670651248, 1.4984985014985017, 0.09169045411326068, 2.497497502497503, 0.020390391583313613], [0.5005004995004995, 1.0, 0.44342216781077326, 1.001000999000999, 0.19160024544186846, 1.5015014985014987, 0.09123803347863672, 2.5025024975024976, 0.02023040032469646], [0.5015014985014984, 1.0, 0.44278168297572573, 1.0030029970029968, 0.19095325428861937, 1.5045044955044957, 0.09078775329654006, 2.507507492507493, 0.02007164586075156], [0.5025024975024974, 1.0, 0.442142727600239, 1.0050049950049948, 0.19030845702322913, 1.5075074925074927, 0.09033960382145882, 2.512512487512488, 0.019914118647122264], [0.5035034965034965, 1.0, 0.4415053001477549, 1.007006993006993, 0.18966584744326515, 1.5105104895104897, 0.08989357535399646, 2.5175174825174826, 0.019757809213234476], [0.5045044955044954, 1.0, 0.44086939908538864, 1.0090089910089908, 0.18902541936733858, 1.5135134865134867, 0.08944965824066183, 2.522522477522478, 0.019602708161727347], [0.5055054945054944, 1.0, 0.44023502288392685, 1.0110109890109888, 0.1883871666350448, 1.5165164835164837, 0.08900784287366037, 2.527527472527473, 0.019448806167888244], [0.5065064935064935, 1.0, 0.43960217001782276, 1.013012987012987, 0.18775108310690444, 1.5195194805194807, 0.08856811969068602, 2.5325324675324676, 0.01929609397909216], [0.5075074925074924, 1.0, 0.438970838965193, 1.0150149850149848, 0.1871171626643039, 1.5225224775224777, 0.08813047917471432, 2.537537462537463, 0.01914456241424548], [0.5085084915084914, 1.0, 0.4383410282078138, 1.0170169830169828, 0.1864853992094369, 1.5255254745254747, 0.0876949118537964, 2.542542457542458, 0.018994202363233983], [0.5095094905094905, 1.0, 0.4377127362311176, 1.019018981018981, 0.18585578666524558, 1.5285284715284717, 0.08726140830085398, 2.5475474525474526, 0.018845004786375123], [0.5105104895104894, 1.0, 0.4370859615241888, 1.0210209790209788, 0.18522831897536224, 1.5315314685314687, 0.08682995913347549, 2.552552447552448, 0.018696960713874604], [0.5115114885114884, 1.0, 0.4364607025797607, 1.0230229770229768, 0.18460299010405062, 1.5345344655344657, 0.08640055501371276, 2.5575574425574428, 0.018550061245287082], [0.5125124875124875, 1.0, 0.4358369578942125, 1.025024975024975, 0.18397979403614872, 1.5375374625374627, 0.08597318664787905, 2.5625624375624376, 0.01840429754898106], [0.5135134865134864, 1.0, 0.43521472596756366, 1.0270269730269728, 0.18335872477700993, 1.5405404595404597, 0.08554784478634789, 2.567567432567433, 0.018259660861607966], [0.5145144855144854, 1.0, 0.43459400530347214, 1.0290289710289708, 0.1827397763524461, 1.5435434565434567, 0.08512452022335293, 2.5725724275724278, 0.018116142487575267], [0.5155154845154845, 1.0, 0.43397479440923, 1.031030969030969, 0.18212294280866964, 1.5465464535464537, 0.08470320379678854, 2.5775774225774226, 0.017973733798523694], [0.5165164835164834, 1.0, 0.43335709179576065, 1.0330329670329668, 0.18150821821223645, 1.5495494505494507, 0.08428388638801176, 2.582582417582418, 0.01783242623280852], [0.5175174825174824, 1.0, 0.43274089597761306, 1.0350349650349648, 0.18089559664998894, 1.5525524475524477, 0.08386655892164467, 2.5875874125874128, 0.017692211294984803], [0.5185184815184815, 1.0, 0.4321262054729611, 1.037036963036963, 0.180285072228999, 1.5555554445554447, 0.0834512123653782, 2.5925924075924076, 0.017553080555296665], [0.5195194805194804, 1.0, 0.4315130188035981, 1.0390389610389608, 0.17967663907651119, 1.5585584415584417, 0.08303783772977646, 2.597597402597403, 0.017415025649170475], [0.5205204795204794, 1.0, 0.43090133449493423, 1.0410409590409588, 0.17907029133988658, 1.5615614385614387, 0.08262642606808253, 2.6026023976023978, 0.017278038276711972], [0.5215214785214785, 1.0, 0.43029115107599186, 1.043042957042957, 0.17846602318654609, 1.5645644355644357, 0.08221696847602417, 2.6076073926073926, 0.01714211020220729], [0.5225224775224774, 1.0, 0.42968246707940333, 1.0450449550449548, 0.17786382880391471, 1.5675674325674327, 0.08180945609162174, 2.612612387612388, 0.017007233253627813], [0.5235234765234764, 1.0, 0.42907528104140646, 1.0470469530469528, 0.17726370239936523, 1.5705704295704297, 0.08140388009499613, 2.6176173826173827, 0.016873399322138837], [0.5245244755244755, 1.0, 0.4284695915018416, 1.049048951048951, 0.17666563820016296, 1.5735734265734267, 0.08100023170817777, 2.622622377622378, 0.016740600361612137], [0.5255254745254744, 1.0, 0.4278653970041476, 1.0510509490509488, 0.17606963045340987, 1.5765764235764237, 0.0805985021949169, 2.627627372627373, 0.01660882838814216], [0.5265264735264734, 1.0, 0.4272626960953588, 1.0530529470529468, 0.17547567342598927, 1.5795794205794207, 0.08019868286049439, 2.6326323676323677, 0.01647807547956608], [0.5275274725274725, 1.0, 0.426661487326101, 1.055054945054945, 0.17488376140451095, 1.5825824175824177, 0.07980076505153338, 2.637637362637363, 0.016348333774987508], [0.5285284715284715, 1.0, 0.4260617692505883, 1.057056943056943, 0.1742938886952559, 1.5855854145854147, 0.07940474015581221, 2.642642357642358, 0.016219595474303874], [0.5295294705294704, 1.0, 0.4254635404266203, 1.0590589410589408, 0.17370604962412164, 1.5885884115884117, 0.07901059960207794, 2.6476473526473527, 0.01609185283773747], [0.5305304695304695, 1.0, 0.42486679941557726, 1.061060939060939, 0.17312023853656772, 1.5915914085914087, 0.07861833485986087, 2.652652347652348, 0.01596509818537018], [0.5315314685314685, 1.0, 0.4242715447824174, 1.063062937062937, 0.17253644979756125, 1.5945944055944057, 0.07822793743928996, 2.657657342657343, 0.015839323896681752], [0.5325324675324674, 1.0, 0.4236777750956739, 1.0650649350649348, 0.17195467779152268, 1.5975974025974027, 0.07783939889090889, 2.6626623376623377, 0.01571452241009158], [0.5335334665334664, 1.0, 0.42308548892745035, 1.067066933066933, 0.17137491692227183, 1.6006003996003997, 0.07745271080549344, 2.667667332667333, 0.015590686222504202], [0.5345344655344655, 1.0, 0.42249468485341773, 1.069068931068931, 0.17079716161297412, 1.6036033966033967, 0.07706786481386922, 2.672672327672328, 0.015467807888858147], [0.5355354645354644, 1.0, 0.42190536145281204, 1.0710709290709288, 0.17022140630608668, 1.6066063936063937, 0.07668485258673079, 2.6776773226773227, 0.01534588002167837], [0.5365364635364634, 1.0, 0.421317517308429, 1.073072927072927, 0.1696476454633051, 1.6096093906093907, 0.07630366583446119, 2.682682317682318, 0.015224895290632076], [0.5375374625374625, 1.0, 0.4207311510066225, 1.075074925074925, 0.16907587356551032, 1.612612387612388, 0.07592429630695269, 2.687687312687313, 0.015104846422088045], [0.5385384615384614, 1.0, 0.4201462611372998, 1.0770769230769228, 0.16850608511271495, 1.615615384615385, 0.0755467357934281, 2.6926923076923077, 0.014985726198679362], [0.5395394605394604, 1.0, 0.41956284629391905, 1.079078921078921, 0.16793827462401117, 1.618618381618382, 0.07517097612226312, 2.697697302697303, 0.014867527458869458], [0.5405404595404595, 1.0, 0.4189809050734853, 1.081080919080919, 0.16737243663751739, 1.621621378621379, 0.07479700916080952, 2.702702297702298, 0.01475024309652158], [0.5415414585414584, 1.0, 0.4184004360765475, 1.0830829170829168, 0.16680856571032587, 1.624624375624376, 0.07442482681521902, 2.7077072927072927, 0.014633866060471597], [0.5425424575424574, 1.0, 0.41782143790719495, 1.085084915084915, 0.1662466564184505, 1.627627372627373, 0.07405442103026821, 2.712712287712288, 0.014518389354104], [0.5435434565434565, 1.0, 0.417243909173054, 1.087086913086913, 0.1656867033567744, 1.63063036963037, 0.0736857837891841, 2.717717282717283, 0.014403806034931368], [0.5445444555444554, 1.0, 0.41666784848528476, 1.0890889110889108, 0.1651287011389982, 1.633633366633367, 0.0733189071134707, 2.722722277722278, 0.014290109214176894], [0.5455454545454544, 1.0, 0.41609325445857703, 1.091090909090909, 0.16457264439758795, 1.6366363636363639, 0.07295378306273645, 2.727727272727273, 0.014177292056360308], [0.5465464535464535, 1.0, 0.41552012571114855, 1.093092907092907, 0.16401852778372392, 1.6396393606393609, 0.07259040373452202, 2.732732267732268, 0.014065347778886862], [0.5475474525474524, 1.0, 0.41494846086474046, 1.0950949050949048, 0.16346634596724824, 1.6426423576423579, 0.07222876126412968, 2.737737262737263, 0.013954269651639609], [0.5485484515484514, 1.0, 0.41437825854461435, 1.0970969030969029, 0.16291609363661486, 1.6456453546453549, 0.07186884782445277, 2.742742257742258, 0.013844050996574734], [0.5495494505494505, 1.0, 0.41380951737954846, 1.099098901098901, 0.1623677654988376, 1.6486483516483519, 0.07151065562580643, 2.747747252747253, 0.013734685187320123], [0.5505504495504494, 1.0, 0.4132422360018353, 1.1011008991008988, 0.1618213562794395, 1.6516513486513489, 0.07115417691575908, 2.752752247752248, 0.013626165648776918], [0.5515514485514484, 1.0, 0.41267641304727776, 1.1031028971028969, 0.16127686072240194, 1.6546543456543459, 0.07079940397896449, 2.757757242757243, 0.0135184858567243], [0.5525524475524475, 1.0, 0.4121120471551859, 1.105104895104895, 0.1607342735901143, 1.6576573426573429, 0.07044632913699482, 2.762762237762238, 0.013411639337427199], [0.5535534465534464, 1.0, 0.41154913696837375, 1.1071068931068928, 0.16019358966332345, 1.6606603396603399, 0.07009494474817449, 2.767767232767233, 0.013305619667247106], [0.5545544455544454, 1.0, 0.41098768113315537, 1.1091088911088909, 0.15965480374108357, 1.6636633366633369, 0.06974524320741476, 2.772772227772228, 0.01320042047225588], [0.5555554445554445, 1.0, 0.4104276782993434, 1.111110889110889, 0.1591179106407062, 1.6666663336663339, 0.06939721694604918, 2.777777222777223, 0.013096035427852537], [0.5565564435564434, 1.0, 0.4098691271202441, 1.1131128871128868, 0.15858290519771026, 1.6696693306693309, 0.06905085843166972, 2.782782217782218, 0.01299245825838303], [0.5575574425574424, 1.0, 0.40931202625265456, 1.1151148851148849, 0.15804978226577232, 1.6726723276723279, 0.06870616016796369, 2.787787212787213, 0.01288968273676295], [0.5585584415584415, 1.0, 0.40875637435685974, 1.117116883116883, 0.15751853671667723, 1.6756753246753249, 0.06836311469455165, 2.792792207792208, 0.012787702684103149], [0.5595594405594405, 1.0, 0.408202170096629, 1.119118881118881, 0.15698916344026892, 1.6786783216783219, 0.06802171458682578, 2.797797202797203, 0.012686511969338253], [0.5605604395604394, 1.0, 0.4076494121392128, 1.1211208791208789, 0.15646165734440093, 1.6816813186813189, 0.06768195245578938, 2.802802197802198, 0.012586104508858095], [0.5615614385614385, 1.0, 0.4070980991553401, 1.123122877122877, 0.15593601335488766, 1.6846843156843159, 0.06734382094789672, 2.807807192807193, 0.01248647426614193], [0.5625624375624375, 1.0, 0.4065482298192145, 1.125124875124875, 0.1554122264154555, 1.6876873126873129, 0.06700731274489408, 2.812812187812188, 0.012387615251395537], [0.5635634365634364, 1.0, 0.4059998028085109, 1.1271268731268729, 0.15489029148769387, 1.6906903096903099, 0.06667242056366122, 2.817817182817183, 0.012289521521191098], [0.5645644355644355, 1.0, 0.4054528168043734, 1.129128871128871, 0.15437020355100758, 1.6936933066933069, 0.0663391371560539, 2.8228221778221783, 0.012192187178109902], [0.5655654345654345, 1.0, 0.4049072704914111, 1.131130869130869, 0.15385195760256754, 1.6966963036963039, 0.06600745530874678, 2.827827172827173, 0.012095606370387759], [0.5665664335664334, 1.0, 0.40436316255769533, 1.1331328671328669, 0.1533355486572634, 1.6996993006993009, 0.06567736784307765, 2.832832167832168, 0.011999773291563208], [0.5675674325674325, 1.0, 0.40382049169475603, 1.135134865134865, 0.15282097174765524, 1.7027022977022979, 0.06534886761489156, 2.8378371628371633, 0.011904682180128452], [0.5685684315684315, 1.0, 0.4032792565975796, 1.137136863136863, 0.15230822192392576, 1.7057052947052949, 0.06502194751438672, 2.842842157842158, 0.011810327319182913], [0.5695694305694304, 1.0, 0.4027394559646049, 1.1391388611388609, 0.15179729425383276, 1.7087082917082919, 0.06469660046596035, 2.847847152847153, 0.011716703036089612], [0.5705704295704295, 1.0, 0.4022010884977204, 1.141140859140859, 0.15128818382266193, 1.7117112887112889, 0.06437281942805548, 2.8528521478521482, 0.011623803702134054], [0.5715714285714285, 1.0, 0.401664152902261, 1.143142857142857, 0.15078088573317905, 1.7147142857142859, 0.06405059739300871, 2.857857142857143, 0.01153162373218588], [0.5725724275724274, 1.0, 0.40112864788700503, 1.1451448551448549, 0.15027539510558335, 1.7177172827172829, 0.06372992738689853, 2.862862137862138, 0.011440157584363064], [0.5735734265734265, 1.0, 0.4005945721641713, 1.147146853146853, 0.14977170707746035, 1.7207202797202799, 0.0634108024693942, 2.8678671328671332, 0.011349399759698732], [0.5745744255744255, 1.0, 0.4000619244494152, 1.149148851148851, 0.14926981680373505, 1.7237232767232769, 0.06309321573360577, 2.872872127872128, 0.01125934480181058], [0.5755754245754244, 1.0, 0.39953070346182695, 1.1511508491508489, 0.1487697194566255, 1.7267262737262739, 0.06277716030593448, 2.877877122877123, 0.01116998729657282], [0.5765764235764235, 1.0, 0.399000907923927, 1.153152847152847, 0.14827141022559623, 1.7297292707292709, 0.06246262934592398, 2.8828821178821182, 0.011081321871790676], [0.5775774225774225, 1.0, 0.39847253656166426, 1.155154845154845, 0.1477748843173121, 1.7327322677322679, 0.062149616046112285, 2.887887112887113, 0.010993343196877422], [0.5785784215784214, 1.0, 0.3979455881044121, 1.1571568431568429, 0.14728013695559186, 1.7357352647352648, 0.0618381136318845, 2.892892107892108, 0.01090604598253391], [0.5795794205794205, 1.0, 0.39742006128496593, 1.159158841158841, 0.1467871633813628, 1.7387382617382618, 0.06152811536132615, 2.8978971028971032, 0.010819424980430549], [0.5805804195804195, 1.0, 0.3968959548395396, 1.161160839160839, 0.14629595885261434, 1.7417412587412588, 0.06121961452507727, 2.902902097902098, 0.010733474982891802], [0.5815814185814184, 1.0, 0.3963732675077634, 1.1631628371628369, 0.14580651864435293, 1.7447442557442558, 0.06091260444618719, 2.907907092907093, 0.010648190822583094], [0.5825824175824175, 1.0, 0.3958519980326797, 1.165164835164835, 0.14531883804855608, 1.7477472527472528, 0.06060707847996998, 2.912912087912088, 0.010563567372200131], [0.5835834165834165, 1.0, 0.3953321451607406, 1.167166833166833, 0.14483291237412768, 1.7507502497502498, 0.06030303001386076, 2.917917082917083, 0.010479599544160662], [0.5845844155844154, 1.0, 0.39481370764180473, 1.1691688311688309, 0.14434873694685224, 1.7537532467532468, 0.06000045246727245, 2.9229220779220784, 0.010396282290298616], [0.5855854145854145, 1.0, 0.39429668422913455, 1.171170829170829, 0.14386630710935058, 1.7567562437562438, 0.05969933929145341, 2.927927072927073, 0.0103136106015606], [0.5865864135864135, 1.0, 0.3937810736793934, 1.173172827172827, 0.14338561822103435, 1.7597592407592408, 0.0593996839693457, 2.932932067932068, 0.010231579507704732], [0.5875874125874125, 1.0, 0.39326687475264205, 1.175174825174825, 0.14290666565806212, 1.7627622377622378, 0.05910148001544404, 2.9379370629370634, 0.010150184077001871], [0.5885884115884115, 1.0, 0.3927540862123356, 1.177176823176823, 0.14242944481329411, 1.765765234765235, 0.05880472097565541, 2.942942057942058, 0.01006941941593909], [0.5895894105894105, 1.0, 0.3922427068253216, 1.179178821178821, 0.14195395109624853, 1.768768231768232, 0.058509400427159394, 2.947947052947053, 0.009989280668925491], [0.5905904095904095, 1.0, 0.39173273536183567, 1.181180819180819, 0.1414801799330571, 1.771771228771229, 0.058215511978269165, 2.9529520479520484, 0.009909763018000272], [0.5915914085914085, 1.0, 0.3912241705954989, 1.183182817182817, 0.1410081267664211, 1.774774225774226, 0.05792304926829311, 2.957957042957043, 0.00983086168254307], [0.5925924075924075, 1.0, 0.3907170113033163, 1.185184815184815, 0.1405377870555677, 1.777777222777223, 0.05763200596739717, 2.962962037962038, 0.009752571918986578], [0.5935934065934065, 1.0, 0.39021125626567194, 1.187186813186813, 0.14006915627620595, 1.78078021978022, 0.05734237577646792, 2.9679670329670333, 0.009674889020531319], [0.5945944055944055, 1.0, 0.38970690426632715, 1.189188811188811, 0.1396022299204836, 1.783783216783217, 0.057054152426976174, 2.972972027972028, 0.009597808316862706], [0.5955954045954045, 1.0, 0.389203954092417, 1.191190809190809, 0.13913700349694352, 1.786786213786214, 0.05676732968084129, 2.977977022977023, 0.009521325173870237], [0.5965964035964035, 1.0, 0.3887024045344483, 1.193192807192807, 0.1386734725304806, 1.789789210789211, 0.056481901330296215, 2.9829820179820183, 0.009445434993368909], [0.5975974025974025, 1.0, 0.3882022543862954, 1.195194805194805, 0.13821163256229863, 1.792792207792208, 0.056197861197753086, 2.987987012987013, 0.009370133212822766], [0.5985984015984015, 1.0, 0.38770350244519836, 1.197196803196803, 0.13775147914986746, 1.795795204795205, 0.05591520313566956, 2.992992007992008, 0.009295415305070595], [0.5995994005994005, 1.0, 0.3872061475117592, 1.199198801198801, 0.13729300786688023, 1.798798201798202, 0.05563392102641578, 2.9979970029970033, 0.00922127677805377], [0.6006003996003995, 1.0, 0.38671018838994026, 1.201200799200799, 0.1368362143032109, 1.801801198801199, 0.055354008782141854, 3.003001998001998, 0.009147713174546154], [0.6016013986013985, 1.0, 0.38621562388705954, 1.203202797202797, 0.1363810940648717, 1.804804195804196, 0.05507546034464621, 3.008006993006993, 0.009074720071886165], [0.6026023976023975, 1.0, 0.3857224528137893, 1.205204795204795, 0.1359276427739707, 1.807807192807193, 0.05479826968524448, 3.0130119880119883, 0.009002293081710862], [0.6036033966033965, 1.0, 0.3852306739841525, 1.207206793206793, 0.13547585606867044, 1.81081018981019, 0.054522430804638915, 3.018016983016983, 0.008930427849692127], [0.6046043956043955, 1.0, 0.3847402862155209, 1.209208791208791, 0.13502572960314474, 1.813813186813187, 0.05424793773278861, 3.0230219780219785, 0.008859120055274882], [0.6056053946053945, 1.0, 0.3842512883286104, 1.211210789210789, 0.13457725904753823, 1.816816183816184, 0.05397478452878045, 3.0280269730269733, 0.008788365411417321], [0.6066063936063935, 1.0, 0.38376367914748033, 1.213212787212787, 0.1341304400879236, 1.819819180819181, 0.053702965280700135, 3.033031968031968, 0.008718159664333196], [0.6076073926073925, 1.0, 0.3832774574995288, 1.215214785214785, 0.13368526842626086, 1.822822177822178, 0.0534324741055046, 3.0380369630369635, 0.008648498593236046], [0.6086083916083915, 1.0, 0.3827926222154909, 1.217216783216783, 0.13324173978035556, 1.825825174825175, 0.05316330514889453, 3.0430419580419583, 0.00857937801008549], [0.6096093906093905, 1.0, 0.38230917212943605, 1.219218781218781, 0.13279984988381774, 1.828828171828172, 0.0528954525851877, 3.048046953046953, 0.008510793759335392], [0.6106103896103895, 1.0, 0.3818271060787636, 1.221220779220779, 0.1323595944860211, 1.831831168831169, 0.05262891061719282, 3.0530519480519485, 0.008442741717684048], [0.6116113886113885, 1.0, 0.3813464229042029, 1.223222777222777, 0.13192096935206163, 1.834834165834166, 0.05236367347608409, 3.0580569430569433, 0.008375217793826308], [0.6126123876123875, 1.0, 0.3808671214498074, 1.225224775224775, 0.1314839702627173, 1.837837162837163, 0.05209973542127643, 3.063061938061938, 0.008308217928207576], [0.6136133866133865, 1.0, 0.38038920056295406, 1.227226773226773, 0.1310485930144073, 1.84084015984016, 0.05183709074030111, 3.0680669330669335, 0.008241738092779772], [0.6146143856143855, 1.0, 0.37991265909433963, 1.229228771228771, 0.1306148334191516, 1.843843156843157, 0.05157573374868218, 3.0730719280719283, 0.008175774290759157], [0.6156153846153845, 1.0, 0.379437495897978, 1.231230769230769, 0.13018268730453075, 1.846846153846154, 0.05131565878981348, 3.078076923076923, 0.008110322556386043], [0.6166163836163835, 1.0, 0.37896370983119776, 1.233232767232767, 0.12975215051364566, 1.849849150849151, 0.05105686023483611, 3.0830819180819184, 0.00804537895468637], [0.6176173826173825, 1.0, 0.37849129975463924, 1.235234765234765, 0.1293232189050776, 1.852852147852148, 0.05079933248251665, 3.0880869130869133, 0.007980939581235144], [0.6186183816183816, 1.0, 0.37802026453225096, 1.2372367632367631, 0.12889588835284857, 1.855855144855145, 0.05054306995912601, 3.093091908091908, 0.007917000561921687], [0.6196193806193805, 1.0, 0.3775506030312889, 1.239238761238761, 0.12847015474638127, 1.858858141858142, 0.05028806711831861, 3.0980969030969034, 0.007853558052716736], [0.6206203796203795, 1.0, 0.37708231412231197, 1.241240759240759, 0.1280460139904597, 1.861861138861139, 0.050034318441012575, 3.1031018981018983, 0.007790608239441332], [0.6216213786213786, 1.0, 0.3766153966791794, 1.2432427572427571, 0.12762346200519004, 1.864864135864136, 0.049781818435270055, 3.108106893106893, 0.007728147337537522], [0.6226223776223775, 1.0, 0.3761498495790498, 1.245244755244755, 0.12720249472596093, 1.867867132867133, 0.049530561636178576, 3.1131118881118884, 0.007666171591840818], [0.6236233766233765, 1.0, 0.3756856717023759, 1.247246753246753, 0.12678310810340482, 1.87087012987013, 0.049280542605732565, 3.1181168831168833, 0.0076046772763544365], [0.6246243756243756, 1.0, 0.37522286193290366, 1.2492487512487511, 0.12636529810335861, 1.873873126873127, 0.0490317559327158, 3.1231218781218786, 0.007543660694025301], [0.6256253746253745, 1.0, 0.37476141915766914, 1.251250749250749, 0.12594906070682513, 1.876876123876124, 0.048784196232584204, 3.1281268731268734, 0.007483118176521767], [0.6266263736263735, 1.0, 0.37430134226699535, 1.253252747252747, 0.12553439190993448, 1.879879120879121, 0.048537858147349414, 3.1331318681318683, 0.007423046084013078], [0.6276273726273726, 1.0, 0.373842630154491, 1.2552547452547451, 0.12512128772390535, 1.882882117882118, 0.048292736345462606, 3.1381368631368636, 0.007363440804950537], [0.6286283716283715, 1.0, 0.3733852817170453, 1.257256743256743, 0.1247097441750066, 1.885885114885115, 0.04804882552169938, 3.1431418581418584, 0.007304298755850394], [0.6296293706293705, 1.0, 0.3729292958548283, 1.259258741258741, 0.12429975730451948, 1.888888111888112, 0.04780612039704471, 3.1481468531468533, 0.007245616381078394], [0.6306303696303696, 1.0, 0.37247467147128555, 1.2612607392607391, 0.12389132316869886, 1.891891108891109, 0.047564615718578826, 3.1531518481518486, 0.007187390152636005], [0.6316313686313685, 1.0, 0.3720214074731372, 1.263262737262737, 0.12348443783873606, 1.894894105894106, 0.04732430625936345, 3.1581568431568434, 0.007129616569948332], [0.6326323676323675, 1.0, 0.37156950277037504, 1.265264735264735, 0.12307909740072032, 1.897897102897103, 0.04708518681832875, 3.1631618381618383, 0.007072292159653643], [0.6336333666333666, 1.0, 0.37111895627625935, 1.2672667332667331, 0.12267529795560177, 1.9009000999001, 0.04684725222016062, 3.1681668331668336, 0.007015413475394578], [0.6346343656343655, 1.0, 0.37066976690731723, 1.269268731268731, 0.12227303561915348, 1.903903096903097, 0.04661049731518884, 3.1731718281718284, 0.0069589770976109105], [0.6356353646353645, 1.0, 0.3702219335833384, 1.271270729270729, 0.12187230652193448, 1.906906093906094, 0.04637491697927551, 3.1781768231768233, 0.006902979633333998], [0.6366363636363636, 1.0, 0.36977545522737454, 1.2732727272727271, 0.12147310680925205, 1.909909090909091, 0.04614050611370423, 3.1831818181818186, 0.006847417715982781], [0.6376373626373625, 1.0, 0.36933033076573535, 1.275274725274725, 0.12107543264112518, 1.912912087912088, 0.045907259645069615, 3.1881868131868134, 0.006792288005161385], [0.6386383616383615, 1.0, 0.3688865591279863, 1.277276723276723, 0.12067928019224718, 1.915915084915085, 0.04567517252516764, 3.1931918081918083, 0.0067375871864583025], [0.6396393606393606, 1.0, 0.36844413924694597, 1.279278721278721, 0.12028464565194917, 1.918918081918082, 0.045444239730886314, 3.1981968031968036, 0.006683311971247118], [0.6406403596403595, 1.0, 0.3680030700586837, 1.281280719280719, 0.11989152522416335, 1.9219210789210792, 0.045214456264096974, 3.2032017982017984, 0.006629459096488797], [0.6416413586413585, 1.0, 0.36756335050251765, 1.283282717282717, 0.11949991512738645, 1.9249240759240762, 0.04498581715154608, 3.2082067932067933, 0.006576025324535523], [0.6426423576423576, 1.0, 0.36712497952101086, 1.285284715284715, 0.11910981159464337, 1.9279270729270732, 0.04475831744474759, 3.2132117882117885, 0.006523007442936036], [0.6436433566433565, 1.0, 0.3666879560599699, 1.287286713286713, 0.11872121087345094, 1.9309300699300702, 0.04453195221987587, 3.2182167832167834, 0.0064704022642425125], [0.6446443556443555, 1.0, 0.3662522790684412, 1.289288711288711, 0.11833410922578187, 1.9339330669330672, 0.04430671657765916, 3.2232217782217782, 0.006418206625818908], [0.6456453546453546, 1.0, 0.3658179474987096, 1.291290709290709, 0.11794850292802862, 1.9369360639360642, 0.04408260564327347, 3.2282267732267735, 0.00636641738965086], [0.6466463536463535, 1.0, 0.36538496030629564, 1.293292707292707, 0.11756438827096792, 1.9399390609390612, 0.04385961456623715, 3.2332317682317684, 0.006315031442157001], [0.6476473526473525, 1.0, 0.36495331644995216, 1.295294705294705, 0.11718176155972479, 1.9429420579420582, 0.043637738520305794, 3.2382367632367637, 0.006264045694001765], [0.6486483516483516, 1.0, 0.3645230148916633, 1.297296703296703, 0.11680061911373694, 1.9459450549450552, 0.04341697270336792, 3.2432417582417585, 0.006213457079909681], [0.6496493506493506, 1.0, 0.36409405459664046, 1.2992987012987012, 0.11642095726671985, 1.9489480519480522, 0.04319731233734093, 3.2482467532467534, 0.006163262558481065], [0.6506503496503495, 1.0, 0.3636664345333207, 1.301300699300699, 0.11604277236663098, 1.9519510489510492, 0.04297875266806778, 3.2532517482517487, 0.006113459112009184], [0.6516513486513485, 1.0, 0.36324015367336404, 1.303302697302697, 0.1156660607756347, 1.9549540459540462, 0.042761288965214014, 3.2582567432567435, 0.006064043746298823], [0.6526523476523476, 1.0, 0.36281521099165137, 1.3053046953046952, 0.11529081887006777, 1.9579570429570432, 0.04254491652216542, 3.2632617382617384, 0.006015013490486274], [0.6536533466533465, 1.0, 0.3623916054662813, 1.307306693306693, 0.1149170430404038, 1.9609600399600402, 0.042329630655926175, 3.2682667332667337, 0.005966365396860734], [0.6546543456543455, 1.0, 0.36196933607856785, 1.309308691308691, 0.11454472969121916, 1.9639630369630372, 0.04211542670701746, 3.2732717282717285, 0.005918096540687078], [0.6556553446553446, 1.0, 0.3615484018130387, 1.3113106893106892, 0.11417387524115792, 1.9669660339660342, 0.041902300039376644, 3.2782767232767234, 0.005870204020030033], [0.6566563436563435, 1.0, 0.3611288016574315, 1.313312687312687, 0.11380447612289775, 1.9699690309690312, 0.0416902460402569, 3.2832817182817187, 0.005822684955579705], [0.6576573426573425, 1.0, 0.3607105346026928, 1.315314685314685, 0.11343652878311536, 1.9729720279720282, 0.041479260120127426, 3.2882867132867135, 0.00577553649047848], [0.6586583416583416, 1.0, 0.3602935996429747, 1.3173166833166832, 0.11307002968245224, 1.9759750249750252, 0.04126933771257408, 3.2932917082917084, 0.005728755790149263], [0.6596593406593405, 1.0, 0.35987799577563295, 1.319318681318681, 0.11270497529548103, 1.9789780219780222, 0.04106047427420055, 3.2982967032967037, 0.005682340042125066], [0.6606603396603395, 1.0, 0.359463722001224, 1.321320679320679, 0.1123413621106712, 1.9819810189810192, 0.040852665284530014, 3.3033016983016985, 0.005636286455879916], [0.6616613386613386, 1.0, 0.35905077732350327, 1.3233226773226772, 0.11197918663035554, 1.9849840159840162, 0.040645906245907346, 3.3083066933066934, 0.005590592262661105], [0.6626623376623375, 1.0, 0.35863916074942204, 1.325324675324675, 0.11161844537069632, 1.9879870129870132, 0.04044019268340168, 3.3133116883116887, 0.005545254715322713], [0.6636633366633365, 1.0, 0.35822887128912584, 1.327326673326673, 0.11125913486165193, 1.9909900099900102, 0.04023552014470969, 3.3183166833166835, 0.005500271088160463], [0.6646643356643356, 1.0, 0.3578199079559511, 1.3293286713286712, 0.11090125164694341, 1.9939930069930072, 0.0400318842000591, 3.3233216783216784, 0.005455638676747834], [0.6656653346653345, 1.0, 0.3574122697664237, 1.331330669330669, 0.11054479228402118, 1.9969960039960042, 0.03982928044211289, 3.3283266733266736, 0.005411354797773492], [0.6666663336663335, 1.0, 0.35700595574025623, 1.333332667332667, 0.11018975334403204, 1.9999990009990014, 0.03962770448587386, 3.3333316683316685, 0.005367416788879948], [0.6676673326673326, 1.0, 0.3566009649003454, 1.3353346653346652, 0.10983613141178612, 2.003001998001998, 0.03942715196858979, 3.338336663336664, 0.005323822008503513], [0.6686683316683315, 1.0, 0.35619729627277014, 1.337336663336663, 0.10948392308572391, 2.006004995004995, 0.03922761854965891, 3.3433416583416586, 0.005280567835715467], [0.6696693306693305, 1.0, 0.3557949488867883, 1.339338661338661, 0.10913312497788377, 2.009007992007992, 0.03902909991053606, 3.3483466533466535, 0.00523765167006452], [0.6706703296703296, 1.0, 0.35539392177483614, 1.3413406593406592, 0.10878373371386932, 2.012010989010989, 0.03883159175463912, 3.353351648351649, 0.005195070931420433], [0.6716713286713285, 1.0, 0.35499421397252456, 1.343342657342657, 0.10843574593281666, 2.015013986013986, 0.03863508980725621, 3.3583566433566436, 0.005152823059818934], [0.6726723276723275, 1.0, 0.3545958245186364, 1.345344655344655, 0.10808915828736243, 2.018016983016983, 0.03843958981545288, 3.3633616383616385, 0.0051109055153077875], [0.6736733266733266, 1.0, 0.35419875245512633, 1.3473466533466532, 0.1077439674436113, 2.02101998001998, 0.03824508754798037, 3.3683666333666338, 0.005069315777794111], [0.6746743256743255, 1.0, 0.3538029968271159, 1.349348651348651, 0.10740017008110424, 2.024022977022977, 0.03805157879518377, 3.3733716283716286, 0.005028051346892851], [0.6756753246753245, 1.0, 0.35340855668289284, 1.351350649350649, 0.10705776289278637, 2.027025974025974, 0.03785905936891107, 3.3783766233766235, 0.00498710974177647], [0.6766763236763236, 1.0, 0.35301543107390804, 1.3533526473526472, 0.10671674258497495, 2.030028971028971, 0.03766752510242249, 3.3833816183816188, 0.004946488501025795], [0.6776773226773226, 1.0, 0.3526236190547742, 1.3553546453546452, 0.10637710587732821, 2.033031968031968, 0.037476971850300224, 3.3883866133866136, 0.004906185182482034], [0.6786783216783215, 1.0, 0.35223311968326204, 1.357356643356643, 0.10603884950281332, 2.036034965034965, 0.03728739548835882, 3.3933916083916085, 0.004866197363099954], [0.6796793206793206, 1.0, 0.3518439320202996, 1.3593586413586412, 0.1057019702076752, 2.039037962037962, 0.03709879191355584, 3.3983966033966038, 0.004826522638802207], [0.6806803196803196, 1.0, 0.35145605512996897, 1.3613606393606392, 0.10536646475140525, 2.042040959040959, 0.03691115704390311, 3.4034015984015986, 0.004787158624334797], [0.6816813186813185, 1.0, 0.35106948807950455, 1.363362637362637, 0.10503232990670994, 2.045043956043956, 0.03672448681837836, 3.4084065934065935, 0.004748102953123683], [0.6826823176823176, 1.0, 0.35068422993929077, 1.3653646353646351, 0.10469956245948, 2.048046953046953, 0.036538777196837284, 3.4134115884115888, 0.004709353277132489], [0.6836833166833166, 1.0, 0.35030027978285916, 1.3673666333666332, 0.10436815920875943, 2.05104995004995, 0.03635402415992619, 3.4184165834165836, 0.00467090726672135], [0.6846843156843155, 1.0, 0.3499176366868876, 1.369368631368631, 0.10403811696671472, 2.054052947052947, 0.03617022370899494, 3.4234215784215785, 0.004632762610506847], [0.6856853146853146, 1.0, 0.3495362997311965, 1.3713706293706291, 0.10370943255860415, 2.057055944055944, 0.035987371866010365, 3.4284265734265738, 0.004594917015223045], [0.6866863136863136, 1.0, 0.34915626799874755, 1.3733726273726272, 0.10338210282274732, 2.060058941058941, 0.03580546467347031, 3.4334315684315686, 0.00455736820558363], [0.6876873126873125, 1.0, 0.3487775405756413, 1.375374625374625, 0.10305612461049465, 2.063061938061938, 0.03562449819431784, 3.438436563436564, 0.004520113924145107], [0.6886883116883116, 1.0, 0.34840011655111486, 1.3773766233766231, 0.10273149478619706, 2.066064935064935, 0.03544446851185607, 3.4434415584415587, 0.00448315193117109], [0.6896893106893106, 1.0, 0.3480239950175392, 1.3793786213786212, 0.10240821022717607, 2.069067932067932, 0.035265371729663486, 3.4484465534465536, 0.00444648000449765], [0.6906903096903095, 1.0, 0.3476491750704186, 1.381380619380619, 0.10208626782369341, 2.072070929070929, 0.03508720397150943, 3.453451548451549, 0.004410095939399706], [0.6916913086913086, 1.0, 0.34727565580838654, 1.3833826173826171, 0.10176566447892131, 2.075073926073926, 0.034909961381270435, 3.4584565434565437, 0.00437399754845849], [0.6926923076923076, 1.0, 0.34690343633320414, 1.3853846153846152, 0.10144639710891269, 2.078076923076923, 0.034733640122846555, 3.4634615384615386, 0.0043381826614300335], [0.6936933066933065, 1.0, 0.3465325157497596, 1.387386613386613, 0.1011284626425715, 2.08107992007992, 0.03455823638007845, 3.468466533466534, 0.004302649125114688], [0.6946943056943056, 1.0, 0.34616289316606313, 1.3893886113886111, 0.10081185802162308, 2.084082917082917, 0.034383746356664774, 3.4734715284715287, 0.004267394803227682], [0.6956953046953046, 1.0, 0.3457945676932471, 1.3913906093906092, 0.10049658020058488, 2.087085914085914, 0.03421016627608002, 3.4784765234765236, 0.004232417576270677], [0.6966963036963035, 1.0, 0.34542753844556334, 1.393392607392607, 0.10018262614673708, 2.090088911088911, 0.034037492381492736, 3.483481518481519, 0.004197715341404351], [0.6976973026973026, 1.0, 0.3450618045403806, 1.3953946053946051, 0.09986999284009349, 2.093091908091908, 0.0338657209356843, 3.4884865134865137, 0.004163286012321975], [0.6986983016983016, 1.0, 0.34469736509818244, 1.3973966033966032, 0.09955867727337231, 2.096094905094905, 0.03369484822096796, 3.4934915084915086, 0.004129127519123979], [0.6996993006993005, 1.0, 0.34433421924256596, 1.399398601398601, 0.09924867645196753, 2.099097902097902, 0.033524870539108416, 3.498496503496504, 0.004095237808193516], [0.7007002997002996, 1.0, 0.3439723661002383, 1.4014005994005991, 0.09893998739391972, 2.102100899100899, 0.0333557842112417, 3.5035014985014987, 0.004061614842072989], [0.7017012987012986, 1.0, 0.34361180480101583, 1.4034025974025972, 0.09863260712988774, 2.105103896103896, 0.03318758557779568, 3.5085064935064936, 0.004028256599341565], [0.7027022977022975, 1.0, 0.34325253447782145, 1.405404595404595, 0.09832653270311989, 2.108106893106893, 0.03302027099841075, 3.513511488511489, 0.0039951610744936444], [0.7037032967032966, 1.0, 0.34289455426668236, 1.4074065934065931, 0.0980217611694257, 2.11110989010989, 0.032853836851861065, 3.5185164835164837, 0.003962326277818292], [0.7047042957042956, 1.0, 0.3425378633067288, 1.4094085914085912, 0.09771828959714725, 2.114112887112887, 0.03268827953597626, 3.5235214785214786, 0.003929750235279611], [0.7057052947052945, 1.0, 0.3421824607401908, 1.411410589410589, 0.0974161150671315, 2.117115884115884, 0.03252359546756331, 3.528526473526474, 0.0038974309883980643], [0.7067062937062936, 1.0, 0.3418283457123972, 1.4134125874125871, 0.09711523467270176, 2.120118881118881, 0.03235978108232912, 3.5335314685314687, 0.0038653665941327372], [0.7077072927072926, 1.0, 0.3414755173717726, 1.4154145854145852, 0.09681564551962987, 2.123121878121878, 0.032196832834803325, 3.538536463536464, 0.0038335551247645106], [0.7087082917082916, 1.0, 0.3411239748698363, 1.4174165834165833, 0.09651734472610843, 2.126124875124875, 0.0320347471982616, 3.543541458541459, 0.0038019946677801723], [0.7097092907092906, 1.0, 0.3407737173611997, 1.4194185814185811, 0.09622032942272307, 2.129127872127872, 0.03187352066464925, 3.5485464535464537, 0.0037706833257574383], [0.7107102897102896, 1.0, 0.3404247440035638, 1.4214205794205792, 0.09592459675242465, 2.132130869130869, 0.03171314974450534, 3.553551448551449, 0.003739619216250871], [0.7117112887112886, 1.0, 0.3400770539577186, 1.4234225774225773, 0.0956301438705021, 2.135133866133866, 0.03155363096688719, 3.558556443556444, 0.0037088004716787164], [0.7127122877122876, 1.0, 0.3397306463875393, 1.4254245754245751, 0.09533696794455478, 2.138136863136863, 0.03139496087929521, 3.5635614385614387, 0.0036782252392106164], [0.7137132867132866, 1.0, 0.3393855204599856, 1.4274265734265732, 0.09504506615446537, 2.14113986013986, 0.031237136047598184, 3.568566433566434, 0.0036478916806562214], [0.7147142857142856, 1.0, 0.33904167534509955, 1.4294285714285713, 0.09475443569237277, 2.144142857142857, 0.031080153055958983, 3.573571428571429, 0.003617797972354674], [0.7157152847152846, 1.0, 0.33869911021600285, 1.4314305694305691, 0.09446507376264494, 2.147145854145854, 0.030924008506760556, 3.5785764235764237, 0.0035879423050649705], [0.7167162837162836, 1.0, 0.338357824248896, 1.4334325674325672, 0.09417697758185219, 2.150148851148851, 0.030768699020532492, 3.583581418581419, 0.003558322883857196], [0.7177172827172826, 1.0, 0.3380178166230547, 1.4354345654345653, 0.09389014437874028, 2.153151848151848, 0.030614221235877804, 3.588586413586414, 0.0035289379280045996], [0.7187182817182816, 1.0, 0.3376790865208295, 1.4374365634365631, 0.0936045713942038, 2.156154845154845, 0.030460571809400223, 3.5935914085914087, 0.0034997856708765514], [0.7197192807192806, 1.0, 0.337341633127643, 1.4394385614385612, 0.09332025588125956, 2.159157842157842, 0.03030774741563179, 3.598596403596404, 0.0034708643598323177], [0.7207202797202796, 1.0, 0.3370054556319878, 1.4414405594405593, 0.09303719510502041, 2.162160839160839, 0.030155744746960908, 3.603601398601399, 0.0034421722561157053], [0.7217212787212786, 1.0, 0.33667055322542483, 1.4434425574425571, 0.0927553863426686, 2.165163836163836, 0.030004560513560787, 3.6086063936063937, 0.003413707634750516], [0.7227222777222776, 1.0, 0.33633692510258173, 1.4454445554445552, 0.09247482688342985, 2.168166833166833, 0.029854191443318193, 3.613611388611389, 0.0033854687844368484], [0.7237232767232766, 1.0, 0.33600457046114995, 1.4474465534465533, 0.09219551402854716, 2.17116983016983, 0.02970463428176265, 3.618616383616384, 0.003357454007448211], [0.7247242757242756, 1.0, 0.33567348850188355, 1.4494485514485511, 0.09191744509125481, 2.174172827172827, 0.029555885791995973, 3.6236213786213787, 0.0033296616195294527], [0.7257252747252746, 1.0, 0.33534367842859747, 1.4514505494505492, 0.09164061739675262, 2.177175824175824, 0.029407942754622253, 3.628626373626374, 0.0033020899497955107], [0.7267262737262736, 1.0, 0.3350151394481653, 1.4534525474525473, 0.09136502828218022, 2.180178821178821, 0.029260801967678184, 3.633631368631369, 0.0032747373406309486], [0.7277272727272726, 1.0, 0.3346878707705167, 1.4554545454545451, 0.09109067509659124, 2.183181818181818, 0.029114460246563702, 3.638636363636364, 0.003247602147590305], [0.7287282717282716, 1.0, 0.33436187160863695, 1.4574565434565432, 0.09081755520092807, 2.186184815184815, 0.028968914423973126, 3.643641358641359, 0.003220682739299231], [0.7297292707292706, 1.0, 0.33403714117856376, 1.4594585414585413, 0.0905456659679963, 2.189187812187812, 0.028824161349826585, 3.648646353646354, 0.003193977497356405], [0.7307302697302696, 1.0, 0.3337136786993858, 1.461460539460539, 0.09027500478243954, 2.192190809190809, 0.02868019789120179, 3.653651348651349, 0.0031674848162362426], [0.7317312687312686, 1.0, 0.3333914833932412, 1.4634625374625372, 0.09000556904071423, 2.195193806193806, 0.028537020932266323, 3.658656343656344, 0.0031412031031923626], [0.7327322677322676, 1.0, 0.3330705544853154, 1.4654645354645353, 0.08973735615106462, 2.198196803196803, 0.028394627374210137, 3.663661338661339, 0.003115130778161839], [0.7337332667332666, 1.0, 0.3327508912038392, 1.467466533466533, 0.08947036353349776, 2.2011998001998, 0.028253014135178472, 3.668666333666334, 0.003089266273670201], [0.7347342657342656, 1.0, 0.33243249278008724, 1.4694685314685312, 0.08920458861975876, 2.204202797202797, 0.028112178150205197, 3.673671328671329, 0.0030636080347372025], [0.7357352647352646, 1.0, 0.332115358448375, 1.4714705294705293, 0.08894002885330611, 2.207205794205794, 0.027972116371146483, 3.678676323676324, 0.0030381545187833266], [0.7367362637362636, 1.0, 0.3317994874460589, 1.473472527472527, 0.08867668168928697, 2.210208791208791, 0.027832825766614794, 3.683681318681319, 0.0030129041955370577], [0.7377372627372626, 1.0, 0.3314848790135329, 1.4754745254745252, 0.08841454459451281, 2.213211788211788, 0.027694303321913284, 3.688686313686314, 0.002987855546942871], [0.7387382617382616, 1.0, 0.33117153239422714, 1.4774765234765233, 0.08815361504743499, 2.216214785214785, 0.027556546038970575, 3.693691308691309, 0.0029630070670699695], [0.7397392607392607, 1.0, 0.33085944683460633, 1.4794785214785213, 0.08789389053812045, 2.219217782217782, 0.027419550936275818, 3.698696303696304, 0.002938357262021753], [0.7407402597402596, 1.0, 0.3305486215841674, 1.4814805194805192, 0.08763536856822779, 2.222220779220779, 0.027283315048814216, 3.703701298701299, 0.0029139046498459936], [0.7417412587412586, 1.0, 0.3302390558954389, 1.4834825174825172, 0.08737804665098288, 2.225223776223776, 0.02714783542800287, 3.708706293706294, 0.0028896477604457515], [0.7427422577422577, 1.0, 0.3299307490239776, 1.4854845154845153, 0.08712192231115522, 2.228226773226773, 0.027013109141626863, 3.713711288711289, 0.0028655851354909847], [0.7437432567432566, 1.0, 0.3296237002283677, 1.4874865134865132, 0.08686699308503404, 2.23122977022977, 0.026879133273775873, 3.718716283716284, 0.0028417153283308754], [0.7447442557442556, 1.0, 0.32931790877021894, 1.4894885114885112, 0.08661325652040464, 2.234232767232767, 0.02674590492478109, 3.723721278721279, 0.0028180369039068607], [0.7457452547452547, 1.0, 0.3290133739141646, 1.4914905094905093, 0.08636071017652469, 2.237235764235764, 0.02661342121115235, 3.728726273726274, 0.002794548438666353], [0.7467462537462536, 1.0, 0.32871009492785963, 1.4934925074925072, 0.08610935162410085, 2.240238761238761, 0.02648167926551586, 3.733731268731269, 0.0027712485204771553], [0.7477472527472526, 1.0, 0.32840807108197967, 1.4954945054945052, 0.08585917844526547, 2.243241758241758, 0.026350676236552042, 3.738736263736264, 0.0027481357485425683], [0.7487482517482517, 1.0, 0.328107301650218, 1.4974965034965033, 0.08561018823355324, 2.246244755244755, 0.026220409288933856, 3.743741258741259, 0.0027252087333171663], [0.7497492507492506, 1.0, 0.3278077859092851, 1.4994985014985012, 0.08536237859387791, 2.249247752247752, 0.02609087560326542, 3.748746253746254, 0.002702466096423266], [0.7507502497502496, 1.0, 0.3275095231389062, 1.5015004995004992, 0.08511574714250951, 2.252250749250749, 0.025962072376021012, 3.753751248751249, 0.00267990647056805], [0.7517512487512487, 1.0, 0.32721251262181944, 1.5035024975024973, 0.08487029150705125, 2.255253746253746, 0.025833996819484388, 3.758756243756244, 0.0026575284994613717], [0.7527522477522476, 1.0, 0.32691675364377437, 1.5055044955044952, 0.08462600932641672, 2.258256743256743, 0.02570664616168844, 3.763761238761239, 0.00263533083773421], [0.7537532467532466, 1.0, 0.3266222454935304, 1.5075064935064932, 0.08438289825080718, 2.26125974025974, 0.02558001764635516, 3.768766233766234, 0.002613312150857787], [0.7547542457542457, 1.0, 0.326328987462855, 1.5095084915084913, 0.08414095594168923, 2.264262737262737, 0.02545410853283609, 3.773771228771229, 0.0025914711150633388], [0.7557552447552446, 1.0, 0.3260369788465218, 1.5115104895104892, 0.08390018007177165, 2.267265734265734, 0.025328916096052874, 3.778776223776224, 0.0025698064172625223], [0.7567562437562436, 1.0, 0.32574621894230893, 1.5135124875124872, 0.08366056832498375, 2.270268731268731, 0.0252044376264384, 3.783781218781219, 0.002548316754968484], [0.7577572427572427, 1.0, 0.32545670705099733, 1.5155144855144853, 0.0834221183964527, 2.273271728271728, 0.025080670429878098, 3.788786213786214, 0.0025270008362175407], [0.7587582417582416, 1.0, 0.3251684424763698, 1.5175164835164832, 0.08318482799248123, 2.276274725274725, 0.024957611827651587, 3.793791208791209, 0.0025058573794915157], [0.7597592407592406, 1.0, 0.32488142452520763, 1.5195184815184812, 0.08294869483052607, 2.279277722277722, 0.02483525915637482, 3.798796203796204, 0.0024848851136406902], [0.7607602397602397, 1.0, 0.32459565250729105, 1.5215204795204793, 0.08271371663917554, 2.282280719280719, 0.0247136097679423, 3.803801198801199, 0.002464082777807385], [0.7617612387612386, 1.0, 0.32431112573539606, 1.5235224775224772, 0.0824798911581278, 2.285283716283716, 0.02459266102946988, 3.808806193806194, 0.002443449121350151], [0.7627622377622376, 1.0, 0.3240278435252932, 1.5255244755244752, 0.08224721613816927, 2.288286713286713, 0.024472410323237694, 3.813811188811189, 0.0024229829037685844], [0.7637632367632367, 1.0, 0.3237458051957458, 1.5275264735264733, 0.08201568934115284, 2.29128971028971, 0.02435285504663358, 3.818816183816184, 0.00240268289462875], [0.7647642357642356, 1.0, 0.323465010068509, 1.5295284715284712, 0.0817853085399764, 2.294292707292707, 0.0242339926120967, 3.823821178821179, 0.0023825478734892], [0.7657652347652346, 1.0, 0.3231854574683268, 1.5315304695304692, 0.08155607151856135, 2.297295704295704, 0.024115820447061512, 3.828826173826174, 0.002362576629827608], [0.7667662337662337, 1.0, 0.3229071467229319, 1.5335324675324673, 0.08132797607183138, 2.300298701298701, 0.023998335993902154, 3.833831168831169, 0.002342767962967987], [0.7677672327672326, 1.0, 0.32263007716304304, 1.5355344655344652, 0.0811010200056912, 2.3033016983016985, 0.023881536709877083, 3.838836163836164, 0.0023231206820085084], [0.7687682317682316, 1.0, 0.3223542481223644, 1.5375364635364632, 0.08087520113700539, 2.3063046953046955, 0.023765420067073967, 3.843841158841159, 0.002303633605749902], [0.7697692307692307, 1.0, 0.32207965893758206, 1.5395384615384613, 0.08065051729357763, 2.3093076923076925, 0.02364998355235508, 3.848846153846154, 0.0022843055626244405], [0.7707702297702297, 1.0, 0.3218063089483647, 1.5415404595404594, 0.0804269663141294, 2.3123106893106895, 0.02353522466730283, 3.8538511488511493, 0.0022651353906255117], [0.7717712287712286, 1.0, 0.3215341974973609, 1.5435424575424572, 0.08020454604827965, 2.3153136863136865, 0.02342114092816572, 3.858856143856144, 0.00224612193723775], [0.7727722277722276, 1.0, 0.32126332393019735, 1.5455444555444553, 0.07998325435652368, 2.3183166833166835, 0.023307729865804556, 3.863861138861139, 0.002227264059367752], [0.7737732267732267, 1.0, 0.3209936875954782, 1.5475464535464534, 0.07976308911021292, 2.3213196803196805, 0.023194989025639087, 3.8688661338661343, 0.00220856062327535], [0.7747742257742256, 1.0, 0.32072528784478227, 1.5495484515484512, 0.07954404819153424, 2.3243226773226775, 0.023082915967594767, 3.873871128871129, 0.002190010504505458], [0.7757752247752246, 1.0, 0.32045812403266205, 1.5515504495504493, 0.07932612949348967, 2.3273256743256745, 0.02297150826605004, 3.878876123876124, 0.002171612587820457], [0.7767762237762237, 1.0, 0.32019219551664285, 1.5535524475524474, 0.07910933091987607, 2.3303286713286715, 0.02286076350978381, 3.8838811188811193, 0.0021533657671331625], [0.7777772227772226, 1.0, 0.3199275016572204, 1.5555544455544452, 0.07889365038526502, 2.3333316683316685, 0.022750679301923236, 3.888886113886114, 0.002135268945440311], [0.7787782217782216, 1.0, 0.31966404181785923, 1.5575564435564433, 0.07867908581498276, 2.3363346653346655, 0.022641253259891872, 3.893891108891109, 0.00211732103475662], [0.7797792207792207, 1.0, 0.3194018153649915, 1.5595584415584414, 0.0784656351450901, 2.3393376623376625, 0.022532483015358075, 3.8988961038961043, 0.002099520956049367], [0.7807802197802196, 1.0, 0.31914082166801583, 1.5615604395604392, 0.0782532963223628, 2.3423406593406595, 0.022424366214183807, 3.903901098901099, 0.0020818676391735286], [0.7817812187812186, 1.0, 0.3188810600992949, 1.5635624375624373, 0.07804206730427173, 2.3453436563436565, 0.02231690051637363, 3.908906093906094, 0.0020643600228074355], [0.7827822177822177, 1.0, 0.3186225300341548, 1.5655644355644354, 0.07783194605896296, 2.3483466533466535, 0.022210083596024076, 3.9139110889110893, 0.0020469970543889678], [0.7837832167832166, 1.0, 0.31836523085088253, 1.5675664335664332, 0.0776229305652387, 2.3513496503496505, 0.022103913141273322, 3.918916083916084, 0.002029777690052278], [0.7847842157842156, 1.0, 0.31810916193072575, 1.5695684315684313, 0.07741501881253751, 2.3543526473526475, 0.021998386854251126, 3.923921078921079, 0.0020127008945650298], [0.7857852147852147, 1.0, 0.31785432265789054, 1.5715704295704294, 0.07720820880091507, 2.3573556443556445, 0.021893502451029112, 3.9289260739260743, 0.001995765641266157], [0.7867862137862136, 1.0, 0.31760071241953985, 1.5735724275724272, 0.07700249854102488, 2.3603586413586415, 0.021789257661571332, 3.933931068931069, 0.0019789709120041485], [0.7877872127872126, 1.0, 0.3173483306057921, 1.5755744255744253, 0.0767978860540992, 2.3633616383616385, 0.021685650229685136, 3.938936063936064, 0.0019623156970758303], [0.7887882117882117, 1.0, 0.31709717660972, 1.5775764235764234, 0.07659436937192995, 2.3663646353646355, 0.021582677912972366, 3.9439410589410593, 0.0019457989951656616], [0.7897892107892106, 1.0, 0.3168472498273491, 1.5795784215784212, 0.0763919465368499, 2.3693676323676325, 0.02148033848278075, 3.948946053946054, 0.0019294198132855406], [0.7907902097902096, 1.0, 0.31659854965765577, 1.5815804195804193, 0.07619061560171361, 2.3723706293706295, 0.021378629724155784, 3.9539510489510494, 0.001913177166715101], [0.7917912087912087, 1.0, 0.31635107550256625, 1.5835824175824174, 0.07599037462987894, 2.3753736263736265, 0.02127754943579268, 3.9589560439560443, 0.0018970700789425143], [0.7927922077922076, 1.0, 0.3161048267669557, 1.5855844155844152, 0.07579122169518833, 2.3783766233766235, 0.021177095429988774, 3.963961038961039, 0.001881097581605778], [0.7937932067932066, 1.0, 0.315859802858645, 1.5875864135864133, 0.07559315488195031, 2.3813796203796205, 0.021077265532596163, 3.9689660339660344, 0.0018652587144345014], [0.7947942057942057, 1.0, 0.3156160031884016, 1.5895884115884114, 0.0753961722849209, 2.3843826173826175, 0.020978057582974698, 3.9739710289710293, 0.001849552525192168], [0.7957952047952046, 1.0, 0.3153734271699362, 1.5915904095904092, 0.07520027200928553, 2.3873856143856145, 0.02087946943394513, 3.978976023976024, 0.0018339780696188922], [0.7967962037962036, 1.0, 0.31513207421990275, 1.5935924075924073, 0.07500545217064063, 2.3903886113886115, 0.02078149895174273, 3.9839810189810194, 0.0018185344113746497], [0.7977972027972027, 1.0, 0.31489194375789586, 1.5955944055944054, 0.0748117108949755, 2.3933916083916085, 0.020684144015971045, 3.9889860139860143, 0.0018032206219829807], [0.7987982017982017, 1.0, 0.3146530352064507, 1.5975964035964034, 0.07461904631865457, 2.3963946053946055, 0.020587402519556024, 3.993991008991009, 0.0017880357807751733], [0.7997992007992006, 1.0, 0.3144153479910399, 1.5995984015984013, 0.07442745658839896, 2.3993976023976025, 0.02049127236870044, 3.9989960039960044, 0.0017729789748349113], [0.8008001998001997, 1.0, 0.3141788815400741, 1.6016003996003993, 0.07423693986126916, 2.4024005994005995, 0.02039575148283852, 4.004000999001, 0.0017580492989433911], [0.8018011988011987, 1.0, 0.31394363528489894, 1.6036023976023974, 0.07404749430464713, 2.4054035964035965, 0.020300837794590968, 4.009005994005994, 0.0017432458555248955], [0.8028021978021976, 1.0, 0.3137096086597947, 1.6056043956043953, 0.07385911809621837, 2.4084065934065935, 0.020206529249720183, 4.014010989010989, 0.0017285677545928366], [0.8038031968031967, 1.0, 0.31347680110197473, 1.6076063936063933, 0.07367180942395489, 2.4114095904095905, 0.02011282380708582, 4.019015984015985, 0.0017140141136962456], [0.8048041958041957, 1.0, 0.3132452120515835, 1.6096083916083914, 0.07348556648609744, 2.4144125874125875, 0.020019719438600626, 4.024020979020979, 0.0016995840578667213], [0.8058051948051946, 1.0, 0.3130148409516966, 1.6116103896103893, 0.0733003874911383, 2.4174155844155845, 0.019927214129186497, 4.029025974025974, 0.0016852767195658265], [0.8068061938061937, 1.0, 0.312785687248318, 1.6136123876123873, 0.073116270657804, 2.4204185814185815, 0.01983530587673091, 4.03403096903097, 0.001671091238632932], [0.8078071928071927, 1.0, 0.312557750390379, 1.6156143856143854, 0.0729332142150383, 2.4234215784215785, 0.019743992692043588, 4.039035964035964, 0.0016570267622335025], [0.8088081918081916, 1.0, 0.3123310298297378, 1.6176163836163833, 0.07275121640198501, 2.4264245754245755, 0.01965327259881341, 4.044040959040959, 0.001643082444807824], [0.8098091908091907, 1.0, 0.31210552502117733, 1.6196183816183813, 0.07257027546797111, 2.4294275724275725, 0.01956314363356566, 4.049045954045955, 0.0016292574480201707], [0.8108101898101897, 1.0, 0.3118812354224036, 1.6216203796203794, 0.0723903896724899, 2.4324305694305695, 0.019473603845619553, 4.054050949050949, 0.0016155509407084004], [0.8118111888111886, 1.0, 0.31165816049404566, 1.6236223776223773, 0.07221155728518427, 2.4354335664335665, 0.01938465129704601, 4.059055944055944, 0.0016019620988339872], [0.8128121878121877, 1.0, 0.3114362996996533, 1.6256243756243753, 0.07203377658583003, 2.4384365634365635, 0.019296284062625665, 4.06406093906094, 0.0015884901054324801], [0.8138131868131867, 1.0, 0.3112156525056962, 1.6276263736263734, 0.07185704586431944, 2.4414395604395605, 0.01920850022980724, 4.069065934065934, 0.0015751341505643862], [0.8148141858141856, 1.0, 0.31099621838156255, 1.6296283716283713, 0.07168136342064464, 2.4444425574425575, 0.01912129789866616, 4.074070929070929, 0.0015618934312664776], [0.8158151848151847, 1.0, 0.31077799679955725, 1.6316303696303693, 0.07150672756488143, 2.4474455544455544, 0.019034675181863418, 4.079075924075925, 0.0015487671515035171], [0.8168161838161837, 1.0, 0.31056098723490166, 1.6336323676323674, 0.07133313661717298, 2.4504485514485514, 0.018948630204604713, 4.084080919080919, 0.0015357545221203982], [0.8178171828171826, 1.0, 0.31034518916573167, 1.6356343656343653, 0.07116058890771347, 2.4534515484515484, 0.018863161104599898, 4.089085914085914, 0.0015228547607947036], [0.8188181818181817, 1.0, 0.31013060207309623, 1.6376363636363633, 0.07098908277673234, 2.4564545454545454, 0.01877826603202264, 4.09409090909091, 0.0015100670919896714], [0.8198191808191807, 1.0, 0.3099172254409568, 1.6396383616383614, 0.0708186165744782, 2.4594575424575424, 0.018693943149470444, 4.099095904095904, 0.0014973907469075698], [0.8208201798201796, 1.0, 0.309705058756186, 1.6416403596403593, 0.0706491886612028, 2.4624605394605394, 0.018610190631924817, 4.104100899100899, 0.0014848249634434737], [0.8218211788211787, 1.0, 0.3094941015085652, 1.6436423576423573, 0.07048079740714551, 2.4654635364635364, 0.018527006666711802, 4.109105894105895, 0.0014723689861394506], [0.8228221778221777, 1.0, 0.3092843531907851, 1.6456443556443554, 0.07031344119251749, 2.4684665334665334, 0.018444389453462776, 4.114110889110889, 0.0014600220661391402], [0.8238231768231766, 1.0, 0.3090758132984431, 1.6476463536463533, 0.07014711840748616, 2.4714695304695304, 0.018362337204075416, 4.119115884115884, 0.0014477834611427351], [0.8248241758241757, 1.0, 0.3088684813300431, 1.6496483516483513, 0.06998182745215968, 2.4744725274725274, 0.018280848142675055, 4.12412087912088, 0.0014356524353623496], [0.8258251748251747, 1.0, 0.30866235678699344, 1.6516503496503494, 0.06981756673657162, 2.4774755244755244, 0.018199920505576225, 4.129125874125874, 0.0014236282594777881], [0.8268261738261736, 1.0, 0.3084574391736063, 1.6536523476523473, 0.06965433468066566, 2.4804785214785214, 0.01811955254124445, 4.134130869130869, 0.001411710210592697], [0.8278271728271727, 1.0, 0.30825372799709627, 1.6556543456543453, 0.06949212971428016, 2.4834815184815184, 0.018039742510258416, 4.139135864135865, 0.0013998975721911022], [0.8288281718281717, 1.0, 0.30805122276757935, 1.6576563436563434, 0.0693309502771336, 2.4864845154845154, 0.01796048868527227, 4.144140859140859, 0.0013881896340943343], [0.8298291708291707, 1.0, 0.30784992299807074, 1.6596583416583415, 0.06917079481880896, 2.4894875124875124, 0.017881789350978266, 4.149145854145854, 0.0013765856924183289], [0.8308301698301697, 1.0, 0.30764982820448566, 1.6616603396603393, 0.06901166179873913, 2.4924905094905094, 0.017803642804069566, 4.15415084915085, 0.0013650850495313153], [0.8318311688311687, 1.0, 0.3074509379056362, 1.6636623376623374, 0.0688535496861921, 2.4954935064935064, 0.017726047353203492, 4.159155844155844, 0.0013536870140118684], [0.8328321678321677, 1.0, 0.3072532516232316, 1.6656643356643355, 0.06869645696025611, 2.4984965034965034, 0.01764900131896482, 4.164160839160839, 0.0013423909006073445], [0.8338331668331667, 1.0, 0.307056768881876, 1.6676663336663333, 0.06854038210982508, 2.5014995004995004, 0.017572503033829484, 4.169165834165835, 0.0013311960301926802], [0.8348341658341657, 1.0, 0.3068614892090685, 1.6696683316683314, 0.06838532363358422, 2.5045024975024974, 0.017496550842128446, 4.174170829170829, 0.0013201017297295656], [0.8358351648351647, 1.0, 0.30666741213520055, 1.6716703296703295, 0.06823128003999523, 2.5075054945054944, 0.017421143100011912, 4.179175824175824, 0.0013091073322259819], [0.8368361638361637, 1.0, 0.3064745371935565, 1.6736723276723273, 0.0680782498472823, 2.5105084915084914, 0.017346278175413735, 4.18418081918082, 0.0012982121766960983], [0.8378371628371627, 1.0, 0.3062828639203106, 1.6756743256743254, 0.06792623158341764, 2.5135114885114884, 0.01727195444801606, 4.189185814185814, 0.0012874156081205375], [0.8388381618381617, 1.0, 0.30609239185452786, 1.6776763236763235, 0.06777522378610745, 2.5165144855144854, 0.017198170309214295, 4.194190809190809, 0.0012767169774069922], [0.8398391608391607, 1.0, 0.305903120538161, 1.6796783216783213, 0.06762522500277786, 2.5195174825174824, 0.017124924162082295, 4.199195804195805, 0.0012661156413512034], [0.8408401598401597, 1.0, 0.30571504951605055, 1.6816803196803194, 0.06747623379056086, 2.5225204795204794, 0.01705221442133776, 4.2042007992008, 0.0012556109625982898], [0.8418411588411587, 1.0, 0.30552817833592394, 1.6836823176823175, 0.06732824871628047, 2.5255234765234764, 0.016980039513307968, 4.209205794205794, 0.0012452023096044312], [0.8428421578421577, 1.0, 0.30534250654839346, 1.6856843156843153, 0.06718126835643892, 2.5285264735264734, 0.016908397875895684, 4.21421078921079, 0.0012348890565988997], [0.8438431568431567, 1.0, 0.3051580337069562, 1.6876863136863134, 0.06703529129720297, 2.5315294705294704, 0.016837287958545374, 4.219215784215785, 0.0012246705835464362], [0.8448441558441557, 1.0, 0.3049747593679923, 1.6896883116883115, 0.06689031613439046, 2.5345324675324674, 0.01676670822220964, 4.224220779220779, 0.0012145462761099766], [0.8458451548451547, 1.0, 0.30479268309076346, 1.6916903096903093, 0.06674634147345652, 2.5375354645354644, 0.01669665713931588, 4.229225774225775, 0.0012045155256137157], [0.8468461538461537, 1.0, 0.3046118044374135, 1.6936923076923074, 0.06660336592948043, 2.5405384615384614, 0.016627133193733296, 4.23423076923077, 0.001194577729006514], [0.8478471528471527, 1.0, 0.30443212297296574, 1.6956943056943055, 0.0664613881271521, 2.5435414585414584, 0.016558134880740004, 4.239235764235764, 0.0011847322888256435], [0.8488481518481517, 1.0, 0.3042536382653226, 1.6976963036963033, 0.0663204067007589, 2.5465444555444554, 0.016489660706990514, 4.24424075924076, 0.0011749786131608649], [0.8498491508491507, 1.0, 0.3040763498852638, 1.6996983016983014, 0.06618042029417252, 2.5495474525474524, 0.01642170919048341, 4.249245754245755, 0.0011653161156188442], [0.8508501498501497, 1.0, 0.30390025740644716, 1.7017002997002995, 0.06604142756083602, 2.5525504495504494, 0.01635427886052923, 4.254250749250749, 0.0011557442152878997], [0.8518511488511487, 1.0, 0.30372536040540576, 1.7037022977022973, 0.06590342716375075, 2.5555534465534464, 0.016287368257718697, 4.259255744255745, 0.0011462623367030742], [0.8528521478521477, 1.0, 0.30355165846154725, 1.7057042957042954, 0.0657664177754635, 2.5585564435564434, 0.016220975933891067, 4.26426073926074, 0.00113686990981154], [0.8538531468531467, 1.0, 0.3033791511571536, 1.7077062937062935, 0.06563039807805394, 2.5615594405594404, 0.016155100452102854, 4.269265734265734, 0.0011275663699383267], [0.8548541458541457, 1.0, 0.30320783807737955, 1.7097082917082913, 0.06549536676312152, 2.5645624375624374, 0.016089740386596676, 4.27427072927073, 0.001118351157752373], [0.8558551448551447, 1.0, 0.30303771881025193, 1.7117102897102894, 0.06536132253177335, 2.5675654345654344, 0.016024894322770433, 4.279275724275725, 0.001109223719232901], [0.8568561438561437, 1.0, 0.30286879294666824, 1.7137122877122875, 0.06522826409461138, 2.5705684315684314, 0.015960560857146658, 4.284280719280719, 0.0011001835056361038], [0.8578571428571427, 1.0, 0.3027010600803956, 1.7157142857142853, 0.06509619017172018, 2.5735714285714284, 0.01589673859734216, 4.289285714285715, 0.0010912299734621594], [0.8588581418581417, 1.0, 0.3025345198080708, 1.7177162837162834, 0.06496509949265453, 2.5765744255744254, 0.015833426162037905, 4.29429070929071, 0.0010823625844225554], [0.8598591408591407, 1.0, 0.3023691717291978, 1.7197182817182814, 0.06483499079642713, 2.5795774225774224, 0.015770622180949084, 4.299295704295704, 0.001073580805407722], [0.8608601398601398, 1.0, 0.3022050154461482, 1.7217202797202795, 0.06470586283149679, 2.5825804195804194, 0.015708325294795485, 4.3043006993007, 0.0010648841084549884], [0.8618611388611387, 1.0, 0.3020420505641591, 1.7237222777222774, 0.06457771435575597, 2.5855834165834164, 0.015646534155272028, 4.309305694305695, 0.0010562719707168345], [0.8628621378621377, 1.0, 0.30188027669133305, 1.7257242757242754, 0.06445054413651903, 2.5885864135864134, 0.015585247425019669, 4.314310689310689, 0.0010477438744294632], [0.8638631368631368, 1.0, 0.3017196934386363, 1.7277262737262735, 0.06432435095051048, 2.5915894105894104, 0.015524463777596365, 4.319315684315685, 0.0010392993068816683], [0.8648641358641357, 1.0, 0.30156030041989856, 1.7297282717282714, 0.0641991335838531, 2.5945924075924074, 0.015464181897448434, 4.32432067932068, 0.0010309377603840127], [0.8658651348651347, 1.0, 0.3014020972518119, 1.7317302697302694, 0.06407489083205621, 2.5975954045954044, 0.015404400479882032, 4.329325674325674, 0.0010226587322383037], [0.8668661338661338, 1.0, 0.3012450835539298, 1.7337322677322675, 0.06395162150000412, 2.6005984015984014, 0.015345118231034939, 4.33433066933067, 0.001014461724707372], [0.8678671328671327, 1.0, 0.301089258948666, 1.7357342657342654, 0.06382932440194478, 2.6036013986013984, 0.015286333867848553, 4.339335664335665, 0.001006346244985148], [0.8688681318681317, 1.0, 0.3009346230612935, 1.7377362637362634, 0.06370799836147809, 2.6066043956043954, 0.01522804611804011, 4.344340659340659, 0.0009983118051670337], [0.8698691308691308, 1.0, 0.3007811755199442, 1.7397382617382615, 0.06358764221154492, 2.6096073926073924, 0.015170253720075173, 4.349345654345655, 0.0009903579222205682], [0.8708701298701297, 1.0, 0.3006289159556081, 1.7417402597402594, 0.06346825479441558, 2.61261038961039, 0.015112955423140315, 4.35435064935065, 0.0009824841179563912], [0.8718711288711287, 1.0, 0.3004778440021313, 1.7437422577422574, 0.06334983496167881, 2.615613386613387, 0.015056149987116033, 4.359355644355644, 0.0009746899189994904], [0.8728721278721278, 1.0, 0.3003279592962167, 1.7457442557442555, 0.06323238157423086, 2.618616383616384, 0.014999836182549924, 4.36436063936064, 0.0009669748567607449], [0.8738731268731267, 1.0, 0.3001792614774214, 1.7477462537462534, 0.0631158935022643, 2.621619380619381, 0.014944012790630075, 4.369365634365635, 0.000959338467408752], [0.8748741258741257, 1.0, 0.3000317501881574, 1.7497482517482514, 0.0630003696252573, 2.624622377622378, 0.014888678603158668, 4.374370629370629, 0.0009517802918419419], [0.8758751248751248, 1.0, 0.2998854250736897, 1.7517502497502495, 0.06288580883196274, 2.627625374625375, 0.01483383242252586, 4.3793756243756246, 0.0009442998756609764], [0.8768761238761237, 1.0, 0.29974028578213613, 1.7537522477522474, 0.06277221002039773, 2.630628371628372, 0.014779473061683833, 4.38438061938062, 0.0009368967691414309], [0.8778771228771227, 1.0, 0.2995963319644658, 1.7557542457542454, 0.06265957209783278, 2.633631368631369, 0.014725599344121126, 4.389385614385614, 0.0009295705272067549], [0.8788781218781218, 1.0, 0.2994535632744988, 1.7577562437562435, 0.06254789398078131, 2.636634365634366, 0.014672210103837149, 4.3943906093906095, 0.0009223207094015166], [0.8798791208791207, 1.0, 0.29931197936890575, 1.7597582417582414, 0.062437174594989486, 2.639637362637363, 0.014619304185316977, 4.399395604395605, 0.0009151468798649208], [0.8808801198801197, 1.0, 0.29917157990720544, 1.7617602397602394, 0.06232741287542557, 2.64264035964036, 0.014566880443506292, 4.4044005994006, 0.0009080486073046062], [0.8818811188811188, 1.0, 0.29903236455176563, 1.7637622377622375, 0.062218607766269876, 2.645643356643357, 0.01451493774378667, 4.4094055944055945, 0.0009010254649707137], [0.8828821178821177, 1.0, 0.29889433296780166, 1.7657642357642354, 0.06211075822090438, 2.648646353646354, 0.014463474961950948, 4.41441058941059, 0.0008940770306302328], [0.8838831168831167, 1.0, 0.2987574848233754, 1.7677662337662334, 0.06200386320190308, 2.651649350649351, 0.014412490984178957, 4.419415584415585, 0.0008872028865416144], [0.8848841158841158, 1.0, 0.2986218197893947, 1.7697682317682315, 0.06189792168102154, 2.654652347652348, 0.01436198470701338, 4.4244205794205795, 0.0008804026194296585], [0.8858851148851147, 1.0, 0.2984873375396127, 1.7717702297702294, 0.061792932639187226, 2.657655344655345, 0.014311955037335879, 4.429425574425575, 0.0008736758204606649], [0.8868861138861137, 1.0, 0.2983540377506263, 1.7737722277722274, 0.061688895066489856, 2.660658341658342, 0.014262400892343435, 4.43443056943057, 0.0008670220852178582], [0.8878871128871128, 1.0, 0.29822192010187637, 1.7757742257742255, 0.061585807962171404, 2.663661338661339, 0.014213321199524913, 4.4394355644355645, 0.0008604410136770705], [0.8888881118881118, 1.0, 0.2980909842756469, 1.7777762237762236, 0.06148367033461651, 2.666664335664336, 0.014164714896637858, 4.44444055944056, 0.0008539322101826929], [0.8898891108891107, 1.0, 0.29796122995706353, 1.7797782217782214, 0.061382481201343174, 2.669667332667333, 0.014116580931685488, 4.449445554445555, 0.0008474952834238908], [0.8908901098901097, 1.0, 0.29783265683409355, 1.7817802197802195, 0.06128223958899298, 2.67267032967033, 0.014068918262893916, 4.4544505494505495, 0.0008411298464110735], [0.8918911088911088, 1.0, 0.29770526459754465, 1.7837822177822176, 0.061182944533322105, 2.675673326673327, 0.014021725858689653, 4.459455544455545, 0.0008348355164526326], [0.8928921078921077, 1.0, 0.2975790529410642, 1.7857842157842154, 0.06108459507919167, 2.678676323676324, 0.013975002697677229, 4.46446053946054, 0.0008286119151319326], [0.8938931068931067, 1.0, 0.2974540215611382, 1.7877862137862135, 0.06098719028055882, 2.681679320679321, 0.013928747768617111, 4.4694655344655345, 0.0008224586682845617], [0.8948941058941058, 1.0, 0.29733017015709207, 1.7897882117882116, 0.06089072920046754, 2.684682317682318, 0.01388296007040382, 4.47447052947053, 0.0008163754059758344], [0.8958951048951047, 1.0, 0.2972074984310876, 1.7917902097902094, 0.060795210911039524, 2.687685314685315, 0.013837638612044234, 4.479475524475525, 0.0008103617624785537], [0.8968961038961037, 1.0, 0.29708600608812435, 1.7937922077922075, 0.06070063449346546, 2.690688311688312, 0.013792782412636184, 4.4844805194805195, 0.0008044173762510223], [0.8978971028971028, 1.0, 0.2969656928360375, 1.7957942057942056, 0.06060699903799606, 2.693691308691309, 0.013748390501347197, 4.489485514485515, 0.0007985418899153055], [0.8988981018981017, 1.0, 0.29684655838549834, 1.7977962037962034, 0.06051430364393329, 2.696694305694306, 0.013704461917393464, 4.49449050949051, 0.0007927349502357488], [0.8998991008991007, 1.0, 0.29672860245001237, 1.7997982017982015, 0.06042254741962183, 2.699697302697303, 0.013660995710019112, 4.4994955044955045, 0.0007869962080977378], [0.9009000999000998, 1.0, 0.29661182474591935, 1.8018001998001996, 0.06033172948244036, 2.7027002997003, 0.013617990938475556, 4.5045004995005, 0.0007813253184867107], [0.9019010989010987, 1.0, 0.29649622499239253, 1.8038021978021974, 0.06024184895879315, 2.705703296703297, 0.013575446672001163, 4.509505494505495, 0.000775721940467416], [0.9029020979020977, 1.0, 0.2963818029114382, 1.8058041958041955, 0.06015290498410163, 2.708706293706294, 0.01353336198980114, 4.5145104895104895, 0.000770185737163416], [0.9039030969030968, 1.0, 0.29626855822789394, 1.8078061938061936, 0.060064896702796085, 2.711709290709291, 0.01349173598102755, 4.519515484515485, 0.0007647163757368326], [0.9049040959040957, 1.0, 0.29615649066942945, 1.8098081918081914, 0.05997782326830743, 2.714712287712288, 0.013450567744759646, 4.52452047952048, 0.0007593135273683383], [0.9059050949050947, 1.0, 0.29604559996654467, 1.8118101898101895, 0.059891683843059075, 2.717715284715285, 0.013409856389984326, 4.5295254745254745, 0.0007539768672373853], [0.9069060939060938, 1.0, 0.29593588585257, 1.8138121878121876, 0.059806477598458745, 2.720718281718282, 0.013369601035576896, 4.53453046953047, 0.0007487060745026797], [0.9079070929070927, 1.0, 0.2958273480636648, 1.8158141858141854, 0.059722203714890794, 2.723721278721279, 0.013329800810281964, 4.539535464535465, 0.0007435008322828908], [0.9089080919080917, 1.0, 0.2957199863388175, 1.8178161838161835, 0.059638861381708, 2.726724275724276, 0.01329045485269461, 4.5445404595404595, 0.0007383608276376005], [0.9099090909090908, 1.0, 0.2956138004198454, 1.8198181818181816, 0.05955644979722389, 2.729727272727273, 0.013251562311241695, 4.549545454545455, 0.0007332857515484901], [0.9109100899100897, 1.0, 0.29550879005139263, 1.8218201798201794, 0.05947496816870522, 2.73273026973027, 0.013213122344163507, 4.55455044955045, 0.0007282752989007611], [0.9119110889110887, 1.0, 0.2954049549809304, 1.8238221778221775, 0.05939441571236403, 2.7357332667332668, 0.013175134119495478, 4.5595554445554445, 0.0007233291684647915], [0.9129120879120878, 1.0, 0.2953022949587565, 1.8258241758241756, 0.059314791653350234, 2.7387362637362638, 0.01313759681505019, 4.56456043956044, 0.000718447062878027], [0.9139130869130867, 1.0, 0.29520080973799373, 1.8278261738261734, 0.05923609522574427, 2.7417392607392608, 0.013100509618399607, 4.569565434565435, 0.0007136286886271015], [0.9149140859140857, 1.0, 0.2951004990745909, 1.8298281718281715, 0.05915832567254964, 2.7447422577422578, 0.013063871726857466, 4.5745704295704295, 0.0007088737560301925], [0.9159150849150848, 1.0, 0.29500136272732136, 1.8318301698301696, 0.05908148224568554, 2.7477452547452548, 0.013027682347461917, 4.579575424575425, 0.0007041819792196061], [0.9169160839160837, 1.0, 0.29490340045778207, 1.8338321678321674, 0.05900556420597985, 2.7507482517482518, 0.01299194069695835, 4.58458041958042, 0.0006995530761245882], [0.9179170829170827, 1.0, 0.2948066120303938, 1.8358341658341655, 0.0589305708231619, 2.7537512487512488, 0.012956646001782451, 4.5895854145854145, 0.0006949867684543685], [0.9189180819180818, 1.0, 0.2947109972123997, 1.8378361638361635, 0.05885650137585551, 2.7567542457542458, 0.01292179749804346, 4.59459040959041, 0.0006904827816814285], [0.9199190809190808, 1.0, 0.2946165557738654, 1.8398381618381616, 0.058783355151572, 2.7597572427572428, 0.012887394431507626, 4.599595404595405, 0.0006860408450249968], [0.9209200799200797, 1.0, 0.2945232874876781, 1.8418401598401595, 0.05871113144670327, 2.7627602397602398, 0.012853436057581906, 4.6046003996003995, 0.0006816606914347709], [0.9219210789210788, 1.0, 0.294431192129547, 1.8438421578421575, 0.05863982956651527, 2.7657632367632368, 0.012819921641297832, 4.609605394605395, 0.00067734205757486], [0.9229220779220778, 1.0, 0.29434026947800107, 1.8458441558441556, 0.058569448825140986, 2.7687662337662338, 0.012786850457295598, 4.61461038961039, 0.0006730846838079549], [0.9239230769230767, 1.0, 0.2942505193143895, 1.8478461538461535, 0.058499988545574234, 2.7717692307692308, 0.012754221789808382, 4.619615384615385, 0.0006688883141797181], [0.9249240759240758, 1.0, 0.2941619414228817, 1.8498481518481515, 0.058431448059662806, 2.7747722277722278, 0.01272203493264684, 4.62462037962038, 0.0006647526964033949], [0.9259250749250748, 1.0, 0.2940745355904656, 1.8518501498501496, 0.05836382670810216, 2.7777752247752248, 0.012690289189183822, 4.629625374625375, 0.000660677581844647], [0.9269260739260737, 1.0, 0.2939883016069476, 1.8538521478521475, 0.05829712384042909, 2.7807782217782218, 0.012658983872339304, 4.63463036963037, 0.0006566627255066045], [0.9279270729270728, 1.0, 0.29390323926495243, 1.8558541458541455, 0.05823133881501554, 2.7837812187812188, 0.0126281183045655, 4.639635364635365, 0.0006527078860151356], [0.9289280719280718, 1.0, 0.2938193483599222, 1.8578561438561436, 0.05816647099906231, 2.7867842157842158, 0.01259769181783221, 4.64464035964036, 0.0006488128256043368], [0.9299290709290707, 1.0, 0.2937366286901163, 1.8598581418581415, 0.05810251976859299, 2.7897872127872128, 0.012567703753612382, 4.649645354645355, 0.0006449773101022368], [0.9309300699300698, 1.0, 0.2936550800566108, 1.8618601398601395, 0.058039484508448126, 2.7927902097902098, 0.012538153462867808, 4.65465034965035, 0.0006412011089167172], [0.9319310689310688, 1.0, 0.29357470226329757, 1.8638621378621376, 0.057977364612278995, 2.7957932067932068, 0.012509040306035125, 4.659655344655345, 0.0006374839950216536], [0.9329320679320677, 1.0, 0.29349549511688433, 1.8658641358641355, 0.05791615948254199, 2.7987962037962038, 0.012480363653011958, 4.66466033966034, 0.0006338257449432606], [0.9339330669330668, 1.0, 0.29341745842689376, 1.8678661338661335, 0.057855868530492835, 2.8017992007992008, 0.012452122883143266, 4.669665334665335, 0.0006302261387466613], [0.9349340659340658, 1.0, 0.2933405920056636, 1.8698681318681316, 0.05779649117618094, 2.8048021978021977, 0.012424317385207922, 4.67467032967033, 0.0006266849600226632], [0.9359350649350647, 1.0, 0.2932648956683452, 1.8718701298701295, 0.05773802684844382, 2.8078051948051947, 0.012396946557405489, 4.679675324675325, 0.0006232019958747478], [0.9369360639360638, 1.0, 0.29319036923290465, 1.8738721278721275, 0.05768047498490145, 2.8108081918081917, 0.012370009807343199, 4.68468031968032, 0.0006197770369062692], [0.9379370629370628, 1.0, 0.29311701252012035, 1.8758741258741256, 0.0576238350319511, 2.8138111888111887, 0.012343506552023105, 4.689685314685315, 0.0006164098772078692], [0.9389380619380617, 1.0, 0.29304482535358467, 1.8778761238761235, 0.057568106444761825, 2.8168141858141857, 0.012317436217829497, 4.69469030969031, 0.0006131003143450941], [0.9399390609390608, 1.0, 0.29297380755970215, 1.8798781218781215, 0.0575132886872693, 2.8198171828171827, 0.012291798240516447, 4.699695304695305, 0.0006098481493462265], [0.9409400599400598, 1.0, 0.29290395896768906, 1.8818801198801196, 0.057459381232170675, 2.8228201798201797, 0.012266592065195647, 4.7047002997003, 0.0006066531866903222], [0.9419410589410587, 1.0, 0.2928352794095733, 1.8838821178821175, 0.057406383560919386, 2.8258231768231767, 0.012241817146324375, 4.709705294705295, 0.0006035152342954554], [0.9429420579420578, 1.0, 0.29276776872019505, 1.8858841158841155, 0.05735429516372043, 2.8288261738261737, 0.012217472947693656, 4.71471028971029, 0.0006004341035071712], [0.9439430569430568, 1.0, 0.2927014267372048, 1.8878861138861136, 0.05730311553952518, 2.8318291708291707, 0.012193558942416725, 4.719715284715285, 0.0005974096090871438], [0.9449440559440557, 1.0, 0.29263625330106313, 1.8898881118881115, 0.057252844196026664, 2.8348321678321677, 0.012170074612917546, 4.72472027972028, 0.0005944415692020395], [0.9459450549450548, 1.0, 0.29257224825504125, 1.8918901098901095, 0.05720348064965488, 2.8378351648351647, 0.012147019450919687, 4.729725274725275, 0.0005915298054125842], [0.9469460539460538, 1.0, 0.29250941144521986, 1.8938921078921076, 0.05715502442557208, 2.8408381618381617, 0.012124392957435257, 4.73473026973027, 0.0005886741426628365], [0.9479470529470527, 1.0, 0.2924477427204891, 1.8958941058941055, 0.05710747505766824, 2.8438411588411587, 0.012102194642754131, 4.739735264735265, 0.0005858744092696631], [0.9489480519480518, 1.0, 0.2923872419325482, 1.8978961038961035, 0.05706083208855663, 2.8468441558441557, 0.012080424026433364, 4.74474025974026, 0.0005831304369124172], [0.9499490509490508, 1.0, 0.292327908935905, 1.8998981018981016, 0.057015095069569276, 2.8498471528471527, 0.012059080637286775, 4.749745254745255, 0.0005804420606228185], [0.9509500499500498, 1.0, 0.29226974358787555, 1.9019000999000997, 0.05697026356075265, 2.8528501498501497, 0.01203816401337474, 4.75475024975025, 0.0005778091187750368], [0.9519510489510488, 1.0, 0.2922127457485838, 1.9039020979020975, 0.05692633713086369, 2.8558531468531467, 0.01201767370199423, 4.759755244755245, 0.0005752314530759719], [0.9529520479520478, 1.0, 0.29215691528096177, 1.9059040959040956, 0.056883315357365356, 2.8588561438561437, 0.011997609259668973, 4.76476023976024, 0.0005727089085557414], [0.9539530469530468, 1.0, 0.2921022520507486, 1.9079060939060937, 0.05684119782642264, 2.8618591408591407, 0.0119779702521399, 4.769765234765235, 0.0005702413335583595], [0.9549540459540458, 1.0, 0.29204875592648966, 1.9099080919080915, 0.05679998413289867, 2.8648621378621377, 0.011958756254355692, 4.77477022977023, 0.0005678285797326227], [0.9559550449550448, 1.0, 0.29199642677953797, 1.9119100899100896, 0.05675967388035078, 2.8678651348651347, 0.011939966850463604, 4.779775224775225, 0.0005654705020231886], [0.9569560439560438, 1.0, 0.2919452644840522, 1.9139120879120877, 0.056720266681026615, 2.8708681318681317, 0.011921601633800499, 4.78478021978022, 0.0005631669586618569], [0.9579570429570428, 1.0, 0.29189526891699774, 1.9159140859140855, 0.056681762155860564, 2.8738711288711287, 0.011903660206883986, 4.789785214785215, 0.0005609178111590449], [0.9589580419580418, 1.0, 0.2918464399581447, 1.9179160839160836, 0.05664415993446999, 2.8768741258741257, 0.01188614218140387, 4.79479020979021, 0.0005587229242954619], [0.9599590409590408, 1.0, 0.2917987774900701, 1.9199180819180817, 0.056607459655151605, 2.8798771228771227, 0.011869047178213719, 4.799795204795205, 0.0005565821661139815], [0.9609600399600398, 1.0, 0.2917522813981546, 1.9219200799200795, 0.05657166096487824, 2.8828801198801197, 0.011852374827322652, 4.8048001998002, 0.0005544954079117039], [0.9619610389610388, 1.0, 0.29170695157058507, 1.9239220779220776, 0.05653676351929517, 2.8858831168831167, 0.011836124767887358, 4.809805194805195, 0.0005524625242322235], [0.9629620379620378, 1.0, 0.29166278789835215, 1.9259240759240757, 0.05650276698271695, 2.8888861138861137, 0.011820296648204246, 4.81481018981019, 0.000550483392858083], [0.9639630369630368, 1.0, 0.2916197902752512, 1.9279260739260735, 0.056469671028124155, 2.8918891108891107, 0.011804890125701906, 4.819815184815186, 0.0005485578948034273], [0.9649640359640358, 1.0, 0.2915779585978818, 1.9299280719280716, 0.05643747533716021, 2.8948921078921077, 0.011789904866933612, 4.82482017982018, 0.0005466859143068484], [0.9659650349650348, 1.0, 0.29153729276564705, 1.9319300699300697, 0.05640617960012842, 2.8978951048951047, 0.011775340547570155, 4.829825174825175, 0.0005448673388244275], [0.9669660339660338, 1.0, 0.29149779268075393, 1.9339320679320675, 0.05637578351598884, 2.9008981018981017, 0.0117611968523928, 4.8348301698301706, 0.0005431020590229682], [0.9679670329670328, 1.0, 0.29145945824821246, 1.9359340659340656, 0.05634628679235557, 2.9039010989010987, 0.011747473475286473, 4.839835164835165, 0.0005413899687734221], [0.9689680319680318, 1.0, 0.29142228937583614, 1.9379360639360637, 0.05631768914549374, 2.9069040959040957, 0.01173417011923315, 4.84484015984016, 0.0005397309651445118], [0.9699690309690308, 1.0, 0.2913862859742415, 1.9399380619380615, 0.05628999030031693, 2.9099070929070927, 0.011721286496305397, 4.8498451548451555, 0.0005381249483965381], [0.9709700299700298, 1.0, 0.2913514479568478, 1.9419400599400596, 0.056263189990384495, 2.9129100899100897, 0.011708822327660165, 4.85485014985015, 0.0005365718219753865], [0.9719710289710288, 1.0, 0.2913177752398762, 1.9439420579420577, 0.05623728795789891, 2.9159130869130867, 0.011696777343532737, 4.859855144855145, 0.0005350714925067226], [0.9729720279720278, 1.0, 0.2912852677423509, 1.9459440559440555, 0.05621228395370344, 2.918916083916084, 0.011685151283230912, 4.8648601398601405, 0.0005336238697903763], [0.9739730269730268, 1.0, 0.29125392538609757, 1.9479460539460536, 0.056188177737279583, 2.921919080919081, 0.011673943895129317, 4.869865134865135, 0.0005322288667949215], [0.9749740259740258, 1.0, 0.29122374809574464, 1.9499480519480517, 0.056164969076744856, 2.924922077922078, 0.011663154936664038, 4.87487012987013, 0.0005308863996524409], [0.9759750249750248, 1.0, 0.2911947357987214, 1.9519500499500495, 0.05614265774885056, 2.927925074925075, 0.011652784174327293, 4.8798751248751255, 0.0005295963876534859], [0.9769760239760238, 1.0, 0.2911668884252591, 1.9539520479520476, 0.056121243538979675, 2.930928071928072, 0.011642831383662405, 4.88488011988012, 0.0005283587532422244], [0.9779770229770228, 1.0, 0.2911402059083908, 1.9559540459540457, 0.0561007262411446, 2.933931068931069, 0.011633296349258982, 4.889885114885115, 0.0005271734220117771], [0.9789780219780219, 1.0, 0.2911146881839498, 1.9579560439560437, 0.05608110565798546, 2.936934065934066, 0.011624178864748192, 4.8948901098901105, 0.0005260403226997444], [0.9799790209790208, 1.0, 0.2910903351905717, 1.9599580419580416, 0.056062381600767895, 2.939937062937063, 0.011615478732798331, 4.899895104895105, 0.0005249593871839227], [0.9809800199800198, 1.0, 0.29106714686969243, 1.9619600399600396, 0.0560445538893815, 2.94294005994006, 0.01160719576511057, 4.9049000999001, 0.0005239305504782083], [0.9819810189810189, 1.0, 0.2910451231655487, 1.9639620379620377, 0.056027622352338005, 2.945943056943057, 0.01159932978241481, 4.9099050949050955, 0.0005229537507286892], [0.9829820179820178, 1.0, 0.291024264025178, 1.9659640359640356, 0.056011586826769655, 2.948946053946054, 0.011591880614465892, 4.91491008991009, 0.0005220289292099299], [0.9839830169830168, 1.0, 0.29100456939841807, 1.9679660339660336, 0.055996447158427526, 2.951949050949051, 0.011584848100039853, 4.919915084915085, 0.0005211560303214375], [0.9849840159840159, 1.0, 0.29098603923790733, 1.9699680319680317, 0.05598220320168007, 2.954952047952048, 0.011578232086930455, 4.9249200799200805, 0.0005203350015843196], [0.9859850149850148, 1.0, 0.29096867349908484, 1.9719700299700296, 0.05596885481951196, 2.957955044955045, 0.01157203243194589, 4.929925074925075, 0.0005195657936381308], [0.9869860139860138, 1.0, 0.29095247214018927, 1.9739720279720276, 0.05595640188352232, 2.960958041958042, 0.011566249000905686, 4.93493006993007, 0.0005188483602379041], [0.9879870129870129, 1.0, 0.2909374351222597, 1.9759740259740257, 0.05594484427392397, 2.963961038961039, 0.011560881668637772, 4.9399350649350655, 0.0005181826582513705], [0.9889880119880118, 1.0, 0.29092356240913503, 1.9779760239760236, 0.05593418187954201, 2.966964035964036, 0.011555930318975808, 4.94494005994006, 0.0005175686476563654], [0.9899890109890108, 1.0, 0.29091085396745425, 1.9799780219780216, 0.055924414597812694, 2.969967032967033, 0.01155139484475667, 4.949945054945055, 0.0005170062915384241], [0.9909900099900099, 1.0, 0.2908993097666561, 1.9819800199800197, 0.055915542334782624, 2.97297002997003, 0.011547275147818089, 4.9549500499500505, 0.0005164955560885614], [0.9919910089910088, 1.0, 0.29088892977897945, 1.9839820179820176, 0.055907565005107754, 2.975973026973027, 0.011543571138996574, 4.959955044955045, 0.0005160364106012384], [0.9929920079920078, 1.0, 0.2908797139794621, 1.9859840159840156, 0.05590048253205257, 2.978976023976024, 0.011540282738125462, 4.96496003996004, 0.0005156288274725179], [0.9939930069930069, 1.0, 0.29087166234594164, 1.9879860139860137, 0.055894294847489354, 2.981979020979021, 0.011537409874033178, 4.9699650349650355, 0.0005152727821984042], [0.9949940059940058, 1.0, 0.2908647748590562, 1.9899880119880116, 0.05588900189189757, 2.984982017982018, 0.011534952484541705, 4.97497002997003, 0.0005149682533733695], [0.9959950049950048, 1.0, 0.2908590515022424, 1.9919900099900096, 0.05588460361436323, 2.987985014985015, 0.011532910516465222, 4.979975024975025, 0.0005147152226890667], [0.9969960039960039, 1.0, 0.29085449226173693, 1.9939920079920077, 0.055881099972578376, 2.990988011988012, 0.011531283925608959, 4.9849800199800205, 0.0005145136749332307], [0.9979970029970028, 1.0, 0.2908510971265756, 1.9959940059940056, 0.05587849093284079, 2.993991008991009, 0.011530072676768277, 4.989985014985015, 0.0005143635979887613], [0.9989980019980018, 1.0, 0.29084886608859367, 1.9979960039960036, 0.055876776470053645, 2.996994005994006, 0.011529276743727824, 4.99499000999001, 0.0005142649828329968], [0.9999990009990009, 1.0, 0.29084779914242603, 1.9999980019980017, 0.055875956567725156, 2.999997002997003, 0.011528896109261076, 4.9999950049950055, 0.0005142178235371697], [1.001, 0.0, 0.290847799142426, 2.002, 0.05587595656772514, 3.003, 0.011528896109261076, 5.005, 0.00051421782353717]]}, \"id\": \"el9520169581592\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAtYAAAIwCAYAAACiDSxZAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
       "text": [
        "<matplotlib.figure.Figure at 0xa1b9c18>"
       ]
      }
     ],
     "prompt_number": 51
    },
    {
     "cell_type": "heading",
     "level": 4,
     "metadata": {},
     "source": [
      "Analytical expression for the transmission probability:"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def transmission_exact(a, E):\n",
      "    assert 0 < E < 1\n",
      "    kappa = sqrt(2 * (1-E))\n",
      "    return 1. / (1 + sinh(kappa*a)**2 / (4. * E * (1-E)))"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [],
     "prompt_number": 52
    },
    {
     "cell_type": "heading",
     "level": 4,
     "metadata": {},
     "source": [
      "Convergence to the Analytical Value"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "a = 2.5\n",
      "V = rect_potential(a=a)\n",
      "Es = [0.71, 0.91]\n",
      "Ts_exact = [transmission_exact(a=a, E=E) for E in Es]\n",
      "step_sizes = [0.5, 0.1, 0.05, 0.01, 0.005, 0.001]\n",
      "\n",
      "plt.title('Convergence of Transmission Coefficient for a = %f and E = %s' % (a, ', '.join(map(str, Es))))\n",
      "plt.xlabel('$\\Delta x$')\n",
      "plt.ylabel('$T$')\n",
      "plt.ylim((0, 0.2))\n",
      "plt.yticks(Ts_exact)\n",
      "for E, T_exact in zip(Es, Ts_exact):\n",
      "    # show theoretical value as horizontal line\n",
      "    plt.axhline(T_exact, color='gray')\n",
      "    \n",
      "    # plot numerical data points\n",
      "    Ts_approx = [scatter(V=V, E=E, x_min=0, x_max=a, n=int(np.ceil(a / dx)))[0] for dx in step_sizes]\n",
      "    plt.semilogx(step_sizes, Ts_approx, 'o')\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el95201703988329077726992\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "       mpld3.draw_figure(\"fig_el95201703988329077726992\", {\"axes\": [{\"xlim\": [0.001, 1.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$\\\\Delta x$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.0505973715651135], \"rotation\": -0.0, \"id\": \"el9520170358488\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.073882728494623642, 0.5], \"rotation\": -90.0, \"id\": \"el9520175865928\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Convergence of Transmission Coefficient for a = 2.500000 and E = 0.71, 0.91\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520169589504\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.001, 1.0], \"ylim\": [0.0, 0.20000000000000001], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"log\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 2, \"tickvalues\": [0.07104331252630669, 0.16859618276248009]}], \"lines\": [{\"color\": \"#808080\", \"yindex\": 1, \"coordinates\": \"display\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169581256\"}, {\"color\": \"#808080\", \"yindex\": 2, \"coordinates\": \"display\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170449216\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168827592pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169553592pts\"}], \"id\": \"el9520170500224\", \"ydomain\": [0.0, 0.20000000000000001], \"collections\": [], \"xscale\": \"log\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data02\": [[0.5, 0.049408831516232224, 0.1506003139039381], [0.1, 0.06504591418600054, 0.16516366426635024], [0.05, 0.06791273935810681, 0.16688426240848886], [0.01, 0.07039503744299909, 0.16825440855718132], [0.005, 0.07071775559169374, 0.16842533193514442], [0.001, 0.07097797288162624, 0.16856201831621243]], \"data01\": [[120.0, 288.2108419483957, 560.3833499073194], [864.0, 288.2108419483957, 560.3833499073194]]}, \"id\": \"el9520170398832\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "         \n",
        "         mpld3.draw_figure(\"fig_el95201703988329077726992\", {\"axes\": [{\"xlim\": [0.001, 1.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$\\\\Delta x$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.0505973715651135], \"rotation\": -0.0, \"id\": \"el9520170358488\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.073882728494623642, 0.5], \"rotation\": -90.0, \"id\": \"el9520175865928\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Convergence of Transmission Coefficient for a = 2.500000 and E = 0.71, 0.91\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520169589504\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.001, 1.0], \"ylim\": [0.0, 0.20000000000000001], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"log\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 2, \"tickvalues\": [0.07104331252630669, 0.16859618276248009]}], \"lines\": [{\"color\": \"#808080\", \"yindex\": 1, \"coordinates\": \"display\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169581256\"}, {\"color\": \"#808080\", \"yindex\": 2, \"coordinates\": \"display\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170449216\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168827592pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169553592pts\"}], \"id\": \"el9520170500224\", \"ydomain\": [0.0, 0.20000000000000001], \"collections\": [], \"xscale\": \"log\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data02\": [[0.5, 0.049408831516232224, 0.1506003139039381], [0.1, 0.06504591418600054, 0.16516366426635024], [0.05, 0.06791273935810681, 0.16688426240848886], [0.01, 0.07039503744299909, 0.16825440855718132], [0.005, 0.07071775559169374, 0.16842533193514442], [0.001, 0.07097797288162624, 0.16856201831621243]], \"data01\": [[120.0, 288.2108419483957, 560.3833499073194], [864.0, 288.2108419483957, 560.3833499073194]]}, \"id\": \"el9520170398832\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "                 \n",
        "                 mpld3.draw_figure(\"fig_el95201703988329077726992\", {\"axes\": [{\"xlim\": [0.001, 1.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$\\\\Delta x$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.0505973715651135], \"rotation\": -0.0, \"id\": \"el9520170358488\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.073882728494623642, 0.5], \"rotation\": -90.0, \"id\": \"el9520175865928\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Convergence of Transmission Coefficient for a = 2.500000 and E = 0.71, 0.91\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520169589504\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.001, 1.0], \"ylim\": [0.0, 0.20000000000000001], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"log\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 2, \"tickvalues\": [0.07104331252630669, 0.16859618276248009]}], \"lines\": [{\"color\": \"#808080\", \"yindex\": 1, \"coordinates\": \"display\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169581256\"}, {\"color\": \"#808080\", \"yindex\": 2, \"coordinates\": \"display\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170449216\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168827592pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169553592pts\"}], \"id\": \"el9520170500224\", \"ydomain\": [0.0, 0.20000000000000001], \"collections\": [], \"xscale\": \"log\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data02\": [[0.5, 0.049408831516232224, 0.1506003139039381], [0.1, 0.06504591418600054, 0.16516366426635024], [0.05, 0.06791273935810681, 0.16688426240848886], [0.01, 0.07039503744299909, 0.16825440855718132], [0.005, 0.07071775559169374, 0.16842533193514442], [0.001, 0.07097797288162624, 0.16856201831621243]], \"data01\": [[120.0, 288.2108419483957, 560.3833499073194], [864.0, 288.2108419483957, 560.3833499073194]]}, \"id\": \"el9520170398832\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAvIAAAI3CAYAAAD5vr9LAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nQh4AADIk5AEAIENCHgAAMvT/ACRqB7cB2jgKAAAAAElFTkSuQmCC\n",
       "text": [
        "<matplotlib.figure.Figure at 0xa281470>"
       ]
      }
     ],
     "prompt_number": 53
    },
    {
     "cell_type": "heading",
     "level": 4,
     "metadata": {},
     "source": [
      "Dependence on Energy"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "as_ = np.linspace(0.5, 5, 10)\n",
      "colors = cm.rainbow(1 - as_ / 5)\n",
      "Es = np.linspace(.01, .99)\n",
      "Es_coarse = np.arange(.01, 1, .05)\n",
      "n = 1e3\n",
      "\n",
      "plt.title('Transmission Coefficient as a Function of Energy')\n",
      "plt.xlabel('$E$')\n",
      "plt.ylabel('$T$')\n",
      "plt.xlim(0, 1.3)\n",
      "for a, color in zip(as_, colors):\n",
      "    # plot theoretical value\n",
      "    plt.plot(Es, [transmission_exact(a=a, E=E) for E in Es], color=color, label='a = %.1f' % a)\n",
      "    \n",
      "    # plot numerical data points\n",
      "    Ts_approx = [scatter(V=rect_potential(a), E=E, x_min=0, x_max=a, n=n)[0] for E in Es_coarse]\n",
      "    l = plt.plot(Es_coarse, Ts_approx, 'o', color=color)\n",
      "plt.legend(loc='upper right')\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el95201703992806042753061\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "       mpld3.draw_figure(\"fig_el95201703992806042753061\", {\"axes\": [{\"xlim\": [0.0, 1.3], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$E$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520194646144\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520169581424\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Transmission Coefficient as a Function of Energy\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520175988632\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 0.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el9520169558648\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el9520168769688\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el9520168770864\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el9520168812672\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.81959378733572308], \"rotation\": -0.0, \"id\": \"el9520176056304\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.78434886499402645], \"rotation\": -0.0, \"id\": \"el9520168815584\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.74910394265232993], \"rotation\": -0.0, \"id\": \"el9520170464592\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 4.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.71385902031063342], \"rotation\": -0.0, \"id\": \"el9520194536616\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 4.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.67861409796893679], \"rotation\": -0.0, \"id\": \"el9520194668584\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 5.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.64336917562724039], \"rotation\": -0.0, \"id\": \"el9520170448544\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 1.3], \"ylim\": [0.0, 0.90000000000000002], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data04\", \"id\": \"el9520169558816\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 10, \"tickvalues\": null}], \"lines\": [{\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168811768\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170382560\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170383904\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168822824\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170492424\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168689848\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169514880\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169514712\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170473456\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168863672\"}, {\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169560608\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168771312\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168814296\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168814240\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170464816\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168768456\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170502352\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520194669032\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520194669368\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170447256\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FF4D27\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168312448pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF954E\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170384800pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#E6CD73\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168823104pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#B2F295\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170491976pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#80FEB3\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170493040pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4CF2CE\", \"edgewidth\": 0.5, \"yindex\": 6, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168690408pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#18CDE3\", \"edgewidth\": 0.5, \"yindex\": 7, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169515272pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#1995F2\", \"edgewidth\": 0.5, \"yindex\": 8, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520175893024pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4D4DFB\", \"edgewidth\": 0.5, \"yindex\": 9, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170472952pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#7F00FF\", \"edgewidth\": 0.5, \"yindex\": 10, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168862608pts\"}], \"id\": \"el9520170358656\", \"ydomain\": [0.0, 0.90000000000000002], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data04\": [[0.8616711469534052, 0.6284348864994028], [0.9910394265232977, 0.6284348864994028], [0.9910394265232977, 0.9880525686977301], [0.8616711469534052, 0.9880525686977301], [0.8616711469534052, 0.6284348864994028]], \"data02\": [[0.01, 0.06344853504451091, 0.010583339995665488, 0.002375888393666644, 0.0005692604561473782, 0.00013852590269955418, 3.383666006050032e-05, 8.272630778546611e-06, 2.0230077871021055e-06, 4.947381853542348e-07, 1.209927166626799e-07], [0.060000000000000005, 0.29071246992612554, 0.06202850138906503, 0.014943702187008488, 0.0037387395911720666, 0.0009446825933065767, 0.0002393002165032453, 6.0656703491843206e-05, 1.5377481615772445e-05, 3.898608338481522e-06, 9.88413363002719e-07], [0.11, 0.43106971447199705, 0.11106787520506595, 0.028696794626959735, 0.0075077811368943785, 0.001972188923567964, 0.0005186451192499174, 0.00013643355691338096, 3.589270830104503e-05, 9.44278902976266e-06, 2.4842583920052985e-06], [0.16000000000000003, 0.526355704491522, 0.1577703833463456, 0.043682612847738965, 0.011968658941778327, 0.0032729497650294684, 0.0008946087147887039, 0.0002444975678169504, 6.68192904396209e-05, 1.8261034349048996e-05, 4.990543990129478e-06], [0.21000000000000002, 0.5952670090163205, 0.2022100859072628, 0.05994181641280863, 0.017226118286076925, 0.004910979952436159, 0.0013969827425635876, 0.0003971405238845973, 0.00011288102511062366, 3.2083077009422586e-05, 9.118532652275172e-06], [0.26, 0.6474154397368123, 0.2444648144039451, 0.07750659857727912, 0.023398521007346313, 0.0069652905728896765, 0.002064929412042227, 0.0006114272849280538, 0.00018097926971581555, 5.3563240353104514e-05, 1.5852262876308347e-05], [0.31000000000000005, 0.6882482739239967, 0.28461497926640267, 0.09639894429906204, 0.03061887045890425, 0.00953345744064533, 0.002950113852689762, 0.0009111758307435065, 0.0002812619916347763, 8.680432569022723e-05, 2.6788443008915422e-05], [0.36000000000000004, 0.7210832956501965, 0.3227425390144358, 0.1166288783427331, 0.03903559962673558, 0.012736013134185157, 0.0041209605553941195, 0.0013298326690558068, 0.00042876491916371475, 0.000138203866231584, 4.454326606650338e-05], [0.41000000000000003, 0.7480567474046081, 0.3589301200359493, 0.1381927699276826, 0.04881296274547962, 0.016721815301092003, 0.005668462513559375, 0.0019146883135644733, 0.0006459628472268159, 0.00021784140212601023, 7.34537156458573e-05], [0.46, 0.770606300259536, 0.39326027137193015, 0.16107177061864378, 0.06013081924723233, 0.02167454047476267, 0.007714139858769179, 0.002733119887640358, 0.0009667912306912413, 0.00034179056098184563, 0.00012080925979798617], [0.51, 0.7897350219905663, 0.42581484236390893, 0.18523047166010342, 0.07318354051728929, 0.02782041932289035, 0.010420974822719645, 0.0038819337477554016, 0.0014430828438871369, 0.0005360446729563266, 0.00019906130040885336], [0.56, 0.8061640629313125, 0.4566744701275893, 0.21061587025366477, 0.08817770915272707, 0.035437240377691276, 0.01400845653670786, 0.005501500568146045, 0.002155043841401391, 0.0008433227245041854, 0.00032988332581726705], [0.6100000000000001, 0.8204251959536566, 0.4859181622764129, 0.23715673350117839, 0.10532822544602145, 0.044864464384898835, 0.018773258570766393, 0.007797376094145474, 0.003228619230889122, 0.0013351504205216984, 0.0005518411258827294], [0.66, 0.8329191509752634, 0.5136229654718514, 0.2647634410482185, 0.12485240149939422, 0.056513947321486686, 0.025117520097638683, 0.011073719058439067, 0.004864855621232653, 0.0021338832212674935, 0.0009353520345489071], [0.7100000000000001, 0.8439536384666498, 0.5398637070478294, 0.29332837136439105, 0.14696163017126834, 0.07088017775218242, 0.03358710313761802, 0.015785414063704938, 0.007390614133214937, 0.003454076972653304, 0.0016129576850827847], [0.76, 0.8537688580617658, 0.5647128006896603, 0.322726875556879, 0.17185029312003597, 0.08854797801090927, 0.04492225700716519, 0.022619868049918897, 0.01134810942803556, 0.005682871860920373, 0.0028432813779235315], [0.81, 0.862555051474255, 0.5882401064705446, 0.3528188523161229, 0.19968175189752, 0.11019417802456587, 0.060122119993871306, 0.032625409294969925, 0.017656455843715148, 0.009542149156486983, 0.005153127716555449], [0.8600000000000001, 0.8704648483921524, 0.6105128363961682, 0.3834509053516691, 0.23057158315678764, 0.13657778320455266, 0.08052086354268495, 0.04741061592039081, 0.027908552173115164, 0.016429145763646895, 0.00967228515103707], [0.91, 0.8776221235225735, 0.6315955002180051, 0.4144590274869386, 0.2645686878554427, 0.1685107663485549, 0.10786394402634085, 0.06944337932786597, 0.04492165350550454, 0.029161371144067954, 0.018977100510000847], [0.9600000000000001, 0.8841284638568696, 0.6515498833849404, 0.44567172323703985, 0.30163552107572394, 0.20679943073654272, 0.14435257482598793, 0.10246266679681, 0.07374313085397445, 0.05365697365741111, 0.03937297913635855]], \"data03\": [[0.8742159498207888, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086, 0.8279569892473121, 0.7927120669056155, 0.757467144563919, 0.7222222222222224, 0.6869772998805258, 0.6517323775388294], [0.8993055555555558, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086, 0.8279569892473121, 0.7927120669056155, 0.757467144563919, 0.7222222222222224, 0.6869772998805258, 0.6517323775388294]], \"data01\": [[0.01, 0.06367988688344325, 0.01063158514692595, 0.0023891360362745754, 0.0005730697817338912, 0.00013961326521384074, 3.414196281818837e-05, 8.357027621677835e-06, 2.046036939983362e-06, 5.009555176587583e-07, 1.2265655130461303e-07], [0.03, 0.16991256230689977, 0.03159161751825681, 0.007303543734334408, 0.0017821366602752606, 0.00044068855148335877, 0.00010933421717165804, 2.7147903948690358e-05, 6.742250508318086e-06, 1.6745395708335787e-06, 4.159023710803665e-07], [0.05, 0.25498680461114004, 0.05215119625415329, 0.012402290429793949, 0.0030792750052342005, 0.0007730229653668831, 0.00019460305243796714, 4.9024470221618055e-05, 1.2352455437097155e-05, 3.1125269291372943e-06, 7.842920931730465e-07], [0.06999999999999999, 0.32464974876257796, 0.07231494472231355, 0.01768866661457462, 0.004469723675984428, 0.0011393626572256358, 0.00029108847404831867, 7.441144962274092e-05, 1.90247487521813e-05, 4.8642352002604336e-06, 1.2436965053628329e-06], [0.09, 0.38273992925849015, 0.0920876391039664, 0.023165835927829136, 0.005959002875813745, 0.0015426921854442906, 0.00040005853353156627, 0.0001037912126231084, 2.693070574959306e-05, 6.98791943069978e-06, 1.8132238309966663e-06], [0.11, 0.4319188411942377, 0.11147419220613831, 0.028836819805588807, 0.007552926154132444, 0.00198625569087927, 0.0005229243161917953, 0.00013771189946502923, 3.62692160458131e-05, 9.552429664270125e-06, 2.51589142240714e-06], [0.13, 0.47408997325107044, 0.1304796380837603, 0.034704481616834836, 0.009257612451647211, 0.002473579981675562, 0.0006612567880854827, 0.00017679675673791667, 4.727098066974943e-05, 1.2639190598020382e-05, 3.3794425898214233e-06], [0.15000000000000002, 0.510650725608884, 0.14910911745492675, 0.04077151033105334, 0.011079498103245421, 0.00300849969572618, 0.0008168057474156411, 0.0002217548824091104, 6.0203791746771436e-05, 1.634456973552653e-05, 4.437341644435059e-06], [0.17, 0.542650121891528, 0.16736786389085395, 0.047040403769916625, 0.013025348698125503, 0.0035951847203394864, 0.0009915211595734504, 0.00027339360709986547, 7.537874031527423e-05, 2.0782715061279267e-05, 5.729988246697359e-06], [0.19, 0.5708910040840596, 0.1852611907606034, 0.053513451503600803, 0.015102270679690152, 0.004238170061185748, 0.0011875771941034794, 0.0003326327789962193, 9.315752690138636e-05, 2.6088961337990558e-05, 7.3062022353349975e-06], [0.21000000000000002, 0.5959982468825064, 0.202794478909404, 0.060192717460334756, 0.017317722548760746, 0.00494238836510139, 0.0014073993265649688, 0.00040052126677265874, 0.00011396108482240573, 3.242392653800315e-05, 9.225042842967103e-06], [0.23, 0.6184654812418521, 0.21997316504841471, 0.06708002232600861, 0.019679525512652674, 0.005713205313548979, 0.0016536949194257496, 0.0004782560507561918, 0.00013827976924534065, 3.997844777687647e-05, 1.1558042324431352e-05], [0.25, 0.6386878321252417, 0.23680273083298423, 0.07417692581896031, 0.02219587339946372, 0.006556458115081259, 0.0019294877546822862, 0.0005672043390537293, 0.00016668541760615573, 4.897954084749824e-05, 1.439195450286643e-05], [0.27, 0.6569853224828244, 0.25328869260588344, 0.08148470893331931, 0.024875341631487014, 0.007478497335541756, 0.002238157057892846, 0.0006689292246708465, 0.00019984565136891514, 5.969761088459275e-05, 1.7832144842371188e-05], [0.29000000000000004, 0.673619907272919, 0.2694365917815751, 0.08900435625240127, 0.027726895023906486, 0.008486232313311862, 0.0025834816299100203, 0.0007852194943941185, 0.00023854086812537717, 7.245519617402295e-05, 2.200678204653747e-05], [0.31, 0.6888080724469053, 0.2852519858473317, 0.0967365384415001, 0.03075989414485019, 0.009587180412868233, 0.002969689790104995, 0.0009181243135902103, 0.00028368447030079655, 8.763759569625411e-05, 2.7072034049898932e-05], [0.33, 0.7027302900447678, 0.3007404399569139, 0.10468159503689814, 0.033984099940501514, 0.010789520372213044, 0.003401515934722812, 0.0010699936469869599, 0.00033634699678667675, 0.00010570581759730596, 3.321852651481573e-05], [0.35000000000000003, 0.7155382081187842, 0.3159075190925285, 0.11283951765485202, 0.03740967629439494, 0.012102149997085615, 0.0038842646277531872, 0.0012435254386915636, 0.0003977849724302706, 0.0001272123955412273, 4.067939342788858e-05], [0.37, 0.727360184292402, 0.33075878077093207, 0.12120993375059774, 0.04104719015344512, 0.013534748445646694, 0.004423883271012405, 0.0014418207709595524, 0.00046947547480648554, 0.0001528207595201384, 4.97403422653791e-05], [0.39, 0.7383055916722793, 0.3452997682697651, 0.12979209106287903, 0.04490760881494969, 0.015097843329543805, 0.005027044546744987, 0.0016684484576235108, 0.0005531576474375159, 0.0001833290259854959, 6.075227739592375e-05], [0.41000000000000003, 0.7484682035359016, 0.35953600435052574, 0.13858484288400263, 0.049002293929187715, 0.01680288282846426, 0.005701239991718905, 0.0019275208132517692, 0.0006508826755883312, 0.00021969930073185583, 7.414718427087213e-05], [0.43, 0.7579288788169939, 0.37347298545498536, 0.14758663429881322, 0.053342991731855846, 0.018662312972458, 0.00645488624816967, 0.0022237826835679294, 0.000765074100337679, 0.00026309388220507353, 9.045818623006736e-05], [0.45, 0.7667577112931204, 0.3871161763523047, 0.15679548953809727, 0.05794181898017751, 0.020689660185818765, 0.007297445745478057, 0.002562716239271076, 0.000898600798629073, 0.00031492013332044334, 0.00011034496278918067], [0.47000000000000003, 0.7750157634005722, 0.40047100521461904, 0.16620900059264357, 0.0628112440270151, 0.022899619103755837, 0.008239563798126043, 0.002950664539807187, 0.001054865527070621, 0.00037688628390057676, 0.00013462608693905567], [0.49, 0.7827564754125486, 0.4135428590994216, 0.17582431723336528, 0.06796406242987232, 0.025308145563207245, 0.009293224360476339, 0.0033949774848838765, 0.0012379126486066813, 0.0004510710703909248, 0.0001643203322832682], [0.51, 0.7900268187497871, 0.42633707981767105, 0.18563813858041225, 0.07341336645770982, 0.02793255452569352, 0.010471926956248568, 0.00390418451265159, 0.001452559577050862, 0.0005400109645078959, 0.00020069966471509683], [0.53, 0.7968682460330774, 0.4388589601671661, 0.19564670635995762, 0.07917250782971055, 0.03079162250573868, 0.011790887597329757, 0.004488199302307413, 0.0017045576412327628, 0.0006468098558134575, 0.0002453575321968572], [0.55, 0.8033174784774164, 0.45111374051138875, 0.20584579998126967, 0.08525505299852983, 0.03390569384453736, 0.013267266817093476, 0.005158562828740815, 0.002000789561924028, 0.0007752775277369821, 0.00030029729098928273], [0.5700000000000001, 0.8094071622165869, 0.4631066056846778, 0.21623073355870007, 0.09167473027847502, 0.037296789875385615, 0.014920428258010156, 0.00592873243730215, 0.0023495126474819624, 0.0009301052299787599, 0.00036804728674839584], [0.59, 0.8151664183251784, 0.47484268220527115, 0.22679635499331172, 0.09844536811913665, 0.04098871966376782, 0.016772231556557642, 0.006814426204204242, 0.0027606592753508102, 0.0011170892791921372, 0.0004518114297410051], [0.61, 0.8206213060970884, 0.4863270357784449, 0.23753704721704258, 0.10558082384021891, 0.04500719055851028, 0.018847363536735308, 0.007834033775786446, 0.003246209403403585, 0.0013434171601997046, 0.0005556673331616795], [0.63, 0.8257952151320227, 0.49756466907266134, 0.24844673168857556, 0.11309490217696608, 0.0493799162476011, 0.021173711922037677, 0.009009107197494818, 0.0038206539677942404, 0.0016180353959165245, 0.0006848286131247813], [0.65, 0.8307091986746882, 0.5085605197523264, 0.25951887421454917, 0.12100126304118822, 0.05413671935896912, 0.02378278585427638, 0.010364948014726264, 0.004501573362436066, 0.0019521249902816858, 0.0008459943535234541], [0.67, 0.8353822582257765, 0.5193194587514406, 0.2707464931524828, 0.12931331798415666, 0.059309624868459726, 0.026710187394843314, 0.011931310215819587, 0.005310362140485372, 0.0023597192112868037, 0.0010478178726558167], [0.6900000000000001, 0.8398315875374739, 0.5298462887730996, 0.2821221700329782, 0.13804411495835384, 0.06493293966108168, 0.02999613778032365, 0.013743242445921577, 0.006273140129311651, 0.002858510848311959, 0.0013015400717670753], [0.7100000000000001, 0.8440727825984484, 0.5401457430004737, 0.2936380626185537, 0.14720621111892696, 0.07104331252630672, 0.03368606137275331, 0.01584209737665371, 0.007421901956610452, 0.0034709132490487655, 0.001621851737296603], [0.73, 0.8481200230135886, 0.5502224840055429, 0.30528592039510005, 0.1568115335861503, 0.07767976764713637, 0.037831228799212156, 0.018276741143902563, 0.008795972382103221, 0.004225463428895871, 0.0020280771744382474], [0.75, 0.85198622922378, 0.5600811028425084, 0.31705710246967095, 0.16687122831020113, 0.08488370326634306, 0.04248945846681752, 0.021105001237584454, 0.010443854873246507, 0.00515868925375802, 0.0025458130532591476], [0.77, 0.8556831992386696, 0.56972611831343, 0.3289425978254107, 0.17739549744126232, 0.09269884569317555, 0.047725872139301725, 0.024395396839681196, 0.012425586852744188, 0.006317610323174869, 0.0032092185073841106], [0.79, 0.8592217279307705, 0.579161976394243, 0.34093304786119416, 0.1883934259124522, 0.10117114717697274, 0.05361369514526779, 0.028229200760318342, 0.014815748498779395, 0.007763109787935119, 0.0040642466278324055], [0.81, 0.862611711431681, 0.5883930498099063, 0.35301877112033275, 0.1998727982899524, 0.11034861446920015, 0.060235084517442375, 0.03270288573088038, 0.01770731451330398, 0.00957451064337302, 0.005173251513484062], [0.8300000000000001, 0.8658622387567482, 0.5974236377480058, 0.365189790089831, 0.21183990733170857, 0.1202810531996541, 0.06768195827290971, 0.0379310080176956, 0.021216591271973173, 0.01185582744778291, 0.006621627820854752], [0.85, 0.8689816724445925, 0.6062579657006925, 0.3774358599295123, 0.22429935611873483, 0.13101971161977816, 0.07605678534756088, 0.04404957504884225, 0.025489545612351616, 0.014744360187155886, 0.008527487865105442], [0.87, 0.8719777197179408, 0.6149001854253731, 0.3897464989692256, 0.23725385607425267, 0.14261680597501072, 0.08547327750500643, 0.051219926083347, 0.030709903973071932, 0.018422574187885704, 0.011055930056695529], [0.89, 0.8748574954406478, 0.6233543750150878, 0.40211102079262523, 0.2507040236555988, 0.1551249089706182, 0.09605690093116133, 0.059633118241102116, 0.03710947360843843, 0.023134596812672256, 0.01444032287192198], [0.91, 0.8776275779535141, 0.6316245390700103, 0.4145185677080473, 0.26464817897886356, 0.1685961827624801, 0.10794509539142386, 0.06951474287699677, 0.04498119112473731, 0.029209186176976456, 0.019014411524148553], [0.93, 0.8802940587112572, 0.6397146089619798, 0.42695814539105037, 0.2790821501001028, 0.1830814389678617, 0.12128705232321715, 0.081129982410075, 0.05469539416680809, 0.03709169848222272, 0.025261236842803785], [0.9500000000000001, 0.8828625865089388, 0.6476284431844384, 0.4394186584695643, 0.2939990871101362, 0.19862901073978972, 0.13624286039932584, 0.09478853168219174, 0.06671965254498287, 0.04738833757926249, 0.03388822002658438], [0.97, 0.8853384069736263, 0.6553698277805843, 0.45188894681150976, 0.30938929057998404, 0.21528342641147066, 0.15298177967920856, 0.11084871981207456, 0.08164202019123602, 0.06092655195157571, 0.04594265558263385], [0.99, 0.887726397902296, 0.662942476842977, 0.46435782226642786, 0.3252400591962998, 0.23308388103379943, 0.17167935752895855, 0.1297197420685918, 0.10019648250115669, 0.07883508554178247, 0.0629879399835792]]}, \"id\": \"el9520170399280\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "         \n",
        "         mpld3.draw_figure(\"fig_el95201703992806042753061\", {\"axes\": [{\"xlim\": [0.0, 1.3], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$E$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520194646144\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520169581424\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Transmission Coefficient as a Function of Energy\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520175988632\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 0.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el9520169558648\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el9520168769688\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el9520168770864\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el9520168812672\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.81959378733572308], \"rotation\": -0.0, \"id\": \"el9520176056304\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.78434886499402645], \"rotation\": -0.0, \"id\": \"el9520168815584\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.74910394265232993], \"rotation\": -0.0, \"id\": \"el9520170464592\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 4.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.71385902031063342], \"rotation\": -0.0, \"id\": \"el9520194536616\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 4.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.67861409796893679], \"rotation\": -0.0, \"id\": \"el9520194668584\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 5.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.64336917562724039], \"rotation\": -0.0, \"id\": \"el9520170448544\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 1.3], \"ylim\": [0.0, 0.90000000000000002], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data04\", \"id\": \"el9520169558816\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 10, \"tickvalues\": null}], \"lines\": [{\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168811768\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170382560\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170383904\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168822824\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170492424\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168689848\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169514880\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169514712\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170473456\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168863672\"}, {\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169560608\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168771312\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168814296\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168814240\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170464816\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168768456\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170502352\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520194669032\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520194669368\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170447256\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FF4D27\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168312448pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF954E\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170384800pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#E6CD73\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168823104pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#B2F295\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170491976pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#80FEB3\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170493040pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4CF2CE\", \"edgewidth\": 0.5, \"yindex\": 6, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168690408pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#18CDE3\", \"edgewidth\": 0.5, \"yindex\": 7, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169515272pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#1995F2\", \"edgewidth\": 0.5, \"yindex\": 8, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520175893024pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4D4DFB\", \"edgewidth\": 0.5, \"yindex\": 9, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170472952pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#7F00FF\", \"edgewidth\": 0.5, \"yindex\": 10, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168862608pts\"}], \"id\": \"el9520170358656\", \"ydomain\": [0.0, 0.90000000000000002], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data04\": [[0.8616711469534052, 0.6284348864994028], [0.9910394265232977, 0.6284348864994028], [0.9910394265232977, 0.9880525686977301], [0.8616711469534052, 0.9880525686977301], [0.8616711469534052, 0.6284348864994028]], \"data02\": [[0.01, 0.06344853504451091, 0.010583339995665488, 0.002375888393666644, 0.0005692604561473782, 0.00013852590269955418, 3.383666006050032e-05, 8.272630778546611e-06, 2.0230077871021055e-06, 4.947381853542348e-07, 1.209927166626799e-07], [0.060000000000000005, 0.29071246992612554, 0.06202850138906503, 0.014943702187008488, 0.0037387395911720666, 0.0009446825933065767, 0.0002393002165032453, 6.0656703491843206e-05, 1.5377481615772445e-05, 3.898608338481522e-06, 9.88413363002719e-07], [0.11, 0.43106971447199705, 0.11106787520506595, 0.028696794626959735, 0.0075077811368943785, 0.001972188923567964, 0.0005186451192499174, 0.00013643355691338096, 3.589270830104503e-05, 9.44278902976266e-06, 2.4842583920052985e-06], [0.16000000000000003, 0.526355704491522, 0.1577703833463456, 0.043682612847738965, 0.011968658941778327, 0.0032729497650294684, 0.0008946087147887039, 0.0002444975678169504, 6.68192904396209e-05, 1.8261034349048996e-05, 4.990543990129478e-06], [0.21000000000000002, 0.5952670090163205, 0.2022100859072628, 0.05994181641280863, 0.017226118286076925, 0.004910979952436159, 0.0013969827425635876, 0.0003971405238845973, 0.00011288102511062366, 3.2083077009422586e-05, 9.118532652275172e-06], [0.26, 0.6474154397368123, 0.2444648144039451, 0.07750659857727912, 0.023398521007346313, 0.0069652905728896765, 0.002064929412042227, 0.0006114272849280538, 0.00018097926971581555, 5.3563240353104514e-05, 1.5852262876308347e-05], [0.31000000000000005, 0.6882482739239967, 0.28461497926640267, 0.09639894429906204, 0.03061887045890425, 0.00953345744064533, 0.002950113852689762, 0.0009111758307435065, 0.0002812619916347763, 8.680432569022723e-05, 2.6788443008915422e-05], [0.36000000000000004, 0.7210832956501965, 0.3227425390144358, 0.1166288783427331, 0.03903559962673558, 0.012736013134185157, 0.0041209605553941195, 0.0013298326690558068, 0.00042876491916371475, 0.000138203866231584, 4.454326606650338e-05], [0.41000000000000003, 0.7480567474046081, 0.3589301200359493, 0.1381927699276826, 0.04881296274547962, 0.016721815301092003, 0.005668462513559375, 0.0019146883135644733, 0.0006459628472268159, 0.00021784140212601023, 7.34537156458573e-05], [0.46, 0.770606300259536, 0.39326027137193015, 0.16107177061864378, 0.06013081924723233, 0.02167454047476267, 0.007714139858769179, 0.002733119887640358, 0.0009667912306912413, 0.00034179056098184563, 0.00012080925979798617], [0.51, 0.7897350219905663, 0.42581484236390893, 0.18523047166010342, 0.07318354051728929, 0.02782041932289035, 0.010420974822719645, 0.0038819337477554016, 0.0014430828438871369, 0.0005360446729563266, 0.00019906130040885336], [0.56, 0.8061640629313125, 0.4566744701275893, 0.21061587025366477, 0.08817770915272707, 0.035437240377691276, 0.01400845653670786, 0.005501500568146045, 0.002155043841401391, 0.0008433227245041854, 0.00032988332581726705], [0.6100000000000001, 0.8204251959536566, 0.4859181622764129, 0.23715673350117839, 0.10532822544602145, 0.044864464384898835, 0.018773258570766393, 0.007797376094145474, 0.003228619230889122, 0.0013351504205216984, 0.0005518411258827294], [0.66, 0.8329191509752634, 0.5136229654718514, 0.2647634410482185, 0.12485240149939422, 0.056513947321486686, 0.025117520097638683, 0.011073719058439067, 0.004864855621232653, 0.0021338832212674935, 0.0009353520345489071], [0.7100000000000001, 0.8439536384666498, 0.5398637070478294, 0.29332837136439105, 0.14696163017126834, 0.07088017775218242, 0.03358710313761802, 0.015785414063704938, 0.007390614133214937, 0.003454076972653304, 0.0016129576850827847], [0.76, 0.8537688580617658, 0.5647128006896603, 0.322726875556879, 0.17185029312003597, 0.08854797801090927, 0.04492225700716519, 0.022619868049918897, 0.01134810942803556, 0.005682871860920373, 0.0028432813779235315], [0.81, 0.862555051474255, 0.5882401064705446, 0.3528188523161229, 0.19968175189752, 0.11019417802456587, 0.060122119993871306, 0.032625409294969925, 0.017656455843715148, 0.009542149156486983, 0.005153127716555449], [0.8600000000000001, 0.8704648483921524, 0.6105128363961682, 0.3834509053516691, 0.23057158315678764, 0.13657778320455266, 0.08052086354268495, 0.04741061592039081, 0.027908552173115164, 0.016429145763646895, 0.00967228515103707], [0.91, 0.8776221235225735, 0.6315955002180051, 0.4144590274869386, 0.2645686878554427, 0.1685107663485549, 0.10786394402634085, 0.06944337932786597, 0.04492165350550454, 0.029161371144067954, 0.018977100510000847], [0.9600000000000001, 0.8841284638568696, 0.6515498833849404, 0.44567172323703985, 0.30163552107572394, 0.20679943073654272, 0.14435257482598793, 0.10246266679681, 0.07374313085397445, 0.05365697365741111, 0.03937297913635855]], \"data03\": [[0.8742159498207888, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086, 0.8279569892473121, 0.7927120669056155, 0.757467144563919, 0.7222222222222224, 0.6869772998805258, 0.6517323775388294], [0.8993055555555558, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086, 0.8279569892473121, 0.7927120669056155, 0.757467144563919, 0.7222222222222224, 0.6869772998805258, 0.6517323775388294]], \"data01\": [[0.01, 0.06367988688344325, 0.01063158514692595, 0.0023891360362745754, 0.0005730697817338912, 0.00013961326521384074, 3.414196281818837e-05, 8.357027621677835e-06, 2.046036939983362e-06, 5.009555176587583e-07, 1.2265655130461303e-07], [0.03, 0.16991256230689977, 0.03159161751825681, 0.007303543734334408, 0.0017821366602752606, 0.00044068855148335877, 0.00010933421717165804, 2.7147903948690358e-05, 6.742250508318086e-06, 1.6745395708335787e-06, 4.159023710803665e-07], [0.05, 0.25498680461114004, 0.05215119625415329, 0.012402290429793949, 0.0030792750052342005, 0.0007730229653668831, 0.00019460305243796714, 4.9024470221618055e-05, 1.2352455437097155e-05, 3.1125269291372943e-06, 7.842920931730465e-07], [0.06999999999999999, 0.32464974876257796, 0.07231494472231355, 0.01768866661457462, 0.004469723675984428, 0.0011393626572256358, 0.00029108847404831867, 7.441144962274092e-05, 1.90247487521813e-05, 4.8642352002604336e-06, 1.2436965053628329e-06], [0.09, 0.38273992925849015, 0.0920876391039664, 0.023165835927829136, 0.005959002875813745, 0.0015426921854442906, 0.00040005853353156627, 0.0001037912126231084, 2.693070574959306e-05, 6.98791943069978e-06, 1.8132238309966663e-06], [0.11, 0.4319188411942377, 0.11147419220613831, 0.028836819805588807, 0.007552926154132444, 0.00198625569087927, 0.0005229243161917953, 0.00013771189946502923, 3.62692160458131e-05, 9.552429664270125e-06, 2.51589142240714e-06], [0.13, 0.47408997325107044, 0.1304796380837603, 0.034704481616834836, 0.009257612451647211, 0.002473579981675562, 0.0006612567880854827, 0.00017679675673791667, 4.727098066974943e-05, 1.2639190598020382e-05, 3.3794425898214233e-06], [0.15000000000000002, 0.510650725608884, 0.14910911745492675, 0.04077151033105334, 0.011079498103245421, 0.00300849969572618, 0.0008168057474156411, 0.0002217548824091104, 6.0203791746771436e-05, 1.634456973552653e-05, 4.437341644435059e-06], [0.17, 0.542650121891528, 0.16736786389085395, 0.047040403769916625, 0.013025348698125503, 0.0035951847203394864, 0.0009915211595734504, 0.00027339360709986547, 7.537874031527423e-05, 2.0782715061279267e-05, 5.729988246697359e-06], [0.19, 0.5708910040840596, 0.1852611907606034, 0.053513451503600803, 0.015102270679690152, 0.004238170061185748, 0.0011875771941034794, 0.0003326327789962193, 9.315752690138636e-05, 2.6088961337990558e-05, 7.3062022353349975e-06], [0.21000000000000002, 0.5959982468825064, 0.202794478909404, 0.060192717460334756, 0.017317722548760746, 0.00494238836510139, 0.0014073993265649688, 0.00040052126677265874, 0.00011396108482240573, 3.242392653800315e-05, 9.225042842967103e-06], [0.23, 0.6184654812418521, 0.21997316504841471, 0.06708002232600861, 0.019679525512652674, 0.005713205313548979, 0.0016536949194257496, 0.0004782560507561918, 0.00013827976924534065, 3.997844777687647e-05, 1.1558042324431352e-05], [0.25, 0.6386878321252417, 0.23680273083298423, 0.07417692581896031, 0.02219587339946372, 0.006556458115081259, 0.0019294877546822862, 0.0005672043390537293, 0.00016668541760615573, 4.897954084749824e-05, 1.439195450286643e-05], [0.27, 0.6569853224828244, 0.25328869260588344, 0.08148470893331931, 0.024875341631487014, 0.007478497335541756, 0.002238157057892846, 0.0006689292246708465, 0.00019984565136891514, 5.969761088459275e-05, 1.7832144842371188e-05], [0.29000000000000004, 0.673619907272919, 0.2694365917815751, 0.08900435625240127, 0.027726895023906486, 0.008486232313311862, 0.0025834816299100203, 0.0007852194943941185, 0.00023854086812537717, 7.245519617402295e-05, 2.200678204653747e-05], [0.31, 0.6888080724469053, 0.2852519858473317, 0.0967365384415001, 0.03075989414485019, 0.009587180412868233, 0.002969689790104995, 0.0009181243135902103, 0.00028368447030079655, 8.763759569625411e-05, 2.7072034049898932e-05], [0.33, 0.7027302900447678, 0.3007404399569139, 0.10468159503689814, 0.033984099940501514, 0.010789520372213044, 0.003401515934722812, 0.0010699936469869599, 0.00033634699678667675, 0.00010570581759730596, 3.321852651481573e-05], [0.35000000000000003, 0.7155382081187842, 0.3159075190925285, 0.11283951765485202, 0.03740967629439494, 0.012102149997085615, 0.0038842646277531872, 0.0012435254386915636, 0.0003977849724302706, 0.0001272123955412273, 4.067939342788858e-05], [0.37, 0.727360184292402, 0.33075878077093207, 0.12120993375059774, 0.04104719015344512, 0.013534748445646694, 0.004423883271012405, 0.0014418207709595524, 0.00046947547480648554, 0.0001528207595201384, 4.97403422653791e-05], [0.39, 0.7383055916722793, 0.3452997682697651, 0.12979209106287903, 0.04490760881494969, 0.015097843329543805, 0.005027044546744987, 0.0016684484576235108, 0.0005531576474375159, 0.0001833290259854959, 6.075227739592375e-05], [0.41000000000000003, 0.7484682035359016, 0.35953600435052574, 0.13858484288400263, 0.049002293929187715, 0.01680288282846426, 0.005701239991718905, 0.0019275208132517692, 0.0006508826755883312, 0.00021969930073185583, 7.414718427087213e-05], [0.43, 0.7579288788169939, 0.37347298545498536, 0.14758663429881322, 0.053342991731855846, 0.018662312972458, 0.00645488624816967, 0.0022237826835679294, 0.000765074100337679, 0.00026309388220507353, 9.045818623006736e-05], [0.45, 0.7667577112931204, 0.3871161763523047, 0.15679548953809727, 0.05794181898017751, 0.020689660185818765, 0.007297445745478057, 0.002562716239271076, 0.000898600798629073, 0.00031492013332044334, 0.00011034496278918067], [0.47000000000000003, 0.7750157634005722, 0.40047100521461904, 0.16620900059264357, 0.0628112440270151, 0.022899619103755837, 0.008239563798126043, 0.002950664539807187, 0.001054865527070621, 0.00037688628390057676, 0.00013462608693905567], [0.49, 0.7827564754125486, 0.4135428590994216, 0.17582431723336528, 0.06796406242987232, 0.025308145563207245, 0.009293224360476339, 0.0033949774848838765, 0.0012379126486066813, 0.0004510710703909248, 0.0001643203322832682], [0.51, 0.7900268187497871, 0.42633707981767105, 0.18563813858041225, 0.07341336645770982, 0.02793255452569352, 0.010471926956248568, 0.00390418451265159, 0.001452559577050862, 0.0005400109645078959, 0.00020069966471509683], [0.53, 0.7968682460330774, 0.4388589601671661, 0.19564670635995762, 0.07917250782971055, 0.03079162250573868, 0.011790887597329757, 0.004488199302307413, 0.0017045576412327628, 0.0006468098558134575, 0.0002453575321968572], [0.55, 0.8033174784774164, 0.45111374051138875, 0.20584579998126967, 0.08525505299852983, 0.03390569384453736, 0.013267266817093476, 0.005158562828740815, 0.002000789561924028, 0.0007752775277369821, 0.00030029729098928273], [0.5700000000000001, 0.8094071622165869, 0.4631066056846778, 0.21623073355870007, 0.09167473027847502, 0.037296789875385615, 0.014920428258010156, 0.00592873243730215, 0.0023495126474819624, 0.0009301052299787599, 0.00036804728674839584], [0.59, 0.8151664183251784, 0.47484268220527115, 0.22679635499331172, 0.09844536811913665, 0.04098871966376782, 0.016772231556557642, 0.006814426204204242, 0.0027606592753508102, 0.0011170892791921372, 0.0004518114297410051], [0.61, 0.8206213060970884, 0.4863270357784449, 0.23753704721704258, 0.10558082384021891, 0.04500719055851028, 0.018847363536735308, 0.007834033775786446, 0.003246209403403585, 0.0013434171601997046, 0.0005556673331616795], [0.63, 0.8257952151320227, 0.49756466907266134, 0.24844673168857556, 0.11309490217696608, 0.0493799162476011, 0.021173711922037677, 0.009009107197494818, 0.0038206539677942404, 0.0016180353959165245, 0.0006848286131247813], [0.65, 0.8307091986746882, 0.5085605197523264, 0.25951887421454917, 0.12100126304118822, 0.05413671935896912, 0.02378278585427638, 0.010364948014726264, 0.004501573362436066, 0.0019521249902816858, 0.0008459943535234541], [0.67, 0.8353822582257765, 0.5193194587514406, 0.2707464931524828, 0.12931331798415666, 0.059309624868459726, 0.026710187394843314, 0.011931310215819587, 0.005310362140485372, 0.0023597192112868037, 0.0010478178726558167], [0.6900000000000001, 0.8398315875374739, 0.5298462887730996, 0.2821221700329782, 0.13804411495835384, 0.06493293966108168, 0.02999613778032365, 0.013743242445921577, 0.006273140129311651, 0.002858510848311959, 0.0013015400717670753], [0.7100000000000001, 0.8440727825984484, 0.5401457430004737, 0.2936380626185537, 0.14720621111892696, 0.07104331252630672, 0.03368606137275331, 0.01584209737665371, 0.007421901956610452, 0.0034709132490487655, 0.001621851737296603], [0.73, 0.8481200230135886, 0.5502224840055429, 0.30528592039510005, 0.1568115335861503, 0.07767976764713637, 0.037831228799212156, 0.018276741143902563, 0.008795972382103221, 0.004225463428895871, 0.0020280771744382474], [0.75, 0.85198622922378, 0.5600811028425084, 0.31705710246967095, 0.16687122831020113, 0.08488370326634306, 0.04248945846681752, 0.021105001237584454, 0.010443854873246507, 0.00515868925375802, 0.0025458130532591476], [0.77, 0.8556831992386696, 0.56972611831343, 0.3289425978254107, 0.17739549744126232, 0.09269884569317555, 0.047725872139301725, 0.024395396839681196, 0.012425586852744188, 0.006317610323174869, 0.0032092185073841106], [0.79, 0.8592217279307705, 0.579161976394243, 0.34093304786119416, 0.1883934259124522, 0.10117114717697274, 0.05361369514526779, 0.028229200760318342, 0.014815748498779395, 0.007763109787935119, 0.0040642466278324055], [0.81, 0.862611711431681, 0.5883930498099063, 0.35301877112033275, 0.1998727982899524, 0.11034861446920015, 0.060235084517442375, 0.03270288573088038, 0.01770731451330398, 0.00957451064337302, 0.005173251513484062], [0.8300000000000001, 0.8658622387567482, 0.5974236377480058, 0.365189790089831, 0.21183990733170857, 0.1202810531996541, 0.06768195827290971, 0.0379310080176956, 0.021216591271973173, 0.01185582744778291, 0.006621627820854752], [0.85, 0.8689816724445925, 0.6062579657006925, 0.3774358599295123, 0.22429935611873483, 0.13101971161977816, 0.07605678534756088, 0.04404957504884225, 0.025489545612351616, 0.014744360187155886, 0.008527487865105442], [0.87, 0.8719777197179408, 0.6149001854253731, 0.3897464989692256, 0.23725385607425267, 0.14261680597501072, 0.08547327750500643, 0.051219926083347, 0.030709903973071932, 0.018422574187885704, 0.011055930056695529], [0.89, 0.8748574954406478, 0.6233543750150878, 0.40211102079262523, 0.2507040236555988, 0.1551249089706182, 0.09605690093116133, 0.059633118241102116, 0.03710947360843843, 0.023134596812672256, 0.01444032287192198], [0.91, 0.8776275779535141, 0.6316245390700103, 0.4145185677080473, 0.26464817897886356, 0.1685961827624801, 0.10794509539142386, 0.06951474287699677, 0.04498119112473731, 0.029209186176976456, 0.019014411524148553], [0.93, 0.8802940587112572, 0.6397146089619798, 0.42695814539105037, 0.2790821501001028, 0.1830814389678617, 0.12128705232321715, 0.081129982410075, 0.05469539416680809, 0.03709169848222272, 0.025261236842803785], [0.9500000000000001, 0.8828625865089388, 0.6476284431844384, 0.4394186584695643, 0.2939990871101362, 0.19862901073978972, 0.13624286039932584, 0.09478853168219174, 0.06671965254498287, 0.04738833757926249, 0.03388822002658438], [0.97, 0.8853384069736263, 0.6553698277805843, 0.45188894681150976, 0.30938929057998404, 0.21528342641147066, 0.15298177967920856, 0.11084871981207456, 0.08164202019123602, 0.06092655195157571, 0.04594265558263385], [0.99, 0.887726397902296, 0.662942476842977, 0.46435782226642786, 0.3252400591962998, 0.23308388103379943, 0.17167935752895855, 0.1297197420685918, 0.10019648250115669, 0.07883508554178247, 0.0629879399835792]]}, \"id\": \"el9520170399280\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "                 \n",
        "                 mpld3.draw_figure(\"fig_el95201703992806042753061\", {\"axes\": [{\"xlim\": [0.0, 1.3], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$E$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520194646144\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520169581424\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Transmission Coefficient as a Function of Energy\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520175988632\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 0.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el9520169558648\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el9520168769688\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el9520168770864\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el9520168812672\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.81959378733572308], \"rotation\": -0.0, \"id\": \"el9520176056304\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.78434886499402645], \"rotation\": -0.0, \"id\": \"el9520168815584\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.74910394265232993], \"rotation\": -0.0, \"id\": \"el9520170464592\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 4.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.71385902031063342], \"rotation\": -0.0, \"id\": \"el9520194536616\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 4.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.67861409796893679], \"rotation\": -0.0, \"id\": \"el9520194668584\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 5.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.64336917562724039], \"rotation\": -0.0, \"id\": \"el9520170448544\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 1.3], \"ylim\": [0.0, 0.90000000000000002], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data04\", \"id\": \"el9520169558816\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 10, \"tickvalues\": null}], \"lines\": [{\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168811768\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170382560\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170383904\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168822824\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170492424\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168689848\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169514880\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169514712\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170473456\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168863672\"}, {\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169560608\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168771312\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168814296\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168814240\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170464816\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168768456\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170502352\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520194669032\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520194669368\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170447256\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FF4D27\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168312448pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF954E\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170384800pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#E6CD73\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168823104pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#B2F295\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170491976pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#80FEB3\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170493040pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4CF2CE\", \"edgewidth\": 0.5, \"yindex\": 6, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168690408pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#18CDE3\", \"edgewidth\": 0.5, \"yindex\": 7, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169515272pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#1995F2\", \"edgewidth\": 0.5, \"yindex\": 8, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520175893024pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4D4DFB\", \"edgewidth\": 0.5, \"yindex\": 9, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170472952pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#7F00FF\", \"edgewidth\": 0.5, \"yindex\": 10, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168862608pts\"}], \"id\": \"el9520170358656\", \"ydomain\": [0.0, 0.90000000000000002], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data04\": [[0.8616711469534052, 0.6284348864994028], [0.9910394265232977, 0.6284348864994028], [0.9910394265232977, 0.9880525686977301], [0.8616711469534052, 0.9880525686977301], [0.8616711469534052, 0.6284348864994028]], \"data02\": [[0.01, 0.06344853504451091, 0.010583339995665488, 0.002375888393666644, 0.0005692604561473782, 0.00013852590269955418, 3.383666006050032e-05, 8.272630778546611e-06, 2.0230077871021055e-06, 4.947381853542348e-07, 1.209927166626799e-07], [0.060000000000000005, 0.29071246992612554, 0.06202850138906503, 0.014943702187008488, 0.0037387395911720666, 0.0009446825933065767, 0.0002393002165032453, 6.0656703491843206e-05, 1.5377481615772445e-05, 3.898608338481522e-06, 9.88413363002719e-07], [0.11, 0.43106971447199705, 0.11106787520506595, 0.028696794626959735, 0.0075077811368943785, 0.001972188923567964, 0.0005186451192499174, 0.00013643355691338096, 3.589270830104503e-05, 9.44278902976266e-06, 2.4842583920052985e-06], [0.16000000000000003, 0.526355704491522, 0.1577703833463456, 0.043682612847738965, 0.011968658941778327, 0.0032729497650294684, 0.0008946087147887039, 0.0002444975678169504, 6.68192904396209e-05, 1.8261034349048996e-05, 4.990543990129478e-06], [0.21000000000000002, 0.5952670090163205, 0.2022100859072628, 0.05994181641280863, 0.017226118286076925, 0.004910979952436159, 0.0013969827425635876, 0.0003971405238845973, 0.00011288102511062366, 3.2083077009422586e-05, 9.118532652275172e-06], [0.26, 0.6474154397368123, 0.2444648144039451, 0.07750659857727912, 0.023398521007346313, 0.0069652905728896765, 0.002064929412042227, 0.0006114272849280538, 0.00018097926971581555, 5.3563240353104514e-05, 1.5852262876308347e-05], [0.31000000000000005, 0.6882482739239967, 0.28461497926640267, 0.09639894429906204, 0.03061887045890425, 0.00953345744064533, 0.002950113852689762, 0.0009111758307435065, 0.0002812619916347763, 8.680432569022723e-05, 2.6788443008915422e-05], [0.36000000000000004, 0.7210832956501965, 0.3227425390144358, 0.1166288783427331, 0.03903559962673558, 0.012736013134185157, 0.0041209605553941195, 0.0013298326690558068, 0.00042876491916371475, 0.000138203866231584, 4.454326606650338e-05], [0.41000000000000003, 0.7480567474046081, 0.3589301200359493, 0.1381927699276826, 0.04881296274547962, 0.016721815301092003, 0.005668462513559375, 0.0019146883135644733, 0.0006459628472268159, 0.00021784140212601023, 7.34537156458573e-05], [0.46, 0.770606300259536, 0.39326027137193015, 0.16107177061864378, 0.06013081924723233, 0.02167454047476267, 0.007714139858769179, 0.002733119887640358, 0.0009667912306912413, 0.00034179056098184563, 0.00012080925979798617], [0.51, 0.7897350219905663, 0.42581484236390893, 0.18523047166010342, 0.07318354051728929, 0.02782041932289035, 0.010420974822719645, 0.0038819337477554016, 0.0014430828438871369, 0.0005360446729563266, 0.00019906130040885336], [0.56, 0.8061640629313125, 0.4566744701275893, 0.21061587025366477, 0.08817770915272707, 0.035437240377691276, 0.01400845653670786, 0.005501500568146045, 0.002155043841401391, 0.0008433227245041854, 0.00032988332581726705], [0.6100000000000001, 0.8204251959536566, 0.4859181622764129, 0.23715673350117839, 0.10532822544602145, 0.044864464384898835, 0.018773258570766393, 0.007797376094145474, 0.003228619230889122, 0.0013351504205216984, 0.0005518411258827294], [0.66, 0.8329191509752634, 0.5136229654718514, 0.2647634410482185, 0.12485240149939422, 0.056513947321486686, 0.025117520097638683, 0.011073719058439067, 0.004864855621232653, 0.0021338832212674935, 0.0009353520345489071], [0.7100000000000001, 0.8439536384666498, 0.5398637070478294, 0.29332837136439105, 0.14696163017126834, 0.07088017775218242, 0.03358710313761802, 0.015785414063704938, 0.007390614133214937, 0.003454076972653304, 0.0016129576850827847], [0.76, 0.8537688580617658, 0.5647128006896603, 0.322726875556879, 0.17185029312003597, 0.08854797801090927, 0.04492225700716519, 0.022619868049918897, 0.01134810942803556, 0.005682871860920373, 0.0028432813779235315], [0.81, 0.862555051474255, 0.5882401064705446, 0.3528188523161229, 0.19968175189752, 0.11019417802456587, 0.060122119993871306, 0.032625409294969925, 0.017656455843715148, 0.009542149156486983, 0.005153127716555449], [0.8600000000000001, 0.8704648483921524, 0.6105128363961682, 0.3834509053516691, 0.23057158315678764, 0.13657778320455266, 0.08052086354268495, 0.04741061592039081, 0.027908552173115164, 0.016429145763646895, 0.00967228515103707], [0.91, 0.8776221235225735, 0.6315955002180051, 0.4144590274869386, 0.2645686878554427, 0.1685107663485549, 0.10786394402634085, 0.06944337932786597, 0.04492165350550454, 0.029161371144067954, 0.018977100510000847], [0.9600000000000001, 0.8841284638568696, 0.6515498833849404, 0.44567172323703985, 0.30163552107572394, 0.20679943073654272, 0.14435257482598793, 0.10246266679681, 0.07374313085397445, 0.05365697365741111, 0.03937297913635855]], \"data03\": [[0.8742159498207888, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086, 0.8279569892473121, 0.7927120669056155, 0.757467144563919, 0.7222222222222224, 0.6869772998805258, 0.6517323775388294], [0.8993055555555558, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086, 0.8279569892473121, 0.7927120669056155, 0.757467144563919, 0.7222222222222224, 0.6869772998805258, 0.6517323775388294]], \"data01\": [[0.01, 0.06367988688344325, 0.01063158514692595, 0.0023891360362745754, 0.0005730697817338912, 0.00013961326521384074, 3.414196281818837e-05, 8.357027621677835e-06, 2.046036939983362e-06, 5.009555176587583e-07, 1.2265655130461303e-07], [0.03, 0.16991256230689977, 0.03159161751825681, 0.007303543734334408, 0.0017821366602752606, 0.00044068855148335877, 0.00010933421717165804, 2.7147903948690358e-05, 6.742250508318086e-06, 1.6745395708335787e-06, 4.159023710803665e-07], [0.05, 0.25498680461114004, 0.05215119625415329, 0.012402290429793949, 0.0030792750052342005, 0.0007730229653668831, 0.00019460305243796714, 4.9024470221618055e-05, 1.2352455437097155e-05, 3.1125269291372943e-06, 7.842920931730465e-07], [0.06999999999999999, 0.32464974876257796, 0.07231494472231355, 0.01768866661457462, 0.004469723675984428, 0.0011393626572256358, 0.00029108847404831867, 7.441144962274092e-05, 1.90247487521813e-05, 4.8642352002604336e-06, 1.2436965053628329e-06], [0.09, 0.38273992925849015, 0.0920876391039664, 0.023165835927829136, 0.005959002875813745, 0.0015426921854442906, 0.00040005853353156627, 0.0001037912126231084, 2.693070574959306e-05, 6.98791943069978e-06, 1.8132238309966663e-06], [0.11, 0.4319188411942377, 0.11147419220613831, 0.028836819805588807, 0.007552926154132444, 0.00198625569087927, 0.0005229243161917953, 0.00013771189946502923, 3.62692160458131e-05, 9.552429664270125e-06, 2.51589142240714e-06], [0.13, 0.47408997325107044, 0.1304796380837603, 0.034704481616834836, 0.009257612451647211, 0.002473579981675562, 0.0006612567880854827, 0.00017679675673791667, 4.727098066974943e-05, 1.2639190598020382e-05, 3.3794425898214233e-06], [0.15000000000000002, 0.510650725608884, 0.14910911745492675, 0.04077151033105334, 0.011079498103245421, 0.00300849969572618, 0.0008168057474156411, 0.0002217548824091104, 6.0203791746771436e-05, 1.634456973552653e-05, 4.437341644435059e-06], [0.17, 0.542650121891528, 0.16736786389085395, 0.047040403769916625, 0.013025348698125503, 0.0035951847203394864, 0.0009915211595734504, 0.00027339360709986547, 7.537874031527423e-05, 2.0782715061279267e-05, 5.729988246697359e-06], [0.19, 0.5708910040840596, 0.1852611907606034, 0.053513451503600803, 0.015102270679690152, 0.004238170061185748, 0.0011875771941034794, 0.0003326327789962193, 9.315752690138636e-05, 2.6088961337990558e-05, 7.3062022353349975e-06], [0.21000000000000002, 0.5959982468825064, 0.202794478909404, 0.060192717460334756, 0.017317722548760746, 0.00494238836510139, 0.0014073993265649688, 0.00040052126677265874, 0.00011396108482240573, 3.242392653800315e-05, 9.225042842967103e-06], [0.23, 0.6184654812418521, 0.21997316504841471, 0.06708002232600861, 0.019679525512652674, 0.005713205313548979, 0.0016536949194257496, 0.0004782560507561918, 0.00013827976924534065, 3.997844777687647e-05, 1.1558042324431352e-05], [0.25, 0.6386878321252417, 0.23680273083298423, 0.07417692581896031, 0.02219587339946372, 0.006556458115081259, 0.0019294877546822862, 0.0005672043390537293, 0.00016668541760615573, 4.897954084749824e-05, 1.439195450286643e-05], [0.27, 0.6569853224828244, 0.25328869260588344, 0.08148470893331931, 0.024875341631487014, 0.007478497335541756, 0.002238157057892846, 0.0006689292246708465, 0.00019984565136891514, 5.969761088459275e-05, 1.7832144842371188e-05], [0.29000000000000004, 0.673619907272919, 0.2694365917815751, 0.08900435625240127, 0.027726895023906486, 0.008486232313311862, 0.0025834816299100203, 0.0007852194943941185, 0.00023854086812537717, 7.245519617402295e-05, 2.200678204653747e-05], [0.31, 0.6888080724469053, 0.2852519858473317, 0.0967365384415001, 0.03075989414485019, 0.009587180412868233, 0.002969689790104995, 0.0009181243135902103, 0.00028368447030079655, 8.763759569625411e-05, 2.7072034049898932e-05], [0.33, 0.7027302900447678, 0.3007404399569139, 0.10468159503689814, 0.033984099940501514, 0.010789520372213044, 0.003401515934722812, 0.0010699936469869599, 0.00033634699678667675, 0.00010570581759730596, 3.321852651481573e-05], [0.35000000000000003, 0.7155382081187842, 0.3159075190925285, 0.11283951765485202, 0.03740967629439494, 0.012102149997085615, 0.0038842646277531872, 0.0012435254386915636, 0.0003977849724302706, 0.0001272123955412273, 4.067939342788858e-05], [0.37, 0.727360184292402, 0.33075878077093207, 0.12120993375059774, 0.04104719015344512, 0.013534748445646694, 0.004423883271012405, 0.0014418207709595524, 0.00046947547480648554, 0.0001528207595201384, 4.97403422653791e-05], [0.39, 0.7383055916722793, 0.3452997682697651, 0.12979209106287903, 0.04490760881494969, 0.015097843329543805, 0.005027044546744987, 0.0016684484576235108, 0.0005531576474375159, 0.0001833290259854959, 6.075227739592375e-05], [0.41000000000000003, 0.7484682035359016, 0.35953600435052574, 0.13858484288400263, 0.049002293929187715, 0.01680288282846426, 0.005701239991718905, 0.0019275208132517692, 0.0006508826755883312, 0.00021969930073185583, 7.414718427087213e-05], [0.43, 0.7579288788169939, 0.37347298545498536, 0.14758663429881322, 0.053342991731855846, 0.018662312972458, 0.00645488624816967, 0.0022237826835679294, 0.000765074100337679, 0.00026309388220507353, 9.045818623006736e-05], [0.45, 0.7667577112931204, 0.3871161763523047, 0.15679548953809727, 0.05794181898017751, 0.020689660185818765, 0.007297445745478057, 0.002562716239271076, 0.000898600798629073, 0.00031492013332044334, 0.00011034496278918067], [0.47000000000000003, 0.7750157634005722, 0.40047100521461904, 0.16620900059264357, 0.0628112440270151, 0.022899619103755837, 0.008239563798126043, 0.002950664539807187, 0.001054865527070621, 0.00037688628390057676, 0.00013462608693905567], [0.49, 0.7827564754125486, 0.4135428590994216, 0.17582431723336528, 0.06796406242987232, 0.025308145563207245, 0.009293224360476339, 0.0033949774848838765, 0.0012379126486066813, 0.0004510710703909248, 0.0001643203322832682], [0.51, 0.7900268187497871, 0.42633707981767105, 0.18563813858041225, 0.07341336645770982, 0.02793255452569352, 0.010471926956248568, 0.00390418451265159, 0.001452559577050862, 0.0005400109645078959, 0.00020069966471509683], [0.53, 0.7968682460330774, 0.4388589601671661, 0.19564670635995762, 0.07917250782971055, 0.03079162250573868, 0.011790887597329757, 0.004488199302307413, 0.0017045576412327628, 0.0006468098558134575, 0.0002453575321968572], [0.55, 0.8033174784774164, 0.45111374051138875, 0.20584579998126967, 0.08525505299852983, 0.03390569384453736, 0.013267266817093476, 0.005158562828740815, 0.002000789561924028, 0.0007752775277369821, 0.00030029729098928273], [0.5700000000000001, 0.8094071622165869, 0.4631066056846778, 0.21623073355870007, 0.09167473027847502, 0.037296789875385615, 0.014920428258010156, 0.00592873243730215, 0.0023495126474819624, 0.0009301052299787599, 0.00036804728674839584], [0.59, 0.8151664183251784, 0.47484268220527115, 0.22679635499331172, 0.09844536811913665, 0.04098871966376782, 0.016772231556557642, 0.006814426204204242, 0.0027606592753508102, 0.0011170892791921372, 0.0004518114297410051], [0.61, 0.8206213060970884, 0.4863270357784449, 0.23753704721704258, 0.10558082384021891, 0.04500719055851028, 0.018847363536735308, 0.007834033775786446, 0.003246209403403585, 0.0013434171601997046, 0.0005556673331616795], [0.63, 0.8257952151320227, 0.49756466907266134, 0.24844673168857556, 0.11309490217696608, 0.0493799162476011, 0.021173711922037677, 0.009009107197494818, 0.0038206539677942404, 0.0016180353959165245, 0.0006848286131247813], [0.65, 0.8307091986746882, 0.5085605197523264, 0.25951887421454917, 0.12100126304118822, 0.05413671935896912, 0.02378278585427638, 0.010364948014726264, 0.004501573362436066, 0.0019521249902816858, 0.0008459943535234541], [0.67, 0.8353822582257765, 0.5193194587514406, 0.2707464931524828, 0.12931331798415666, 0.059309624868459726, 0.026710187394843314, 0.011931310215819587, 0.005310362140485372, 0.0023597192112868037, 0.0010478178726558167], [0.6900000000000001, 0.8398315875374739, 0.5298462887730996, 0.2821221700329782, 0.13804411495835384, 0.06493293966108168, 0.02999613778032365, 0.013743242445921577, 0.006273140129311651, 0.002858510848311959, 0.0013015400717670753], [0.7100000000000001, 0.8440727825984484, 0.5401457430004737, 0.2936380626185537, 0.14720621111892696, 0.07104331252630672, 0.03368606137275331, 0.01584209737665371, 0.007421901956610452, 0.0034709132490487655, 0.001621851737296603], [0.73, 0.8481200230135886, 0.5502224840055429, 0.30528592039510005, 0.1568115335861503, 0.07767976764713637, 0.037831228799212156, 0.018276741143902563, 0.008795972382103221, 0.004225463428895871, 0.0020280771744382474], [0.75, 0.85198622922378, 0.5600811028425084, 0.31705710246967095, 0.16687122831020113, 0.08488370326634306, 0.04248945846681752, 0.021105001237584454, 0.010443854873246507, 0.00515868925375802, 0.0025458130532591476], [0.77, 0.8556831992386696, 0.56972611831343, 0.3289425978254107, 0.17739549744126232, 0.09269884569317555, 0.047725872139301725, 0.024395396839681196, 0.012425586852744188, 0.006317610323174869, 0.0032092185073841106], [0.79, 0.8592217279307705, 0.579161976394243, 0.34093304786119416, 0.1883934259124522, 0.10117114717697274, 0.05361369514526779, 0.028229200760318342, 0.014815748498779395, 0.007763109787935119, 0.0040642466278324055], [0.81, 0.862611711431681, 0.5883930498099063, 0.35301877112033275, 0.1998727982899524, 0.11034861446920015, 0.060235084517442375, 0.03270288573088038, 0.01770731451330398, 0.00957451064337302, 0.005173251513484062], [0.8300000000000001, 0.8658622387567482, 0.5974236377480058, 0.365189790089831, 0.21183990733170857, 0.1202810531996541, 0.06768195827290971, 0.0379310080176956, 0.021216591271973173, 0.01185582744778291, 0.006621627820854752], [0.85, 0.8689816724445925, 0.6062579657006925, 0.3774358599295123, 0.22429935611873483, 0.13101971161977816, 0.07605678534756088, 0.04404957504884225, 0.025489545612351616, 0.014744360187155886, 0.008527487865105442], [0.87, 0.8719777197179408, 0.6149001854253731, 0.3897464989692256, 0.23725385607425267, 0.14261680597501072, 0.08547327750500643, 0.051219926083347, 0.030709903973071932, 0.018422574187885704, 0.011055930056695529], [0.89, 0.8748574954406478, 0.6233543750150878, 0.40211102079262523, 0.2507040236555988, 0.1551249089706182, 0.09605690093116133, 0.059633118241102116, 0.03710947360843843, 0.023134596812672256, 0.01444032287192198], [0.91, 0.8776275779535141, 0.6316245390700103, 0.4145185677080473, 0.26464817897886356, 0.1685961827624801, 0.10794509539142386, 0.06951474287699677, 0.04498119112473731, 0.029209186176976456, 0.019014411524148553], [0.93, 0.8802940587112572, 0.6397146089619798, 0.42695814539105037, 0.2790821501001028, 0.1830814389678617, 0.12128705232321715, 0.081129982410075, 0.05469539416680809, 0.03709169848222272, 0.025261236842803785], [0.9500000000000001, 0.8828625865089388, 0.6476284431844384, 0.4394186584695643, 0.2939990871101362, 0.19862901073978972, 0.13624286039932584, 0.09478853168219174, 0.06671965254498287, 0.04738833757926249, 0.03388822002658438], [0.97, 0.8853384069736263, 0.6553698277805843, 0.45188894681150976, 0.30938929057998404, 0.21528342641147066, 0.15298177967920856, 0.11084871981207456, 0.08164202019123602, 0.06092655195157571, 0.04594265558263385], [0.99, 0.887726397902296, 0.662942476842977, 0.46435782226642786, 0.3252400591962998, 0.23308388103379943, 0.17167935752895855, 0.1297197420685918, 0.10019648250115669, 0.07883508554178247, 0.0629879399835792]]}, \"id\": \"el9520170399280\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAs8AAAIyCAYAAAA0fidwAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nP6sW51jp1D2XAAAAAElFTkSuQmCC\n",
       "text": [
        "<matplotlib.figure.Figure at 0xa281630>"
       ]
      }
     ],
     "prompt_number": 54
    },
    {
     "cell_type": "heading",
     "level": 4,
     "metadata": {},
     "source": [
      "Dependence on Barrier Width"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "E = .96\n",
      "as_ = np.linspace(.01, 5)\n",
      "as_coarse = np.linspace(0.5, 5, 10)\n",
      "n = 1e3\n",
      "\n",
      "plt.title('Transmission Coefficient as a Function of the Barrier Width for Fixed Energy $E = %s$' % E)\n",
      "plt.xlabel('$a$')\n",
      "plt.ylabel('$T$')\n",
      "plt.ylim(0, 1)\n",
      "plt.plot(as_, [transmission_exact(a=a, E=E) for a in as_])\n",
      "plt.plot(as_coarse, [scatter(V=rect_potential(a=a), E=E, x_min=0, x_max=a, n=n)[0] for a in as_coarse], 'o')\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el95201703841841421194049\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "       mpld3.draw_figure(\"fig_el95201703841841421194049\", {\"axes\": [{\"xlim\": [0.0, 5.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$a$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520168818392\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520176062984\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Transmission Coefficient as a Function of the Barrier Width for Fixed Energy $E = 0.96$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520175878664\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 5.0], \"ylim\": [0.0, 1.0], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 6, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170381552\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170383232pts\"}], \"id\": \"el9520169586080\", \"ydomain\": [0.0, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data02\": [[0.5, 0.8841284638568696], [1.0, 0.6515498833849404], [1.5, 0.44567172323703985], [2.0, 0.30163552107572394], [2.5, 0.20679943073654272], [3.0, 0.14435257482598793], [3.5, 0.10246266679681], [4.0, 0.07374313085397445], [4.5, 0.05365697365741111], [5.0, 0.03937297913635855]], \"data01\": [[0.01, 0.9999479192403244], [0.11183673469387755, 0.9935257168731396], [0.2136734693877551, 0.9767453390242892], [0.31551020408163266, 0.9505838848065624], [0.4173469387755102, 0.9164725973116348], [0.5191836734693878, 0.8761143243680741], [0.6210204081632653, 0.8312951229214085], [0.7228571428571429, 0.7837233901191285], [0.8246938775510204, 0.7349156144822747], [0.926530612244898, 0.6861328608289816], [1.0283673469387755, 0.6383612018274555], [1.130204081632653, 0.5923240048219476], [1.2320408163265306, 0.5485133471996938], [1.3338775510204082, 0.5072299626224689], [1.4357142857142857, 0.46862425194479607], [1.5375510204081633, 0.43273388285625325], [1.6393877551020408, 0.3995158282439261], [1.7412244897959184, 0.3688722553266201], [1.843061224489796, 0.3406705895841132], [1.9448979591836735, 0.31475852007666383], [2.046734693877551, 0.290974855938272], [2.1485714285714286, 0.2691571179818464], [2.250408163265306, 0.24914664240871312], [2.3522448979591832, 0.23079183903971134], [2.454081632653061, 0.2139501134807048], [2.555918367346939, 0.1984888449393678], [2.657755102040816, 0.18428571373749036], [2.7595918367346934, 0.17122859485032668], [2.861428571428571, 0.15921517379117914], [2.963265306122449, 0.1481523958429155], [3.0651020408163263, 0.13795582602334733], [3.1669387755102036, 0.12854897260692222], [3.2687755102040814, 0.11986260931313213], [3.370612244897959, 0.11183411866436058], [3.4724489795918365, 0.1044068701608907], [3.574285714285714, 0.09752964079421562], [3.6761224489795916, 0.09115608125720194], [3.7779591836734694, 0.08524422844725889], [3.8797959183673467, 0.0797560630846589], [3.981632653061224, 0.0746571101842086], [4.083469387755102, 0.06991607951008239], [4.18530612244898, 0.06550454285768782], [4.287142857142857, 0.061396644934432906], [4.388979591836734, 0.05756884467696822], [4.490816326530612, 0.053999683992810035], [4.59265306122449, 0.050669581112702], [4.694489795918367, 0.04756064596190254], [4.7963265306122445, 0.04465651518736964], [4.898163265306122, 0.04194220470295319], [5.0, 0.03940397782965568]]}, \"id\": \"el9520170384184\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "         \n",
        "         mpld3.draw_figure(\"fig_el95201703841841421194049\", {\"axes\": [{\"xlim\": [0.0, 5.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$a$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520168818392\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520176062984\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Transmission Coefficient as a Function of the Barrier Width for Fixed Energy $E = 0.96$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520175878664\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 5.0], \"ylim\": [0.0, 1.0], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 6, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170381552\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170383232pts\"}], \"id\": \"el9520169586080\", \"ydomain\": [0.0, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data02\": [[0.5, 0.8841284638568696], [1.0, 0.6515498833849404], [1.5, 0.44567172323703985], [2.0, 0.30163552107572394], [2.5, 0.20679943073654272], [3.0, 0.14435257482598793], [3.5, 0.10246266679681], [4.0, 0.07374313085397445], [4.5, 0.05365697365741111], [5.0, 0.03937297913635855]], \"data01\": [[0.01, 0.9999479192403244], [0.11183673469387755, 0.9935257168731396], [0.2136734693877551, 0.9767453390242892], [0.31551020408163266, 0.9505838848065624], [0.4173469387755102, 0.9164725973116348], [0.5191836734693878, 0.8761143243680741], [0.6210204081632653, 0.8312951229214085], [0.7228571428571429, 0.7837233901191285], [0.8246938775510204, 0.7349156144822747], [0.926530612244898, 0.6861328608289816], [1.0283673469387755, 0.6383612018274555], [1.130204081632653, 0.5923240048219476], [1.2320408163265306, 0.5485133471996938], [1.3338775510204082, 0.5072299626224689], [1.4357142857142857, 0.46862425194479607], [1.5375510204081633, 0.43273388285625325], [1.6393877551020408, 0.3995158282439261], [1.7412244897959184, 0.3688722553266201], [1.843061224489796, 0.3406705895841132], [1.9448979591836735, 0.31475852007666383], [2.046734693877551, 0.290974855938272], [2.1485714285714286, 0.2691571179818464], [2.250408163265306, 0.24914664240871312], [2.3522448979591832, 0.23079183903971134], [2.454081632653061, 0.2139501134807048], [2.555918367346939, 0.1984888449393678], [2.657755102040816, 0.18428571373749036], [2.7595918367346934, 0.17122859485032668], [2.861428571428571, 0.15921517379117914], [2.963265306122449, 0.1481523958429155], [3.0651020408163263, 0.13795582602334733], [3.1669387755102036, 0.12854897260692222], [3.2687755102040814, 0.11986260931313213], [3.370612244897959, 0.11183411866436058], [3.4724489795918365, 0.1044068701608907], [3.574285714285714, 0.09752964079421562], [3.6761224489795916, 0.09115608125720194], [3.7779591836734694, 0.08524422844725889], [3.8797959183673467, 0.0797560630846589], [3.981632653061224, 0.0746571101842086], [4.083469387755102, 0.06991607951008239], [4.18530612244898, 0.06550454285768782], [4.287142857142857, 0.061396644934432906], [4.388979591836734, 0.05756884467696822], [4.490816326530612, 0.053999683992810035], [4.59265306122449, 0.050669581112702], [4.694489795918367, 0.04756064596190254], [4.7963265306122445, 0.04465651518736964], [4.898163265306122, 0.04194220470295319], [5.0, 0.03940397782965568]]}, \"id\": \"el9520170384184\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "                 \n",
        "                 mpld3.draw_figure(\"fig_el95201703841841421194049\", {\"axes\": [{\"xlim\": [0.0, 5.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$a$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520168818392\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520176062984\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Transmission Coefficient as a Function of the Barrier Width for Fixed Energy $E = 0.96$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520175878664\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 5.0], \"ylim\": [0.0, 1.0], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 6, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520170381552\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170383232pts\"}], \"id\": \"el9520169586080\", \"ydomain\": [0.0, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data02\": [[0.5, 0.8841284638568696], [1.0, 0.6515498833849404], [1.5, 0.44567172323703985], [2.0, 0.30163552107572394], [2.5, 0.20679943073654272], [3.0, 0.14435257482598793], [3.5, 0.10246266679681], [4.0, 0.07374313085397445], [4.5, 0.05365697365741111], [5.0, 0.03937297913635855]], \"data01\": [[0.01, 0.9999479192403244], [0.11183673469387755, 0.9935257168731396], [0.2136734693877551, 0.9767453390242892], [0.31551020408163266, 0.9505838848065624], [0.4173469387755102, 0.9164725973116348], [0.5191836734693878, 0.8761143243680741], [0.6210204081632653, 0.8312951229214085], [0.7228571428571429, 0.7837233901191285], [0.8246938775510204, 0.7349156144822747], [0.926530612244898, 0.6861328608289816], [1.0283673469387755, 0.6383612018274555], [1.130204081632653, 0.5923240048219476], [1.2320408163265306, 0.5485133471996938], [1.3338775510204082, 0.5072299626224689], [1.4357142857142857, 0.46862425194479607], [1.5375510204081633, 0.43273388285625325], [1.6393877551020408, 0.3995158282439261], [1.7412244897959184, 0.3688722553266201], [1.843061224489796, 0.3406705895841132], [1.9448979591836735, 0.31475852007666383], [2.046734693877551, 0.290974855938272], [2.1485714285714286, 0.2691571179818464], [2.250408163265306, 0.24914664240871312], [2.3522448979591832, 0.23079183903971134], [2.454081632653061, 0.2139501134807048], [2.555918367346939, 0.1984888449393678], [2.657755102040816, 0.18428571373749036], [2.7595918367346934, 0.17122859485032668], [2.861428571428571, 0.15921517379117914], [2.963265306122449, 0.1481523958429155], [3.0651020408163263, 0.13795582602334733], [3.1669387755102036, 0.12854897260692222], [3.2687755102040814, 0.11986260931313213], [3.370612244897959, 0.11183411866436058], [3.4724489795918365, 0.1044068701608907], [3.574285714285714, 0.09752964079421562], [3.6761224489795916, 0.09115608125720194], [3.7779591836734694, 0.08524422844725889], [3.8797959183673467, 0.0797560630846589], [3.981632653061224, 0.0746571101842086], [4.083469387755102, 0.06991607951008239], [4.18530612244898, 0.06550454285768782], [4.287142857142857, 0.061396644934432906], [4.388979591836734, 0.05756884467696822], [4.490816326530612, 0.053999683992810035], [4.59265306122449, 0.050669581112702], [4.694489795918367, 0.04756064596190254], [4.7963265306122445, 0.04465651518736964], [4.898163265306122, 0.04194220470295319], [5.0, 0.03940397782965568]]}, \"id\": \"el9520170384184\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAtIAAAIyCAYAAADmLi0oAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
       "text": [
        "<matplotlib.figure.Figure at 0xa27db38>"
       ]
      }
     ],
     "prompt_number": 55
    },
    {
     "cell_type": "heading",
     "level": 2,
     "metadata": {},
     "source": [
      "Parabolic Potential"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "def parabolic_potential(a):\n",
      "    a = float(a)\n",
      "    def V(x):\n",
      "        if 0 < x <= a:\n",
      "            return 4. * (x / a  - x**2 / a**2)\n",
      "        return 0.\n",
      "    return V\n",
      "\n",
      "xs = np.linspace(-0.5, 5.5, num=100)\n",
      "plt.figure(figsize=(4, 3))\n",
      "plt.ylim(0, 1.1)\n",
      "plt.plot(xs, [rect_potential(a=5)(x) for x in xs], '--')\n",
      "plt.plot(xs, [parabolic_potential(a=5)(x) for x in xs])\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el95201696409049731992438\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "       mpld3.draw_figure(\"fig_el95201696409049731992438\", {\"axes\": [{\"xlim\": [-1.0, 6.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-1.0, 6.0], \"ylim\": [0.0, 1.1000000000000001], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 7, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169640624\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520176032008\"}], \"markers\": [], \"id\": \"el9520194554512\", \"ydomain\": [0.0, 1.1000000000000001], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 240.0, \"width\": 320.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data01\": [[-0.5, 0.0, 0.0], [-0.4393939393939394, 0.0, 0.0], [-0.3787878787878788, 0.0, 0.0], [-0.3181818181818182, 0.0, 0.0], [-0.25757575757575757, 0.0, 0.0], [-0.19696969696969696, 0.0, 0.0], [-0.13636363636363635, 0.0, 0.0], [-0.07575757575757575, 0.0, 0.0], [-0.015151515151515138, 0.0, 0.0], [0.045454545454545414, 1.0, 0.03603305785123964], [0.10606060606060608, 1.0, 0.08304866850321398], [0.16666666666666674, 1.0, 0.12888888888888894], [0.2272727272727273, 1.0, 0.17355371900826447], [0.28787878787878785, 1.0, 0.21704315886134068], [0.3484848484848485, 1.0, 0.25935720844811755], [0.40909090909090917, 1.0, 0.3004958677685951], [0.4696969696969697, 1.0, 0.34045913682277323], [0.5303030303030303, 1.0, 0.37924701561065194], [0.5909090909090908, 1.0, 0.4168595041322314], [0.6515151515151516, 1.0, 0.45329660238751146], [0.7121212121212122, 1.0, 0.48855831037649217], [0.7727272727272727, 1.0, 0.5226446280991736], [0.8333333333333335, 1.0, 0.5555555555555556], [0.893939393939394, 1.0, 0.5872910927456383], [0.9545454545454546, 1.0, 0.6178512396694216], [1.0151515151515151, 1.0, 0.6472359963269054], [1.0757575757575757, 1.0, 0.6754453627180901], [1.1363636363636365, 1.0, 0.7024793388429752], [1.196969696969697, 1.0, 0.7283379247015611], [1.2575757575757576, 1.0, 0.7530211202938476], [1.3181818181818183, 1.0, 0.7765289256198348], [1.378787878787879, 1.0, 0.7988613406795224], [1.4393939393939394, 1.0, 0.820018365472911], [1.5, 1.0, 0.84], [1.5606060606060606, 1.0, 0.8588062442607898], [1.621212121212121, 1.0, 0.87643709825528], [1.6818181818181817, 1.0, 0.8928925619834709], [1.7424242424242427, 1.0, 0.9081726354453628], [1.8030303030303032, 1.0, 0.9222773186409551], [1.8636363636363638, 1.0, 0.935206611570248], [1.9242424242424243, 1.0, 0.9469605142332416], [1.9848484848484849, 1.0, 0.9575390266299357], [2.0454545454545454, 1.0, 0.9669421487603305], [2.106060606060606, 1.0, 0.975169880624426], [2.166666666666667, 1.0, 0.9822222222222223], [2.2272727272727275, 1.0, 0.988099173553719], [2.287878787878788, 1.0, 0.9928007346189166], [2.3484848484848486, 1.0, 0.9963269054178145], [2.409090909090909, 1.0, 0.9986776859504132], [2.4696969696969697, 1.0, 0.9998530762167126], [2.5303030303030303, 1.0, 0.9998530762167128], [2.590909090909091, 1.0, 0.9986776859504134], [2.6515151515151514, 1.0, 0.9963269054178145], [2.7121212121212124, 1.0, 0.9928007346189165], [2.772727272727273, 1.0, 0.988099173553719], [2.8333333333333335, 1.0, 0.9822222222222221], [2.893939393939394, 1.0, 0.9751698806244262], [2.9545454545454546, 1.0, 0.9669421487603307], [3.015151515151515, 1.0, 0.9575390266299355], [3.0757575757575757, 1.0, 0.9469605142332413], [3.1363636363636367, 1.0, 0.9352066115702478], [3.1969696969696972, 1.0, 0.9222773186409547], [3.257575757575758, 1.0, 0.908172635445363], [3.3181818181818183, 1.0, 0.8928925619834709], [3.378787878787879, 1.0, 0.8764370982552803], [3.4393939393939394, 1.0, 0.8588062442607898], [3.5, 1.0, 0.8399999999999999], [3.5606060606060606, 1.0, 0.8200183654729112], [3.621212121212121, 1.0, 0.7988613406795224], [3.6818181818181817, 1.0, 0.7765289256198344], [3.742424242424242, 1.0, 0.7530211202938477], [3.8030303030303028, 1.0, 0.7283379247015609], [3.8636363636363633, 1.0, 0.7024793388429758], [3.9242424242424248, 1.0, 0.6754453627180896], [3.9848484848484853, 1.0, 0.6472359963269052], [4.045454545454546, 1.0, 0.6178512396694211], [4.106060606060606, 1.0, 0.5872910927456378], [4.166666666666667, 1.0, 0.5555555555555554], [4.2272727272727275, 1.0, 0.5226446280991732], [4.287878787878788, 1.0, 0.48855831037649233], [4.348484848484849, 1.0, 0.45329660238751135], [4.409090909090909, 1.0, 0.4168595041322316], [4.46969696969697, 1.0, 0.3792470156106522], [4.53030303030303, 1.0, 0.3404591368227732], [4.590909090909091, 1.0, 0.3004958677685954], [4.651515151515151, 1.0, 0.25935720844811794], [4.712121212121212, 1.0, 0.21704315886134085], [4.7727272727272725, 1.0, 0.17355371900826455], [4.833333333333334, 1.0, 0.12888888888888816], [4.8939393939393945, 1.0, 0.08304866850321302], [4.954545454545455, 1.0, 0.036033057851239114], [5.015151515151516, 0.0, 0.0], [5.075757575757576, 0.0, 0.0], [5.136363636363637, 0.0, 0.0], [5.196969696969697, 0.0, 0.0], [5.257575757575758, 0.0, 0.0], [5.318181818181818, 0.0, 0.0], [5.378787878787879, 0.0, 0.0], [5.4393939393939394, 0.0, 0.0], [5.5, 0.0, 0.0]]}, \"id\": \"el9520169640904\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "         \n",
        "         mpld3.draw_figure(\"fig_el95201696409049731992438\", {\"axes\": [{\"xlim\": [-1.0, 6.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-1.0, 6.0], \"ylim\": [0.0, 1.1000000000000001], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 7, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169640624\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520176032008\"}], \"markers\": [], \"id\": \"el9520194554512\", \"ydomain\": [0.0, 1.1000000000000001], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 240.0, \"width\": 320.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data01\": [[-0.5, 0.0, 0.0], [-0.4393939393939394, 0.0, 0.0], [-0.3787878787878788, 0.0, 0.0], [-0.3181818181818182, 0.0, 0.0], [-0.25757575757575757, 0.0, 0.0], [-0.19696969696969696, 0.0, 0.0], [-0.13636363636363635, 0.0, 0.0], [-0.07575757575757575, 0.0, 0.0], [-0.015151515151515138, 0.0, 0.0], [0.045454545454545414, 1.0, 0.03603305785123964], [0.10606060606060608, 1.0, 0.08304866850321398], [0.16666666666666674, 1.0, 0.12888888888888894], [0.2272727272727273, 1.0, 0.17355371900826447], [0.28787878787878785, 1.0, 0.21704315886134068], [0.3484848484848485, 1.0, 0.25935720844811755], [0.40909090909090917, 1.0, 0.3004958677685951], [0.4696969696969697, 1.0, 0.34045913682277323], [0.5303030303030303, 1.0, 0.37924701561065194], [0.5909090909090908, 1.0, 0.4168595041322314], [0.6515151515151516, 1.0, 0.45329660238751146], [0.7121212121212122, 1.0, 0.48855831037649217], [0.7727272727272727, 1.0, 0.5226446280991736], [0.8333333333333335, 1.0, 0.5555555555555556], [0.893939393939394, 1.0, 0.5872910927456383], [0.9545454545454546, 1.0, 0.6178512396694216], [1.0151515151515151, 1.0, 0.6472359963269054], [1.0757575757575757, 1.0, 0.6754453627180901], [1.1363636363636365, 1.0, 0.7024793388429752], [1.196969696969697, 1.0, 0.7283379247015611], [1.2575757575757576, 1.0, 0.7530211202938476], [1.3181818181818183, 1.0, 0.7765289256198348], [1.378787878787879, 1.0, 0.7988613406795224], [1.4393939393939394, 1.0, 0.820018365472911], [1.5, 1.0, 0.84], [1.5606060606060606, 1.0, 0.8588062442607898], [1.621212121212121, 1.0, 0.87643709825528], [1.6818181818181817, 1.0, 0.8928925619834709], [1.7424242424242427, 1.0, 0.9081726354453628], [1.8030303030303032, 1.0, 0.9222773186409551], [1.8636363636363638, 1.0, 0.935206611570248], [1.9242424242424243, 1.0, 0.9469605142332416], [1.9848484848484849, 1.0, 0.9575390266299357], [2.0454545454545454, 1.0, 0.9669421487603305], [2.106060606060606, 1.0, 0.975169880624426], [2.166666666666667, 1.0, 0.9822222222222223], [2.2272727272727275, 1.0, 0.988099173553719], [2.287878787878788, 1.0, 0.9928007346189166], [2.3484848484848486, 1.0, 0.9963269054178145], [2.409090909090909, 1.0, 0.9986776859504132], [2.4696969696969697, 1.0, 0.9998530762167126], [2.5303030303030303, 1.0, 0.9998530762167128], [2.590909090909091, 1.0, 0.9986776859504134], [2.6515151515151514, 1.0, 0.9963269054178145], [2.7121212121212124, 1.0, 0.9928007346189165], [2.772727272727273, 1.0, 0.988099173553719], [2.8333333333333335, 1.0, 0.9822222222222221], [2.893939393939394, 1.0, 0.9751698806244262], [2.9545454545454546, 1.0, 0.9669421487603307], [3.015151515151515, 1.0, 0.9575390266299355], [3.0757575757575757, 1.0, 0.9469605142332413], [3.1363636363636367, 1.0, 0.9352066115702478], [3.1969696969696972, 1.0, 0.9222773186409547], [3.257575757575758, 1.0, 0.908172635445363], [3.3181818181818183, 1.0, 0.8928925619834709], [3.378787878787879, 1.0, 0.8764370982552803], [3.4393939393939394, 1.0, 0.8588062442607898], [3.5, 1.0, 0.8399999999999999], [3.5606060606060606, 1.0, 0.8200183654729112], [3.621212121212121, 1.0, 0.7988613406795224], [3.6818181818181817, 1.0, 0.7765289256198344], [3.742424242424242, 1.0, 0.7530211202938477], [3.8030303030303028, 1.0, 0.7283379247015609], [3.8636363636363633, 1.0, 0.7024793388429758], [3.9242424242424248, 1.0, 0.6754453627180896], [3.9848484848484853, 1.0, 0.6472359963269052], [4.045454545454546, 1.0, 0.6178512396694211], [4.106060606060606, 1.0, 0.5872910927456378], [4.166666666666667, 1.0, 0.5555555555555554], [4.2272727272727275, 1.0, 0.5226446280991732], [4.287878787878788, 1.0, 0.48855831037649233], [4.348484848484849, 1.0, 0.45329660238751135], [4.409090909090909, 1.0, 0.4168595041322316], [4.46969696969697, 1.0, 0.3792470156106522], [4.53030303030303, 1.0, 0.3404591368227732], [4.590909090909091, 1.0, 0.3004958677685954], [4.651515151515151, 1.0, 0.25935720844811794], [4.712121212121212, 1.0, 0.21704315886134085], [4.7727272727272725, 1.0, 0.17355371900826455], [4.833333333333334, 1.0, 0.12888888888888816], [4.8939393939393945, 1.0, 0.08304866850321302], [4.954545454545455, 1.0, 0.036033057851239114], [5.015151515151516, 0.0, 0.0], [5.075757575757576, 0.0, 0.0], [5.136363636363637, 0.0, 0.0], [5.196969696969697, 0.0, 0.0], [5.257575757575758, 0.0, 0.0], [5.318181818181818, 0.0, 0.0], [5.378787878787879, 0.0, 0.0], [5.4393939393939394, 0.0, 0.0], [5.5, 0.0, 0.0]]}, \"id\": \"el9520169640904\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "                 \n",
        "                 mpld3.draw_figure(\"fig_el95201696409049731992438\", {\"axes\": [{\"xlim\": [-1.0, 6.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [], \"zoomable\": true, \"images\": [], \"xdomain\": [-1.0, 6.0], \"ylim\": [0.0, 1.1000000000000001], \"paths\": [], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 7, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169640624\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520176032008\"}], \"markers\": [], \"id\": \"el9520194554512\", \"ydomain\": [0.0, 1.1000000000000001], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 240.0, \"width\": 320.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data01\": [[-0.5, 0.0, 0.0], [-0.4393939393939394, 0.0, 0.0], [-0.3787878787878788, 0.0, 0.0], [-0.3181818181818182, 0.0, 0.0], [-0.25757575757575757, 0.0, 0.0], [-0.19696969696969696, 0.0, 0.0], [-0.13636363636363635, 0.0, 0.0], [-0.07575757575757575, 0.0, 0.0], [-0.015151515151515138, 0.0, 0.0], [0.045454545454545414, 1.0, 0.03603305785123964], [0.10606060606060608, 1.0, 0.08304866850321398], [0.16666666666666674, 1.0, 0.12888888888888894], [0.2272727272727273, 1.0, 0.17355371900826447], [0.28787878787878785, 1.0, 0.21704315886134068], [0.3484848484848485, 1.0, 0.25935720844811755], [0.40909090909090917, 1.0, 0.3004958677685951], [0.4696969696969697, 1.0, 0.34045913682277323], [0.5303030303030303, 1.0, 0.37924701561065194], [0.5909090909090908, 1.0, 0.4168595041322314], [0.6515151515151516, 1.0, 0.45329660238751146], [0.7121212121212122, 1.0, 0.48855831037649217], [0.7727272727272727, 1.0, 0.5226446280991736], [0.8333333333333335, 1.0, 0.5555555555555556], [0.893939393939394, 1.0, 0.5872910927456383], [0.9545454545454546, 1.0, 0.6178512396694216], [1.0151515151515151, 1.0, 0.6472359963269054], [1.0757575757575757, 1.0, 0.6754453627180901], [1.1363636363636365, 1.0, 0.7024793388429752], [1.196969696969697, 1.0, 0.7283379247015611], [1.2575757575757576, 1.0, 0.7530211202938476], [1.3181818181818183, 1.0, 0.7765289256198348], [1.378787878787879, 1.0, 0.7988613406795224], [1.4393939393939394, 1.0, 0.820018365472911], [1.5, 1.0, 0.84], [1.5606060606060606, 1.0, 0.8588062442607898], [1.621212121212121, 1.0, 0.87643709825528], [1.6818181818181817, 1.0, 0.8928925619834709], [1.7424242424242427, 1.0, 0.9081726354453628], [1.8030303030303032, 1.0, 0.9222773186409551], [1.8636363636363638, 1.0, 0.935206611570248], [1.9242424242424243, 1.0, 0.9469605142332416], [1.9848484848484849, 1.0, 0.9575390266299357], [2.0454545454545454, 1.0, 0.9669421487603305], [2.106060606060606, 1.0, 0.975169880624426], [2.166666666666667, 1.0, 0.9822222222222223], [2.2272727272727275, 1.0, 0.988099173553719], [2.287878787878788, 1.0, 0.9928007346189166], [2.3484848484848486, 1.0, 0.9963269054178145], [2.409090909090909, 1.0, 0.9986776859504132], [2.4696969696969697, 1.0, 0.9998530762167126], [2.5303030303030303, 1.0, 0.9998530762167128], [2.590909090909091, 1.0, 0.9986776859504134], [2.6515151515151514, 1.0, 0.9963269054178145], [2.7121212121212124, 1.0, 0.9928007346189165], [2.772727272727273, 1.0, 0.988099173553719], [2.8333333333333335, 1.0, 0.9822222222222221], [2.893939393939394, 1.0, 0.9751698806244262], [2.9545454545454546, 1.0, 0.9669421487603307], [3.015151515151515, 1.0, 0.9575390266299355], [3.0757575757575757, 1.0, 0.9469605142332413], [3.1363636363636367, 1.0, 0.9352066115702478], [3.1969696969696972, 1.0, 0.9222773186409547], [3.257575757575758, 1.0, 0.908172635445363], [3.3181818181818183, 1.0, 0.8928925619834709], [3.378787878787879, 1.0, 0.8764370982552803], [3.4393939393939394, 1.0, 0.8588062442607898], [3.5, 1.0, 0.8399999999999999], [3.5606060606060606, 1.0, 0.8200183654729112], [3.621212121212121, 1.0, 0.7988613406795224], [3.6818181818181817, 1.0, 0.7765289256198344], [3.742424242424242, 1.0, 0.7530211202938477], [3.8030303030303028, 1.0, 0.7283379247015609], [3.8636363636363633, 1.0, 0.7024793388429758], [3.9242424242424248, 1.0, 0.6754453627180896], [3.9848484848484853, 1.0, 0.6472359963269052], [4.045454545454546, 1.0, 0.6178512396694211], [4.106060606060606, 1.0, 0.5872910927456378], [4.166666666666667, 1.0, 0.5555555555555554], [4.2272727272727275, 1.0, 0.5226446280991732], [4.287878787878788, 1.0, 0.48855831037649233], [4.348484848484849, 1.0, 0.45329660238751135], [4.409090909090909, 1.0, 0.4168595041322316], [4.46969696969697, 1.0, 0.3792470156106522], [4.53030303030303, 1.0, 0.3404591368227732], [4.590909090909091, 1.0, 0.3004958677685954], [4.651515151515151, 1.0, 0.25935720844811794], [4.712121212121212, 1.0, 0.21704315886134085], [4.7727272727272725, 1.0, 0.17355371900826455], [4.833333333333334, 1.0, 0.12888888888888816], [4.8939393939393945, 1.0, 0.08304866850321302], [4.954545454545455, 1.0, 0.036033057851239114], [5.015151515151516, 0.0, 0.0], [5.075757575757576, 0.0, 0.0], [5.136363636363637, 0.0, 0.0], [5.196969696969697, 0.0, 0.0], [5.257575757575758, 0.0, 0.0], [5.318181818181818, 0.0, 0.0], [5.378787878787879, 0.0, 0.0], [5.4393939393939394, 0.0, 0.0], [5.5, 0.0, 0.0]]}, \"id\": \"el9520169640904\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAQIAAADDCAYAAABpjB/1AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n/we4nt9efPOWrQAAAABJRU5ErkJggg==\n",
       "text": [
        "<matplotlib.figure.Figure at 0xa1c83c8>"
       ]
      }
     ],
     "prompt_number": 56
    },
    {
     "cell_type": "heading",
     "level": 4,
     "metadata": {},
     "source": [
      "Compare Dependence on Energy"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "as_ = np.linspace(0.5, 5, 10)\n",
      "colors = cm.rainbow(1 - as_ / 5)\n",
      "Es = np.linspace(.01, .99)\n",
      "Es_coarse = np.arange(.01, 1, .05)\n",
      "n = 1e3\n",
      "\n",
      "plt.title('Transmission Coefficient as a Function of Energy')\n",
      "plt.xlabel('$E$')\n",
      "plt.ylabel('$T$')\n",
      "plt.xlim(0, 1.3)\n",
      "for a, color in zip(as_, colors):\n",
      "    # plot theoretical value\n",
      "    plt.plot(Es, [transmission_exact(a=a, E=E) for E in Es], '--', color=color)\n",
      "    \n",
      "    # plot numerical data points\n",
      "    Ts_parabolic = [scatter(V=parabolic_potential(a), E=E, x_min=0, x_max=a, n=n)[0] for E in Es_coarse]\n",
      "    l = plt.plot(Es_coarse, Ts_parabolic, 'o-', color=color, label='a = %.1f' % a)\n",
      "plt.legend()\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el95201703575363078586156\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "       mpld3.draw_figure(\"fig_el95201703575363078586156\", {\"axes\": [{\"xlim\": [0.0, 1.3], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$E$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520176030552\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520170500896\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Transmission Coefficient as a Function of Energy\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520175881128\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 0.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el9520176055800\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el9520170347656\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el9520170398328\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el9520169653528\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.81959378733572308], \"rotation\": -0.0, \"id\": \"el9520169652296\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.78434886499402645], \"rotation\": -0.0, \"id\": \"el9520169652968\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.74910394265232993], \"rotation\": -0.0, \"id\": \"el9520175893752\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 4.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.71385902031063342], \"rotation\": -0.0, \"id\": \"el9520175892744\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 4.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.67861409796893679], \"rotation\": -0.0, \"id\": \"el9520194630992\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 5.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.64336917562724039], \"rotation\": -0.0, \"id\": \"el9520170423408\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 1.3], \"ylim\": [0.0, 1.0], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data04\", \"id\": \"el9520176054960\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 6, \"tickvalues\": null}], \"lines\": [{\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520194538968\"}, {\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170341880\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520194536560\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520194538520\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169641856\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520169642136\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520176027800\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520176027184\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520175870472\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520175871368\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520175871704\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520169613464\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169612624\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520168816936\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168817216\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520168629248\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169585688\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520169584344\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520176078128\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520176077680\"}, {\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520176055296\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170347096\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170401632\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169654144\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169655488\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170401016\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520175892240\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520175893976\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168863112\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169586984\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FF4D27\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170341880pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF954E\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520194538520pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#E6CD73\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169642136pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#B2F295\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520176027184pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#80FEB3\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520175871368pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4CF2CE\", \"edgewidth\": 0.5, \"yindex\": 6, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169613464pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#18CDE3\", \"edgewidth\": 0.5, \"yindex\": 7, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168816936pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#1995F2\", \"edgewidth\": 0.5, \"yindex\": 8, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168629248pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4D4DFB\", \"edgewidth\": 0.5, \"yindex\": 9, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169584344pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#7F00FF\", \"edgewidth\": 0.5, \"yindex\": 10, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520176077680pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF4D27\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520176057032pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF954E\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170398272pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#E6CD73\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170398496pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#B2F295\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520169653416pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#80FEB3\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520169655768pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4CF2CE\", \"edgewidth\": 0.5, \"yindex\": 6, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170398384pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#18CDE3\", \"edgewidth\": 0.5, \"yindex\": 7, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520175891736pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#1995F2\", \"edgewidth\": 0.5, \"yindex\": 8, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520175891568pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4D4DFB\", \"edgewidth\": 0.5, \"yindex\": 9, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520168862944pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#7F00FF\", \"edgewidth\": 0.5, \"yindex\": 10, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520169586816pts\"}], \"id\": \"el9520176038912\", \"ydomain\": [0.0, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data04\": [[0.8616711469534052, 0.6284348864994028], [0.9910394265232977, 0.6284348864994028], [0.9910394265232977, 0.9880525686977301], [0.8616711469534052, 0.9880525686977301], [0.8616711469534052, 0.6284348864994028]], \"data02\": [[0.01, 0.14175236580161701, 0.03130595480281132, 0.009658433062826, 0.003300000621556616, 0.001163076919618643, 0.0004128125326337932, 0.00014634371496658342, 5.168388658980766e-05, 1.8174615434868167e-05, 6.364727454141362e-06], [0.060000000000000005, 0.4990473647282906, 0.1650622816090265, 0.05745309493892235, 0.020814248061803167, 0.007648204251116953, 0.0028169348009602605, 0.001035322119102686, 0.0003791838055793262, 0.0001383601056998834, 5.031018955073075e-05], [0.11, 0.6473860091191651, 0.2698258199336136, 0.10429022457020837, 0.040050193859974374, 0.015362935089411651, 0.0058790522215085616, 0.0022426216475887164, 0.0008526260794384018, 0.0003231442550339387, 0.00012212480736391207], [0.16000000000000003, 0.7285954754861615, 0.3540290822408626, 0.15001289752189176, 0.061035364779582824, 0.024472392188590705, 0.009743241879826945, 0.0038620572632538062, 0.0015259014956975267, 0.0006013192834069632, 0.00023645219356654537], [0.21000000000000002, 0.7798324948015666, 0.42312495876419975, 0.1944869900733602, 0.0837757189026328, 0.03515363599243139, 0.014581519443334965, 0.006013802646858443, 0.0024722184550123104, 0.0010141798774982312, 0.00041542693629363886], [0.26, 0.8151030108461015, 0.4807959257070117, 0.23760090311382662, 0.10825275715753362, 0.047593253196816794, 0.02059797957184405, 0.008851534610387813, 0.0037911016666275004, 0.0016210778671696925, 0.0006926042235823477], [0.31000000000000005, 0.8408625435653327, 0.5296185882440089, 0.27926482166106914, 0.1344211048752018, 0.06198360909319639, 0.028032869098568766, 0.012571293715095758, 0.005617942914899381, 0.002507539573762502, 0.0011190489951066042], [0.36000000000000004, 0.8604998398062218, 0.571449794817811, 0.3194095994792329, 0.1622067677037997, 0.07851749548002346, 0.03716614558307663, 0.017422279911933323, 0.008136990204686997, 0.003797163944718315, 0.001772835140705889], [0.41000000000000003, 0.87596468056925, 0.6076615371676065, 0.3579853580857308, 0.19150625596578283, 0.09738094722159778, 0.04831982347562214, 0.023719659103283955, 0.01159889595364126, 0.005669092243742508, 0.0027739614762865763], [0.46, 0.8884583669390078, 0.6392894931893691, 0.3949598848412503, 0.22218674145768696, 0.1187440966343186, 0.06185808434153972, 0.031859136733191205, 0.016344149705203082, 0.008383644770876268, 0.00430790888309349], [0.51, 0.8987614271219073, 0.6671301130768066, 0.4303169071834561, 0.2540873601771997, 0.14275010143578493, 0.07818373800876581, 0.04233243623825031, 0.02283376252849708, 0.012319783160949118, 0.006662997648828588], [0.56, 0.9074030105009236, 0.6918059097180345, 0.4640543103153372, 0.2870217056535714, 0.16950242873483917, 0.0977292146437108, 0.055741732660400216, 0.031688154962612125, 0.018029284242753175, 0.010289682635018291], [0.6100000000000001, 0.9147545461826005, 0.7138104731088184, 0.49618235488251705, 0.32078147556423836, 0.1990511008891426, 0.12093994880491252, 0.07280933088378125, 0.04373373930262088, 0.026313451580103002, 0.015894199734243313], [0.66, 0.9210844312615979, 0.7335401934687417, 0.5267219402679432, 0.35514114717466805, 0.23137888382011057, 0.1482479738215129, 0.09437628091323029, 0.06005310741599442, 0.03832748212138495, 0.02458414031559329], [0.7100000000000001, 0.926591439449374, 0.7513170568613249, 0.5557029486051607, 0.3898634742471421, 0.266388771327904, 0.18003406041081507, 0.1213802633302114, 0.08202732197464706, 0.05571183103586635, 0.038086633079419015], [0.76, 0.931425921939389, 0.7674053131452563, 0.5831626949154749, 0.42470552967514424, 0.30389440757629893, 0.2165781486422397, 0.15479965930898307, 0.11134542267775309, 0.08073165908017138, 0.059050259452266475], [0.81, 0.9357037059928575, 0.7820238554240406, 0.6091445003498197, 0.45942497271667804, 0.3436151931610898, 0.25800041935016926, 0.19554916816344256, 0.1499358539166862, 0.11636144422948295, 0.09138990711283893], [0.8600000000000001, 0.9395154662609339, 0.7953555454891748, 0.6336963982357713, 0.4937862032870633, 0.3851776410633647, 0.30419912041840474, 0.24431632515434648, 0.1997516630012543, 0.1661668081358127, 0.14047435204159775], [0.91, 0.9429332007814218, 0.8075543294680111, 0.6568699766965246, 0.5275660801325409, 0.4281240300532364, 0.3547955955864936, 0.3013427819349562, 0.2623349092386554, 0.23371876514543166, 0.21260558239730354], [0.9600000000000001, 0.9460148041146761, 0.8187507313141976, 0.6787193569568764, 0.5605589225924162, 0.4719285625612047, 0.40910043023608084, 0.3661825608323638, 0.3381367042920002, 0.3212353326214318, 0.3127976273495801]], \"data03\": [[0.8742159498207888, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086, 0.8279569892473121, 0.7927120669056155, 0.757467144563919, 0.7222222222222224, 0.6869772998805258, 0.6517323775388294], [0.8993055555555558, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086, 0.8279569892473121, 0.7927120669056155, 0.757467144563919, 0.7222222222222224, 0.6869772998805258, 0.6517323775388294]], \"data01\": [[0.01, 0.06367988688344325, 0.01063158514692595, 0.0023891360362745754, 0.0005730697817338912, 0.00013961326521384074, 3.414196281818837e-05, 8.357027621677835e-06, 2.046036939983362e-06, 5.009555176587583e-07, 1.2265655130461303e-07], [0.03, 0.16991256230689977, 0.03159161751825681, 0.007303543734334408, 0.0017821366602752606, 0.00044068855148335877, 0.00010933421717165804, 2.7147903948690358e-05, 6.742250508318086e-06, 1.6745395708335787e-06, 4.159023710803665e-07], [0.05, 0.25498680461114004, 0.05215119625415329, 0.012402290429793949, 0.0030792750052342005, 0.0007730229653668831, 0.00019460305243796714, 4.9024470221618055e-05, 1.2352455437097155e-05, 3.1125269291372943e-06, 7.842920931730465e-07], [0.06999999999999999, 0.32464974876257796, 0.07231494472231355, 0.01768866661457462, 0.004469723675984428, 0.0011393626572256358, 0.00029108847404831867, 7.441144962274092e-05, 1.90247487521813e-05, 4.8642352002604336e-06, 1.2436965053628329e-06], [0.09, 0.38273992925849015, 0.0920876391039664, 0.023165835927829136, 0.005959002875813745, 0.0015426921854442906, 0.00040005853353156627, 0.0001037912126231084, 2.693070574959306e-05, 6.98791943069978e-06, 1.8132238309966663e-06], [0.11, 0.4319188411942377, 0.11147419220613831, 0.028836819805588807, 0.007552926154132444, 0.00198625569087927, 0.0005229243161917953, 0.00013771189946502923, 3.62692160458131e-05, 9.552429664270125e-06, 2.51589142240714e-06], [0.13, 0.47408997325107044, 0.1304796380837603, 0.034704481616834836, 0.009257612451647211, 0.002473579981675562, 0.0006612567880854827, 0.00017679675673791667, 4.727098066974943e-05, 1.2639190598020382e-05, 3.3794425898214233e-06], [0.15000000000000002, 0.510650725608884, 0.14910911745492675, 0.04077151033105334, 0.011079498103245421, 0.00300849969572618, 0.0008168057474156411, 0.0002217548824091104, 6.0203791746771436e-05, 1.634456973552653e-05, 4.437341644435059e-06], [0.17, 0.542650121891528, 0.16736786389085395, 0.047040403769916625, 0.013025348698125503, 0.0035951847203394864, 0.0009915211595734504, 0.00027339360709986547, 7.537874031527423e-05, 2.0782715061279267e-05, 5.729988246697359e-06], [0.19, 0.5708910040840596, 0.1852611907606034, 0.053513451503600803, 0.015102270679690152, 0.004238170061185748, 0.0011875771941034794, 0.0003326327789962193, 9.315752690138636e-05, 2.6088961337990558e-05, 7.3062022353349975e-06], [0.21000000000000002, 0.5959982468825064, 0.202794478909404, 0.060192717460334756, 0.017317722548760746, 0.00494238836510139, 0.0014073993265649688, 0.00040052126677265874, 0.00011396108482240573, 3.242392653800315e-05, 9.225042842967103e-06], [0.23, 0.6184654812418521, 0.21997316504841471, 0.06708002232600861, 0.019679525512652674, 0.005713205313548979, 0.0016536949194257496, 0.0004782560507561918, 0.00013827976924534065, 3.997844777687647e-05, 1.1558042324431352e-05], [0.25, 0.6386878321252417, 0.23680273083298423, 0.07417692581896031, 0.02219587339946372, 0.006556458115081259, 0.0019294877546822862, 0.0005672043390537293, 0.00016668541760615573, 4.897954084749824e-05, 1.439195450286643e-05], [0.27, 0.6569853224828244, 0.25328869260588344, 0.08148470893331931, 0.024875341631487014, 0.007478497335541756, 0.002238157057892846, 0.0006689292246708465, 0.00019984565136891514, 5.969761088459275e-05, 1.7832144842371188e-05], [0.29000000000000004, 0.673619907272919, 0.2694365917815751, 0.08900435625240127, 0.027726895023906486, 0.008486232313311862, 0.0025834816299100203, 0.0007852194943941185, 0.00023854086812537717, 7.245519617402295e-05, 2.200678204653747e-05], [0.31, 0.6888080724469053, 0.2852519858473317, 0.0967365384415001, 0.03075989414485019, 0.009587180412868233, 0.002969689790104995, 0.0009181243135902103, 0.00028368447030079655, 8.763759569625411e-05, 2.7072034049898932e-05], [0.33, 0.7027302900447678, 0.3007404399569139, 0.10468159503689814, 0.033984099940501514, 0.010789520372213044, 0.003401515934722812, 0.0010699936469869599, 0.00033634699678667675, 0.00010570581759730596, 3.321852651481573e-05], [0.35000000000000003, 0.7155382081187842, 0.3159075190925285, 0.11283951765485202, 0.03740967629439494, 0.012102149997085615, 0.0038842646277531872, 0.0012435254386915636, 0.0003977849724302706, 0.0001272123955412273, 4.067939342788858e-05], [0.37, 0.727360184292402, 0.33075878077093207, 0.12120993375059774, 0.04104719015344512, 0.013534748445646694, 0.004423883271012405, 0.0014418207709595524, 0.00046947547480648554, 0.0001528207595201384, 4.97403422653791e-05], [0.39, 0.7383055916722793, 0.3452997682697651, 0.12979209106287903, 0.04490760881494969, 0.015097843329543805, 0.005027044546744987, 0.0016684484576235108, 0.0005531576474375159, 0.0001833290259854959, 6.075227739592375e-05], [0.41000000000000003, 0.7484682035359016, 0.35953600435052574, 0.13858484288400263, 0.049002293929187715, 0.01680288282846426, 0.005701239991718905, 0.0019275208132517692, 0.0006508826755883312, 0.00021969930073185583, 7.414718427087213e-05], [0.43, 0.7579288788169939, 0.37347298545498536, 0.14758663429881322, 0.053342991731855846, 0.018662312972458, 0.00645488624816967, 0.0022237826835679294, 0.000765074100337679, 0.00026309388220507353, 9.045818623006736e-05], [0.45, 0.7667577112931204, 0.3871161763523047, 0.15679548953809727, 0.05794181898017751, 0.020689660185818765, 0.007297445745478057, 0.002562716239271076, 0.000898600798629073, 0.00031492013332044334, 0.00011034496278918067], [0.47000000000000003, 0.7750157634005722, 0.40047100521461904, 0.16620900059264357, 0.0628112440270151, 0.022899619103755837, 0.008239563798126043, 0.002950664539807187, 0.001054865527070621, 0.00037688628390057676, 0.00013462608693905567], [0.49, 0.7827564754125486, 0.4135428590994216, 0.17582431723336528, 0.06796406242987232, 0.025308145563207245, 0.009293224360476339, 0.0033949774848838765, 0.0012379126486066813, 0.0004510710703909248, 0.0001643203322832682], [0.51, 0.7900268187497871, 0.42633707981767105, 0.18563813858041225, 0.07341336645770982, 0.02793255452569352, 0.010471926956248568, 0.00390418451265159, 0.001452559577050862, 0.0005400109645078959, 0.00020069966471509683], [0.53, 0.7968682460330774, 0.4388589601671661, 0.19564670635995762, 0.07917250782971055, 0.03079162250573868, 0.011790887597329757, 0.004488199302307413, 0.0017045576412327628, 0.0006468098558134575, 0.0002453575321968572], [0.55, 0.8033174784774164, 0.45111374051138875, 0.20584579998126967, 0.08525505299852983, 0.03390569384453736, 0.013267266817093476, 0.005158562828740815, 0.002000789561924028, 0.0007752775277369821, 0.00030029729098928273], [0.5700000000000001, 0.8094071622165869, 0.4631066056846778, 0.21623073355870007, 0.09167473027847502, 0.037296789875385615, 0.014920428258010156, 0.00592873243730215, 0.0023495126474819624, 0.0009301052299787599, 0.00036804728674839584], [0.59, 0.8151664183251784, 0.47484268220527115, 0.22679635499331172, 0.09844536811913665, 0.04098871966376782, 0.016772231556557642, 0.006814426204204242, 0.0027606592753508102, 0.0011170892791921372, 0.0004518114297410051], [0.61, 0.8206213060970884, 0.4863270357784449, 0.23753704721704258, 0.10558082384021891, 0.04500719055851028, 0.018847363536735308, 0.007834033775786446, 0.003246209403403585, 0.0013434171601997046, 0.0005556673331616795], [0.63, 0.8257952151320227, 0.49756466907266134, 0.24844673168857556, 0.11309490217696608, 0.0493799162476011, 0.021173711922037677, 0.009009107197494818, 0.0038206539677942404, 0.0016180353959165245, 0.0006848286131247813], [0.65, 0.8307091986746882, 0.5085605197523264, 0.25951887421454917, 0.12100126304118822, 0.05413671935896912, 0.02378278585427638, 0.010364948014726264, 0.004501573362436066, 0.0019521249902816858, 0.0008459943535234541], [0.67, 0.8353822582257765, 0.5193194587514406, 0.2707464931524828, 0.12931331798415666, 0.059309624868459726, 0.026710187394843314, 0.011931310215819587, 0.005310362140485372, 0.0023597192112868037, 0.0010478178726558167], [0.6900000000000001, 0.8398315875374739, 0.5298462887730996, 0.2821221700329782, 0.13804411495835384, 0.06493293966108168, 0.02999613778032365, 0.013743242445921577, 0.006273140129311651, 0.002858510848311959, 0.0013015400717670753], [0.7100000000000001, 0.8440727825984484, 0.5401457430004737, 0.2936380626185537, 0.14720621111892696, 0.07104331252630672, 0.03368606137275331, 0.01584209737665371, 0.007421901956610452, 0.0034709132490487655, 0.001621851737296603], [0.73, 0.8481200230135886, 0.5502224840055429, 0.30528592039510005, 0.1568115335861503, 0.07767976764713637, 0.037831228799212156, 0.018276741143902563, 0.008795972382103221, 0.004225463428895871, 0.0020280771744382474], [0.75, 0.85198622922378, 0.5600811028425084, 0.31705710246967095, 0.16687122831020113, 0.08488370326634306, 0.04248945846681752, 0.021105001237584454, 0.010443854873246507, 0.00515868925375802, 0.0025458130532591476], [0.77, 0.8556831992386696, 0.56972611831343, 0.3289425978254107, 0.17739549744126232, 0.09269884569317555, 0.047725872139301725, 0.024395396839681196, 0.012425586852744188, 0.006317610323174869, 0.0032092185073841106], [0.79, 0.8592217279307705, 0.579161976394243, 0.34093304786119416, 0.1883934259124522, 0.10117114717697274, 0.05361369514526779, 0.028229200760318342, 0.014815748498779395, 0.007763109787935119, 0.0040642466278324055], [0.81, 0.862611711431681, 0.5883930498099063, 0.35301877112033275, 0.1998727982899524, 0.11034861446920015, 0.060235084517442375, 0.03270288573088038, 0.01770731451330398, 0.00957451064337302, 0.005173251513484062], [0.8300000000000001, 0.8658622387567482, 0.5974236377480058, 0.365189790089831, 0.21183990733170857, 0.1202810531996541, 0.06768195827290971, 0.0379310080176956, 0.021216591271973173, 0.01185582744778291, 0.006621627820854752], [0.85, 0.8689816724445925, 0.6062579657006925, 0.3774358599295123, 0.22429935611873483, 0.13101971161977816, 0.07605678534756088, 0.04404957504884225, 0.025489545612351616, 0.014744360187155886, 0.008527487865105442], [0.87, 0.8719777197179408, 0.6149001854253731, 0.3897464989692256, 0.23725385607425267, 0.14261680597501072, 0.08547327750500643, 0.051219926083347, 0.030709903973071932, 0.018422574187885704, 0.011055930056695529], [0.89, 0.8748574954406478, 0.6233543750150878, 0.40211102079262523, 0.2507040236555988, 0.1551249089706182, 0.09605690093116133, 0.059633118241102116, 0.03710947360843843, 0.023134596812672256, 0.01444032287192198], [0.91, 0.8776275779535141, 0.6316245390700103, 0.4145185677080473, 0.26464817897886356, 0.1685961827624801, 0.10794509539142386, 0.06951474287699677, 0.04498119112473731, 0.029209186176976456, 0.019014411524148553], [0.93, 0.8802940587112572, 0.6397146089619798, 0.42695814539105037, 0.2790821501001028, 0.1830814389678617, 0.12128705232321715, 0.081129982410075, 0.05469539416680809, 0.03709169848222272, 0.025261236842803785], [0.9500000000000001, 0.8828625865089388, 0.6476284431844384, 0.4394186584695643, 0.2939990871101362, 0.19862901073978972, 0.13624286039932584, 0.09478853168219174, 0.06671965254498287, 0.04738833757926249, 0.03388822002658438], [0.97, 0.8853384069736263, 0.6553698277805843, 0.45188894681150976, 0.30938929057998404, 0.21528342641147066, 0.15298177967920856, 0.11084871981207456, 0.08164202019123602, 0.06092655195157571, 0.04594265558263385], [0.99, 0.887726397902296, 0.662942476842977, 0.46435782226642786, 0.3252400591962998, 0.23308388103379943, 0.17167935752895855, 0.1297197420685918, 0.10019648250115669, 0.07883508554178247, 0.0629879399835792]]}, \"id\": \"el9520170357536\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "         \n",
        "         mpld3.draw_figure(\"fig_el95201703575363078586156\", {\"axes\": [{\"xlim\": [0.0, 1.3], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$E$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520176030552\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520170500896\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Transmission Coefficient as a Function of Energy\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520175881128\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 0.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el9520176055800\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el9520170347656\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el9520170398328\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el9520169653528\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.81959378733572308], \"rotation\": -0.0, \"id\": \"el9520169652296\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.78434886499402645], \"rotation\": -0.0, \"id\": \"el9520169652968\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.74910394265232993], \"rotation\": -0.0, \"id\": \"el9520175893752\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 4.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.71385902031063342], \"rotation\": -0.0, \"id\": \"el9520175892744\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 4.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.67861409796893679], \"rotation\": -0.0, \"id\": \"el9520194630992\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 5.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.64336917562724039], \"rotation\": -0.0, \"id\": \"el9520170423408\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 1.3], \"ylim\": [0.0, 1.0], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data04\", \"id\": \"el9520176054960\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 6, \"tickvalues\": null}], \"lines\": [{\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520194538968\"}, {\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170341880\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520194536560\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520194538520\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169641856\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520169642136\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520176027800\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520176027184\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520175870472\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520175871368\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520175871704\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520169613464\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169612624\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520168816936\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168817216\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520168629248\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169585688\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520169584344\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520176078128\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520176077680\"}, {\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520176055296\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170347096\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170401632\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169654144\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169655488\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170401016\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520175892240\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520175893976\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168863112\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169586984\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FF4D27\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170341880pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF954E\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520194538520pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#E6CD73\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169642136pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#B2F295\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520176027184pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#80FEB3\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520175871368pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4CF2CE\", \"edgewidth\": 0.5, \"yindex\": 6, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169613464pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#18CDE3\", \"edgewidth\": 0.5, \"yindex\": 7, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168816936pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#1995F2\", \"edgewidth\": 0.5, \"yindex\": 8, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168629248pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4D4DFB\", \"edgewidth\": 0.5, \"yindex\": 9, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169584344pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#7F00FF\", \"edgewidth\": 0.5, \"yindex\": 10, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520176077680pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF4D27\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520176057032pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF954E\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170398272pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#E6CD73\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170398496pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#B2F295\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520169653416pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#80FEB3\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520169655768pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4CF2CE\", \"edgewidth\": 0.5, \"yindex\": 6, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170398384pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#18CDE3\", \"edgewidth\": 0.5, \"yindex\": 7, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520175891736pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#1995F2\", \"edgewidth\": 0.5, \"yindex\": 8, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520175891568pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4D4DFB\", \"edgewidth\": 0.5, \"yindex\": 9, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520168862944pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#7F00FF\", \"edgewidth\": 0.5, \"yindex\": 10, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520169586816pts\"}], \"id\": \"el9520176038912\", \"ydomain\": [0.0, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data04\": [[0.8616711469534052, 0.6284348864994028], [0.9910394265232977, 0.6284348864994028], [0.9910394265232977, 0.9880525686977301], [0.8616711469534052, 0.9880525686977301], [0.8616711469534052, 0.6284348864994028]], \"data02\": [[0.01, 0.14175236580161701, 0.03130595480281132, 0.009658433062826, 0.003300000621556616, 0.001163076919618643, 0.0004128125326337932, 0.00014634371496658342, 5.168388658980766e-05, 1.8174615434868167e-05, 6.364727454141362e-06], [0.060000000000000005, 0.4990473647282906, 0.1650622816090265, 0.05745309493892235, 0.020814248061803167, 0.007648204251116953, 0.0028169348009602605, 0.001035322119102686, 0.0003791838055793262, 0.0001383601056998834, 5.031018955073075e-05], [0.11, 0.6473860091191651, 0.2698258199336136, 0.10429022457020837, 0.040050193859974374, 0.015362935089411651, 0.0058790522215085616, 0.0022426216475887164, 0.0008526260794384018, 0.0003231442550339387, 0.00012212480736391207], [0.16000000000000003, 0.7285954754861615, 0.3540290822408626, 0.15001289752189176, 0.061035364779582824, 0.024472392188590705, 0.009743241879826945, 0.0038620572632538062, 0.0015259014956975267, 0.0006013192834069632, 0.00023645219356654537], [0.21000000000000002, 0.7798324948015666, 0.42312495876419975, 0.1944869900733602, 0.0837757189026328, 0.03515363599243139, 0.014581519443334965, 0.006013802646858443, 0.0024722184550123104, 0.0010141798774982312, 0.00041542693629363886], [0.26, 0.8151030108461015, 0.4807959257070117, 0.23760090311382662, 0.10825275715753362, 0.047593253196816794, 0.02059797957184405, 0.008851534610387813, 0.0037911016666275004, 0.0016210778671696925, 0.0006926042235823477], [0.31000000000000005, 0.8408625435653327, 0.5296185882440089, 0.27926482166106914, 0.1344211048752018, 0.06198360909319639, 0.028032869098568766, 0.012571293715095758, 0.005617942914899381, 0.002507539573762502, 0.0011190489951066042], [0.36000000000000004, 0.8604998398062218, 0.571449794817811, 0.3194095994792329, 0.1622067677037997, 0.07851749548002346, 0.03716614558307663, 0.017422279911933323, 0.008136990204686997, 0.003797163944718315, 0.001772835140705889], [0.41000000000000003, 0.87596468056925, 0.6076615371676065, 0.3579853580857308, 0.19150625596578283, 0.09738094722159778, 0.04831982347562214, 0.023719659103283955, 0.01159889595364126, 0.005669092243742508, 0.0027739614762865763], [0.46, 0.8884583669390078, 0.6392894931893691, 0.3949598848412503, 0.22218674145768696, 0.1187440966343186, 0.06185808434153972, 0.031859136733191205, 0.016344149705203082, 0.008383644770876268, 0.00430790888309349], [0.51, 0.8987614271219073, 0.6671301130768066, 0.4303169071834561, 0.2540873601771997, 0.14275010143578493, 0.07818373800876581, 0.04233243623825031, 0.02283376252849708, 0.012319783160949118, 0.006662997648828588], [0.56, 0.9074030105009236, 0.6918059097180345, 0.4640543103153372, 0.2870217056535714, 0.16950242873483917, 0.0977292146437108, 0.055741732660400216, 0.031688154962612125, 0.018029284242753175, 0.010289682635018291], [0.6100000000000001, 0.9147545461826005, 0.7138104731088184, 0.49618235488251705, 0.32078147556423836, 0.1990511008891426, 0.12093994880491252, 0.07280933088378125, 0.04373373930262088, 0.026313451580103002, 0.015894199734243313], [0.66, 0.9210844312615979, 0.7335401934687417, 0.5267219402679432, 0.35514114717466805, 0.23137888382011057, 0.1482479738215129, 0.09437628091323029, 0.06005310741599442, 0.03832748212138495, 0.02458414031559329], [0.7100000000000001, 0.926591439449374, 0.7513170568613249, 0.5557029486051607, 0.3898634742471421, 0.266388771327904, 0.18003406041081507, 0.1213802633302114, 0.08202732197464706, 0.05571183103586635, 0.038086633079419015], [0.76, 0.931425921939389, 0.7674053131452563, 0.5831626949154749, 0.42470552967514424, 0.30389440757629893, 0.2165781486422397, 0.15479965930898307, 0.11134542267775309, 0.08073165908017138, 0.059050259452266475], [0.81, 0.9357037059928575, 0.7820238554240406, 0.6091445003498197, 0.45942497271667804, 0.3436151931610898, 0.25800041935016926, 0.19554916816344256, 0.1499358539166862, 0.11636144422948295, 0.09138990711283893], [0.8600000000000001, 0.9395154662609339, 0.7953555454891748, 0.6336963982357713, 0.4937862032870633, 0.3851776410633647, 0.30419912041840474, 0.24431632515434648, 0.1997516630012543, 0.1661668081358127, 0.14047435204159775], [0.91, 0.9429332007814218, 0.8075543294680111, 0.6568699766965246, 0.5275660801325409, 0.4281240300532364, 0.3547955955864936, 0.3013427819349562, 0.2623349092386554, 0.23371876514543166, 0.21260558239730354], [0.9600000000000001, 0.9460148041146761, 0.8187507313141976, 0.6787193569568764, 0.5605589225924162, 0.4719285625612047, 0.40910043023608084, 0.3661825608323638, 0.3381367042920002, 0.3212353326214318, 0.3127976273495801]], \"data03\": [[0.8742159498207888, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086, 0.8279569892473121, 0.7927120669056155, 0.757467144563919, 0.7222222222222224, 0.6869772998805258, 0.6517323775388294], [0.8993055555555558, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086, 0.8279569892473121, 0.7927120669056155, 0.757467144563919, 0.7222222222222224, 0.6869772998805258, 0.6517323775388294]], \"data01\": [[0.01, 0.06367988688344325, 0.01063158514692595, 0.0023891360362745754, 0.0005730697817338912, 0.00013961326521384074, 3.414196281818837e-05, 8.357027621677835e-06, 2.046036939983362e-06, 5.009555176587583e-07, 1.2265655130461303e-07], [0.03, 0.16991256230689977, 0.03159161751825681, 0.007303543734334408, 0.0017821366602752606, 0.00044068855148335877, 0.00010933421717165804, 2.7147903948690358e-05, 6.742250508318086e-06, 1.6745395708335787e-06, 4.159023710803665e-07], [0.05, 0.25498680461114004, 0.05215119625415329, 0.012402290429793949, 0.0030792750052342005, 0.0007730229653668831, 0.00019460305243796714, 4.9024470221618055e-05, 1.2352455437097155e-05, 3.1125269291372943e-06, 7.842920931730465e-07], [0.06999999999999999, 0.32464974876257796, 0.07231494472231355, 0.01768866661457462, 0.004469723675984428, 0.0011393626572256358, 0.00029108847404831867, 7.441144962274092e-05, 1.90247487521813e-05, 4.8642352002604336e-06, 1.2436965053628329e-06], [0.09, 0.38273992925849015, 0.0920876391039664, 0.023165835927829136, 0.005959002875813745, 0.0015426921854442906, 0.00040005853353156627, 0.0001037912126231084, 2.693070574959306e-05, 6.98791943069978e-06, 1.8132238309966663e-06], [0.11, 0.4319188411942377, 0.11147419220613831, 0.028836819805588807, 0.007552926154132444, 0.00198625569087927, 0.0005229243161917953, 0.00013771189946502923, 3.62692160458131e-05, 9.552429664270125e-06, 2.51589142240714e-06], [0.13, 0.47408997325107044, 0.1304796380837603, 0.034704481616834836, 0.009257612451647211, 0.002473579981675562, 0.0006612567880854827, 0.00017679675673791667, 4.727098066974943e-05, 1.2639190598020382e-05, 3.3794425898214233e-06], [0.15000000000000002, 0.510650725608884, 0.14910911745492675, 0.04077151033105334, 0.011079498103245421, 0.00300849969572618, 0.0008168057474156411, 0.0002217548824091104, 6.0203791746771436e-05, 1.634456973552653e-05, 4.437341644435059e-06], [0.17, 0.542650121891528, 0.16736786389085395, 0.047040403769916625, 0.013025348698125503, 0.0035951847203394864, 0.0009915211595734504, 0.00027339360709986547, 7.537874031527423e-05, 2.0782715061279267e-05, 5.729988246697359e-06], [0.19, 0.5708910040840596, 0.1852611907606034, 0.053513451503600803, 0.015102270679690152, 0.004238170061185748, 0.0011875771941034794, 0.0003326327789962193, 9.315752690138636e-05, 2.6088961337990558e-05, 7.3062022353349975e-06], [0.21000000000000002, 0.5959982468825064, 0.202794478909404, 0.060192717460334756, 0.017317722548760746, 0.00494238836510139, 0.0014073993265649688, 0.00040052126677265874, 0.00011396108482240573, 3.242392653800315e-05, 9.225042842967103e-06], [0.23, 0.6184654812418521, 0.21997316504841471, 0.06708002232600861, 0.019679525512652674, 0.005713205313548979, 0.0016536949194257496, 0.0004782560507561918, 0.00013827976924534065, 3.997844777687647e-05, 1.1558042324431352e-05], [0.25, 0.6386878321252417, 0.23680273083298423, 0.07417692581896031, 0.02219587339946372, 0.006556458115081259, 0.0019294877546822862, 0.0005672043390537293, 0.00016668541760615573, 4.897954084749824e-05, 1.439195450286643e-05], [0.27, 0.6569853224828244, 0.25328869260588344, 0.08148470893331931, 0.024875341631487014, 0.007478497335541756, 0.002238157057892846, 0.0006689292246708465, 0.00019984565136891514, 5.969761088459275e-05, 1.7832144842371188e-05], [0.29000000000000004, 0.673619907272919, 0.2694365917815751, 0.08900435625240127, 0.027726895023906486, 0.008486232313311862, 0.0025834816299100203, 0.0007852194943941185, 0.00023854086812537717, 7.245519617402295e-05, 2.200678204653747e-05], [0.31, 0.6888080724469053, 0.2852519858473317, 0.0967365384415001, 0.03075989414485019, 0.009587180412868233, 0.002969689790104995, 0.0009181243135902103, 0.00028368447030079655, 8.763759569625411e-05, 2.7072034049898932e-05], [0.33, 0.7027302900447678, 0.3007404399569139, 0.10468159503689814, 0.033984099940501514, 0.010789520372213044, 0.003401515934722812, 0.0010699936469869599, 0.00033634699678667675, 0.00010570581759730596, 3.321852651481573e-05], [0.35000000000000003, 0.7155382081187842, 0.3159075190925285, 0.11283951765485202, 0.03740967629439494, 0.012102149997085615, 0.0038842646277531872, 0.0012435254386915636, 0.0003977849724302706, 0.0001272123955412273, 4.067939342788858e-05], [0.37, 0.727360184292402, 0.33075878077093207, 0.12120993375059774, 0.04104719015344512, 0.013534748445646694, 0.004423883271012405, 0.0014418207709595524, 0.00046947547480648554, 0.0001528207595201384, 4.97403422653791e-05], [0.39, 0.7383055916722793, 0.3452997682697651, 0.12979209106287903, 0.04490760881494969, 0.015097843329543805, 0.005027044546744987, 0.0016684484576235108, 0.0005531576474375159, 0.0001833290259854959, 6.075227739592375e-05], [0.41000000000000003, 0.7484682035359016, 0.35953600435052574, 0.13858484288400263, 0.049002293929187715, 0.01680288282846426, 0.005701239991718905, 0.0019275208132517692, 0.0006508826755883312, 0.00021969930073185583, 7.414718427087213e-05], [0.43, 0.7579288788169939, 0.37347298545498536, 0.14758663429881322, 0.053342991731855846, 0.018662312972458, 0.00645488624816967, 0.0022237826835679294, 0.000765074100337679, 0.00026309388220507353, 9.045818623006736e-05], [0.45, 0.7667577112931204, 0.3871161763523047, 0.15679548953809727, 0.05794181898017751, 0.020689660185818765, 0.007297445745478057, 0.002562716239271076, 0.000898600798629073, 0.00031492013332044334, 0.00011034496278918067], [0.47000000000000003, 0.7750157634005722, 0.40047100521461904, 0.16620900059264357, 0.0628112440270151, 0.022899619103755837, 0.008239563798126043, 0.002950664539807187, 0.001054865527070621, 0.00037688628390057676, 0.00013462608693905567], [0.49, 0.7827564754125486, 0.4135428590994216, 0.17582431723336528, 0.06796406242987232, 0.025308145563207245, 0.009293224360476339, 0.0033949774848838765, 0.0012379126486066813, 0.0004510710703909248, 0.0001643203322832682], [0.51, 0.7900268187497871, 0.42633707981767105, 0.18563813858041225, 0.07341336645770982, 0.02793255452569352, 0.010471926956248568, 0.00390418451265159, 0.001452559577050862, 0.0005400109645078959, 0.00020069966471509683], [0.53, 0.7968682460330774, 0.4388589601671661, 0.19564670635995762, 0.07917250782971055, 0.03079162250573868, 0.011790887597329757, 0.004488199302307413, 0.0017045576412327628, 0.0006468098558134575, 0.0002453575321968572], [0.55, 0.8033174784774164, 0.45111374051138875, 0.20584579998126967, 0.08525505299852983, 0.03390569384453736, 0.013267266817093476, 0.005158562828740815, 0.002000789561924028, 0.0007752775277369821, 0.00030029729098928273], [0.5700000000000001, 0.8094071622165869, 0.4631066056846778, 0.21623073355870007, 0.09167473027847502, 0.037296789875385615, 0.014920428258010156, 0.00592873243730215, 0.0023495126474819624, 0.0009301052299787599, 0.00036804728674839584], [0.59, 0.8151664183251784, 0.47484268220527115, 0.22679635499331172, 0.09844536811913665, 0.04098871966376782, 0.016772231556557642, 0.006814426204204242, 0.0027606592753508102, 0.0011170892791921372, 0.0004518114297410051], [0.61, 0.8206213060970884, 0.4863270357784449, 0.23753704721704258, 0.10558082384021891, 0.04500719055851028, 0.018847363536735308, 0.007834033775786446, 0.003246209403403585, 0.0013434171601997046, 0.0005556673331616795], [0.63, 0.8257952151320227, 0.49756466907266134, 0.24844673168857556, 0.11309490217696608, 0.0493799162476011, 0.021173711922037677, 0.009009107197494818, 0.0038206539677942404, 0.0016180353959165245, 0.0006848286131247813], [0.65, 0.8307091986746882, 0.5085605197523264, 0.25951887421454917, 0.12100126304118822, 0.05413671935896912, 0.02378278585427638, 0.010364948014726264, 0.004501573362436066, 0.0019521249902816858, 0.0008459943535234541], [0.67, 0.8353822582257765, 0.5193194587514406, 0.2707464931524828, 0.12931331798415666, 0.059309624868459726, 0.026710187394843314, 0.011931310215819587, 0.005310362140485372, 0.0023597192112868037, 0.0010478178726558167], [0.6900000000000001, 0.8398315875374739, 0.5298462887730996, 0.2821221700329782, 0.13804411495835384, 0.06493293966108168, 0.02999613778032365, 0.013743242445921577, 0.006273140129311651, 0.002858510848311959, 0.0013015400717670753], [0.7100000000000001, 0.8440727825984484, 0.5401457430004737, 0.2936380626185537, 0.14720621111892696, 0.07104331252630672, 0.03368606137275331, 0.01584209737665371, 0.007421901956610452, 0.0034709132490487655, 0.001621851737296603], [0.73, 0.8481200230135886, 0.5502224840055429, 0.30528592039510005, 0.1568115335861503, 0.07767976764713637, 0.037831228799212156, 0.018276741143902563, 0.008795972382103221, 0.004225463428895871, 0.0020280771744382474], [0.75, 0.85198622922378, 0.5600811028425084, 0.31705710246967095, 0.16687122831020113, 0.08488370326634306, 0.04248945846681752, 0.021105001237584454, 0.010443854873246507, 0.00515868925375802, 0.0025458130532591476], [0.77, 0.8556831992386696, 0.56972611831343, 0.3289425978254107, 0.17739549744126232, 0.09269884569317555, 0.047725872139301725, 0.024395396839681196, 0.012425586852744188, 0.006317610323174869, 0.0032092185073841106], [0.79, 0.8592217279307705, 0.579161976394243, 0.34093304786119416, 0.1883934259124522, 0.10117114717697274, 0.05361369514526779, 0.028229200760318342, 0.014815748498779395, 0.007763109787935119, 0.0040642466278324055], [0.81, 0.862611711431681, 0.5883930498099063, 0.35301877112033275, 0.1998727982899524, 0.11034861446920015, 0.060235084517442375, 0.03270288573088038, 0.01770731451330398, 0.00957451064337302, 0.005173251513484062], [0.8300000000000001, 0.8658622387567482, 0.5974236377480058, 0.365189790089831, 0.21183990733170857, 0.1202810531996541, 0.06768195827290971, 0.0379310080176956, 0.021216591271973173, 0.01185582744778291, 0.006621627820854752], [0.85, 0.8689816724445925, 0.6062579657006925, 0.3774358599295123, 0.22429935611873483, 0.13101971161977816, 0.07605678534756088, 0.04404957504884225, 0.025489545612351616, 0.014744360187155886, 0.008527487865105442], [0.87, 0.8719777197179408, 0.6149001854253731, 0.3897464989692256, 0.23725385607425267, 0.14261680597501072, 0.08547327750500643, 0.051219926083347, 0.030709903973071932, 0.018422574187885704, 0.011055930056695529], [0.89, 0.8748574954406478, 0.6233543750150878, 0.40211102079262523, 0.2507040236555988, 0.1551249089706182, 0.09605690093116133, 0.059633118241102116, 0.03710947360843843, 0.023134596812672256, 0.01444032287192198], [0.91, 0.8776275779535141, 0.6316245390700103, 0.4145185677080473, 0.26464817897886356, 0.1685961827624801, 0.10794509539142386, 0.06951474287699677, 0.04498119112473731, 0.029209186176976456, 0.019014411524148553], [0.93, 0.8802940587112572, 0.6397146089619798, 0.42695814539105037, 0.2790821501001028, 0.1830814389678617, 0.12128705232321715, 0.081129982410075, 0.05469539416680809, 0.03709169848222272, 0.025261236842803785], [0.9500000000000001, 0.8828625865089388, 0.6476284431844384, 0.4394186584695643, 0.2939990871101362, 0.19862901073978972, 0.13624286039932584, 0.09478853168219174, 0.06671965254498287, 0.04738833757926249, 0.03388822002658438], [0.97, 0.8853384069736263, 0.6553698277805843, 0.45188894681150976, 0.30938929057998404, 0.21528342641147066, 0.15298177967920856, 0.11084871981207456, 0.08164202019123602, 0.06092655195157571, 0.04594265558263385], [0.99, 0.887726397902296, 0.662942476842977, 0.46435782226642786, 0.3252400591962998, 0.23308388103379943, 0.17167935752895855, 0.1297197420685918, 0.10019648250115669, 0.07883508554178247, 0.0629879399835792]]}, \"id\": \"el9520170357536\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "                 \n",
        "                 mpld3.draw_figure(\"fig_el95201703575363078586156\", {\"axes\": [{\"xlim\": [0.0, 1.3], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$E$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520176030552\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520170500896\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Transmission Coefficient as a Function of Energy\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520175881128\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 0.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el9520176055800\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el9520170347656\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 1.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el9520170398328\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el9520169653528\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 2.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.81959378733572308], \"rotation\": -0.0, \"id\": \"el9520169652296\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.78434886499402645], \"rotation\": -0.0, \"id\": \"el9520169652968\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 3.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.74910394265232993], \"rotation\": -0.0, \"id\": \"el9520175893752\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 4.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.71385902031063342], \"rotation\": -0.0, \"id\": \"el9520175892744\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 4.5\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.67861409796893679], \"rotation\": -0.0, \"id\": \"el9520194630992\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"a = 5.0\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.91901881720430134, 0.64336917562724039], \"rotation\": -0.0, \"id\": \"el9520170423408\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 1.3], \"ylim\": [0.0, 1.0], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data04\", \"id\": \"el9520176054960\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 8, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 6, \"tickvalues\": null}], \"lines\": [{\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520194538968\"}, {\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170341880\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520194536560\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520194538520\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169641856\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520169642136\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520176027800\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520176027184\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520175870472\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520175871368\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520175871704\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520169613464\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169612624\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520168816936\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520168817216\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520168629248\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520169585688\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520169584344\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520176078128\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520176077680\"}, {\"color\": \"#FF4D27\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520176055296\"}, {\"color\": \"#FF954E\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170347096\"}, {\"color\": \"#E6CD73\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170401632\"}, {\"color\": \"#B2F295\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169654144\"}, {\"color\": \"#80FEB3\", \"yindex\": 5, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169655488\"}, {\"color\": \"#4CF2CE\", \"yindex\": 6, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170401016\"}, {\"color\": \"#18CDE3\", \"yindex\": 7, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520175892240\"}, {\"color\": \"#1995F2\", \"yindex\": 8, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520175893976\"}, {\"color\": \"#4D4DFB\", \"yindex\": 9, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168863112\"}, {\"color\": \"#7F00FF\", \"yindex\": 10, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169586984\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FF4D27\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170341880pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF954E\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520194538520pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#E6CD73\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169642136pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#B2F295\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520176027184pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#80FEB3\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520175871368pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4CF2CE\", \"edgewidth\": 0.5, \"yindex\": 6, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169613464pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#18CDE3\", \"edgewidth\": 0.5, \"yindex\": 7, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168816936pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#1995F2\", \"edgewidth\": 0.5, \"yindex\": 8, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168629248pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4D4DFB\", \"edgewidth\": 0.5, \"yindex\": 9, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520169584344pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#7F00FF\", \"edgewidth\": 0.5, \"yindex\": 10, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520176077680pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF4D27\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520176057032pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#FF954E\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170398272pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#E6CD73\", \"edgewidth\": 0.5, \"yindex\": 3, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170398496pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#B2F295\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520169653416pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#80FEB3\", \"edgewidth\": 0.5, \"yindex\": 5, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520169655768pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4CF2CE\", \"edgewidth\": 0.5, \"yindex\": 6, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170398384pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#18CDE3\", \"edgewidth\": 0.5, \"yindex\": 7, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520175891736pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#1995F2\", \"edgewidth\": 0.5, \"yindex\": 8, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520175891568pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#4D4DFB\", \"edgewidth\": 0.5, \"yindex\": 9, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520168862944pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#7F00FF\", \"edgewidth\": 0.5, \"yindex\": 10, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520169586816pts\"}], \"id\": \"el9520176038912\", \"ydomain\": [0.0, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data04\": [[0.8616711469534052, 0.6284348864994028], [0.9910394265232977, 0.6284348864994028], [0.9910394265232977, 0.9880525686977301], [0.8616711469534052, 0.9880525686977301], [0.8616711469534052, 0.6284348864994028]], \"data02\": [[0.01, 0.14175236580161701, 0.03130595480281132, 0.009658433062826, 0.003300000621556616, 0.001163076919618643, 0.0004128125326337932, 0.00014634371496658342, 5.168388658980766e-05, 1.8174615434868167e-05, 6.364727454141362e-06], [0.060000000000000005, 0.4990473647282906, 0.1650622816090265, 0.05745309493892235, 0.020814248061803167, 0.007648204251116953, 0.0028169348009602605, 0.001035322119102686, 0.0003791838055793262, 0.0001383601056998834, 5.031018955073075e-05], [0.11, 0.6473860091191651, 0.2698258199336136, 0.10429022457020837, 0.040050193859974374, 0.015362935089411651, 0.0058790522215085616, 0.0022426216475887164, 0.0008526260794384018, 0.0003231442550339387, 0.00012212480736391207], [0.16000000000000003, 0.7285954754861615, 0.3540290822408626, 0.15001289752189176, 0.061035364779582824, 0.024472392188590705, 0.009743241879826945, 0.0038620572632538062, 0.0015259014956975267, 0.0006013192834069632, 0.00023645219356654537], [0.21000000000000002, 0.7798324948015666, 0.42312495876419975, 0.1944869900733602, 0.0837757189026328, 0.03515363599243139, 0.014581519443334965, 0.006013802646858443, 0.0024722184550123104, 0.0010141798774982312, 0.00041542693629363886], [0.26, 0.8151030108461015, 0.4807959257070117, 0.23760090311382662, 0.10825275715753362, 0.047593253196816794, 0.02059797957184405, 0.008851534610387813, 0.0037911016666275004, 0.0016210778671696925, 0.0006926042235823477], [0.31000000000000005, 0.8408625435653327, 0.5296185882440089, 0.27926482166106914, 0.1344211048752018, 0.06198360909319639, 0.028032869098568766, 0.012571293715095758, 0.005617942914899381, 0.002507539573762502, 0.0011190489951066042], [0.36000000000000004, 0.8604998398062218, 0.571449794817811, 0.3194095994792329, 0.1622067677037997, 0.07851749548002346, 0.03716614558307663, 0.017422279911933323, 0.008136990204686997, 0.003797163944718315, 0.001772835140705889], [0.41000000000000003, 0.87596468056925, 0.6076615371676065, 0.3579853580857308, 0.19150625596578283, 0.09738094722159778, 0.04831982347562214, 0.023719659103283955, 0.01159889595364126, 0.005669092243742508, 0.0027739614762865763], [0.46, 0.8884583669390078, 0.6392894931893691, 0.3949598848412503, 0.22218674145768696, 0.1187440966343186, 0.06185808434153972, 0.031859136733191205, 0.016344149705203082, 0.008383644770876268, 0.00430790888309349], [0.51, 0.8987614271219073, 0.6671301130768066, 0.4303169071834561, 0.2540873601771997, 0.14275010143578493, 0.07818373800876581, 0.04233243623825031, 0.02283376252849708, 0.012319783160949118, 0.006662997648828588], [0.56, 0.9074030105009236, 0.6918059097180345, 0.4640543103153372, 0.2870217056535714, 0.16950242873483917, 0.0977292146437108, 0.055741732660400216, 0.031688154962612125, 0.018029284242753175, 0.010289682635018291], [0.6100000000000001, 0.9147545461826005, 0.7138104731088184, 0.49618235488251705, 0.32078147556423836, 0.1990511008891426, 0.12093994880491252, 0.07280933088378125, 0.04373373930262088, 0.026313451580103002, 0.015894199734243313], [0.66, 0.9210844312615979, 0.7335401934687417, 0.5267219402679432, 0.35514114717466805, 0.23137888382011057, 0.1482479738215129, 0.09437628091323029, 0.06005310741599442, 0.03832748212138495, 0.02458414031559329], [0.7100000000000001, 0.926591439449374, 0.7513170568613249, 0.5557029486051607, 0.3898634742471421, 0.266388771327904, 0.18003406041081507, 0.1213802633302114, 0.08202732197464706, 0.05571183103586635, 0.038086633079419015], [0.76, 0.931425921939389, 0.7674053131452563, 0.5831626949154749, 0.42470552967514424, 0.30389440757629893, 0.2165781486422397, 0.15479965930898307, 0.11134542267775309, 0.08073165908017138, 0.059050259452266475], [0.81, 0.9357037059928575, 0.7820238554240406, 0.6091445003498197, 0.45942497271667804, 0.3436151931610898, 0.25800041935016926, 0.19554916816344256, 0.1499358539166862, 0.11636144422948295, 0.09138990711283893], [0.8600000000000001, 0.9395154662609339, 0.7953555454891748, 0.6336963982357713, 0.4937862032870633, 0.3851776410633647, 0.30419912041840474, 0.24431632515434648, 0.1997516630012543, 0.1661668081358127, 0.14047435204159775], [0.91, 0.9429332007814218, 0.8075543294680111, 0.6568699766965246, 0.5275660801325409, 0.4281240300532364, 0.3547955955864936, 0.3013427819349562, 0.2623349092386554, 0.23371876514543166, 0.21260558239730354], [0.9600000000000001, 0.9460148041146761, 0.8187507313141976, 0.6787193569568764, 0.5605589225924162, 0.4719285625612047, 0.40910043023608084, 0.3661825608323638, 0.3381367042920002, 0.3212353326214318, 0.3127976273495801]], \"data03\": [[0.8742159498207888, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086, 0.8279569892473121, 0.7927120669056155, 0.757467144563919, 0.7222222222222224, 0.6869772998805258, 0.6517323775388294], [0.8993055555555558, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086, 0.8279569892473121, 0.7927120669056155, 0.757467144563919, 0.7222222222222224, 0.6869772998805258, 0.6517323775388294]], \"data01\": [[0.01, 0.06367988688344325, 0.01063158514692595, 0.0023891360362745754, 0.0005730697817338912, 0.00013961326521384074, 3.414196281818837e-05, 8.357027621677835e-06, 2.046036939983362e-06, 5.009555176587583e-07, 1.2265655130461303e-07], [0.03, 0.16991256230689977, 0.03159161751825681, 0.007303543734334408, 0.0017821366602752606, 0.00044068855148335877, 0.00010933421717165804, 2.7147903948690358e-05, 6.742250508318086e-06, 1.6745395708335787e-06, 4.159023710803665e-07], [0.05, 0.25498680461114004, 0.05215119625415329, 0.012402290429793949, 0.0030792750052342005, 0.0007730229653668831, 0.00019460305243796714, 4.9024470221618055e-05, 1.2352455437097155e-05, 3.1125269291372943e-06, 7.842920931730465e-07], [0.06999999999999999, 0.32464974876257796, 0.07231494472231355, 0.01768866661457462, 0.004469723675984428, 0.0011393626572256358, 0.00029108847404831867, 7.441144962274092e-05, 1.90247487521813e-05, 4.8642352002604336e-06, 1.2436965053628329e-06], [0.09, 0.38273992925849015, 0.0920876391039664, 0.023165835927829136, 0.005959002875813745, 0.0015426921854442906, 0.00040005853353156627, 0.0001037912126231084, 2.693070574959306e-05, 6.98791943069978e-06, 1.8132238309966663e-06], [0.11, 0.4319188411942377, 0.11147419220613831, 0.028836819805588807, 0.007552926154132444, 0.00198625569087927, 0.0005229243161917953, 0.00013771189946502923, 3.62692160458131e-05, 9.552429664270125e-06, 2.51589142240714e-06], [0.13, 0.47408997325107044, 0.1304796380837603, 0.034704481616834836, 0.009257612451647211, 0.002473579981675562, 0.0006612567880854827, 0.00017679675673791667, 4.727098066974943e-05, 1.2639190598020382e-05, 3.3794425898214233e-06], [0.15000000000000002, 0.510650725608884, 0.14910911745492675, 0.04077151033105334, 0.011079498103245421, 0.00300849969572618, 0.0008168057474156411, 0.0002217548824091104, 6.0203791746771436e-05, 1.634456973552653e-05, 4.437341644435059e-06], [0.17, 0.542650121891528, 0.16736786389085395, 0.047040403769916625, 0.013025348698125503, 0.0035951847203394864, 0.0009915211595734504, 0.00027339360709986547, 7.537874031527423e-05, 2.0782715061279267e-05, 5.729988246697359e-06], [0.19, 0.5708910040840596, 0.1852611907606034, 0.053513451503600803, 0.015102270679690152, 0.004238170061185748, 0.0011875771941034794, 0.0003326327789962193, 9.315752690138636e-05, 2.6088961337990558e-05, 7.3062022353349975e-06], [0.21000000000000002, 0.5959982468825064, 0.202794478909404, 0.060192717460334756, 0.017317722548760746, 0.00494238836510139, 0.0014073993265649688, 0.00040052126677265874, 0.00011396108482240573, 3.242392653800315e-05, 9.225042842967103e-06], [0.23, 0.6184654812418521, 0.21997316504841471, 0.06708002232600861, 0.019679525512652674, 0.005713205313548979, 0.0016536949194257496, 0.0004782560507561918, 0.00013827976924534065, 3.997844777687647e-05, 1.1558042324431352e-05], [0.25, 0.6386878321252417, 0.23680273083298423, 0.07417692581896031, 0.02219587339946372, 0.006556458115081259, 0.0019294877546822862, 0.0005672043390537293, 0.00016668541760615573, 4.897954084749824e-05, 1.439195450286643e-05], [0.27, 0.6569853224828244, 0.25328869260588344, 0.08148470893331931, 0.024875341631487014, 0.007478497335541756, 0.002238157057892846, 0.0006689292246708465, 0.00019984565136891514, 5.969761088459275e-05, 1.7832144842371188e-05], [0.29000000000000004, 0.673619907272919, 0.2694365917815751, 0.08900435625240127, 0.027726895023906486, 0.008486232313311862, 0.0025834816299100203, 0.0007852194943941185, 0.00023854086812537717, 7.245519617402295e-05, 2.200678204653747e-05], [0.31, 0.6888080724469053, 0.2852519858473317, 0.0967365384415001, 0.03075989414485019, 0.009587180412868233, 0.002969689790104995, 0.0009181243135902103, 0.00028368447030079655, 8.763759569625411e-05, 2.7072034049898932e-05], [0.33, 0.7027302900447678, 0.3007404399569139, 0.10468159503689814, 0.033984099940501514, 0.010789520372213044, 0.003401515934722812, 0.0010699936469869599, 0.00033634699678667675, 0.00010570581759730596, 3.321852651481573e-05], [0.35000000000000003, 0.7155382081187842, 0.3159075190925285, 0.11283951765485202, 0.03740967629439494, 0.012102149997085615, 0.0038842646277531872, 0.0012435254386915636, 0.0003977849724302706, 0.0001272123955412273, 4.067939342788858e-05], [0.37, 0.727360184292402, 0.33075878077093207, 0.12120993375059774, 0.04104719015344512, 0.013534748445646694, 0.004423883271012405, 0.0014418207709595524, 0.00046947547480648554, 0.0001528207595201384, 4.97403422653791e-05], [0.39, 0.7383055916722793, 0.3452997682697651, 0.12979209106287903, 0.04490760881494969, 0.015097843329543805, 0.005027044546744987, 0.0016684484576235108, 0.0005531576474375159, 0.0001833290259854959, 6.075227739592375e-05], [0.41000000000000003, 0.7484682035359016, 0.35953600435052574, 0.13858484288400263, 0.049002293929187715, 0.01680288282846426, 0.005701239991718905, 0.0019275208132517692, 0.0006508826755883312, 0.00021969930073185583, 7.414718427087213e-05], [0.43, 0.7579288788169939, 0.37347298545498536, 0.14758663429881322, 0.053342991731855846, 0.018662312972458, 0.00645488624816967, 0.0022237826835679294, 0.000765074100337679, 0.00026309388220507353, 9.045818623006736e-05], [0.45, 0.7667577112931204, 0.3871161763523047, 0.15679548953809727, 0.05794181898017751, 0.020689660185818765, 0.007297445745478057, 0.002562716239271076, 0.000898600798629073, 0.00031492013332044334, 0.00011034496278918067], [0.47000000000000003, 0.7750157634005722, 0.40047100521461904, 0.16620900059264357, 0.0628112440270151, 0.022899619103755837, 0.008239563798126043, 0.002950664539807187, 0.001054865527070621, 0.00037688628390057676, 0.00013462608693905567], [0.49, 0.7827564754125486, 0.4135428590994216, 0.17582431723336528, 0.06796406242987232, 0.025308145563207245, 0.009293224360476339, 0.0033949774848838765, 0.0012379126486066813, 0.0004510710703909248, 0.0001643203322832682], [0.51, 0.7900268187497871, 0.42633707981767105, 0.18563813858041225, 0.07341336645770982, 0.02793255452569352, 0.010471926956248568, 0.00390418451265159, 0.001452559577050862, 0.0005400109645078959, 0.00020069966471509683], [0.53, 0.7968682460330774, 0.4388589601671661, 0.19564670635995762, 0.07917250782971055, 0.03079162250573868, 0.011790887597329757, 0.004488199302307413, 0.0017045576412327628, 0.0006468098558134575, 0.0002453575321968572], [0.55, 0.8033174784774164, 0.45111374051138875, 0.20584579998126967, 0.08525505299852983, 0.03390569384453736, 0.013267266817093476, 0.005158562828740815, 0.002000789561924028, 0.0007752775277369821, 0.00030029729098928273], [0.5700000000000001, 0.8094071622165869, 0.4631066056846778, 0.21623073355870007, 0.09167473027847502, 0.037296789875385615, 0.014920428258010156, 0.00592873243730215, 0.0023495126474819624, 0.0009301052299787599, 0.00036804728674839584], [0.59, 0.8151664183251784, 0.47484268220527115, 0.22679635499331172, 0.09844536811913665, 0.04098871966376782, 0.016772231556557642, 0.006814426204204242, 0.0027606592753508102, 0.0011170892791921372, 0.0004518114297410051], [0.61, 0.8206213060970884, 0.4863270357784449, 0.23753704721704258, 0.10558082384021891, 0.04500719055851028, 0.018847363536735308, 0.007834033775786446, 0.003246209403403585, 0.0013434171601997046, 0.0005556673331616795], [0.63, 0.8257952151320227, 0.49756466907266134, 0.24844673168857556, 0.11309490217696608, 0.0493799162476011, 0.021173711922037677, 0.009009107197494818, 0.0038206539677942404, 0.0016180353959165245, 0.0006848286131247813], [0.65, 0.8307091986746882, 0.5085605197523264, 0.25951887421454917, 0.12100126304118822, 0.05413671935896912, 0.02378278585427638, 0.010364948014726264, 0.004501573362436066, 0.0019521249902816858, 0.0008459943535234541], [0.67, 0.8353822582257765, 0.5193194587514406, 0.2707464931524828, 0.12931331798415666, 0.059309624868459726, 0.026710187394843314, 0.011931310215819587, 0.005310362140485372, 0.0023597192112868037, 0.0010478178726558167], [0.6900000000000001, 0.8398315875374739, 0.5298462887730996, 0.2821221700329782, 0.13804411495835384, 0.06493293966108168, 0.02999613778032365, 0.013743242445921577, 0.006273140129311651, 0.002858510848311959, 0.0013015400717670753], [0.7100000000000001, 0.8440727825984484, 0.5401457430004737, 0.2936380626185537, 0.14720621111892696, 0.07104331252630672, 0.03368606137275331, 0.01584209737665371, 0.007421901956610452, 0.0034709132490487655, 0.001621851737296603], [0.73, 0.8481200230135886, 0.5502224840055429, 0.30528592039510005, 0.1568115335861503, 0.07767976764713637, 0.037831228799212156, 0.018276741143902563, 0.008795972382103221, 0.004225463428895871, 0.0020280771744382474], [0.75, 0.85198622922378, 0.5600811028425084, 0.31705710246967095, 0.16687122831020113, 0.08488370326634306, 0.04248945846681752, 0.021105001237584454, 0.010443854873246507, 0.00515868925375802, 0.0025458130532591476], [0.77, 0.8556831992386696, 0.56972611831343, 0.3289425978254107, 0.17739549744126232, 0.09269884569317555, 0.047725872139301725, 0.024395396839681196, 0.012425586852744188, 0.006317610323174869, 0.0032092185073841106], [0.79, 0.8592217279307705, 0.579161976394243, 0.34093304786119416, 0.1883934259124522, 0.10117114717697274, 0.05361369514526779, 0.028229200760318342, 0.014815748498779395, 0.007763109787935119, 0.0040642466278324055], [0.81, 0.862611711431681, 0.5883930498099063, 0.35301877112033275, 0.1998727982899524, 0.11034861446920015, 0.060235084517442375, 0.03270288573088038, 0.01770731451330398, 0.00957451064337302, 0.005173251513484062], [0.8300000000000001, 0.8658622387567482, 0.5974236377480058, 0.365189790089831, 0.21183990733170857, 0.1202810531996541, 0.06768195827290971, 0.0379310080176956, 0.021216591271973173, 0.01185582744778291, 0.006621627820854752], [0.85, 0.8689816724445925, 0.6062579657006925, 0.3774358599295123, 0.22429935611873483, 0.13101971161977816, 0.07605678534756088, 0.04404957504884225, 0.025489545612351616, 0.014744360187155886, 0.008527487865105442], [0.87, 0.8719777197179408, 0.6149001854253731, 0.3897464989692256, 0.23725385607425267, 0.14261680597501072, 0.08547327750500643, 0.051219926083347, 0.030709903973071932, 0.018422574187885704, 0.011055930056695529], [0.89, 0.8748574954406478, 0.6233543750150878, 0.40211102079262523, 0.2507040236555988, 0.1551249089706182, 0.09605690093116133, 0.059633118241102116, 0.03710947360843843, 0.023134596812672256, 0.01444032287192198], [0.91, 0.8776275779535141, 0.6316245390700103, 0.4145185677080473, 0.26464817897886356, 0.1685961827624801, 0.10794509539142386, 0.06951474287699677, 0.04498119112473731, 0.029209186176976456, 0.019014411524148553], [0.93, 0.8802940587112572, 0.6397146089619798, 0.42695814539105037, 0.2790821501001028, 0.1830814389678617, 0.12128705232321715, 0.081129982410075, 0.05469539416680809, 0.03709169848222272, 0.025261236842803785], [0.9500000000000001, 0.8828625865089388, 0.6476284431844384, 0.4394186584695643, 0.2939990871101362, 0.19862901073978972, 0.13624286039932584, 0.09478853168219174, 0.06671965254498287, 0.04738833757926249, 0.03388822002658438], [0.97, 0.8853384069736263, 0.6553698277805843, 0.45188894681150976, 0.30938929057998404, 0.21528342641147066, 0.15298177967920856, 0.11084871981207456, 0.08164202019123602, 0.06092655195157571, 0.04594265558263385], [0.99, 0.887726397902296, 0.662942476842977, 0.46435782226642786, 0.3252400591962998, 0.23308388103379943, 0.17167935752895855, 0.1297197420685918, 0.10019648250115669, 0.07883508554178247, 0.0629879399835792]]}, \"id\": \"el9520170357536\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAs8AAAIyCAYAAAA0fidwAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
       "text": [
        "<matplotlib.figure.Figure at 0xa277320>"
       ]
      }
     ],
     "prompt_number": 57
    },
    {
     "cell_type": "heading",
     "level": 4,
     "metadata": {},
     "source": [
      "Compare Dependence on Barrier Width"
     ]
    },
    {
     "cell_type": "code",
     "collapsed": false,
     "input": [
      "Es = [.51, .71]\n",
      "colors = ['blue', 'green']\n",
      "as_ = np.linspace(.01, 5)\n",
      "as_coarse = np.linspace(0.5, 5, 10)\n",
      "n = 1e3\n",
      "\n",
      "plt.title('Transmission Coefficient as a Function of the Barrier Width for Energies E = %s' % ', '.join(map(str, Es)))\n",
      "plt.xlabel('$a$')\n",
      "plt.ylabel('$T$')\n",
      "plt.ylim(0, 1)\n",
      "for E, color in zip(Es, colors):\n",
      "    plt.plot(as_, [transmission_exact(a=a, E=E) for a in as_], '--', color=color, label='E = %s (rect)' % E)\n",
      "    plt.plot(as_coarse, [scatter(V=parabolic_potential(a=a), E=E, x_min=0, x_max=a, n=n)[0] for a in as_coarse], 'o-', label='E = %s (parabolic)' % E)\n",
      "plt.legend()\n",
      "plt.show()"
     ],
     "language": "python",
     "metadata": {},
     "outputs": [
      {
       "html": [
        "\n",
        "\n",
        "<style>\n",
        "\n",
        "</style>\n",
        "\n",
        "<div id=\"fig_el95201703455285723918132\"></div>\n",
        "<script>\n",
        "function mpld3_load_lib(url, callback){\n",
        "  var s = document.createElement('script');\n",
        "  s.src = url;\n",
        "  s.async = true;\n",
        "  s.onreadystatechange = s.onload = callback;\n",
        "  s.onerror = function(){console.warn(\"failed to load library \" + url);};\n",
        "  document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
        "}\n",
        "\n",
        "if(typeof(mpld3) !== \"undefined\" && mpld3._mpld3IsLoaded){\n",
        "   // already loaded: just create the figure\n",
        "   !function(mpld3){\n",
        "       \n",
        "       mpld3.draw_figure(\"fig_el95201703455285723918132\", {\"axes\": [{\"xlim\": [0.0, 5.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$a$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520176030496\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520170463696\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Transmission Coefficient as a Function of the Barrier Width for Energies E = 0.51, 0.71\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520169550848\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"E = 0.51 (rect)\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.80441448252688197, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el9520168823496\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"E = 0.51 (parabolic)\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.80441448252688197, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el9520170493096\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"E = 0.71 (rect)\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.80441448252688197, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el9520170493040\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"E = 0.71 (parabolic)\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.80441448252688197, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el9520169514600\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 5.0], \"ylim\": [0.0, 1.0], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data04\", \"id\": \"el9520168821592\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 6, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520194670208\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170384016\"}, {\"color\": \"#008000\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520175912720\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520168824504\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168821480\"}, {\"color\": \"#0000FF\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170494104\"}, {\"color\": \"#008000\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169514152\"}, {\"color\": \"#007F00\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169514992\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170384016pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168824504pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170495224pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520169515552pts\"}], \"id\": \"el9520170346592\", \"ydomain\": [0.0, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data04\": [[0.7470668122759858, 0.8399044205495819], [0.9910394265232977, 0.8399044205495819], [0.9910394265232977, 0.9880525686977301], [0.7470668122759858, 0.9880525686977301], [0.7470668122759858, 0.8399044205495819]], \"data02\": [[0.5, 0.8987614271219073, 0.926591439449374], [1.0, 0.6671301130768066, 0.7513170568612382], [1.5, 0.4303169071834561, 0.5557029486050791], [2.0, 0.2540873601771997, 0.3898634742471966], [2.5, 0.14275010143578493, 0.266388771327929], [3.0, 0.07818373800876581, 0.18003406041083048], [3.5, 0.04233243623825031, 0.12138026333020861], [4.0, 0.02283376252849708, 0.08202732197464667], [4.5, 0.012319783160949118, 0.05571183103586635], [5.0, 0.006662997648828588, 0.03808663307941903]], \"data03\": [[0.7596116151433694, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086], [0.7847012208781364, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086]], \"data01\": [[0.01, 0.9999019671930309, 0.9999295810624518], [0.11183673469387755, 0.9878373577216182, 0.991247889238243], [0.2136734693877551, 0.9565417174519889, 0.9685819431726385], [0.31551020408163266, 0.9084219740095258, 0.9333034145887186], [0.4173469387755102, 0.8469529088940115, 0.8874315463996753], [0.5191836734693878, 0.7761738312927958, 0.8333846697343533], [0.6210204081632653, 0.7001791540343375, 0.7737180189690599], [0.7228571428571429, 0.6226993785964363, 0.7108928879793392], [0.8246938775510204, 0.5468256840439275, 0.6471054419119363], [0.926530612244898, 0.4748856364920667, 0.584184481857325], [1.0283673469387755, 0.40844445561240594, 0.523552305758006], [1.130204081632653, 0.34839095859326097, 0.46623417930543526], [1.2320408163265306, 0.29506700341375375, 0.41289943415894004], [1.3338775510204082, 0.24840775743619847, 0.3639188785083255], [1.4357142857142857, 0.20807148460410457, 0.31942685678945165], [1.5375510204081633, 0.17354788538451435, 0.27938029286776755], [1.6393877551020408, 0.14424162702300958, 0.2436104768257354], [1.7412244897959184, 0.1195323761733551, 0.21186587412910682], [1.843061224489796, 0.09881495548110367, 0.18384586501457334], [1.9448979591836735, 0.08152395771831311, 0.15922623762687685], [2.046734693877551, 0.06714694506872115, 0.13767767198469905], [2.1485714285714286, 0.05522972809884429, 0.11887854859128938], [2.250408163265306, 0.04537646459218668, 0.1025233345577313], [2.3522448979591832, 0.037246606868128695, 0.08832763530869925], [2.454081632653061, 0.03055012843695713, 0.0760308089899198], [2.555918367346939, 0.025041993942438057, 0.06539685568389529], [2.657755102040816, 0.020516490357319787, 0.05621412992422594], [2.7595918367346934, 0.016801791646332286, 0.04829428824574126], [2.861428571428571, 0.013754961040023963, 0.04147077357946588], [2.963265306122449, 0.011257484385090865, 0.03559705247986384], [3.0651020408163263, 0.009211358208652423, 0.03054475572240465], [3.1669387755102036, 0.007535714460856406, 0.026201823890690604], [3.2687755102040814, 0.006163941050535805, 0.022470723680831025], [3.370612244897959, 0.005041246625452826, 0.019266774797818947], [3.4724489795918365, 0.0041226149804405995, 0.016516609061119524], [3.574285714285714, 0.0033710959063656333, 0.014156770735558143], [3.6761224489795916, 0.002756383183567756, 0.012132458653721704], [3.7779591836734694, 0.0022536354731664287, 0.010396405249148132], [3.8797959183673467, 0.0018425012643469882, 0.008907884312037548], [3.981632653061224, 0.0015063143222904345, 0.007631837469821256], [4.083469387755102, 0.001231430991586194, 0.006538108613025579], [4.18530612244898, 0.0010066851217307752, 0.0056007753909786025], [4.287142857142857, 0.0008229402561077552, 0.004797567247225109], [4.388979591836734, 0.0006727220739857387, 0.0041093600778607815], [4.490816326530612, 0.0005499169334729242, 0.0035197383567747375], [4.59265306122449, 0.0004495247815156903, 0.0030146163976328922], [4.694489795918367, 0.0003674567284367802, 0.0025819112585144413], [4.7963265306122445, 0.0003003692817320262, 0.0022112606062231364], [4.898163265306122, 0.000245528645778834, 0.0018937796220438354], [5.0, 0.00020069966471509683, 0.0016218517372966017]]}, \"id\": \"el9520170345528\"});\n",
        "   }(mpld3);\n",
        "}else if(typeof define === \"function\" && define.amd){\n",
        "   // require.js is available: use it to load d3/mpld3\n",
        "   require.config({paths: {d3: \"https://mpld3.github.io/js/d3.v3.min\"}});\n",
        "   require([\"d3\"], function(d3){\n",
        "      window.d3 = d3;\n",
        "      mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "         \n",
        "         mpld3.draw_figure(\"fig_el95201703455285723918132\", {\"axes\": [{\"xlim\": [0.0, 5.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$a$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520176030496\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520170463696\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Transmission Coefficient as a Function of the Barrier Width for Energies E = 0.51, 0.71\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520169550848\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"E = 0.51 (rect)\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.80441448252688197, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el9520168823496\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"E = 0.51 (parabolic)\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.80441448252688197, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el9520170493096\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"E = 0.71 (rect)\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.80441448252688197, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el9520170493040\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"E = 0.71 (parabolic)\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.80441448252688197, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el9520169514600\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 5.0], \"ylim\": [0.0, 1.0], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data04\", \"id\": \"el9520168821592\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 6, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520194670208\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170384016\"}, {\"color\": \"#008000\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520175912720\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520168824504\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168821480\"}, {\"color\": \"#0000FF\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170494104\"}, {\"color\": \"#008000\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169514152\"}, {\"color\": \"#007F00\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169514992\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170384016pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168824504pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170495224pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520169515552pts\"}], \"id\": \"el9520170346592\", \"ydomain\": [0.0, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data04\": [[0.7470668122759858, 0.8399044205495819], [0.9910394265232977, 0.8399044205495819], [0.9910394265232977, 0.9880525686977301], [0.7470668122759858, 0.9880525686977301], [0.7470668122759858, 0.8399044205495819]], \"data02\": [[0.5, 0.8987614271219073, 0.926591439449374], [1.0, 0.6671301130768066, 0.7513170568612382], [1.5, 0.4303169071834561, 0.5557029486050791], [2.0, 0.2540873601771997, 0.3898634742471966], [2.5, 0.14275010143578493, 0.266388771327929], [3.0, 0.07818373800876581, 0.18003406041083048], [3.5, 0.04233243623825031, 0.12138026333020861], [4.0, 0.02283376252849708, 0.08202732197464667], [4.5, 0.012319783160949118, 0.05571183103586635], [5.0, 0.006662997648828588, 0.03808663307941903]], \"data03\": [[0.7596116151433694, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086], [0.7847012208781364, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086]], \"data01\": [[0.01, 0.9999019671930309, 0.9999295810624518], [0.11183673469387755, 0.9878373577216182, 0.991247889238243], [0.2136734693877551, 0.9565417174519889, 0.9685819431726385], [0.31551020408163266, 0.9084219740095258, 0.9333034145887186], [0.4173469387755102, 0.8469529088940115, 0.8874315463996753], [0.5191836734693878, 0.7761738312927958, 0.8333846697343533], [0.6210204081632653, 0.7001791540343375, 0.7737180189690599], [0.7228571428571429, 0.6226993785964363, 0.7108928879793392], [0.8246938775510204, 0.5468256840439275, 0.6471054419119363], [0.926530612244898, 0.4748856364920667, 0.584184481857325], [1.0283673469387755, 0.40844445561240594, 0.523552305758006], [1.130204081632653, 0.34839095859326097, 0.46623417930543526], [1.2320408163265306, 0.29506700341375375, 0.41289943415894004], [1.3338775510204082, 0.24840775743619847, 0.3639188785083255], [1.4357142857142857, 0.20807148460410457, 0.31942685678945165], [1.5375510204081633, 0.17354788538451435, 0.27938029286776755], [1.6393877551020408, 0.14424162702300958, 0.2436104768257354], [1.7412244897959184, 0.1195323761733551, 0.21186587412910682], [1.843061224489796, 0.09881495548110367, 0.18384586501457334], [1.9448979591836735, 0.08152395771831311, 0.15922623762687685], [2.046734693877551, 0.06714694506872115, 0.13767767198469905], [2.1485714285714286, 0.05522972809884429, 0.11887854859128938], [2.250408163265306, 0.04537646459218668, 0.1025233345577313], [2.3522448979591832, 0.037246606868128695, 0.08832763530869925], [2.454081632653061, 0.03055012843695713, 0.0760308089899198], [2.555918367346939, 0.025041993942438057, 0.06539685568389529], [2.657755102040816, 0.020516490357319787, 0.05621412992422594], [2.7595918367346934, 0.016801791646332286, 0.04829428824574126], [2.861428571428571, 0.013754961040023963, 0.04147077357946588], [2.963265306122449, 0.011257484385090865, 0.03559705247986384], [3.0651020408163263, 0.009211358208652423, 0.03054475572240465], [3.1669387755102036, 0.007535714460856406, 0.026201823890690604], [3.2687755102040814, 0.006163941050535805, 0.022470723680831025], [3.370612244897959, 0.005041246625452826, 0.019266774797818947], [3.4724489795918365, 0.0041226149804405995, 0.016516609061119524], [3.574285714285714, 0.0033710959063656333, 0.014156770735558143], [3.6761224489795916, 0.002756383183567756, 0.012132458653721704], [3.7779591836734694, 0.0022536354731664287, 0.010396405249148132], [3.8797959183673467, 0.0018425012643469882, 0.008907884312037548], [3.981632653061224, 0.0015063143222904345, 0.007631837469821256], [4.083469387755102, 0.001231430991586194, 0.006538108613025579], [4.18530612244898, 0.0010066851217307752, 0.0056007753909786025], [4.287142857142857, 0.0008229402561077552, 0.004797567247225109], [4.388979591836734, 0.0006727220739857387, 0.0041093600778607815], [4.490816326530612, 0.0005499169334729242, 0.0035197383567747375], [4.59265306122449, 0.0004495247815156903, 0.0030146163976328922], [4.694489795918367, 0.0003674567284367802, 0.0025819112585144413], [4.7963265306122445, 0.0003003692817320262, 0.0022112606062231364], [4.898163265306122, 0.000245528645778834, 0.0018937796220438354], [5.0, 0.00020069966471509683, 0.0016218517372966017]]}, \"id\": \"el9520170345528\"});\n",
        "      });\n",
        "    });\n",
        "}else{\n",
        "    // require.js not available: dynamically load d3 & mpld3\n",
        "    mpld3_load_lib(\"https://mpld3.github.io/js/d3.v3.min.js\", function(){\n",
        "         mpld3_load_lib(\"https://mpld3.github.io/js/mpld3.v0.2.js\", function(){\n",
        "                 \n",
        "                 mpld3.draw_figure(\"fig_el95201703455285723918132\", {\"axes\": [{\"xlim\": [0.0, 5.0], \"yscale\": \"linear\", \"axesbg\": \"#FFFFFF\", \"texts\": [{\"v_baseline\": \"hanging\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$a$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [0.5, -0.035842293906810041], \"rotation\": -0.0, \"id\": \"el9520176030496\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"$T$\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 10.0, \"position\": [-0.035576276881720409, 0.5], \"rotation\": -90.0, \"id\": \"el9520170463696\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"middle\", \"color\": \"#000000\", \"text\": \"Transmission Coefficient as a Function of the Barrier Width for Energies E = 0.51, 0.71\", \"coordinates\": \"axes\", \"zorder\": 3, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.5, 1.0099561927518916], \"rotation\": -0.0, \"id\": \"el9520169550848\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"E = 0.51 (rect)\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.80441448252688197, 0.96057347670250925], \"rotation\": -0.0, \"id\": \"el9520168823496\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"E = 0.51 (parabolic)\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.80441448252688197, 0.92532855436081263], \"rotation\": -0.0, \"id\": \"el9520170493096\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"E = 0.71 (rect)\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.80441448252688197, 0.890083632019116], \"rotation\": -0.0, \"id\": \"el9520170493040\"}, {\"v_baseline\": \"auto\", \"h_anchor\": \"start\", \"color\": \"#000000\", \"text\": \"E = 0.71 (parabolic)\", \"coordinates\": \"axes\", \"zorder\": 1000003.0, \"alpha\": 1, \"fontsize\": 12.0, \"position\": [0.80441448252688197, 0.85483870967741959], \"rotation\": -0.0, \"id\": \"el9520169514600\"}], \"zoomable\": true, \"images\": [], \"xdomain\": [0.0, 5.0], \"ylim\": [0.0, 1.0], \"paths\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#FFFFFF\", \"edgewidth\": 1.0, \"pathcodes\": [\"M\", \"L\", \"L\", \"L\", \"L\", \"Z\"], \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000001.0, \"alpha\": 1, \"xindex\": 0, \"data\": \"data04\", \"id\": \"el9520168821592\"}], \"sharey\": [], \"sharex\": [], \"axesbgalpha\": null, \"axes\": [{\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"bottom\", \"nticks\": 6, \"tickvalues\": null}, {\"scale\": \"linear\", \"tickformat\": null, \"grid\": {\"gridOn\": false}, \"fontsize\": 10.0, \"position\": \"left\", \"nticks\": 6, \"tickvalues\": null}], \"lines\": [{\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520194670208\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520170384016\"}, {\"color\": \"#008000\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"6,6\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data01\", \"id\": \"el9520175912720\"}, {\"color\": \"#007F00\", \"yindex\": 2, \"coordinates\": \"data\", \"dasharray\": \"10,0\", \"zorder\": 2, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data02\", \"id\": \"el9520168824504\"}, {\"color\": \"#0000FF\", \"yindex\": 1, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520168821480\"}, {\"color\": \"#0000FF\", \"yindex\": 2, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520170494104\"}, {\"color\": \"#008000\", \"yindex\": 3, \"coordinates\": \"axes\", \"dasharray\": \"6,6\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169514152\"}, {\"color\": \"#007F00\", \"yindex\": 4, \"coordinates\": \"axes\", \"dasharray\": \"10,0\", \"zorder\": 1000002.0, \"alpha\": 1, \"xindex\": 0, \"linewidth\": 1.0, \"data\": \"data03\", \"id\": \"el9520169514992\"}], \"markers\": [{\"edgecolor\": \"#000000\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 1, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520170384016pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"data\", \"zorder\": 2, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data02\", \"id\": \"el9520168824504pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#0000FF\", \"edgewidth\": 0.5, \"yindex\": 2, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520170495224pts\"}, {\"edgecolor\": \"#000000\", \"facecolor\": \"#007F00\", \"edgewidth\": 0.5, \"yindex\": 4, \"coordinates\": \"axes\", \"zorder\": 1000002.0, \"markerpath\": [[[0.0, 3.0], [0.7956093000000001, 3.0], [1.5587396123545605, 2.683901074764725], [2.121320343559643, 2.121320343559643], [2.683901074764725, 1.5587396123545605], [3.0, 0.7956093000000001], [3.0, 0.0], [3.0, -0.7956093000000001], [2.683901074764725, -1.5587396123545605], [2.121320343559643, -2.121320343559643], [1.5587396123545605, -2.683901074764725], [0.7956093000000001, -3.0], [0.0, -3.0], [-0.7956093000000001, -3.0], [-1.5587396123545605, -2.683901074764725], [-2.121320343559643, -2.121320343559643], [-2.683901074764725, -1.5587396123545605], [-3.0, -0.7956093000000001], [-3.0, 0.0], [-3.0, 0.7956093000000001], [-2.683901074764725, 1.5587396123545605], [-2.121320343559643, 2.121320343559643], [-1.5587396123545605, 2.683901074764725], [-0.7956093000000001, 3.0], [0.0, 3.0]], [\"M\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"C\", \"Z\"]], \"alpha\": 1, \"xindex\": 0, \"data\": \"data03\", \"id\": \"el9520169515552pts\"}], \"id\": \"el9520170346592\", \"ydomain\": [0.0, 1.0], \"collections\": [], \"xscale\": \"linear\", \"bbox\": [0.125, 0.125, 0.77500000000000002, 0.77500000000000002]}], \"height\": 720.0, \"width\": 960.0, \"plugins\": [{\"type\": \"reset\"}, {\"enabled\": false, \"button\": true, \"type\": \"zoom\"}, {\"enabled\": false, \"button\": true, \"type\": \"boxzoom\"}], \"data\": {\"data04\": [[0.7470668122759858, 0.8399044205495819], [0.9910394265232977, 0.8399044205495819], [0.9910394265232977, 0.9880525686977301], [0.7470668122759858, 0.9880525686977301], [0.7470668122759858, 0.8399044205495819]], \"data02\": [[0.5, 0.8987614271219073, 0.926591439449374], [1.0, 0.6671301130768066, 0.7513170568612382], [1.5, 0.4303169071834561, 0.5557029486050791], [2.0, 0.2540873601771997, 0.3898634742471966], [2.5, 0.14275010143578493, 0.266388771327929], [3.0, 0.07818373800876581, 0.18003406041083048], [3.5, 0.04233243623825031, 0.12138026333020861], [4.0, 0.02283376252849708, 0.08202732197464667], [4.5, 0.012319783160949118, 0.05571183103586635], [5.0, 0.006662997648828588, 0.03808663307941903]], \"data03\": [[0.7596116151433694, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086], [0.7847012208781364, 0.9689366786140983, 0.9336917562724016, 0.898446833930705, 0.8632019115890086]], \"data01\": [[0.01, 0.9999019671930309, 0.9999295810624518], [0.11183673469387755, 0.9878373577216182, 0.991247889238243], [0.2136734693877551, 0.9565417174519889, 0.9685819431726385], [0.31551020408163266, 0.9084219740095258, 0.9333034145887186], [0.4173469387755102, 0.8469529088940115, 0.8874315463996753], [0.5191836734693878, 0.7761738312927958, 0.8333846697343533], [0.6210204081632653, 0.7001791540343375, 0.7737180189690599], [0.7228571428571429, 0.6226993785964363, 0.7108928879793392], [0.8246938775510204, 0.5468256840439275, 0.6471054419119363], [0.926530612244898, 0.4748856364920667, 0.584184481857325], [1.0283673469387755, 0.40844445561240594, 0.523552305758006], [1.130204081632653, 0.34839095859326097, 0.46623417930543526], [1.2320408163265306, 0.29506700341375375, 0.41289943415894004], [1.3338775510204082, 0.24840775743619847, 0.3639188785083255], [1.4357142857142857, 0.20807148460410457, 0.31942685678945165], [1.5375510204081633, 0.17354788538451435, 0.27938029286776755], [1.6393877551020408, 0.14424162702300958, 0.2436104768257354], [1.7412244897959184, 0.1195323761733551, 0.21186587412910682], [1.843061224489796, 0.09881495548110367, 0.18384586501457334], [1.9448979591836735, 0.08152395771831311, 0.15922623762687685], [2.046734693877551, 0.06714694506872115, 0.13767767198469905], [2.1485714285714286, 0.05522972809884429, 0.11887854859128938], [2.250408163265306, 0.04537646459218668, 0.1025233345577313], [2.3522448979591832, 0.037246606868128695, 0.08832763530869925], [2.454081632653061, 0.03055012843695713, 0.0760308089899198], [2.555918367346939, 0.025041993942438057, 0.06539685568389529], [2.657755102040816, 0.020516490357319787, 0.05621412992422594], [2.7595918367346934, 0.016801791646332286, 0.04829428824574126], [2.861428571428571, 0.013754961040023963, 0.04147077357946588], [2.963265306122449, 0.011257484385090865, 0.03559705247986384], [3.0651020408163263, 0.009211358208652423, 0.03054475572240465], [3.1669387755102036, 0.007535714460856406, 0.026201823890690604], [3.2687755102040814, 0.006163941050535805, 0.022470723680831025], [3.370612244897959, 0.005041246625452826, 0.019266774797818947], [3.4724489795918365, 0.0041226149804405995, 0.016516609061119524], [3.574285714285714, 0.0033710959063656333, 0.014156770735558143], [3.6761224489795916, 0.002756383183567756, 0.012132458653721704], [3.7779591836734694, 0.0022536354731664287, 0.010396405249148132], [3.8797959183673467, 0.0018425012643469882, 0.008907884312037548], [3.981632653061224, 0.0015063143222904345, 0.007631837469821256], [4.083469387755102, 0.001231430991586194, 0.006538108613025579], [4.18530612244898, 0.0010066851217307752, 0.0056007753909786025], [4.287142857142857, 0.0008229402561077552, 0.004797567247225109], [4.388979591836734, 0.0006727220739857387, 0.0041093600778607815], [4.490816326530612, 0.0005499169334729242, 0.0035197383567747375], [4.59265306122449, 0.0004495247815156903, 0.0030146163976328922], [4.694489795918367, 0.0003674567284367802, 0.0025819112585144413], [4.7963265306122445, 0.0003003692817320262, 0.0022112606062231364], [4.898163265306122, 0.000245528645778834, 0.0018937796220438354], [5.0, 0.00020069966471509683, 0.0016218517372966017]]}, \"id\": \"el9520170345528\"});\n",
        "            })\n",
        "         });\n",
        "}\n",
        "</script>"
       ],
       "metadata": {},
       "output_type": "display_data",
       "png": "iVBORw0KGgoAAAANSUhEUgAAAtIAAAIwCAYAAACr5owjAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\ngARpIYQQQgghbsD/A1eY3VHT7sMIAAAAAElFTkSuQmCC\n",
       "text": [
        "<matplotlib.figure.Figure at 0xa274438>"
       ]
      }
     ],
     "prompt_number": 58
    }
   ],
   "metadata": {}
  }
 ]
}